<?php

/**
 *
 * @link              https://profiles.wordpress.org/gutotheme/
 * @since             1.0.0
 * @package           Guto_Toolkit
 *
 * @wordpress-plugin
 * Plugin Name:       Guto Toolkit
 * Plugin URI:        https://wordpress.org/plugins/guto-toolkit/
 * Description:       Guto Toolkit is an Elementor addon WordPress plugin that allows you to create 65+ unique layouts on your site.
 * Version:           2.1.1
 * Requires at least: 5.3
 * Tested up to: 6.0.2
 * Requires PHP: 7.4
 * Author:            GutoTheme
 * Author URI:        https://profiles.wordpress.org/gutotheme/
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       guto-toolkit
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Plugin directory path
 */
define('GUTO_ACC_PATH', plugin_dir_path(__FILE__));

define('GUTO_ASSET_PATH', wp_upload_dir()['basedir'] . '/guto-toolkit-data');
define('GUTO_ASSET_URL', wp_upload_dir()['baseurl'] . '/guto-toolkit-data');
define('GUTO_PLUGIN_PATH', trailingslashit(plugin_dir_path(__FILE__)));
define('GUTO_PLUGIN_URL', trailingslashit(plugins_url('/', __FILE__)));
define('GUTO_PLUGIN_VERSION', '2.0.6');

/**
 * Including plugin config.
 */
$GLOBALS['guto_config'] = require_once GUTO_PLUGIN_PATH . 'config.php';

/**
 * Plugin image folder path
 */
define('GUTO_TOOLKIT_IMAGES', GUTO_ACC_PATH . '/public/assets/img');

/**
 * Plugin image folder path
 */
define('GUTO_TOOLKIT_SCRIPTS', GUTO_ACC_PATH . '/public/js');

/**
 * Currently plugin version.
 * Start at version 2.0.6 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'GUTO_TOOLKIT_VERSION', '2.0.6' );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-guto-toolkit-activator.php
 */
function activate_guto_toolkit() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-guto-toolkit-activator.php';
	Guto_Toolkit_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-guto-toolkit-deactivator.php
 */
function deactivate_guto_toolkit() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-guto-toolkit-deactivator.php';
	Guto_Toolkit_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_guto_toolkit' );
register_deactivation_hook( __FILE__, 'deactivate_guto_toolkit' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-guto-toolkit.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since   1.0.0
 */
function run_guto_toolkit() {

	$plugin = new Guto_Toolkit();
	$plugin->run();

}
run_guto_toolkit();
