<?php
/**
 * CS Amenities Widget
 */
namespace Elementor;
class Guto_CS_Amenities extends Widget_Base{
    public function get_name(){
        return "Guto_CS_Amenities";
    }
    public function get_title(){
        return "Amenities";
    }
    public function get_icon(){
        return 'eicon-tools';
    }
    public function get_categories(){
        return [ 'guto-coworking-space' ];
    }
    protected function _register_controls(){

        $this->start_controls_section(
            'Guto_Amenities',
            [
                'label' => esc_html__( 'Guto Amenities', 'guto-toolkit' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

            $this->add_control(
                'columns',
                [
                    'label' => esc_html__( 'Choose Columns', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        '1'   => esc_html__( '1', 'guto-toolkit' ),
                        '2'   => esc_html__( '2', 'guto-toolkit' ),
                        '3'   => esc_html__( '3', 'guto-toolkit' ),
                        '4'   => esc_html__( '4', 'guto-toolkit' ),
                    ],
                    'default' => '3',
                ]
            );

            $repeater = new Repeater();
            $repeater->add_control(
                'feature_img',
                [
                    'label' => esc_html__( 'Image', 'guto-toolkit' ),
                    'type' => Controls_Manager::MEDIA,
                    'label_block' => true,
                ]
            );
            $repeater->add_control(
                'title',
                [
                    'label' => esc_html__( 'Title', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default'       => esc_html__('Conference Rooms', 'guto-toolkit'),
                    'label_block'   => true,
                ]
            );
            $repeater->add_control(
                'content',
                [
                    'label' => esc_html__( 'Content', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXTAREA,
                    'label_block'   => true,
                ]
            );
            $this->add_control(
                'card_items',
                [
                    'label' => esc_html__( 'Add Card Content', 'guto-toolkit' ),
                    'type' => Controls_Manager::REPEATER,
                    'fields' => $repeater->get_controls(),
                ]
            );
        $this-> end_controls_section();

        // Start Style content controls
        $this-> start_controls_section(
            'style',
            [
                'label' => esc_html__('Style', 'guto-toolkit'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
            $this->add_control(
                'post_title_color',
                [
                    'label' => esc_html__( 'Title Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .single-cws-amenities-box h3' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'posttitle_typography',
                    'label' => esc_html__( 'Title Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .single-cws-amenities-box h3',
                ]
            );

            $this->add_control(
                'content_color',
                [
                    'label' => esc_html__( 'Content Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .single-cws-amenities-box p' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'content_typography',
                    'label' => esc_html__( 'Content Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .single-cws-amenities-box p',
                ]
            );
        $this-> end_controls_section();
    }
    protected function render()
    {
        $settings = $this->get_settings_for_display();

        // Card Columns
        $columns = $settings['columns'];
        if ($columns == '1') {
            $column = 'col-lg-12 col-md-6';
        } elseif ($columns == '2') {
            $column = 'col-lg-6 col-md-6';
        } elseif ($columns == '4') {
            $column = 'col-lg-3 col-sm-6 col-md-6';
        } else {
            $column = 'col-lg-4 col-sm-6 col-md-6';
        }
        ?>
        <div class="container">
            <div class="row justify-content-center">
                <?php foreach( $settings['card_items'] as $item ) : ?>
                    <div class="<?php echo esc_attr( $column ); ?>">
                        <div class="single-cws-amenities-box">
                            <?php if( $item['feature_img']['url'] != '' ): ?>
                                <div class="icon">
                                    <img src="<?php echo esc_url( $item['feature_img']['url'] ); ?>" alt="<?php echo esc_attr('Image', 'guto-toolkit' ); ?>">
                                </div>
                            <?php endif; ?>

                            <h3><?php echo esc_html( $item['title'] ); ?></h3>
                            <?php echo wp_kses_post( $item['content'] ); ?>
                        </div>
                    </div>
                <?php endforeach; ?>
            </div>
        </div>

        <?php
    }


}

Plugin::instance()->widgets_manager->register( new Guto_CS_Amenities );
