<?php
/**
 * CS Banner Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_CS_Banner extends Widget_Base {

	public function get_name() {
        return 'Guto_CS_Banner';
    }

	public function get_title() {
        return esc_html__( 'CS Banner', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-banner';
    }

	public function get_categories() {
        return [ 'guto-coworking-space' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'Guto_DM_Banner_Area',
			[
				'label' => esc_html__( 'Banner Controls', 'guto-toolkit' ),
				'tab' 	=> Controls_Manager::TAB_CONTENT,
			]
		);
            $this->add_control(
                'bg_image',
                [
                    'label'		=> esc_html__('Banner Image', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: MEDIA,
                ]
            );
			$this->add_control(
				'title',
				[
					'label' 	=> esc_html__( 'Title', 'guto-toolkit' ),
					'type' 		=> Controls_Manager::TEXTAREA,
					'default' 	=> esc_html__('We Are Creative Digital Marketing Expert!', 'guto-toolkit'),
				]
			);

			$this->add_control(
                'title_tag',
                [
                    'label' 	=> esc_html__( 'Title Tag', 'guto-toolkit' ),
                    'type' 		=> Controls_Manager::SELECT,
                    'options' 	=> [
                        'h1'         => esc_html__( 'h1', 'guto-toolkit' ),
                        'h2'         => esc_html__( 'h2', 'guto-toolkit' ),
                        'h3'         => esc_html__( 'h3', 'guto-toolkit' ),
                        'h4'         => esc_html__( 'h4', 'guto-toolkit' ),
                        'h5'         => esc_html__( 'h5', 'guto-toolkit' ),
                        'h6'         => esc_html__( 'h6', 'guto-toolkit' ),
                    ],
                    'default' => 'h1',
                ]
            );

			$this->add_control(
				'content',
				[
					'label' 	=> esc_html__( 'Content', 'guto-toolkit' ),
					'type' 		=> Controls_Manager::TEXTAREA,
					'default' 	=> esc_html__('There are many variations of passages of Lorem Ipsum available, but the majority have suffered alteration in some form, by injected humour, or randomised words which does not look even slightly believable.', 'guto-toolkit'),
				]
            );

            // Button One
            $this->add_control(
				'button_icon',
				[
					'label' => esc_html__( 'Button One Icon', 'guto-toolkit' ),
                    'type' => Controls_Manager::ICON,
                    'label_block' => true,
                    'options' => guto_toolkit_icons(),
				]
            );

			$this->add_control(
				'button_text1',
				[
					'label' 	=> esc_html__( 'Button Text One', 'guto-toolkit' ),
					'type' 		=> Controls_Manager::TEXT,
					'default' 	=> esc_html__('Book A Room', 'guto-toolkit'),
				]
            );

            $this->add_control(
                'link_type',
                [
                    'label' 		=> esc_html__( 'Button Link Type', 'guto-toolkit' ),
                    'type' 			=> Controls_Manager::SELECT,
                    'label_block' 	=> true,
                    'options' => [
                        '1'  	=> esc_html__( 'Link To Page', 'guto-toolkit' ),
                        '2' 	=> esc_html__( 'External Link', 'guto-toolkit' ),
                    ],
                    'default' => '2'
                ]
            );

            $this->add_control(
                'link_to_page',
                [
                    'label' 		=> esc_html__( 'Button Link Page', 'guto-toolkit' ),
                    'type' 			=> Controls_Manager::SELECT,
                    'label_block' 	=> true,
                    'options' 		=> guto_toolkit_get_page_as_list(),
                    'condition' => [
                        'link_type' => '1',
                    ]
                ]
            );

            $this->add_control(
                'ex_link',
                [
                    'label'		=> esc_html__('Button External Link', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: URL,
                    'show_external' => true,
                    'default' => [
                        'url' => '#',
                        'is_external' => true,
                        'nofollow' => true,
                    ],
                    'condition' => [
                        'link_type' => '2',
                    ]
                ]
            );

            // Button Two
            $this->add_control(
				'button_icon2',
				[
					'label' => esc_html__( 'Button Two Icon', 'guto-toolkit' ),
                    'type' => Controls_Manager::ICON,
                    'label_block' => true,
                    'options' => guto_toolkit_icons(),
				]
            );

			$this->add_control(
				'button_text2',
				[
					'label' 	=> esc_html__( 'Button Text Two', 'guto-toolkit' ),
					'type' 		=> Controls_Manager::TEXT,
					'default' 	=> esc_html__('Contact Us', 'guto-toolkit'),
				]
            );

            $this->add_control(
                'link_type2',
                [
                    'label' 		=> esc_html__( 'Button Link Type', 'guto-toolkit' ),
                    'type' 			=> Controls_Manager::SELECT,
                    'label_block' 	=> true,
                    'options' => [
                        '1'  	=> esc_html__( 'Link To Page', 'guto-toolkit' ),
                        '2' 	=> esc_html__( 'External Link', 'guto-toolkit' ),
                    ],
                    'default' => '2'
                ]
            );

            $this->add_control(
                'link_to_page2',
                [
                    'label' 		=> esc_html__( 'Button Link Page', 'guto-toolkit' ),
                    'type' 			=> Controls_Manager::SELECT,
                    'label_block' 	=> true,
                    'options' 		=> guto_toolkit_get_page_as_list(),
                    'condition' => [
                        'link_type2' => '1',
                    ]
                ]
            );

            $this->add_control(
                'ex_link2',
                [
                    'label'		=> esc_html__('Button External Link', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: URL,
                    'show_external' => true,
                    'default' => [
                        'url' => '#',
                        'is_external' => true,
                        'nofollow' => true,
                    ],
                    'condition' => [
                        'link_type2' => '2',
                    ]
                ]
            );

            $this->add_control(
				'video_icon',
				[
					'label' => esc_html__( 'Video Icon', 'guto-toolkit' ),
                    'type' => Controls_Manager::ICON,
                    'label_block' => true,
                    'options' => guto_toolkit_icons(),
				]
            );
            $this->add_control(
				'video_link',
				[
					'label' 	=> esc_html__( 'Video Link', 'guto-toolkit' ),
					'type' 		=> Controls_Manager::TEXT,
					'default' 	=> 'https://www.youtube.com/watch?v=bk7McNUjWgw',
				]
            );

        $this->end_controls_section();

        $this->start_controls_section(
			'banner_style',
			[
				'label' => esc_html__( 'Style', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

            $this->add_group_control(
                Group_Control_Background::get_type(),
                [
                    'name' => 'background',
                    'label' => __( 'Background', 'guto-toolkit' ),
                    'types' => [ 'classic', 'gradient'],
                    'selector' => '{{WRAPPER}} .dm-banner-area',
                ]
            );

			$this->add_control(
				'title_color',
				[
					'label' => esc_html__( 'Title Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .cws-banner-content h1, .cws-banner-content h2, .cws-banner-content h3, .cws-banner-content h4, .cws-banner-content h5, .cws-banner-content h6' => 'color: {{VALUE}}',
					],
                    'separator' => 'before',
				]
			);

			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'title_typography',
                    'label' => esc_html__( 'Title Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .cws-banner-content h1, .cws-banner-content h2, .cws-banner-content h3, .cws-banner-content h4, .cws-banner-content h5, .cws-banner-content h6',
                ]
            );

			$this->add_control(
				'content_color',
				[
					'label' => esc_html__( 'Content Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .cws-banner-content p' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'content_typography',
                    'label' => esc_html__( 'Content Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .cws-banner-content p',
                ]
            );

            $this->add_control(
				'button_color',
				[
					'label' => esc_html__( 'Button Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .cws-default-btn' => 'color: {{VALUE}}',
					],
				]
			);
			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'btn_typography',
                    'label' => esc_html__( 'Button Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .cws-default-btn',
                ]
            );
        $this->end_controls_section();

    }

	protected function render() {

		$settings = $this->get_settings_for_display();

        // Button One Link
        if($settings['link_type'] == 1){
            $link = get_page_link( $settings['link_to_page'] );
        } elseif($settings['link_type'] == 2) {
            $link = $settings['ex_link']['url'];
            $target = $settings['ex_link']['is_external'] ? ' target="_blank"' : '';
		    $nofollow = $settings['ex_link']['nofollow'] ? ' rel="nofollow"' : '';
        }

        // Button Two Link
        if($settings['link_type2'] == 1){
            $link2 = get_page_link( $settings['link_to_page2'] );
        } elseif($settings['link_type2'] == 2) {
            $link2 = $settings['ex_link2']['url'];
            $target2 = $settings['ex_link2']['is_external'] ? ' target="_blank"' : '';
		    $nofollow2 = $settings['ex_link2']['nofollow'] ? ' rel="nofollow"' : '';
        }

        $button_text1 = $settings['button_text1'];
        $button_text2 = $settings['button_text2'];
        $video_link = $settings['video_link'];

        ?>
            <div class="cws-banner-area">
                <div class="container-fluid">
                    <div class="cws-banner-inner " style="background-image:url(<?php echo esc_url( $settings['bg_image']['url'] ); ?>);">
                        <div class="row align-items-center">
                            <div class="col-lg-6 col-md-12">
                                <div class="cws-banner-content">
                                    <<?php echo esc_attr( $settings['title_tag'] ); ?>>
                                        <?php echo esc_html( $settings['title'] ); ?>
                                    </<?php echo esc_attr( $settings['title_tag'] ); ?>>

                                    <p ><?php echo wp_kses_post( $settings['content'] ); ?> </p>

                                    <?php if( !empty( $button_text1 || $button_text2 ) ) : ?>
                                        <div class="btn-box">
                                            <?php if( $button_text1 != '' ): ?>
                                                <?php if($settings['link_type'] == 1) : ?>
                                                    <a href="<?php echo esc_url( $link ); ?>" class="cws-default-btn">
                                                        <i class="<?php echo esc_attr( $settings['button_icon'] ); ?>"></i>
                                                        <?php echo esc_html( $button_text1 ); ?>
                                                    </a>
                                                <?php elseif($settings['link_type'] == 2) :
                                                    echo '<a href="' .  $link . '" class="cws-default-btn" ' . $target . $nofollow . '> <i class="'.$settings['button_icon'].'"></i> ' . $button_text1 . ' </a>';
                                                endif; ?>
                                            <?php endif; ?>

                                            <?php if( $button_text2 != '' ): ?>
                                                <?php if($settings['link_type2'] == 1) : ?>
                                                    <a href="<?php echo esc_url( $link2 ); ?>" class="cws-default-btn">
                                                        <i class="<?php echo esc_attr( $settings['button_icon2'] ); ?>"></i>
                                                        <?php echo esc_html( $button_text2 ); ?>
                                                    </a>
                                                <?php elseif($settings['link_type2'] == 2) :
                                                    echo '<a href="' .  $link2 . '" class="cws-default-btn" ' . $target2 . $nofollow2 . '> <i class="'.$settings['button_icon2'].'"></i> ' . $button_text2 . ' </a>';
                                                endif; ?>
                                            <?php endif; ?>
                                        </div>
                                    <?php endif; ?>
                                </div>
                            </div>

                            <?php if( !empty( $video_link ) ) : ?>
                            <div class="col-lg-6 col-md-12">
                                <div class="cws-banner-video">
                                    <a href="<?php echo esc_url($video_link) ?>" class="video-btn popup-youtube"><i class='<?php echo esc_attr($settings['video_icon']) ?>'></i></a>
                                </div>
                            </div>
                            <?php endif; ?>

                        </div>
                    </div>
                </div>
            </div>

        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_CS_Banner );