<?php
/**
 * Contact Area Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

class Guto_CSContact_Area extends Widget_Base {

    public function get_name() {
        return 'CS_Contact_Card';
    }

    public function get_title() {
        return esc_html__( 'Contact Card', 'guto-toolkit' );
    }

    public function get_icon() {
        return 'eicon-form-horizontal';
    }

    public function get_categories() {
        return [ 'guto-coworking-space' ];
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'Guto_Contact_Area',
            [
                'label' => esc_html__( 'Guto Contact Area', 'guto-toolkit' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

            $repeater = new Repeater();
            $repeater->add_control(
                'icon',
                [
                    'label' => esc_html__( 'Select Icon', 'guto-toolkit' ),
                    'type' => Controls_Manager::ICON,
                    'label_block' => true,
                    'options' => guto_toolkit_icons(),
                ]
            );
            $repeater->add_control(
                'title',
                [
                    'label' => esc_html__( 'Title', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default'       => esc_html__('Phone', 'guto-toolkit'),
                    'label_block'   => true,
                ]
            );
            $repeater->add_control(
                'content',
                [
                    'label'     => esc_html__( 'Content', 'guto-toolkit' ),
                    'type'      => Controls_Manager::TEXTAREA,
                    'default'   => esc_html__('175 5th Ave, New York, NY 10010, United States', 'guto-toolkit'),
                ]
            );
            $this->add_control(
                'list_items',
                [
                    'label' => esc_html__('List Item', 'guto-toolkit'),
                    'type' => Controls_Manager::REPEATER,
                    'fields' => $repeater->get_controls(),
                ]
            );
        $this->end_controls_section();
    }

    protected function render() {

        $settings = $this->get_settings_for_display();

        ?>

            <div class="container">
                <div class="row justify-content-center">
                    <?php foreach( $settings['list_items'] as $item ) :
                        $icon = $item['icon'];
                    ?>
                        <div class="col-lg-4 col-sm-6 col-md-6">
                            <div class="single-cws-contact-info">
                                <?php if( !empty( $icon ) ) : ?>
                                <div class="icon">
                                    <i class='<?php echo esc_attr( $icon ); ?>'></i>
                                </div>
                                <?php endif; ?>

                                <h3><?php echo esc_html( $item['title'] ); ?></h3>
                                <?php echo wp_kses_post( $item['content'] ); ?>

                            </div>
                        </div>
                    <?php endforeach; ?>
                </div>
            </div>

        <?php
    }



}

Plugin::instance()->widgets_manager->register( new Guto_CSContact_Area );
