<?php
/**
 * CS FAQ Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_CS_Faq extends Widget_Base {

	public function get_name() {
        return 'CS_FAQ';
    }

	public function get_title() {
        return esc_html__( 'FAQ', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-help-o';
    }

	public function get_categories() {
        return [ 'guto-coworking-space' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'Guto_cs_Faq',
			[
				'label' => esc_html__( 'Faq Control', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );
            $repeater = new Repeater();
            $repeater->add_control(
				'title',
				[
                    'label' => esc_html__( 'Title', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__( 'What type of people work out of the (co)working space?', 'guto-toolkit' ),
				]
            );
            $repeater->add_control(
                'content',
                [
                    'label' => esc_html__( 'Content', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXTAREA,
                    'label_block' => true,
                ]
            );
            $this->add_control(
                'faq_items',
                [
                    'label' => esc_html__('Faq Items', 'guto-toolkit'),
                    'type'   => Controls_Manager::REPEATER,
                    'fields' => $repeater->get_controls(),
                ]
            );
        $this->end_controls_section();

        $this->start_controls_section(
			'Guto_help_Faq',
			[
				'label' => esc_html__( 'Faq Help Box', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );
            $this->add_control(
                'box_title',
                [
                    'label' => esc_html__( 'Box Title', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__( 'Need some help?', 'guto-toolkit' ),
                ]
            );
            // Help box
            $repeater2 = new Repeater();
            $repeater2->add_control(
                'icon',
                [
                    'label' => esc_html__( 'Icon', 'guto-toolkit' ),
                    'type' => Controls_Manager::ICON,
                    'label_block' => true,
                    'options' => guto_toolkit_icons(),
                ]
            );
            $repeater2->add_control(
				'title2',
				[
                    'label' => esc_html__( 'Title', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__( 'How does Guto Production house Work?', 'guto-toolkit' ),
				]
            );
            $repeater2->add_control(
                'box_content',
                [
                    'label' => esc_html__( 'Content', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXTAREA,
                    'label_block' => true,
                ]
            );
            $this->add_control(
                'faq_info',
                [
                    'label' => esc_html__('Faq Help Info', 'guto-toolkit'),
                    'type'   => Controls_Manager::REPEATER,
                    'fields' => $repeater2->get_controls(),
                ]
            );
        $this->end_controls_section();

        $this->start_controls_section(
			'dmfaq_style',
			[
				'label' => esc_html__( 'Style', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
        );
            $this->add_control(
                'title_color',
                [
                    'label' => esc_html__( 'Faq Title Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .cws-faq-item h3' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'title_typography',
                    'label' => esc_html__( 'Faq Title Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .cws-faq-item h3',
                ]
            );

            $this->add_control(
                'content_color',
                [
                    'label' => esc_html__( 'Faq Content Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .cws-faq-item p, .cws-faq-item ul li' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'content_typography',
                    'label' => esc_html__( 'Faq Content Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .cws-faq-item p, .cws-faq-item ul li',
                ]
            );


            $this->add_control(
                'box_title_color',
                [
                    'label' => esc_html__( 'Box Title Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .cws-faq-help-box h3, .cws-faq-help-box ul li span' => 'color: {{VALUE}}',
                    ],
                ]
            );
            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'boxtitle_typography',
                    'label' => esc_html__( 'Box Title Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .cws-faq-help-box h3',
                ]
            );

            $this->add_control(
                'boxcontent_color',
                [
                    'label' => esc_html__( 'Box Content Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .cws-faq-help-box ul li a' => 'color: {{VALUE}}',
                    ],
                ]
            );
            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'box_content_typography',
                    'label' => esc_html__( 'Box Content Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .cws-faq-help-box ul li a',
                ]
            );
        $this->end_controls_section();

    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        $count = 0;
        foreach($settings['faq_info'] as $item):
            $count++;
        endforeach;
        ?>

            <div class="container">
                <div class="row">
                    <?php if($count == 0 ) : ?>
                    <div class="col-lg-12 col-md-12">
                    <?php else: ?>
                    <div class="col-lg-8 col-md-12">
                    <?php endif; ?>
                        <?php foreach( $settings['faq_items'] as $item ) : ?>
                            <div class="cws-faq-item">
                                <h3><?php echo esc_html( $item['title'] ); ?></h3>
                                <?php echo wp_kses_post( $item['content'] ); ?>
                            </div>
                        <?php endforeach; ?>
                    </div>

                    <?php if($count != 0 ) : ?>
                    <div class="col-lg-4 col-md-12">
                        <div class="cws-faq-help-box">

                            <?php if( !empty( $settings['box_title'] ) ) : ?>
                            <h3><?php echo esc_html( $settings['box_title'] ); ?></h3>
                            <?php endif; ?>

                            <ul>
                                <?php foreach( $settings['faq_info'] as $item ) : ?>
                                    <li>
                                        <i class='<?php echo esc_attr( $item['icon'] ); ?>'></i>
                                        <span><?php echo esc_html( $item['title2'] ); ?></span>
                                        <?php echo wp_kses_post( $item['box_content'] ); ?>
                                    </li>
                                <?php endforeach; ?>
                            </ul>
                        </div>
                    </div>
                    <?php endif; ?>
                </div>
            </div>

        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_CS_Faq );