<?php
/**
 * CS Feedback Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_CS_Feedback extends Widget_Base {

	public function get_name() {
        return 'CS_Feedback';
    }

	public function get_title() {
        return esc_html__( 'Feedback', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-testimonial';
    }

	public function get_categories() {
        return [ 'guto-coworking-space' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'feed_section',
			[
				'label' => esc_html__( 'Feedback Section Content', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );
            $this->add_control(
                'top_title',
                [
                    'label' 	=> esc_html__( 'Top Title', 'guto-toolkit' ),
                    'type' 		=> Controls_Manager::TEXTAREA,
                    'default' 	=> esc_html__('About Us', 'guto-toolkit'),
                ]
            );
            $this->add_control(
                'title',
                [
                    'label' 	=> esc_html__( 'Title', 'guto-toolkit' ),
                    'type' 		=> Controls_Manager::TEXTAREA,
                    'default' 	=> esc_html__('We offer creative working environments', 'guto-toolkit'),
                ]
            );

            $this->add_control(
                'title_tag',
                [
                    'label' 	=> esc_html__( 'Title Tag', 'guto-toolkit' ),
                    'type' 		=> Controls_Manager::SELECT,
                    'options' 	=> [
                        'h1'         => esc_html__( 'h1', 'guto-toolkit' ),
                        'h2'         => esc_html__( 'h2', 'guto-toolkit' ),
                        'h3'         => esc_html__( 'h3', 'guto-toolkit' ),
                        'h4'         => esc_html__( 'h4', 'guto-toolkit' ),
                        'h5'         => esc_html__( 'h5', 'guto-toolkit' ),
                        'h6'         => esc_html__( 'h6', 'guto-toolkit' ),
                    ],
                    'default' => 'h2',
                ]
            );

            $this->add_control(
                'content',
                [
                    'label' 	=> esc_html__( 'Content', 'guto-toolkit' ),
                    'type' 		=> Controls_Manager::TEXTAREA,
                    'default' 	=> esc_html__('Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.', 'guto-toolkit'),
                ]
            );

            $this->add_control(
                'image1',
                [
                    'label'		=> esc_html__('Featured Image', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: MEDIA,
                ]
            );
        $this->end_controls_section();


        $this->start_controls_section(
			'content_section',
			[
				'label' => esc_html__( 'Feedback Controls', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

            $repeater = new Repeater();
            $repeater->add_control(
				'rating',
				[
                    'label'       => esc_html__('Rating', 'guto-toolkit'),
                    'type'        => Controls_Manager::NUMBER,
                    'min'         => 1,
                    'max'         => 5,
                    'step'        => 1,
                    'default'     => 5,
				]
            );
            $repeater->add_control(
                'feedback',
                [
                    'label'       => esc_html__('Feedback Content', 'guto-toolkit'),
                    'type'        => Controls_Manager::TEXTAREA,
                    'default'     => esc_html__('There are many variations of ages of Lorem Ipsum available, but the majority have suffered alteration in some form, by injected humour, or randomised words which dont look even slightly believable.', 'guto-toolkit'),
                    'label_block' => true,
                ]
            );
            $repeater->add_control(
				'name',
				[
                    'label'       => esc_html__('Name', 'guto-toolkit'),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => esc_html__('Olivar Lucy', 'guto-toolkit'),
                    'label_block' => true,
				]
            );
            $repeater->add_control(
                'designation',
                [
                    'label'       => esc_html__('Designation', 'guto-toolkit'),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => esc_html__('Designer', 'guto-toolkit'),
                    'label_block' => true,
                ]
            );
            $repeater->add_control(
                'client_img',
                [
                    'label'		=> esc_html__('Image', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: MEDIA,
                ]
            );

            $this->add_control(
                'guto_feedback_items',
                [
                    'label'  => esc_html__('Slider Item', 'guto-toolkit'),
                    'type'   => Controls_Manager::REPEATER,
                    'fields' => $repeater->get_controls(),
                ]
            );
        $this->end_controls_section();

        $this->start_controls_section(
            'style',
            [
                'label' => esc_html__( 'Style', 'guto-toolkit' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
            $this->add_control(
                'top_title_color',
                [
                    'label' => esc_html__( 'Top Title Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .cws-feedback-content .sub-title' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'top_title_typography',
                    'label' => esc_html__( 'Top Title Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .cws-feedback-content .sub-title',
                ]
            );
            $this->add_control(
                'title_color',
                [
                    'label' => esc_html__( 'Title Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .cws-feedback-content h2, .cws-feedback-content h1, .cws-feedback-content h3, .cws-feedback-content h4, .cws-feedback-content h5, .cws-feedback-content h6' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'title_typography',
                    'label' => esc_html__( 'Title Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .cws-feedback-content h2, .cws-feedback-content h1, .cws-feedback-content h3, .cws-feedback-content h4, .cws-feedback-content h5, .cws-feedback-content h6',
                ]
            );

            $this->add_control(
                'content_color',
                [
                    'label' => esc_html__( 'Content Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .cws-feedback-content p' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'content_typography',
                    'label' => esc_html__( 'Content Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .cws-feedback-content p',
                ]
            );

            $this->add_control(
                'name_color',
                [
                    'label' => esc_html__( 'Name Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .single-cws-feedback-box .client-info .title h5' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'name_typography',
                    'label' => esc_html__( 'Name Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .single-cws-feedback-box .client-info .title h5',
                ]
            );
            $this->add_control(
                'des_color',
                [
                    'label' => esc_html__( 'Designation Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .single-cws-feedback-box .client-info .title span' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'des_typography',
                    'label' => esc_html__( 'Designation Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .single-cws-feedback-box .client-info .title span',
                ]
            );

            $this->add_control(
                'feed_color',
                [
                    'label' => esc_html__( 'Feedback Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .single-cws-feedback-box p' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'feed_typography',
                    'label' => esc_html__( 'Feedback Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .single-cws-feedback-box p',
                ]
            );
            $this->add_control(
                'feed_bgcolor',
                [
                    'label' => esc_html__( 'Feedback Background Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .single-cws-feedback-box' => 'background-color: {{VALUE}}',
                    ],
                ]
            );

        $this->end_controls_section();

    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        $slider = $settings['guto_feedback_items'];

        // Inline Editing
        $this-> add_inline_editing_attributes('title','none');

        $count = 0;
        foreach ($slider as $items => $counts):
            $count++;
        endforeach;
        ?>

            <div class="container">
                <div class="row align-items-center">
                    <div class="col-lg-6 col-md-12">
                        <div class="cws-feedback-content">

                            <span class="sub-title"><?php echo esc_html( $settings['top_title'] ); ?></span>

                            <<?php echo esc_attr( $settings['title_tag'] ); ?>>
                                <?php echo esc_html( $settings['title'] ); ?>
                            </<?php echo esc_attr( $settings['title_tag'] ); ?>>

                            <?php echo wp_kses_post( $settings['content'] ); ?>

                            <div class="cws-feedback-slides owl-carousel owl-theme">
                                <?php foreach( $slider as $key => $value ) : ?>
                                    <div class="single-cws-feedback-box">
                                        <?php if( $value['rating'] !='' ) : ?>
                                            <div class="rating">
                                                <?php if( $value['rating'] == 1 ){ ?>
                                                    <i class='bx bxs-star'></i>
                                                    <i class='bx bx-star'></i>
                                                    <i class='bx bx-star'></i>
                                                    <i class='bx bx-star'></i>
                                                    <i class='bx bx-star'></i><?php
                                                } elseif( $value['rating'] == 2 ){ ?>
                                                    <i class='bx bxs-star'></i>
                                                    <i class='bx bxs-star'></i>
                                                    <i class='bx bx-star'></i>
                                                    <i class='bx bx-star'></i>
                                                    <i class='bx bx-star'></i><?php
                                                } elseif( $value['rating'] == 3 ){ ?>
                                                    <i class='bx bxs-star'></i>
                                                    <i class='bx bxs-star'></i>
                                                    <i class='bx bxs-star'></i>
                                                    <i class='bx bx-star'></i>
                                                    <i class='bx bx-star'></i><?php
                                                } elseif( $value['rating'] == 4 ){ ?>
                                                    <i class='bx bxs-star'></i>
                                                    <i class='bx bxs-star'></i>
                                                    <i class='bx bxs-star'></i>
                                                    <i class='bx bxs-star'></i>
                                                    <i class='bx bx-star'></i><?php
                                                } elseif( $value['rating'] == 5 ) { ?>
                                                    <i class='bx bxs-star'></i>
                                                    <i class='bx bxs-star'></i>
                                                    <i class='bx bxs-star'></i>
                                                    <i class='bx bxs-star'></i>
                                                    <i class='bx bxs-star'></i><?php
                                                } ?>
                                            </div>
                                        <?php endif; ?>

                                        <p><?php echo wp_kses_post( $value['feedback'] ); ?></p>
                                        <div class="client-info">
                                            <?php if($value['client_img']['url'] != '') : ?>
                                                <img src="<?php echo esc_url( $value['client_img']['url'] ); ?>" alt="<?php echo esc_attr('Image','guto-toolkit'); ?>">
                                            <?php endif; ?>

                                            <div class="title">
                                                <h5><?php echo esc_html( $value['name'] ); ?></h5>
                                                <span><?php echo esc_html( $value['designation'] ); ?></span>
                                            </div>
                                        </div>
                                    </div>
                                <?php endforeach; ?>
                            </div>
                        </div>
                    </div>

                    <?php if( $settings['image1']['url'] != '' ): ?>
                        <div class="col-lg-6 col-md-12">
                            <div class="cws-feedback-image">
                                <img src="<?php echo esc_url( $settings['image1']['url'] ); ?>" alt="<?php echo esc_attr('Image','guto-toolkit'); ?>">
                            </div>
                        </div>
                    <?php endif; ?>

                </div>
            </div>

        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_CS_Feedback );
