<?php
/**
 * CS Gallery Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_CS_Gallery extends Widget_Base {

	public function get_name() {
        return 'CS_Gallery';
    }

	public function get_title() {
        return esc_html__( 'Gallery', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-gallery-masonry';
    }

	public function get_categories() {
        return [ 'guto-coworking-space' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'feed_section',
			[
				'label' => esc_html__( 'Section Content', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );
            $this->add_control(
                'show_section',
                [
                    'label'        => __( 'Section Title Hide/Show?', 'guto-toolkit' ),
                    'type'         => Controls_Manager::SWITCHER,
                    'label_on'     => __( 'Show', 'tovi-toolkit' ),
                    'label_off'    => __( 'Hide', 'tovi-toolkit' ),
                    'return_value' => 'yes',
                    'default'      => 'yes',
                ]
            );
            $this->add_control(
                'top_title',
                [
                    'label' 	=> esc_html__( 'Top Title', 'guto-toolkit' ),
                    'type' 		=> Controls_Manager::TEXTAREA,
                    'default' 	=> esc_html__('About Us', 'guto-toolkit'),
                    'condition' => [
                        'show_section' => 'yes',
                    ]
                ]
            );
            $this->add_control(
                'title',
                [
                    'label' 	=> esc_html__( 'Title', 'guto-toolkit' ),
                    'type' 		=> Controls_Manager::TEXTAREA,
                    'default' 	=> esc_html__('Popular view of space', 'guto-toolkit'),
                    'condition' => [
                        'show_section' => 'yes',
                    ]
                ]
            );

            $this->add_control(
                'title_tag',
                [
                    'label' 	=> esc_html__( 'Title Tag', 'guto-toolkit' ),
                    'type' 		=> Controls_Manager::SELECT,
                    'options' 	=> [
                        'h1'         => esc_html__( 'h1', 'guto-toolkit' ),
                        'h2'         => esc_html__( 'h2', 'guto-toolkit' ),
                        'h3'         => esc_html__( 'h3', 'guto-toolkit' ),
                        'h4'         => esc_html__( 'h4', 'guto-toolkit' ),
                        'h5'         => esc_html__( 'h5', 'guto-toolkit' ),
                        'h6'         => esc_html__( 'h6', 'guto-toolkit' ),
                    ],
                    'default' => 'h2',
                    'condition' => [
                        'show_section' => 'yes',
                    ]
                ]
            );

            $this->add_control(
                'content',
                [
                    'label' 	=> esc_html__( 'Content', 'guto-toolkit' ),
                    'type' 		=> Controls_Manager::TEXTAREA,
                    'default' 	=> esc_html__('Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua.', 'guto-toolkit'),
                    'condition' => [
                        'show_section' => 'yes',
                    ]
                ]
            );

            $this->add_control(
				'button_icon',
				[
					'label' => esc_html__( 'Button Icon', 'guto-toolkit' ),
                    'type' => Controls_Manager::ICON,
                    'label_block' => true,
                    'options' => guto_toolkit_icons(),
                    'condition' => [
                        'show_section' => 'yes',
                    ]
				]
            );

			$this->add_control(
				'button_text',
				[
					'label' 	=> esc_html__( 'Button Text', 'guto-toolkit' ),
					'type' 		=> Controls_Manager::TEXT,
					'default' 	=> esc_html__('More About Us', 'guto-toolkit'),
                    'condition' => [
                        'show_section' => 'yes',
                    ]
				]
            );

            $this->add_control(
                'link_type',
                [
                    'label' 		=> esc_html__( 'Button Link Type', 'guto-toolkit' ),
                    'type' 			=> Controls_Manager::SELECT,
                    'label_block' 	=> true,
                    'options' => [
                        '1'  	=> esc_html__( 'Link To Page', 'guto-toolkit' ),
                        '2' 	=> esc_html__( 'External Link', 'guto-toolkit' ),
                    ],
                    'default' => '2',
                    'condition' => [
                        'show_section' => 'yes',
                    ]
                ]
            );

            $this->add_control(
                'link_to_page',
                [
                    'label' 		=> esc_html__( 'Button Link Page', 'guto-toolkit' ),
                    'type' 			=> Controls_Manager::SELECT,
                    'label_block' 	=> true,
                    'options' 		=> guto_toolkit_get_page_as_list(),
                    'condition' => [
                        'link_type' => '1',
                        'show_section' => 'yes',
                    ]
                ]
            );

            $this->add_control(
                'ex_link',
                [
                    'label'		=> esc_html__('Button External Link', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: URL,
                    'show_external' => true,
                    'default' => [
                        'url' => '#',
                        'is_external' => true,
                        'nofollow' => true,
                    ],
                    'condition' => [
                        'link_type' => '2',
                        'show_section' => 'yes',
                    ]
                ]
            );
        $this->end_controls_section();


        $this->start_controls_section(
			'content_section',
			[
				'label' => esc_html__( 'Gallery Controls', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

            $repeater = new Repeater();
            $repeater->add_control(
                'gallery_img',
                [
                    'label'		=> esc_html__('Image', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: MEDIA,
                ]
            );

            $this->add_control(
                'guto_gallery_items',
                [
                    'label'  => esc_html__('Gallery Item', 'guto-toolkit'),
                    'type'   => Controls_Manager::REPEATER,
                    'fields' => $repeater->get_controls(),
                ]
            );
        $this->end_controls_section();

        $this->start_controls_section(
            'style',
            [
                'label' => esc_html__( 'Style', 'guto-toolkit' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
            $this->add_control(
                'top_title_color',
                [
                    'label' => esc_html__( 'Top Title Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .cws-section-title .sub-title' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'top_title_typography',
                    'label' => esc_html__( 'Top Title Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .cws-section-title .sub-title',
                ]
            );
            $this->add_control(
                'title_color',
                [
                    'label' => esc_html__( 'Title Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .cws-section-title h2, .cws-section-title h1, .cws-section-title h3, .cws-section-title h4, .cws-section-title h5, .cws-section-title h6' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'title_typography',
                    'label' => esc_html__( 'Title Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .cws-section-title h2, .cws-section-title h1, .cws-section-title h3, .cws-section-title h4, .cws-section-title h5, .cws-section-title h6',
                ]
            );

            $this->add_control(
                'content_color',
                [
                    'label' => esc_html__( 'Content Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .cws-section-title p' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'content_typography',
                    'label' => esc_html__( 'Content Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .cws-section-title p',
                ]
            );

            $this->add_control(
                'button_color',
                [
                    'label' => esc_html__( 'Button Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .cws-default-btn' => 'color: {{VALUE}}',
                    ],
                ]
            );
            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'btn_typography',
                    'label' => esc_html__( 'Button Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .cws-default-btn',
                ]
            );
        $this->end_controls_section();

    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        // Get Button Link
        if($settings['link_type'] == 1){
            $link = get_page_link( $settings['link_to_page'] );
        } elseif($settings['link_type'] == 2) {
            $link = $settings['ex_link']['url'];
            $target = $settings['ex_link']['is_external'] ? ' target="_blank"' : '';
		    $nofollow = $settings['ex_link']['nofollow'] ? ' rel="nofollow"' : '';
        }

        $button_text = $settings['button_text'];

        $slider = $settings['guto_gallery_items'];
        ?>

            <div class="container">
                <?php if ( $settings['show_section'] == 'yes' ) : ?>
                    <div class="cws-section-title text-start">
                        <?php if( $button_text != '' ) : ?>
                            <?php if( $settings['link_type'] == 1 ) : ?>
                                <a href="<?php echo esc_url( $link ); ?>" class="cws-default-btn">
                                    <i class="<?php echo esc_attr( $settings['button_icon'] ); ?>"></i>
                                    <?php echo esc_html( $button_text ); ?>
                                </a>
                            <?php elseif($settings['link_type'] == 2) :
                                echo '<a href="' .  $link . '" class="cws-default-btn" ' . $target . $nofollow . '> <i class="'.$settings['button_icon'].'"></i> ' . $button_text . ' </a>';
                            endif; ?>
                        <?php endif; ?>

                        <span class="sub-title"><?php echo esc_html( $settings['top_title'] ); ?></span>

                        <<?php echo esc_attr( $settings['title_tag'] ); ?>>
                            <?php echo esc_html( $settings['title'] ); ?>
                        </<?php echo esc_attr( $settings['title_tag'] ); ?>>

                        <?php echo wp_kses_post( $settings['content'] ); ?>
                    </div>
                <?php endif; ?>

                <div class="row justify-content-center">
                    <?php foreach( $slider as $item ) : ?>
                        <div class="col-lg-4 col-sm-6 col-md-6">
                            <div class="single-cws-gallery-item">
                                <a class="popup-btn" href="<?php echo esc_url( $item['gallery_img']['url'] ); ?>">
                                    <img src="<?php echo esc_url( $item['gallery_img']['url'] ); ?>" alt="<?php echo esc_attr__('Image','blinic-toolkit'); ?>">
                                </a>
                            </div>
                        </div>
                    <?php endforeach; ?>
                </div>
            </div>

        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_CS_Gallery );
