<?php
/**
 * Service Details Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_CS_Services_Details extends Widget_Base {

	public function get_name() {
        return 'Services_Details_Area';
    }

	public function get_title() {
        return esc_html__( 'Service Details Area', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-info-box';
    }

	public function get_categories() {
        return [ 'guto-coworking-space' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'Guto_Ser_Details_Area',
			[
				'label' => esc_html__( 'Service Details Area', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

            $this->add_control(
                'image_align',
                [
                    'label' => esc_html__( 'Image Alignment', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        'left'   => esc_html__( 'Left', 'guto-toolkit' ),
                        'right'   => esc_html__( 'Right', 'guto-toolkit' ),
                    ],
                    'default' => 'right',
                ]
            );

            $this->add_control(
                'title',
                [
                    'label' => esc_html__( 'Title', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__('What is SEO?', 'guto-toolkit'),
                ]
            );

            $this->add_control(
                'title_tag',
                [
                    'label' => esc_html__( 'Title Tag', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        'h1'         => esc_html__( 'h1', 'guto-toolkit' ),
                        'h2'         => esc_html__( 'h2', 'guto-toolkit' ),
                        'h3'         => esc_html__( 'h3', 'guto-toolkit' ),
                        'h4'         => esc_html__( 'h4', 'guto-toolkit' ),
                        'h5'         => esc_html__( 'h5', 'guto-toolkit' ),
                        'h6'         => esc_html__( 'h6', 'guto-toolkit' ),
                    ],
                    'default' => 'h3',
                ]
            );

            $this->add_control(
                'content',
                [
                    'label' => esc_html__( 'Content', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXTAREA,
                    'default' => esc_html__('Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Quis ipsum suspendisse ultrices gravida.', 'guto-toolkit'),
                ]
            );

            $this->add_control(
                'image',
                [
                    'label' => esc_html__( 'Image', 'guto-toolkit' ),
                    'type'	 => Controls_Manager::MEDIA,
                ]
            );
        $this->end_controls_section();

        $this->start_controls_section(
			'section_style',
			[
				'label' => esc_html__( 'Style', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
        );
            $this->add_control(
                'title_color',
                [
                    'label' => esc_html__( 'Title Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .cws-services-details-overview .cws-services-details-desc h2, .cws-services-details-overview .cws-services-details-desc h1, .cws-services-details-overview .cws-services-details-desc h3, .cws-services-details-overview .cws-services-details-desc h4, .cws-services-details-overview .cws-services-details-desc h5, .cws-services-details-overview .cws-services-details-desc h6' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'title_typography',
                    'label' => esc_html__( 'Title Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .cws-services-details-overview .cws-services-details-desc h2, .cws-services-details-overview .cws-services-details-desc h1, .cws-services-details-overview .cws-services-details-desc h3, .cws-services-details-overview .cws-services-details-desc h4, .cws-services-details-overview .cws-services-details-desc h5, .cws-services-details-overview .cws-services-details-desc h6',
                ]
            );

            $this->add_control(
                'content_color',
                [
                    'label' => esc_html__( 'Content Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .cws-services-details-desc p, .cws-services-details-desc ul li, .cws-services-details-desc ol li' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'content_typography',
                    'label' => esc_html__( 'Content Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .cws-services-details-desc p, .cws-services-details-desc ul li, .cws-services-details-desc ol li',
                ]
            );

        $this->end_controls_section();
    }

	protected function render() {

        $settings = $this->get_settings_for_display(); ?>

        <div class="container">
            <div class="cws-services-details-overview">

                <?php if( $settings['image_align'] == 'left' ) :
                    if( $settings['image']['url'] != '' ) : ?>
                        <div class="cws-services-details-image">
                            <img src="<?php echo esc_url($settings['image']['url']); ?>" alt="<?php esc_attr_e('Image', 'guto-toolkit'); ?>">
                        </div>
                    <?php endif;
                endif; ?>

                <div class="cws-services-details-desc">
                    <<?php echo esc_attr( $settings['title_tag'] ); ?>><?php echo wp_kses_post( $settings['title'] ); ?></<?php echo esc_attr( $settings['title_tag'] ); ?>>

                    <?php echo wp_kses_post( $settings['content'] ); ?>
                </div>

                <?php if( $settings['image_align'] == 'right' ) :
                    if( $settings['image']['url'] != '' ) : ?>
                    <div class="cws-services-details-image">
                        <img src="<?php echo esc_url($settings['image']['url']); ?>" alt="<?php esc_attr_e('Image', 'guto-toolkit'); ?>">
                    </div>
                    <?php endif;
                endif; ?>

            </div>
        </div>

        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_CS_Services_Details );