<?php
/**
 * CS Services Widget
 */

namespace Elementor;
class Guto_CS_Services extends Widget_Base {

	public function get_name() {
        return 'CS_Services';
    }

	public function get_title() {
        return esc_html__( 'Services', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-tools';
    }

	public function get_categories() {
        return [ 'guto-coworking-space' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'services_section',
			[
				'label' => esc_html__( 'Services', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

            $this->add_control(
                'columns',
                [
                    'label' => esc_html__( 'Choose Columns', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        '1'   => esc_html__( '1', 'guto-toolkit' ),
                        '2'   => esc_html__( '2', 'guto-toolkit' ),
                        '3'   => esc_html__( '3', 'guto-toolkit' ),
                        '4'   => esc_html__( '4', 'guto-toolkit' ),
                    ],
                    'default' => '3',
                ]
            );

            $this->add_control(
                'cat',
                [
                    'label' => __( 'Choose Category', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => guto_toolkit_get_page_services_cat_el(),
                ]
            );

            $this->add_control(
                'order',
                [
                    'label' => esc_html__( 'Services Order By', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        'DESC'      => esc_html__( 'DESC', 'guto-toolkit' ),
                        'ASC'       => esc_html__( 'ASC', 'guto-toolkit' ),
                    ],
                    'default' => 'DESC',
                ]
            );

            $this->add_control(
                'count',
                [
                    'label' => esc_html__( 'Post Per Page', 'guto-toolkit' ),
                    'type' => Controls_Manager::NUMBER,
                    'default' => 3,
                ]
            );

            $this->add_control(
				'pagination_show',
				[
					'label'        => __( 'Show Pagination?', 'guto-toolkit' ),
					'type'         => Controls_Manager::SWITCHER,
					'label_on'     => __( 'Show', 'vaximo-toolkit' ),
					'label_off'    => __( 'Hide', 'vaximo-toolkit' ),
					'return_value' => 'yes',
                    'default'      => 'no',
				]
            );
        $this->end_controls_section();

        $this->start_controls_section(
			'service_style',
			[
				'label' => esc_html__( 'Posts Style', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
        );
            $this->add_control(
                'post_title_color',
                [
                    'label' => esc_html__( 'Title Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .single-cws-amenities-box h3 a' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'posttitle_typography',
                    'label' => esc_html__( 'Title Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .single-cws-amenities-box h3 a',
                ]
            );

            $this->add_control(
                'content_color',
                [
                    'label' => esc_html__( 'Content Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .single-cws-amenities-box p' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'content_typography',
                    'label' => esc_html__( 'Content Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .single-cws-amenities-box p',
                ]
            );
        $this->end_controls_section();

    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        // Card Columns
        $columns = $settings['columns'];
        if ($columns == '1') {
            $column = 'col-lg-12 col-md-6';
        }elseif ($columns == '2') {
            $column = 'col-lg-6 col-md-6';
        }elseif ($columns == '3') {
            $column = 'col-lg-4 col-md-6';
        }else {
            $column = 'col-lg-3 col-md-6';
        }

        // Services Query
        if( $settings['cat'] != '' ) {
            $args = array(
                'post_type'     => 'services',
                'posts_per_page'=> $settings['count'],
                'order'         => $settings['order'],
                'paged'         => get_query_var('paged') ? get_query_var('paged') : 1,
                'tax_query'     => array(
                    array(
                        'taxonomy'      => 'service_cat',
                        'field'         => 'slug',
                        'terms'         => $settings['cat'],
                        'hide_empty'    => false
                    )
                )
            );
        } else {
            $args = array(
                'post_type'         => 'services',
                'posts_per_page'    => $settings['count'],
                'order'             => $settings['order'],
                'paged'               => get_query_var('paged') ? get_query_var('paged') : 1
            );
        }
        $services_array = new \WP_Query( $args ); ?>

        <div class="container">
            <div class="row justify-content-center">
                <?php while($services_array->have_posts()): $services_array->the_post(); ?>
                    <div class="<?php echo esc_attr( $column ); ?>">
                        <div class="single-cws-amenities-box">
                            <?php if( get_the_post_thumbnail_url() ): ?>
                                <div class="icon">
                                    <img src="<?php the_post_thumbnail_url(); ?>" alt="<?php the_title(); ?>">
                                </div>
                            <?php endif; ?>

                            <h3><a href="<?php the_permalink(); ?>"><?php the_title(); ?></h3>
                            <?php the_excerpt(); ?>
                        </div>
                    </div>
                <?php endwhile; ?>
                <?php wp_reset_query(); ?>

                <?php if ( $settings['pagination_show'] == 'yes' ) { ?>
                    <div class="col-lg-12 col-md-12 col-sm-12">
                        <div class="cws-pagination-area">
                            <div class="nav-links">
                            <?php
                            $big = 999999999; // need an unlikely integer
                            echo paginate_links( array(
                                'base' => str_replace( $big, '%#%', get_pagenum_link( $big ) ),
                                'format' => '?paged=%#%',
                                'current' => max(1, get_query_var('paged') ),
                                'total' => $services_array->max_num_pages,
                                //'format' => '?paged=%#%',
                                'prev_text' => '<i class="bx bx-left-arrow-alt"></i>',
                                'next_text' => '<i class="bx bx-right-arrow-alt"></i>',
                            ) ); ?>
                            </div>
                        </div>
                    </div>
                <?php } ?>

            </div>
        </div>

        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_CS_Services );