<?php
/**
 * DM Banner Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_DM_Banner extends Widget_Base {

	public function get_name() {
        return 'Guto_DM_Banner';
    }

	public function get_title() {
        return esc_html__( 'DM Banner', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-banner';
    }

	public function get_categories() {
        return [ 'guto-digital-marketing' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'Guto_DM_Banner_Area',
			[
				'label' => esc_html__( 'Banner Controls', 'guto-toolkit' ),
				'tab' 	=> Controls_Manager::TAB_CONTENT,
			]
		);
			$this->add_control(
				'title',
				[
					'label' 	=> esc_html__( 'Title', 'guto-toolkit' ),
					'type' 		=> Controls_Manager::TEXTAREA,
					'default' 	=> esc_html__('We Are Creative Digital Marketing Expert!', 'guto-toolkit'),
				]
			);

			$this->add_control(
                'title_tag',
                [
                    'label' 	=> esc_html__( 'Title Tag', 'guto-toolkit' ),
                    'type' 		=> Controls_Manager::SELECT,
                    'options' 	=> [
                        'h1'         => esc_html__( 'h1', 'guto-toolkit' ),
                        'h2'         => esc_html__( 'h2', 'guto-toolkit' ),
                        'h3'         => esc_html__( 'h3', 'guto-toolkit' ),
                        'h4'         => esc_html__( 'h4', 'guto-toolkit' ),
                        'h5'         => esc_html__( 'h5', 'guto-toolkit' ),
                        'h6'         => esc_html__( 'h6', 'guto-toolkit' ),
                    ],
                    'default' => 'h1',
                ]
            );

			$this->add_control(
				'content',
				[
					'label' 	=> esc_html__( 'Content', 'guto-toolkit' ),
					'type' 		=> Controls_Manager::TEXTAREA,
					'default' 	=> esc_html__('Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Quis ipsum suspendisse ultrices gravida. Risus commodo viverra maecenas accumsan lacus vel facilisis.', 'guto-toolkit'),
				]
            );

            $this->add_control(
				'button_icon',
				[
					'label' => esc_html__( 'Button Icon', 'guto-toolkit' ),
                    'type' => Controls_Manager::ICON,
                    'label_block' => true,
                    'options' => guto_toolkit_icons(),
				]
            );

			$this->add_control(
				'button_text',
				[
					'label' 	=> esc_html__( 'Button Text', 'guto-toolkit' ),
					'type' 		=> Controls_Manager::TEXT,
					'default' 	=> esc_html__('Get Started', 'guto-toolkit'),
				]
            );

            $this->add_control(
                'link_type',
                [
                    'label' 		=> esc_html__( 'Button Link Type', 'guto-toolkit' ),
                    'type' 			=> Controls_Manager::SELECT,
                    'label_block' 	=> true,
                    'options' => [
                        '1'  	=> esc_html__( 'Link To Page', 'guto-toolkit' ),
                        '2' 	=> esc_html__( 'External Link', 'guto-toolkit' ),
                    ],
                    'default' => '2'
                ]
            );

            $this->add_control(
                'link_to_page',
                [
                    'label' 		=> esc_html__( 'Button Link Page', 'guto-toolkit' ),
                    'type' 			=> Controls_Manager::SELECT,
                    'label_block' 	=> true,
                    'options' 		=> guto_toolkit_get_page_as_list(),
                    'condition' => [
                        'link_type' => '1',
                    ]
                ]
            );

            $this->add_control(
                'ex_link',
                [
                    'label'		=> esc_html__('Button External Link', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: URL,
                    'show_external' => true,
                    'default' => [
                        'url' => '#',
                        'is_external' => true,
                        'nofollow' => true,
                    ],
                    'condition' => [
                        'link_type' => '2',
                    ]
                ]
            );

            $this->add_control(
				'call_us_icon',
				[
					'label' => esc_html__( 'Call US Icon', 'guto-toolkit' ),
                    'type' => Controls_Manager::ICON,
                    'label_block' => true,
                    'options' => guto_toolkit_icons(),
				]
            );

			$this->add_control(
				'call_us_text',
				[
					'label' 	=> esc_html__( 'Call US Text', 'guto-toolkit' ),
					'type' 		=> Controls_Manager::TEXT,
					'default' 	=> esc_html__('Call Us', 'guto-toolkit'),
				]
            );

            $this->add_control(
				'call_us_num',
				[
					'label' 	=> esc_html__( 'Call Number', 'guto-toolkit' ),
					'type' 		=> Controls_Manager::TEXT,
					'default' 	=> '+1 (123) 456 7890',
				]
            );

            $this->add_control(
				'call_us_link',
				[
					'label' 	=> esc_html__( 'Call Number Link', 'guto-toolkit' ),
					'type' 		=> Controls_Manager::TEXT,
					'default' 	=> '+1 (123) 456 7890',
				]
            );
        $this->end_controls_section();

        // Images
        $this->start_controls_section(
			'banner_images',
			[
				'label' => esc_html__( 'Images', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

            $this->add_control(
                'image1',
                [
                    'label'		=> esc_html__('Banner Image One', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: MEDIA,
                ]
            );
            $this->add_control(
                'shape1',
                [
                    'label'		=> esc_html__('Shape Image One', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: MEDIA,
                ]
            );

            $this->add_control(
                'shape2',
                [
                    'label'		=> esc_html__('Shape Image Two', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: MEDIA,
                ]
            );
        $this->end_controls_section();

        $this->start_controls_section(
			'Guto_DM_Banner_Feature',
			[
				'label' => esc_html__( 'Banner Services Feature', 'guto-toolkit' ),
				'tab' 	=> Controls_Manager::TAB_CONTENT,
			]
		);
        $this->add_control(
            'columns',
            [
                'label' => esc_html__( 'Choose Columns', 'guto-toolkit' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    '1'   => esc_html__( '1', 'guto-toolkit' ),
                    '2'   => esc_html__( '2', 'guto-toolkit' ),
                    '3'   => esc_html__( '3', 'guto-toolkit' ),
                    '4'   => esc_html__( '4', 'guto-toolkit' ),
                ],
                'default' => '3',
            ]
        );

        $this->add_control(
            'cat',
            [
                'label' => __( 'Choose Category', 'guto-toolkit' ),
                'type' => Controls_Manager::SELECT,
                'options' => guto_toolkit_get_page_services_cat_el(),
            ]
        );

        $this->add_control(
            'order',
            [
                'label' => esc_html__( 'Services Order By', 'guto-toolkit' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'DESC'      => esc_html__( 'DESC', 'guto-toolkit' ),
                    'ASC'       => esc_html__( 'ASC', 'guto-toolkit' ),
                ],
                'default' => 'DESC',
            ]
        );

        $this->add_control(
            'count',
            [
                'label' => esc_html__( 'Post Per Page', 'guto-toolkit' ),
                'type' => Controls_Manager::NUMBER,
                'default' => 3,
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
			'banner_style',
			[
				'label' => esc_html__( 'Style', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

            $this->add_group_control(
                Group_Control_Background::get_type(),
                [
                    'name' => 'background',
                    'label' => __( 'Background', 'guto-toolkit' ),
                    'types' => [ 'classic', 'gradient'],
                    'selector' => '{{WRAPPER}} .dm-banner-area',
                ]
            );

			$this->add_control(
				'title_color',
				[
					'label' => esc_html__( 'Title Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .dm-banner-content h1, .dm-banner-content h2, .dm-banner-content h3, .dm-banner-content h4, .dm-banner-content h5, .dm-banner-content h6' => 'color: {{VALUE}}',
					],
                    'separator' => 'before',
				]
			);

			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'title_typography',
                    'label' => esc_html__( 'Title Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .dm-banner-content h1, .dm-banner-content h2, .dm-banner-content h3, .dm-banner-content h4, .dm-banner-content h5, .dm-banner-content h6',
                ]
            );
			$this->add_control(
				'content_color',
				[
					'label' => esc_html__( 'Content Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .dm-banner-content p' => 'color: {{VALUE}}',
					],
				]
			);
			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'content_typography',
                    'label' => esc_html__( 'Content Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .dm-banner-content p',
                ]
            );
            $this->add_control(
				'button_color',
				[
					'label' => esc_html__( 'Button Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .dm-default-btn' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'btn_typography',
                    'label' => esc_html__( 'Button Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .dm-default-btn',
                ]
            );
            $this->add_control(
				'call_us_tcolor',
				[
					'label' => esc_html__( 'Call Us Text Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .dm-banner-content .banner-btn-with-info .information span' => 'color: {{VALUE}}',
					],
				]
			);
			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'call_us_text_typography',
                    'label' => esc_html__( 'Call Us Text Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .dm-banner-content .banner-btn-with-info .information span',
                ]
            );
            $this->add_control(
				'call_us_numcolor',
				[
					'label' => esc_html__( 'Call Us Number Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .dm-banner-content .banner-btn-with-info .information a' => 'color: {{VALUE}}',
					],
				]
			);
			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'call_us_num_typography',
                    'label' => esc_html__( 'Call Us Number Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .dm-banner-content .banner-btn-with-info .information a',
                ]
            );
            $this->add_control(
				'feature_titlecolor',
				[
					'label' => esc_html__( 'Feature Title Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .dm-single-features h3 a' => 'color: {{VALUE}}',
					],
                    'separator' => 'before',
				]
			);
			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'feature_title_typography',
                    'label' => esc_html__( 'Feature Title Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .dm-single-features h3 a',
                ]
            );
            $this->add_control(
				'feature_desc_color',
				[
					'label' => esc_html__( 'Feature Description Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .dm-single-features p' => 'color: {{VALUE}}',
					],
                    'separator' => 'before',
				]
			);

			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'feature_desc_typography',
                    'label' => esc_html__( 'Feature Description Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .dm-single-features p',
                ]
            );
            $this->add_control(
				'feature_icon_color',
				[
					'label' => esc_html__( 'Feature Icon Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .dm-single-features .icon i' => 'color: {{VALUE}}',
					],
				]
			);
        $this->end_controls_section();

    }

	protected function render() {

		$settings = $this->get_settings_for_display();

        // Inline Editing
        $this-> add_inline_editing_attributes('title','none');
        $this-> add_inline_editing_attributes('content','none');

        // Get Button Link
        if($settings['link_type'] == 1){
            $link = get_page_link( $settings['link_to_page'] );
        } elseif($settings['link_type'] == 2) {
            $link = $settings['ex_link']['url'];
            $target = $settings['ex_link']['is_external'] ? ' target="_blank"' : '';
		    $nofollow = $settings['ex_link']['nofollow'] ? ' rel="nofollow"' : '';
        }

        $button_text = $settings['button_text'];
        $call_us_text = $settings['call_us_text'];


        // Card Columns
        $columns = $settings['columns'];
        if ($columns == '1') {
            $column = 'col-lg-12 col-md-6';
        }elseif ($columns == '2') {
            $column = 'col-lg-6 col-md-6';
        }elseif ($columns == '3') {
            $column = 'col-lg-4 col-md-6';
        }elseif ($columns == '4') {
            $column = 'col-lg-3 col-md-6';
        }

        // Services Query
        if( $settings['cat'] != '' ) {
            $args = array(
                'post_type'     => 'services',
                'posts_per_page'=> $settings['count'],
                'order'         => $settings['order'],
                'tax_query'     => array(
                    array(
                        'taxonomy'      => 'service_cat',
                        'field'         => 'slug',
                        'terms'         => $settings['cat'],
                        'hide_empty'    => false
                    )
                )
            );
        } else {
            $args = array(
                'post_type'         => 'services',
                'posts_per_page'    => $settings['count'],
                'order'             => $settings['order']
            );
        }
        $services_array = new \WP_Query( $args );

        ?>
            <div class="dm-banner-area">
                <div class="container-fluid">
                    <div class="row align-items-center">
                        <div class="col-lg-6 col-md-12">
                            <div class="dm-banner-content">
                                <<?php echo esc_attr( $settings['title_tag'] ); ?> class="wow fadeInLeft" data-wow-delay="00ms" data-wow-duration="1000ms">
                                    <?php echo esc_html( $settings['title'] ); ?>
                                </<?php echo esc_attr( $settings['title_tag'] ); ?>>

                                <p class="wow fadeInLeft" data-wow-delay="100ms" data-wow-duration="1000ms"><?php echo wp_kses_post( $settings['content'] ); ?> </p>

                                <?php if( !empty( $button_text || $call_us_num ) ) : ?>
                                    <ul class="banner-btn-with-info">
                                        <?php if( $button_text != '' ): ?>
                                            <?php if($settings['link_type'] == 1) : ?>
                                                <li>
                                                    <a href="<?php echo esc_url( $link ); ?>" class="dm-default-btn wow fadeInRight" data-wow-delay="300ms" data-wow-duration="1500ms"> <?php echo esc_html( $button_text ); ?><i class="<?php echo esc_attr( $settings['button_icon'] ); ?>"></i></a>
                                                </li>
                                            <?php elseif($settings['link_type'] == 2) :
                                                echo '<li><a href="' .  $link . '" class="dm-default-btn wow fadeInRight" data-wow-delay="300ms" data-wow-duration="1500ms" ' . $target . $nofollow . '> ' . $button_text . ' <i class="'.$settings['button_icon'].'"></i> </a></li>';
                                            endif; ?>
                                        <?php endif; ?>

                                        <?php if( $call_us_text != '' ): ?>
                                            <li class="information wow fadeInLeft" data-wow-delay="200ms" data-wow-duration="1000ms">
                                                <?php if( !empty( $settings['call_us_icon'] ) ) : ?>
                                                    <i class="<?php echo esc_attr( $settings['call_us_icon'] ); ?>"></i>
                                                <?php endif; ?>
                                                <span><?php echo esc_html( $call_us_text ); ?></span>
                                                <a href="<?php echo esc_url( $settings['call_us_link'] ); ?>"><?php echo esc_html( $settings['call_us_num'] ); ?></a>
                                            </li>
                                        <?php endif; ?>
                                    </ul>
                                <?php endif; ?>
                            </div>
                        </div>

                        <?php if( $settings['image1']['url'] != '' ): ?>
                            <div class="col-lg-6 col-md-12">
                                <div class="dm-banner-image wow fadeInRight" data-wow-delay="300ms" data-wow-duration="1500ms">
                                    <img src="<?php echo esc_url($settings['image1']['url']); ?>" alt="<?php echo esc_attr($settings['title']); ?>">
                                </div>
                            </div>
                        <?php endif; ?>

                    </div>
                </div>

                <?php if( $settings['shape1']['url'] != '' ): ?>
                    <div class="dm-circle-shape">
                        <img src="<?php echo esc_url($settings['shape1']['url']); ?>" alt="<?php esc_attr_e('Shape Image', 'guto-toolkit'); ?>">
                    </div>
                <?php endif; ?>

                <?php if( $settings['shape2']['url'] != '' ): ?>
                    <div class="dm-large-shape">
                        <img src="<?php echo esc_url($settings['shape2']['url']); ?>" alt="<?php esc_attr_e('Shape Image', 'guto-toolkit'); ?>">
                    </div>
                <?php endif; ?>

                <!-- Start DM Features Area -->
                <?php if($services_array->have_posts()): ?>
                <div class="dm-features-area">
                    <div class="container">
                        <div class="dm-features-inner-box">
                            <div class="row justify-content-center">
                                <?php while($services_array->have_posts()): $services_array->the_post();
                                // Card Icon
                                    if ( defined( 'FW' ) ) {
                                        $icon = fw_get_db_post_option( get_the_ID(), 'services_icon' );
                                    }else{
                                        $icon = '';
                                    }
                                ?>
                                    <div class="<?php echo esc_attr( $column );?>">
                                        <div class="dm-single-features">
                                            <?php if( $icon != '' ): ?>
                                                <div class="icon">
                                                    <i class="<?php echo esc_attr($icon); ?>"></i>
                                                </div>
                                            <?php endif; ?>

                                            <h3><a href="<?php the_permalink(); ?>"><?php the_title(); ?></h3>
                                            <p><?php the_excerpt(); ?></p>
                                        </div>
                                    </div>
                                <?php endwhile; ?>
                                <?php wp_reset_query(); ?>
                            </div>
                        </div>
                    </div>
                </div>
                <?php endif; ?>
                <!-- End DM Features Area -->
            </div>
        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_DM_Banner );