<?php
/**
 * Dm Contact Area Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_DM_Contact_Area extends Widget_Base {

	public function get_name() {
        return 'DMContact_Area';
    }

	public function get_title() {
        return esc_html__( 'DM Contact Area', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-form-horizontal';
    }

	public function get_categories() {
        return [ 'guto-digital-marketing' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
            'Guto_Contact_Area',
            [
                'label' => esc_html__( 'Guto Contact Area', 'guto-toolkit' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

            $this->add_control(
                'title',
                [
                    'label'     => esc_html__( 'Info Title', 'guto-toolkit' ),
                    'type'      => Controls_Manager::TEXT,
                    'default'   => esc_html__('Get In Touch', 'guto-toolkit'),
                ]
            );
            $this->add_control(
                'content',
                [
                    'label'     => esc_html__( 'Info Content', 'guto-toolkit' ),
                    'type'      => Controls_Manager::TEXTAREA,
                ]
            );

            $this->add_control(
                'title2',
                [
                    'label'     => esc_html__('Working Title', 'guto-toolkit'),
                    'type'      => Controls_Manager::TEXT,
                    'default'   => esc_html__('Working Hours', 'guto-toolkit'),
                ]
            );
            $this->add_control(
                'content2',
                [
                    'label'     => esc_html__('Working Content', 'guto-toolkit'),
                    'type'      => Controls_Manager::TEXTAREA,
                ]
            );

            // Form
            $this->add_control(
                'shortcode',
                [
                    'label' => esc_html__( 'Contact Shortcode', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                ]
            );

        $this->end_controls_section();

        $this->start_controls_section(
			'contact_style',
			[
				'label' => esc_html__( 'Style', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
            $this->add_group_control(
                Group_Control_Background::get_type(),
                [
                    'name' => 'background',
                    'label' => __( 'Background', 'guto-toolkit' ),
                    'types' => [ 'classic', 'gradient'],
                    'selector' => '{{WRAPPER}} .dm-contact-address',
                ]
            );

			$this->add_control(
				'title_color',
				[
					'label' => esc_html__( 'Info Title Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .dm-contact-address h3' => 'color: {{VALUE}}',
					],
                    'separator' => 'before',
				]
			);
			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'title_typography',
                    'label' => esc_html__( 'Info Title Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .dm-contact-address h3',
                ]
            );
            $this->add_control(
				'content_color',
				[
					'label' => esc_html__( 'Info Content Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .dm-contact-address .address-info li, .dm-contact-address .address-info li a, .dm-contact-address .dm-hours .info li' => 'color: {{VALUE}}',
					],
                    'separator' => 'before',
				]
			);
			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'info_con_typography',
                    'label' => esc_html__( 'Info Content Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .dm-contact-address .address-info li, .dm-contact-address .address-info li a, .dm-contact-address .dm-hours .info li',
                ]
            );
        $this->end_controls_section();
    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        ?>
            <div class="dm-contact-area ptb-100">
                <div class="container">
                    <div class="row">
                        <div class="col-lg-4 col-md-12">
                            <div class="dm-contact-address">
                                <h3><?php echo esc_html( $settings['title'] ); ?></h3>
                                <ul class="address-info">
                                    <?php echo wp_kses_post( $settings['content'] ); ?>
                                </ul>

                                <div class="dm-hours">
                                    <h3><?php echo esc_html( $settings['title2'] ); ?></h3>
                                    <ul class="info">
                                        <?php echo wp_kses_post( $settings['content2'] ); ?>
                                    </ul>
                                </div>
                            </div>
                        </div>

                        <div class="col-lg-8 col-md-12">
                            <?php if($settings['shortcode']): ?>
                                <div class="dm-contact-form">
                                    <?php echo do_shortcode( $settings['shortcode'] ); ?>
                                </div>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
            </div>

        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_DM_Contact_Area );