<?php
/**
 * DM Feedback Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_DM_Feedback extends Widget_Base {

	public function get_name() {
        return 'DM Feedback';
    }

	public function get_title() {
        return esc_html__( 'DM Feedback', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-testimonial';
    }

	public function get_categories() {
        return [ 'guto-digital-marketing' ];
    }

	protected function _register_controls() {

        // Images
        $this->start_controls_section(
			'feedback_images',
			[
				'label' => esc_html__( 'Feedback Images', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

            $this->add_control(
                'image1',
                [
                    'label'		=> esc_html__('Image One', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: MEDIA,
                ]
            );
            $this->add_control(
                'image2',
                [
                    'label'		=> esc_html__('Image Two', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: MEDIA,
                ]
            );
            $this->add_control(
                'image3',
                [
                    'label'		=> esc_html__('Image Three', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: MEDIA,
                ]
            );
            $this->add_control(
                'image4',
                [
                    'label'		=> esc_html__('Image Four', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: MEDIA,
                ]
            );
            $this->add_control(
                'image5',
                [
                    'label'		=> esc_html__('Image Five', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: MEDIA,
                ]
            );
            $this->add_control(
                'feedback_map_img',
                [
                    'label' => esc_html__( 'Map Image', 'guto-toolkit' ),
                    'type' => Controls_Manager::MEDIA,
                    'show_label' => true,
                ]
            );
        $this->end_controls_section();

        $this->start_controls_section(
			'content_section',
			[
				'label' => esc_html__( 'Feedback Content', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );
            $repeater = new Repeater();
            $repeater->add_control(
				'name',
				[
                    'label'       => esc_html__('Name', 'guto-toolkit'),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => esc_html__('Olivar Lucy', 'guto-toolkit'),
                    'label_block' => true,
				]
            );
            $repeater->add_control(
                'designation',
                [
                    'label'       => esc_html__('Designation', 'guto-toolkit'),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => esc_html__('Designer', 'guto-toolkit'),
                    'label_block' => true,
                ]
            );
            $repeater->add_control(
                'feedback',
                [
                    'label'       => esc_html__('Feedback Content', 'guto-toolkit'),
                    'type'        => Controls_Manager::TEXTAREA,
                    'default'     => esc_html__('Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Quis ipsum suspendisse ultrices gravida. Risus commodo viverra maecenas accumsan lacus vel facilisis.', 'guto-toolkit'),
                    'label_block' => true,
                ]
            );
            $this->add_control(
                'guto_feedback_items',
                [
                    'label'  => esc_html__('Slider Item', 'guto-toolkit'),
                    'type'   => Controls_Manager::REPEATER,
                    'fields' => $repeater->get_controls(),
                ]
            );

        $this->end_controls_section();

        $this->start_controls_section(
            'style',
            [
                'label' => esc_html__( 'Style', 'guto-toolkit' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
            $this->add_control(
                'title_color',
                [
                    'label' => esc_html__( 'Name Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .dm-testimonials-item .info h3' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'title_typography',
                    'label' => esc_html__( 'Name Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .dm-testimonials-item .info h3',
                ]
            );
            $this->add_control(
                'des_color',
                [
                    'label' => esc_html__( 'Designation Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .dm-testimonials-item .info span' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'des_typography',
                    'label' => esc_html__( 'Designation Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .dm-testimonials-item .info span',
                ]
            );

            $this->add_control(
                'feed_color',
                [
                    'label' => esc_html__( 'Feedback Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .dm-testimonials-item p' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'feed_typography',
                    'label' => esc_html__( 'Feedback Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .dm-testimonials-item p',
                ]
            );

        $this->end_controls_section();

    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        $slider = $settings['guto_feedback_items'];

        // Inline Editing
        $this-> add_inline_editing_attributes('title','none');

        $count = 0;
        foreach ($slider as $items => $counts):
            $count++;
        endforeach;
        ?>
            <div class="container">
                <div class="row">
                    <div class="col-lg-6 col-md-12">
                        <div class="dm-testimonials-image">
                            <?php if( $settings['feedback_map_img']['url'] != '' ): ?>
                                <img src="<?php echo esc_url( $settings['feedback_map_img']['url'] ); ?>" alt="<?php echo esc_attr('Map Image','guto-toolkit'); ?>">
                            <?php endif; ?>

                            <?php if( $settings['image1']['url'] != '' ): ?>
                                <div class="image-1">
                                    <img src="<?php echo esc_url( $settings['image1']['url'] ); ?>" alt="<?php echo esc_attr('Image1','guto-toolkit'); ?>">
                                </div>
                            <?php endif; ?>

                            <?php if( $settings['image2']['url'] != '' ): ?>
                                <div class="image-2">
                                    <img src="<?php echo esc_url( $settings['image2']['url'] ); ?>" alt="<?php echo esc_attr('Image2','guto-toolkit'); ?>">
                                </div>
                            <?php endif; ?>

                            <?php if( $settings['image3']['url'] != '' ): ?>
                                <div class="image-3">
                                    <img src="<?php echo esc_url( $settings['image3']['url'] ); ?>" alt="<?php echo esc_attr('Image3','guto-toolkit'); ?>">
                                </div>
                            <?php endif; ?>

                            <?php if( $settings['image4']['url'] != '' ): ?>
                                <div class="image-4">
                                    <img src="<?php echo esc_url( $settings['image4']['url'] ); ?>" alt="<?php echo esc_attr('Image4','guto-toolkit'); ?>">
                                </div>
                            <?php endif; ?>

                            <?php if( $settings['image5']['url'] != '' ): ?>
                                <div class="image-5">
                                    <img src="<?php echo esc_url( $settings['image5']['url'] ); ?>" alt="<?php echo esc_attr('Image5','guto-toolkit'); ?>">
                                </div>
                            <?php endif; ?>
                        </div>
                    </div>

                    <div class="col-lg-6 col-md-12 o">
                        <div class="dm-testimonials-slides owl-carousel owl-theme">
                            <?php foreach($slider as $key => $value) : ?>
                                <div class="dm-testimonials-item">
                                    <i class="flaticon-quote"></i>
                                    <p><?php echo wp_kses_post( $value['feedback'] ); ?></p>

                                    <div class="info">
                                        <h3><?php echo esc_html( $value['name'] ); ?></h3>
                                        <span><?php echo esc_html( $value['designation'] ); ?></span>
                                    </div>
                                </div>
                            <?php endforeach; ?>
                        </div>
                    </div>
                </div>
            </div>
        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_DM_Feedback );
