<?php
/**
 * DM Partner Logo Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_DM_Partner_Logo extends Widget_Base {

	public function get_name() {
        return 'Guto_DMPartner_Logo';
    }

	public function get_title() {
        return esc_html__( 'DM Partner Logo', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-logo';
    }

	public function get_categories() {
        return [ 'guto-digital-marketing' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'partner_section',
			[
				'label' => esc_html__( 'Partner Logo Control', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

            $repeater = new Repeater();
            $repeater->add_control(
				'partner_logo',
				[
                    'label'       => esc_html__('Logo', 'guto-toolkit'),
                    'type'        => Controls_Manager::MEDIA,
                    'label_block' => true,
				]
            );
            $repeater->add_control(
                'logo_link',
                [
                    'label'       => esc_html__('Link', 'guto-toolkit'),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => '#',
                    'label_block' => true,
                ]
            );
            $this->add_control(
                'logos',
                [
                    'label'   => esc_html__( 'Add Partner Logos', 'guto-toolkit' ),
                    'type'   => Controls_Manager::REPEATER,
                    'fields' => $repeater->get_controls(),
                ]
            );

        $this->end_controls_section();

    }

	protected function render() {
        $settings = $this->get_settings_for_display();

        $slider = $settings['logos'];
        ?>
        <div class="container">
            <div class="dm-partner-slides owl-carousel owl-theme">
                <?php foreach($slider as $key => $item) : ?>
                    <?php if( $item['partner_logo']['url'] != '' ): ?>
                        <div class="single-partner">
                            <a href="<?php echo esc_url( $item['logo_link'] ); ?>"><img src="<?php echo esc_url( $item['partner_logo']['url'] ); ?>" alt="<?php echo esc_attr('logo', 'guto-toolkit'); ?>"></a>
                        </div>
                    <?php endif; ?>
                <?php endforeach; ?>
            </div>
        </div>

        <?php
	}


}

Plugin::instance()->widgets_manager->register( new Guto_DM_Partner_Logo );