<?php
/**
 * DM Pricing Widget
 */

namespace Elementor;
class Guto_DM_Pricing extends Widget_Base {

	public function get_name() {
        return 'Guto_DMPricing';
    }

	public function get_title() {
        return __( 'DM Pricing Table', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-price-table';
    }

	public function get_categories() {
        return [ 'guto-digital-marketing' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'Guto_Section',
			[
				'label' => esc_html__( 'Section Content', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
                'condition' => [
                    'card_style' => '1',
                ]
			]
        );

            $this->add_control(
                'top_title',
                [
                    'label' => esc_html__( 'Top Title', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__('Choose a Plan', 'guto-toolkit'),
                ]
            );

            $this->add_control(
                'title',
                [
                    'label' => esc_html__( 'Title', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXTAREA,
                    'default' => esc_html__('Our Pricing Plans', 'guto-toolkit'),
                ]
            );

            $this->add_control(
                'title_tag',
                [
                    'label' => esc_html__( 'Title Tag', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        'h1'         => esc_html__( 'h1', 'guto-toolkit' ),
                        'h2'         => esc_html__( 'h2', 'guto-toolkit' ),
                        'h3'         => esc_html__( 'h3', 'guto-toolkit' ),
                        'h4'         => esc_html__( 'h4', 'guto-toolkit' ),
                        'h5'         => esc_html__( 'h5', 'guto-toolkit' ),
                        'h6'         => esc_html__( 'h6', 'guto-toolkit' ),
                    ],
                    'default' => 'h3',
                ]
            );
            $this->add_control(
                'content',
                [
                    'label' => esc_html__( 'Content', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXTAREA,
                    'default' => esc_html__('We Provide Best Services for Our Customers Based on Needs', 'guto-toolkit'),
                ]
            );
        $this->end_controls_section();

        // Pricing Controls
        $this->start_controls_section(
			'Guto_Pricing_Area',
			[
				'label' => esc_html__( 'Pricing Controls', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

            $this->add_control(
                'card_style',
                [
                    'label' => esc_html__( 'Choose Style', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        '1'   => esc_html__( 'Style One', 'guto-toolkit' ),
                        '2'   => esc_html__( 'Style Two', 'guto-toolkit' ),
                    ],
                    'default' => '1',
                ]
            );

            $this->add_control(
                'columns',
                [
                    'label' => esc_html__( 'Choose Columns', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        '1'   => esc_html__( '1', 'guto-toolkit' ),
                        '2'   => esc_html__( '2', 'guto-toolkit' ),
                        '3'   => esc_html__( '3', 'guto-toolkit' ),
                        '4'   => esc_html__( '4', 'guto-toolkit' ),
                    ],
                    'default' => '3',
                    'condition' => [
                        'card_style' => '1',
                    ]
                ]
            );

            $pricing_items = new Repeater();

            $pricing_items->add_control(
                'card_color',
                [
                    'label' => esc_html__( 'Card Text Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        'blue'       => esc_html__('Color One', 'guto-toolkit' ),
                        'orange'     => esc_html__('Color Two(Orange)', 'guto-toolkit' ),
                    ],
                ]
            );

            $pricing_items->add_control(
                'title',
                [
                    'label' => esc_html__( 'Title', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__('Basic', 'guto-toolkit'),
                ]
            );

            $pricing_items->add_control(
                'price',
                [
                    'label' => esc_html__( 'Price', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__('$99 ', 'guto-toolkit'),
                ]
            );

            $pricing_items->add_control(
                'price_suffix',
                [
                    'label' => esc_html__( 'Number Suffix', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__('/ Month', 'guto-toolkit'),
                ]
            );

            $pricing_items->add_control(
                'features',
                [
                    'label' => esc_html__( 'Features', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXTAREA,
                    'default' =>
                        '<li><i class="bx bx-check"></i> Audience Research</li>
                        <li><i class="bx bx-check"></i> Copywriting</li>
                        <li><i class="bx bx-check"></i> Google Analytics Tracking</li>
                        <li><i class="bx bx-check"></i> Monthly Reports</li>
                        <li><i class="bx bx-check"></i> Editorial Services</li>
                        <li><del><i class="bx bx-x"></i> Consultancy</del></li>
                        <li><del><i class="bx bx-x"></i> Digital Strategy</del></li>',
                ]
            );
            $pricing_items->add_control(
                'button',
                [
                    'label' => esc_html__( 'Button Text', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__('Get Started', 'guto-toolkit'),
                ]
            );

            $pricing_items->add_control(
                'button_link',
                [
                    'label' => esc_html__( 'Button Link', 'guto-toolkit' ),
                    'type' => Controls_Manager::URL,
                ]
            );

            $pricing_items->add_control(
                'is_popular_card',
                [
                    'label'        => __( 'Is Popular?', 'tovi-toolkit' ),
                    'type'         => Controls_Manager::SWITCHER,
                    'label_on'     => __( 'Yes', 'tovi-toolkit' ),
                    'label_off'    => __( 'No', 'tovi-toolkit' ),
                    'return_value' => 'yes',
                    'default'      => 'no',
                ]
            );
            $pricing_items->add_control(
                'popular_text',
                [
                    'label' => __('Popular Text', 'prine-toolkit'),
                    'type'  => Controls_Manager:: TEXT,
                    'condition' => [
                        'is_popular_card' => 'yes',
                    ]
                ]
            );

            $this->add_control(
                'list_items',
                [
                    'label' => esc_html__( 'Add Item', 'guto-toolkit' ),
                    'type' => Controls_Manager::REPEATER,
                    'fields' => $pricing_items->get_controls(),
                    'title_field' => '{{{ title }}}',
                ]
            );

            $this->add_control(
                'icon',
                [
                    'label' => esc_html__( 'Button Icons', 'guto-toolkit' ),
                    'type' => Controls_Manager::ICON,
                    'label_block' => true,
                    'options' => guto_toolkit_icons(),
                ]
            );
        $this->end_controls_section();

        $this->start_controls_section(
			'section_style',
			[
				'label' => esc_html__( 'Section Style', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'card_style' => '1',
                ]
			]
        );
            $this->add_group_control(
                Group_Control_Background::get_type(),
                [
                    'name'     => 'background',
                    'label'    => __( 'Section Background', 'guto-toolkit' ),
                    'types'    => [ 'classic', 'gradient'],
                    'selector' => '{{WRAPPER}} .dm-pricing-area',
                ]
            );

            $this->add_control(
                'sectop_title_color',
                [
                    'label' => esc_html__( 'Top Title Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .dm-pricing-content span' => 'color: {{VALUE}}',
                    ],
                    'separator' => 'before',
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'sectop_title_typography',
                    'label' => esc_html__( 'Top Title Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .dm-pricing-content span',
                ]
            );

            $this->add_control(
                'sec_title_color',
                [
                    'label' => esc_html__( 'Title Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .dm-pricing-content h3, .dm-pricing-content h1, .dm-pricing-content h2, .dm-pricing-content h4, .dm-pricing-content h5, .dm-pricing-content h6' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'sec_title_typography',
                    'label' => esc_html__( 'Title Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .dm-pricing-content h3, .dm-pricing-content h1, .dm-pricing-content h2, .dm-pricing-content h4, .dm-pricing-content h5, .dm-pricing-content h6',
                ]
            );

            $this->add_control(
                'sec_content_color',
                [
                    'label' => esc_html__( 'Content Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .dm-pricing-content p' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'sec_content_typography',
                    'label' => esc_html__( 'Content Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .dm-pricing-content p',
                ]
            );

        $this->end_controls_section();

        $this->start_controls_section(
			'pricing_plan_style',
			[
				'label' => esc_html__( 'Pricing Card Style', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
        );
			$this->add_control(
				'title_color',
				[
					'label' => esc_html__( 'Title Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .dm-pricing-box .pricing-header h3' => 'color: {{VALUE}}',
					],
				]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'title_typography',
                    'label' => esc_html__( 'Title Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .dm-pricing-box .pricing-header h3',
                ]
            );

            $this->add_control(
				'price_color',
				[
					'label' => esc_html__( 'Price Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .dm-pricing-box .price' => 'color: {{VALUE}}',
					],
				]
			);

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'price_typography',
                    'label' => esc_html__( 'Price Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .dm-pricing-box .price',
                ]
            );

            $this->add_control(
				'suf_color',
				[
					'label' => esc_html__( 'Price Suffix Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .dm-pricing-box .price span' => 'color: {{VALUE}}',
					],
				]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'suf_typography',
                    'label' => esc_html__( 'Price Suffix Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .dm-pricing-box .price span',
                ]
            );

            $this->add_control(
				'content_color',
				[
					'label' => esc_html__( 'Feature Lists Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .dm-pricing-box .pricing-features li' => 'color: {{VALUE}}',
					],
				]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'content_typography',
                    'label' => esc_html__( 'Feature Lists Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .dm-pricing-box .pricing-features li',
                ]
            );

            $this->add_control(
				'popular_text_bgcolor',
				[
					'label' => esc_html__( 'Popular Text BG Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .dm-pricing-box .dm-popular-tag' => 'background: {{VALUE}}',
					],
				]
            );

            $this->add_control(
				'popular_text_color',
				[
					'label' => esc_html__( 'Popular Text Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .dm-pricing-box .dm-popular-tag' => 'color: {{VALUE}}',
					],
				]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'popular_text_typography',
                    'label' => esc_html__( 'Popular Text Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .dm-pricing-box .dm-popular-tag',
                ]
            );

        $this->end_controls_section();

    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        // Card Columns
        $columns = $settings['columns'];
        if ($columns == '1') {
            $column = 'col-lg-12 col-md-6';
        }elseif ($columns == '2') {
            $column = 'col-lg-6 col-md-6';
        }elseif ($columns == '4') {
            $column = 'col-lg-3 col-md-6';
        }else {
            $column = 'col-lg-4 col-md-6';
        }
        ?>

        <?php if( $settings['card_style']  == '1' ): ?>
            <div class="dm-pricing-area pt-100 pb-100">
                <div class="container">
                    <div class="row align-items-center">
                        <div class="col-lg-4 col-md-12">
                            <?php if( !empty( $settings['top_title'] || $settings['title'] || $settings['content'] ) ) : ?>
                                <div class="dm-pricing-content">
                                    <?php if($settings['top_title'] != '' ): ?>
                                        <span><?php echo wp_kses_post( $settings['top_title'] ); ?></span>
                                    <?php endif; ?>

                                    <<?php echo esc_attr( $settings['title_tag'] ); ?>>
                                        <?php echo wp_kses_post( $settings['title'] ); ?>
                                    </<?php echo esc_attr( $settings['title_tag'] ); ?>>

                                    <?php echo wp_kses_post( $settings['content'] ); ?>
                                </div>
                            <?php endif; ?>
                        </div>

                        <div class="col-lg-8 col-md-12">
                            <div class="dm-pricing-slides owl-carousel owl-theme">
                                <?php foreach( $settings['list_items'] as $item ) :
                                    if( $item['card_color'] == 'orange'):
                                        $style_class = "style-two";
                                    else:
                                        $style_class = "";
                                    endif;
                                ?>
                                    <div class="dm-pricing-box <?php echo esc_attr( $style_class ); ?>">
                                        <div class="pricing-header">
                                            <h3><?php echo esc_html( $item['title'] ); ?></h3>
                                        </div>

                                        <div class="price"><?php echo esc_html( $item['price'] ); ?>
                                            <span><?php echo esc_html( $item['price_suffix'] ); ?></span>
                                        </div>

                                        <ul class="pricing-features">
                                            <?php echo wp_kses_post($item['features']); ?>
                                        </ul>

                                        <?php if( $item['button'] != '' ) : ?>
                                            <div class="pricing-btn">
                                                <a href="<?php echo esc_url( $item['button_link']['url'] ); ?>" class="dm-default-btn"><?php echo esc_html( $item['button'] ); ?> <i class='<?php echo esc_attr($settings['icon']); ?>'></i></a>
                                            </div>
                                        <?php endif; ?>

                                        <?php if ( $item['is_popular_card'] == 'yes' ) :
                                            if( !empty( $item['popular_text'] ) ) : ?>
                                                <div class="dm-popular-tag"><?php echo esc_html( $item['popular_text'] ); ?></div>
                                            <?php endif;
                                        endif; ?>
                                    </div>
                                <?php endforeach; ?>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        <?php else: ?>
            <div class="container">
                <div class="row justify-content-center">
                    <?php foreach( $settings['list_items'] as $item ) : ?>
                    <div class="<?php echo esc_attr( $column ); ?>">
                        <div class="dm-pricing-box">
                            <div class="pricing-header">
                                <h3><?php echo esc_html( $item['title'] ); ?></h3>
                            </div>
                            <div class="price"><?php echo esc_html( $item['price'] ); ?>
                                <span><?php echo esc_html( $item['price_suffix'] ); ?></span>
                            </div>

                            <ul class="pricing-features">
                                <?php echo wp_kses_post($item['features']); ?>
                            </ul>

                            <?php if( $item['button'] != '' ) : ?>
                                <div class="pricing-btn">
                                    <a href="<?php echo esc_url( $item['button_link']['url'] ); ?>" class="dm-default-btn"><?php echo esc_html( $item['button'] ); ?> <i class='<?php echo esc_attr($settings['icon']); ?>'></i></a>
                                </div>
                            <?php endif; ?>

                            <?php if ( $item['is_popular_card'] == 'yes' ) :
                                if( !empty( $item['popular_text'] ) ) : ?>
                                    <div class="dm-popular-tag"><?php echo esc_html( $item['popular_text'] ); ?></div>
                                <?php endif;
                            endif; ?>
                        </div>
                    </div>
                    <?php endforeach; ?>
                </div>
            </div>
        <?php endif;
    }



}

Plugin::instance()->widgets_manager->register( new Guto_DM_Pricing );