<?php
/**
 * DM Privacy Policy Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_DM_Privacy_TC extends Widget_Base {

	public function get_name() {
        return 'DM Privacy Policy';
    }

	public function get_title() {
        return esc_html__( 'DM Privacy Policy', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-handle';
    }

	public function get_categories() {
        return [ 'guto-digital-marketing' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'Guto_Section',
			[
				'label' => esc_html__( 'Guto Section', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

            $this->add_control(
                'sec_img',
                [
                    'label' => esc_html__( 'Image', 'guto-toolkit' ),
                    'type' => Controls_Manager::MEDIA,
                    'label_block' => true,
                ]
            );

            $this->add_control(
                'content',
                [
                    'label' => esc_html__( 'Content', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXTAREA,
                ]
            );
        $this->end_controls_section();

        $this->start_controls_section(
			'section_style',
			[
				'label' => esc_html__( 'Style', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
        );
            $this->add_control(
                'title_color',
                [
                    'label' => esc_html__( 'Title Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .dm-terms-of-service-content h3' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'title_typography',
                    'label' => esc_html__( 'Title Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .dm-terms-of-service-content h3',
                ]
            );

            $this->add_control(
                'content_color',
                [
                    'label' => esc_html__( 'Content Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .dm-terms-of-service-content p, .dm-terms-of-service-content ol li, .dm-terms-of-service-content ul li, .dm-terms-of-service-content ol li, .dm-terms-of-service-content ol li' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'con_typography',
                    'label' => esc_html__( 'Content Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .dm-terms-of-service-content p, .dm-terms-of-service-content ol li, .dm-terms-of-service-content ul li, .dm-terms-of-service-content ol li, .dm-terms-of-service-content ol li',
                ]
            );

        $this->end_controls_section();

    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        ?>
            <div class="dm-terms-of-service-area ptb-100">
                <div class="container">
                    <div class="dm-terms-of-service-content">
                        <?php if( $settings['sec_img']['url'] != '' ): ?>
                            <img src="<?php echo esc_url( $settings['sec_img']['url'] ); ?>" alt="<?php echo esc_attr('image', 'guto-toolkit'); ?>">
                        <?php endif; ?>

                        <?php echo wp_kses_post( $settings['content'] ); ?>
                    </div>
                </div>
            </div>
        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_DM_Privacy_TC );