<?php
/**
 * DM Service Details Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_DMSEO_Area extends Widget_Base {

	public function get_name() {
        return 'DM_SEO_Area';
    }

	public function get_title() {
        return esc_html__( 'DM SEO Area', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-info-box';
    }

	public function get_categories() {
        return [ 'guto-digital-marketing' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'Guto_About_Area',
			[
				'label' => esc_html__( 'Guto SEO Area', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

            $this->add_control(
                'seo_style',
                [
                    'label' => esc_html__( 'Choose Style', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        '1'   => esc_html__( 'Style One', 'guto-toolkit' ),
                        '2'   => esc_html__( 'Style Two', 'guto-toolkit' ),
                        '3'   => esc_html__( 'Style Three', 'guto-toolkit' ),
                    ],
                    'default' => '1',
                ]
            );

            $this->add_control(
                'title',
                [
                    'label' => esc_html__( 'Title', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__('What is SEO?', 'guto-toolkit'),
                ]
            );

            $this->add_control(
                'title_tag',
                [
                    'label' => esc_html__( 'Title Tag', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        'h1'         => esc_html__( 'h1', 'guto-toolkit' ),
                        'h2'         => esc_html__( 'h2', 'guto-toolkit' ),
                        'h3'         => esc_html__( 'h3', 'guto-toolkit' ),
                        'h4'         => esc_html__( 'h4', 'guto-toolkit' ),
                        'h5'         => esc_html__( 'h5', 'guto-toolkit' ),
                        'h6'         => esc_html__( 'h6', 'guto-toolkit' ),
                    ],
                    'default' => 'h3',
                ]
            );

            $this->add_control(
                'content',
                [
                    'label' => esc_html__( 'Content', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXTAREA,
                    'default' => esc_html__('Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Quis ipsum suspendisse ultrices gravida.', 'guto-toolkit'),
                ]
            );

            $this->add_control(
                'image',
                [
                    'label' => esc_html__( 'Image', 'guto-toolkit' ),
                    'type'	 => Controls_Manager::MEDIA,
                ]
            );
        $this->end_controls_section();

        $this->start_controls_section(
			'section_style',
			[
				'label' => esc_html__( 'Style', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
        );
            $this->add_control(
                'title_color',
                [
                    'label' => esc_html__( 'Title Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .dm-seo-content h3, .dm-seo-content h1, .dm-seo-content h2, .dm-seo-content h4, .dm-seo-content h5, .dm-seo-content h6, .dm-search-content h3, .dm-search-content h1, .dm-search-content h2, .dm-search-content h4, .dm-search-content h5, .dm-search-content h6, .dm-copywriting-content h3, .dm-copywriting-content h1, .dm-copywriting-content h2, .dm-copywriting-content h4, .dm-copywriting-content h5, .dm-copywriting-content h6' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'title_typography',
                    'label' => esc_html__( 'Title Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .dm-seo-content h3, .dm-seo-content h1, .dm-seo-content h2, .dm-seo-content h4, .dm-seo-content h5, .dm-seo-content h6, .dm-search-content h3, .dm-search-content h1, .dm-search-content h2, .dm-search-content h4, .dm-search-content h5, .dm-search-content h6, .dm-copywriting-content h3, .dm-copywriting-content h1, .dm-copywriting-content h2, .dm-copywriting-content h4, .dm-copywriting-content h5, .dm-copywriting-content h6',
                ]
            );

            $this->add_control(
                'content_color',
                [
                    'label' => esc_html__( 'Content Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .dm-seo-content p, .dm-seo-content .seo-list li, .dm-search-content p, .dm-copywriting-content p, .dm-search-content ul li, .dm-copywriting-content ul li' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'content_typography',
                    'label' => esc_html__( 'Content Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .dm-seo-content p, .dm-seo-content .seo-list li, .dm-search-content p, .dm-copywriting-content p, .dm-search-content ul li, .dm-copywriting-content ul li',
                ]
            );

        $this->end_controls_section();
    }

	protected function render() {

        $settings = $this->get_settings_for_display(); ?>

        <?php if($settings['seo_style'] == '1') : ?>
            <div class="container">
                <div class="row align-items-center">
                    <?php if( $settings['image']['url'] != '' ) : ?>
                        <div class="col-lg-6 col-md-12">
                            <div class="dm-seo-image">
                                <img src="<?php echo esc_url($settings['image']['url']); ?>" alt="<?php esc_attr_e('Image', 'guto-toolkit'); ?>">
                            </div>
                        </div>
                        <div class="col-lg-6 col-md-12">
                    <?php else : ?>
                        <div class="col-lg-12 col-md-12">
                    <?php endif; ?>

                        <div class="dm-seo-content">
                            <<?php echo esc_attr( $settings['title_tag'] ); ?>><?php echo wp_kses_post( $settings['title'] ); ?></<?php echo esc_attr( $settings['title_tag'] ); ?>>

                            <?php echo wp_kses_post( $settings['content'] ); ?>

                        </div>
                    </div>

                </div>
            </div>
        <?php elseif($settings['seo_style'] == '2') : ?>
            <div class="container">
                <div class="row align-items-center">
                <?php if( $settings['image']['url'] != '' ) : ?>
                    <div class="col-lg-6 col-md-12">
                <?php else : ?>
                    <div class="col-lg-12 col-md-12">
                <?php endif; ?>
                        <div class="dm-search-content">
                            <<?php echo esc_attr( $settings['title_tag'] ); ?>><?php echo wp_kses_post( $settings['title'] ); ?></<?php echo esc_attr( $settings['title_tag'] ); ?>>

                            <?php echo wp_kses_post( $settings['content'] ); ?>
                        </div>
                    </div>

                    <?php if( $settings['image']['url'] != '' ) : ?>
                    <div class="col-lg-6 col-md-12">
                        <div class="dm-search-image">
                            <img src="<?php echo esc_url($settings['image']['url']); ?>" alt="<?php esc_attr_e('Image', 'guto-toolkit'); ?>">
                        </div>
                    </div>
                    <?php endif; ?>
                </div>
            </div>
        <?php else: ?>
            <div class="container">
                <div class="row align-items-center">
                    <?php if( $settings['image']['url'] != '' ) : ?>
                    <div class="col-lg-5 col-md-12">
                        <div class="dm-copywriting-image">
                            <img src="<?php echo esc_url($settings['image']['url']); ?>" alt="<?php esc_attr_e('Image', 'guto-toolkit'); ?>">
                        </div>
                    </div>
                    <div class="col-lg-7 col-md-12">
                    <?php else : ?>
                    <div class="col-lg-12 col-md-12">
                    <?php endif; ?>
                        <div class="dm-copywriting-content">
                            <<?php echo esc_attr( $settings['title_tag'] ); ?>><?php echo wp_kses_post( $settings['title'] ); ?></<?php echo esc_attr( $settings['title_tag'] ); ?>>

                            <?php echo wp_kses_post( $settings['content'] ); ?>
                        </div>
                    </div>
                </div>
            </div>
        <?php endif; ?>

        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_DMSEO_Area );