<?php
/**
 * DM Services Widget
 */

namespace Elementor;
class Guto_DM_Services extends Widget_Base {

	public function get_name() {
        return 'DM_Services';
    }

	public function get_title() {
        return esc_html__( 'DM Services', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-tools';
    }

	public function get_categories() {
        return [ 'guto-digital-marketing' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'services_section',
			[
				'label' => esc_html__( 'Services', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

            $this->add_control(
                'show_section',
                [
                    'label'        => __( 'Section Hide/Show?', 'guto-toolkit' ),
                    'type'         => Controls_Manager::SWITCHER,
                    'label_on'     => __( 'Show', 'guto-toolkit' ),
                    'label_off'    => __( 'Hide', 'guto-toolkit' ),
                    'return_value' => 'yes',
                    'default'      => 'yes',
                ]
            );

            $this->add_control(
                'card_style',
                [
                    'label' => esc_html__( 'Choose Style', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        '1'   => esc_html__( 'Style One', 'guto-toolkit' ),
                        '2'   => esc_html__( 'Style Two', 'guto-toolkit' ),
                    ],
                    'default' => '1',
                ]
            );

            $this->add_control(
                'columns',
                [
                    'label' => esc_html__( 'Choose Columns', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        '1'   => esc_html__( '1', 'guto-toolkit' ),
                        '2'   => esc_html__( '2', 'guto-toolkit' ),
                        '3'   => esc_html__( '3', 'guto-toolkit' ),
                        '4'   => esc_html__( '4', 'guto-toolkit' ),
                    ],
                    'default' => '4',
                ]
            );

            $this->add_control(
                'cat',
                [
                    'label' => __( 'Choose Category', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => guto_toolkit_get_page_services_cat_el(),
                ]
            );

            $this->add_control(
                'order',
                [
                    'label' => esc_html__( 'Services Order By', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        'DESC'      => esc_html__( 'DESC', 'guto-toolkit' ),
                        'ASC'       => esc_html__( 'ASC', 'guto-toolkit' ),
                    ],
                    'default' => 'DESC',
                ]
            );

            $this->add_control(
                'count',
                [
                    'label' => esc_html__( 'Post Per Page', 'guto-toolkit' ),
                    'type' => Controls_Manager::NUMBER,
                    'default' => 4,
                ]
            );
        $this->end_controls_section();

        $this->start_controls_section(
			'Guto_DM_section_Area',
			[
				'label' => esc_html__( 'Section Controls', 'guto-toolkit' ),
				'tab' 	=> Controls_Manager::TAB_CONTENT,
                'condition' => [
                    'show_section' => 'yes',
                ]
			]
		);
            $this->add_control(
                'top_title',
                [
                    'label' 	=> esc_html__( 'Top Title', 'guto-toolkit' ),
                    'type' 		=> Controls_Manager::TEXTAREA,
                    'default' 	=> esc_html__('About Guto Marketing', 'guto-toolkit'),
                ]
            );
			$this->add_control(
				'title',
				[
					'label' 	=> esc_html__( 'Title', 'guto-toolkit' ),
					'type' 		=> Controls_Manager::TEXTAREA,
					'default' 	=> esc_html__('We and Our Team Have been Working Successfully in Digital Marketing for Over 25 Years', 'guto-toolkit'),
				]
			);

			$this->add_control(
                'title_tag',
                [
                    'label' 	=> esc_html__( 'Title Tag', 'guto-toolkit' ),
                    'type' 		=> Controls_Manager::SELECT,
                    'options' 	=> [
                        'h1'         => esc_html__( 'h1', 'guto-toolkit' ),
                        'h2'         => esc_html__( 'h2', 'guto-toolkit' ),
                        'h3'         => esc_html__( 'h3', 'guto-toolkit' ),
                        'h4'         => esc_html__( 'h4', 'guto-toolkit' ),
                        'h5'         => esc_html__( 'h5', 'guto-toolkit' ),
                        'h6'         => esc_html__( 'h6', 'guto-toolkit' ),
                    ],
                    'default' => 'h2',
                ]
            );

            $this->add_control(
				'button_icon',
				[
					'label' => esc_html__( 'Button Icon', 'guto-toolkit' ),
                    'type' => Controls_Manager::ICON,
                    'label_block' => true,
                    'options' => guto_toolkit_icons(),
				]
            );

			$this->add_control(
				'button_text',
				[
					'label' 	=> esc_html__( 'Button Text', 'guto-toolkit' ),
					'type' 		=> Controls_Manager::TEXT,
					'default' 	=> esc_html__('All Services', 'guto-toolkit'),
				]
            );

            $this->add_control(
                'link_type',
                [
                    'label' 		=> esc_html__( 'Button Link Type', 'guto-toolkit' ),
                    'type' 			=> Controls_Manager::SELECT,
                    'label_block' 	=> true,
                    'options' => [
                        '1'  	=> esc_html__( 'Link To Page', 'guto-toolkit' ),
                        '2' 	=> esc_html__( 'External Link', 'guto-toolkit' ),
                    ],
                    'default' => '2'
                ]
            );

            $this->add_control(
                'link_to_page',
                [
                    'label' 		=> esc_html__( 'Button Link Page', 'guto-toolkit' ),
                    'type' 			=> Controls_Manager::SELECT,
                    'label_block' 	=> true,
                    'options' 		=> guto_toolkit_get_page_as_list(),
                    'condition' => [
                        'link_type' => '1',
                    ]
                ]
            );

            $this->add_control(
                'ex_link',
                [
                    'label'		=> esc_html__('Button External Link', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: URL,
                    'show_external' => true,
                    'default' => [
                        'url' => '#',
                        'is_external' => true,
                        'nofollow' => true,
                    ],
                    'condition' => [
                        'link_type' => '2',
                    ]
                ]
            );
        $this->end_controls_section();

        $this->start_controls_section(
			'sec_style',
			[
				'label' => esc_html__( 'Section Style', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'show_section' => 'yes',
                ]
			]
		);
            $this->add_control(
                'top_title_color',
                [
                    'label' => esc_html__( 'Top Title Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .dm-services-section-title .dm-services-title span, .dm-section-title span' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'top_title_typography',
                    'label' => esc_html__( 'Top Title Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .dm-services-section-title .dm-services-title span, .dm-section-title span',
                ]
            );
			$this->add_control(
				'title_color',
				[
					'label' => esc_html__( 'Title Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .dm-services-section-title .dm-services-title h2, .dm-services-section-title .dm-services-title h1, .dm-services-section-title .dm-services-title h3, .dm-services-section-title .dm-services-title h4, .dm-services-section-title .dm-services-title h5, .dm-services-section-title .dm-services-title h6, .dm-section-title h2, .dm-section-title h1, .dm-section-title h3, .dm-section-title h4, .dm-section-title h5, .dm-section-title h6' => 'color: {{VALUE}}',
					],
				]
			);
			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'title_typography',
                    'label' => esc_html__( 'Title Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .dm-services-section-title .dm-services-title h2, .dm-services-section-title .dm-services-title h1, .dm-services-section-title .dm-services-title h3, .dm-services-section-title .dm-services-title h4, .dm-services-section-title .dm-services-title h5, .dm-services-section-title .dm-services-title h6, .dm-section-title h2, .dm-section-title h1, .dm-section-title h3, .dm-section-title h4, .dm-section-title h5, .dm-section-title h6',
                ]
            );
            $this->add_control(
				'button_color',
				[
					'label' => esc_html__( 'Button Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .dm-default-btn' => 'color: {{VALUE}}',
					],
				]
			);
			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'btn_typography',
                    'label' => esc_html__( 'Button Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .dm-default-btn',
                ]
            );
        $this->end_controls_section();

        $this->start_controls_section(
			'service_style',
			[
				'label' => esc_html__( 'Posts Style', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
        );
            $this->add_control(
                'icon_color',
                [
                    'label' => esc_html__( 'Icon Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .dm-single-services .icon i' => 'color: {{VALUE}}',
                    ],
                ]
            );
            $this->add_control(
                'post_title_color',
                [
                    'label' => esc_html__( 'Title Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .dm-single-services h3 a' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'posttitle_typography',
                    'label' => esc_html__( 'Title Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .dm-single-services h3 a',
                ]
            );

            $this->add_control(
                'content_color',
                [
                    'label' => esc_html__( 'Content Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .dm-single-services p' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'content_typography',
                    'label' => esc_html__( 'Content Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .dm-single-services p',
                ]
            );

        $this->end_controls_section();

    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        // Card Columns
        $columns = $settings['columns'];
        if ($columns == '1') {
            $column = 'col-lg-12 col-md-6';
        }elseif ($columns == '2') {
            $column = 'col-lg-6 col-md-6';
        }elseif ($columns == '3') {
            $column = 'col-lg-4 col-md-6';
        }else {
            $column = 'col-lg-3 col-md-6';
        }

        // Services Query
        if( $settings['cat'] != '' ) {
            $args = array(
                'post_type'     => 'services',
                'posts_per_page'=> $settings['count'],
                'order'         => $settings['order'],
                'tax_query'     => array(
                    array(
                        'taxonomy'      => 'service_cat',
                        'field'         => 'slug',
                        'terms'         => $settings['cat'],
                        'hide_empty'    => false
                    )
                )
            );
        } else {
            $args = array(
                'post_type'         => 'services',
                'posts_per_page'    => $settings['count'],
                'order'             => $settings['order']
            );
        }
        $services_array = new \WP_Query( $args );


        // Get Button Link
        if($settings['link_type'] == 1){
            $link = get_page_link( $settings['link_to_page'] );
        } elseif($settings['link_type'] == 2) {
            $link = $settings['ex_link']['url'];
            $target = $settings['ex_link']['is_external'] ? ' target="_blank"' : '';
		    $nofollow = $settings['ex_link']['nofollow'] ? ' rel="nofollow"' : '';
        }

        $button_text = $settings['button_text'];

        ?>

        <?php if( $settings['card_style']  == '1' ) : ?>
            <div class="container">
                <?php if ( $settings['show_section'] == 'yes' ) : ?>
                    <div class="dm-services-section-title">
                        <div class="row align-items-center">
                            <?php if( !empty( $settings['top_title'] || $settings['title'] ) ): ?>
                                <div class="col-lg-7 col-md-12">
                                    <div class="dm-services-title">
                                        <span><?php echo esc_html( $settings['top_title'] ); ?></span>

                                        <<?php echo esc_attr( $settings['title_tag'] ); ?>>
                                            <?php echo esc_html( $settings['title'] ); ?>
                                        </<?php echo esc_attr( $settings['title_tag'] ); ?>>
                                    </div>
                                </div>
                            <?php endif; ?>

                            <?php if( $button_text != '' ): ?>
                                <div class="col-lg-5 col-md-12">
                                    <?php if($settings['link_type'] == 1) : ?>
                                        <div class="dm-services-btn">
                                            <a href="<?php echo esc_url( $link ); ?>" class="dm-default-btn"><?php echo esc_html( $button_text ); ?> <i class="<?php echo esc_attr( $settings['button_icon'] ); ?>"></i></a>
                                        </div>
                                    <?php elseif($settings['link_type'] == 2) :
                                        echo '<div class="dm-services-btn"><a href="' .  $link . '" class="dm-default-btn" ' . $target . $nofollow . '> ' . $button_text . ' <i class="'.$settings['button_icon'].'"></i> </a></div>';
                                    endif; ?>
                                </div>
                            <?php endif; ?>
                        </div>
                    </div>
                <?php endif; ?>

                <div class="row justify-content-center">
                    <?php $i = 1; while($services_array->have_posts()): $services_array->the_post();
                        if( $i == 1 ) :
                            $color_cls = 'style-one';
                        elseif( $i == 2 ) :
                            $color_cls = 'style-two';
                        elseif( $i == 3 ) :
                            $color_cls = 'style-three';
                        else:
                            $color_cls = 'style-four';
                        endif;

                        // Card Icon
                        if ( defined( 'FW' ) ) {
                            $icon = fw_get_db_post_option( get_the_ID(), 'services_icon' );
                        }else{
                            $icon = '';
                        }
                    ?>
                        <div class="<?php echo esc_attr( $column ); ?>">
                            <div class="dm-single-services <?php echo esc_attr( $color_cls ); ?>">
                                <?php if( $icon != '' ): ?>
                                    <div class="icon">
                                        <i class="<?php echo esc_attr($icon); ?>"></i>
                                    </div>
                                <?php endif; ?>

                                <h3><a href="<?php the_permalink(); ?>"><?php the_title(); ?></h3>
                                <p><?php the_excerpt(); ?></p>

                                <div class="dm-plus-btn">
                                    <a href="<?php the_permalink(); ?>"><i class="bx bx-plus"></i></a>
                                </div>
                            </div>
                        </div>
                    <?php $i++; endwhile; ?>
                    <?php wp_reset_query(); ?>
                </div>
            </div>
        <?php else: ?>
            <div class="container">
                <?php if ( $settings['show_section'] == 'yes' ) : ?>
                    <?php if( !empty( $settings['top_title'] || $settings['title'] ) ): ?>
                        <div class="dm-section-title">
                            <span><?php echo esc_html( $settings['top_title'] ); ?></span>

                            <<?php echo esc_attr( $settings['title_tag'] ); ?>>
                                <?php echo esc_html( $settings['title'] ); ?>
                            </<?php echo esc_attr( $settings['title_tag'] ); ?>>
                        </div>
                    <?php endif; ?>
                <?php endif; ?>

                <div class="row justify-content-center">
                    <?php $i = 1; while($services_array->have_posts()): $services_array->the_post();
                        if( $i == 2 ) :
                            $color_cls = 'bg-e5e5ff';
                        elseif( $i == 3 ) :
                            $color_cls = 'bg-dff4ff';
                        elseif( $i == 4 ) :
                            $color_cls = 'bg-e7f1ff';
                        elseif( $i == 5 ) :
                            $color_cls = 'bg-fff3ed';
                        elseif( $i == 6 ) :
                            $color_cls = 'bg-ecf8ea';
                        else:
                            $color_cls = '';
                        endif;

                        // Card Icon
                        if ( defined( 'FW' ) ) {
                            $icon = fw_get_db_post_option( get_the_ID(), 'services_icon' );
                        }else{
                            $icon = '';
                        }
                    ?>
                        <div class="<?php echo esc_attr( $column ); ?>">
                            <div class="dm-single-services <?php echo esc_attr( $color_cls ); ?>">
                                <?php if( $icon != '' ): ?>
                                    <div class="icon">
                                        <i class="<?php echo esc_attr($icon); ?>"></i>
                                    </div>
                                <?php endif; ?>
                                <h3><a href="<?php the_permalink(); ?>"><?php the_title(); ?></h3>
                                <p><?php the_excerpt(); ?></p>

                                <div class="dm-plus-btn">
                                    <a href="<?php the_permalink(); ?>"><i class="bx bx-plus"></i></a>
                                </div>
                            </div>
                        </div>
                    <?php $i++; endwhile; ?>
                    <?php wp_reset_query(); ?>
                </div>
            </div>
        <?php endif; ?>

        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_DM_Services );