<?php
/**
 * Feedback Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_Feedback extends Widget_Base {

	public function get_name() {
        return 'Feedback';
    }

	public function get_title() {
        return esc_html__( 'Feedback', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-testimonial';
    }

	public function get_categories() {
        return [ 'guto-elements' ];
    }

	protected function register_controls() {

        $this->start_controls_section(
			'content_section',
			[
				'label' => esc_html__( 'Content', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

        $this->add_control(
            'feedback_style',
            [
                'label' => esc_html__( 'Feedback Style', 'guto-toolkit' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    '1'         => esc_html__( 'Style One', 'guto-toolkit' ),
                    '2'         => esc_html__( 'Style Two', 'guto-toolkit' ),
                ],
                'default' => '1',
            ]
        );

        $this->add_control(
            'top_title',
            [
                'label' => esc_html__( 'Top Title', 'guto-toolkit' ),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('TESTIMONIALS', 'guto-toolkit'),
                'condition' => [
                    'feedback_style' => '1',
                ]
            ]
        );

        $this->add_control(
            'title',
            [
                'label' => esc_html__( 'Title', 'guto-toolkit' ),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('What Clients Say About Us', 'guto-toolkit'),
            ]
        );

        $this->add_control(
            'feedback_section_desc',
            [
                'label' => esc_html__( 'Description', 'guto-toolkit' ),
                'type' => Controls_Manager::TEXTAREA,
                'default' => esc_html__('Lorem ipsum dolor, sit amet consectetur adipisicing elit. Quam ratione excepturi officia adipisci sapiente porro aliquam modi, velit corporis accusantium. Quo ducimus quia', 'guto-toolkit'),
                'condition' => [
                    'feedback_style' => '2',
                ]
            ]
        );

        $this->add_control(
            'title_tag',
            [
                'label' => esc_html__( 'Title Tag', 'guto-toolkit' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'h1'         => esc_html__( 'h1', 'guto-toolkit' ),
                    'h2'         => esc_html__( 'h2', 'guto-toolkit' ),
                    'h3'         => esc_html__( 'h3', 'guto-toolkit' ),
                    'h4'         => esc_html__( 'h4', 'guto-toolkit' ),
                    'h5'         => esc_html__( 'h5', 'guto-toolkit' ),
                    'h6'         => esc_html__( 'h6', 'guto-toolkit' ),
                ],
                'default' => 'h2',
            ]
        );

        $this->add_control(
            'feedback_featured_img',
            [
                'label' => esc_html__( 'Featured Image', 'guto-toolkit' ),
                'type' => Controls_Manager::MEDIA,
                'show_label' => true,
                'condition' => [
                    'feedback_style' => '2',
                ]
            ]
        );

        $this->add_control(
            'feedback_shape_img',
            [
                'label' => esc_html__( 'Shape Image', 'guto-toolkit' ),
                'type' => Controls_Manager::MEDIA,

                'show_label' => true,
                'condition' => [
                    'feedback_style' => '2',
                ]
            ]
        );

        $this->add_control(
            'feedback_video_link',
            [
                'label' => esc_html__( 'Video Link', 'guto-toolkit' ),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('https://www.youtube.com/watch?v=hWkYtZxpQUo', 'guto-toolkit'),
            ]
        );

		$this->add_control(
            'guto_feedback_items',
            [
                'label' => esc_html__('Slider Item', 'guto-toolkit'),
                'type' => Controls_Manager::REPEATER,
                'default' => [
                    [ 'name' => esc_html__(' Item #1', 'guto-toolkit') ],

                ],
                'fields' => [
                    [
                        'name'  => 'image',
                        'label' => esc_html__( 'Image', 'guto-toolkit' ),
                        'type' => Controls_Manager::MEDIA,
                    ],
                    [
                        'name' => 'name',
                        'label' => esc_html__('Name', 'guto-toolkit'),
                        'type' => Controls_Manager::TEXT,
                        'default' => esc_html__('Olivar Lucy', 'guto-toolkit'),
                        'label_block' => true,
                    ],
                    [
                        'name' => 'designation',
                        'label' => esc_html__('Designation', 'guto-toolkit'),
                        'type' => Controls_Manager::TEXT,
                        'default' => esc_html__('Designer', 'guto-toolkit'),
                        'label_block' => true,
                    ],
                    [
                        'name' => 'feedback',
                        'label' => esc_html__('Feedback Content', 'guto-toolkit'),
                        'type' => Controls_Manager::TEXTAREA,
                        'default' => esc_html__('Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Quis ipsum suspendisse ultrices gravida. Risus commodo viverra maecenas accumsan lacus vel facilisis.', 'guto-toolkit'),
                        'label_block' => true,
                    ],
                ],
            ]
        );

    $this->end_controls_section();

    $this->start_controls_section(
        'style',
        [
            'label' => esc_html__( 'Style', 'guto-toolkit' ),
            'tab' => Controls_Manager::TAB_STYLE,
        ]
    );

        $this->add_control(
            'bg_color',
            [
                'label' => esc_html__( 'Section Background Color', 'guto-toolkit' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .testimonials-area.bg-f3f3f4, .os-clients-area' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'top_title_color',
            [
                'label' => esc_html__( 'Top Title Color', 'guto-toolkit' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .section-title .sub-title' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'feedback_style' => '1',
                ]
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'top_title_typography',
                'label' => esc_html__( 'Top Title Typography', 'guto-toolkit' ),
                'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                'selector' => '{{WRAPPER}} .section-title .sub-title',
                'condition' => [
                    'feedback_style' => '1',
                ]
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label' => esc_html__( 'Title Color', 'guto-toolkit' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .section-title h1, .section-title h2, .section-title h3, .section-title h4, .section-title h5, .section-title h6' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'feedback_style' => '1',
                ]
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'title_typography',
                'label' => esc_html__( 'Title Typography', 'guto-toolkit' ),
                'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                'selector' => '{{WRAPPER}} .section-title h1, .section-title h2, .section-title h3, .section-title h4, .section-title h5, .section-title h6',
                'condition' => [
                    'feedback_style' => '1',
                ]
            ]
        );

        $this->add_control(
            'feedback_color',
            [
                'label' => esc_html__( 'Feedback Color', 'guto-toolkit' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .single-testimonials-item p, .os-clients-area .os-single-clients p' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'feedback_typography',
                'label' => esc_html__( 'Feedback Typography', 'guto-toolkit' ),
                'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                'selector' => '{{WRAPPER}} .single-testimonials-item p, .os-clients-area .os-single-clients p',
            ]
        );

        $this->add_control(
            'name_color',
            [
                'label' => esc_html__( 'Name Color', 'guto-toolkit' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .single-testimonials-item h3, .os-clients-area .os-single-clients h3' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'name_typography',
                'label' => esc_html__( 'Name Typography', 'guto-toolkit' ),
                'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                'selector' => '{{WRAPPER}} .single-testimonials-item h3, .os-clients-area .os-single-clients h3',
            ]
        );

        $this->add_control(
            'designation_color',
            [
                'label' => esc_html__( 'Designation Color', 'guto-toolkit' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .single-testimonials-item .clients-info .info span' => 'color: {{VALUE}}',
                ],
                'condition' => [
                    'feedback_style' => '1',
                ]
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'designation_typography',
                'label' => esc_html__( 'Designation Typography', 'guto-toolkit' ),
                'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                'selector' => '{{WRAPPER}} .single-testimonials-item .clients-info .info span',
                'condition' => [
                    'feedback_style' => '1',
                ]
            ]
        );

    $this->end_controls_section();

    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        $slider = $settings['guto_feedback_items'];

        // Inline Editing
        $this-> add_inline_editing_attributes('title','none');

        $count = 0;
        foreach ($slider as $items => $counts):
            $count++;
        endforeach;

        if( $settings['feedback_style'] == '1' ): ?>

            <div class="testimonials-area bg-f3f3f4 ptb-100">
                <div class="container">
                    <div class="section-title">
                        <span class="sub-title"><?php echo esc_html( $settings['top_title'] ); ?></span>
                        <<?php echo esc_attr( $settings['title_tag'] ); ?> <?php echo $this-> get_render_attribute_string('title'); ?>>
                            <?php echo esc_html( $settings['title'] ); ?>
                        </<?php echo esc_attr( $settings['title_tag'] ); ?>>
                    </div>

                    <?php if( $count == 1 ): ?>
                        <div class="col-lg-12">
                    <?php else: ?>
                        <div class="testimonials-slides owl-carousel owl-theme">
                    <?php endif; ?>
                        <?php foreach ($slider as $key => $value): ?>
                            <div class="single-testimonials-item">
                                <p><?php echo wp_kses_post( $value['feedback'] ); ?></p>
                                <div class="clients-info d-flex align-items-center justify-content-center">
                                    <?php if( $value['image']['url'] != '' ): ?>
                                        <img src="<?php echo esc_url( $value['image']['url'] ); ?>" alt="<?php echo esc_attr( $value['name'] ) ?>">
                                    <?php endif; ?>

                                    <div class="info">
                                        <h3><?php echo esc_html( $value['name'] ); ?></h3>
                                        <span><?php echo esc_html( $value['designation'] ); ?></span>
                                    </div>
                                </div>
                            </div>
                        <?php endforeach; ?>
                    </div>
                </div>
            </div>

        <?php elseif( $settings['feedback_style'] == '2' ): ?>
            <!-- Start OS Clients Area -->
            <section class="os-clients-area pb-70">
                <div class="container">
                    <div class="section-title">
                        <<?php echo esc_attr( $settings['title_tag'] ); ?> <?php echo $this-> get_render_attribute_string('title'); ?>>
                            <?php echo esc_html( $settings['title'] ); ?>
                        </<?php echo esc_attr( $settings['title_tag'] ); ?>>
                        <p><?php echo esc_html( $settings['feedback_section_desc'] ); ?></p>
                    </div>
                    <div class="row align-items-center">
                        <div class="col-lg-6">
                            <div class="os-clients-content">
                                <div class="os-clients-slider owl-carousel owl-theme">
                                    <?php foreach ($slider as $key => $value): ?>
                                    <div class="os-single-clients">
                                        <i class="flaticon-quote"></i>
                                        <p><?php echo wp_kses_post( $value['feedback'] ); ?></p>
                                        <h3><?php echo esc_html( $value['name'] ); ?></h3>
                                    </div>
                                    <?php endforeach; ?>
                                </div>
                                <?php if( $settings['feedback_shape_img']['url'] != '' ): ?>
                                    <div class="client-shape">
                                        <img src="<?php echo esc_url( $settings['feedback_shape_img']['url'] ); ?>" alt="Image">
                                    </div>
                                <?php endif; ?>
                            </div>
                        </div>
                        <div class="col-lg-6">
                            <div class="os-client-img">
                                <?php if( $settings['feedback_featured_img']['url'] != '' ): ?>
                                    <img src="<?php echo esc_url( $settings['feedback_featured_img']['url'] ); ?>" alt="Image">
                                <?php endif; ?>
                                <?php if( $settings['feedback_video_link'] != '' ): ?>
                                    <div class="os-video-button">
                                        <a href="<?php echo esc_url(  $settings['feedback_video_link'] ); ?>" class="popup-youtube">
                                            <i class="bx bx-play"></i>
                                        </a>
                                    </div>
                                <?php endif; ?>
                            </div>
                        </div>
                    </div>
                </div>
            </section>
            <!-- End OS Clients Area -->
        <?php endif;
	}



}

Plugin::instance()->widgets_manager->register( new Guto_Feedback );
