<?php
/**
 * FR About Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_FR_About_Area extends Widget_Base {

	public function get_name() {
        return 'Guto_FR_About';
    }

	public function get_title() {
        return esc_html__( 'FR About', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-info-box';
    }

	public function get_categories() {
        return [ 'guto-freelancer' ];
    }

	protected function register_controls() {

        $this->start_controls_section(
			'Guto_FR_About_Area',
			[
				'label' => esc_html__( 'About Controls', 'guto-toolkit' ),
				'tab' 	=> Controls_Manager::TAB_CONTENT,
			]
		);

        $this->add_control(
            'choose_style',
            [
                'label' => esc_html__( 'Choose Style', 'guto-toolkit' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    '1'   => esc_html__( 'Style One', 'guto-toolkit' ),
                    '2'   => esc_html__( 'Style Two', 'guto-toolkit' ),
                ],
                'default' => '1',
            ]
        );
			$this->add_control(
				'title',
				[
					'label' 	=> esc_html__( 'Title', 'guto-toolkit' ),
					'type'      =>Controls_Manager:: WYSIWYG,
					'default' 	=> esc_html__('I’m David Smith
                    A Freelance Full Stack Web Developer', 'guto-toolkit'),
				]
			);

			$this->add_control(
                'title_tag',
                [
                    'label' 	=> esc_html__( 'Title Tag', 'guto-toolkit' ),
                    'type' 		=> Controls_Manager::SELECT,
                    'options' 	=> [
                        'h1'         => esc_html__( 'h1', 'guto-toolkit' ),
                        'h2'         => esc_html__( 'h2', 'guto-toolkit' ),
                        'h3'         => esc_html__( 'h3', 'guto-toolkit' ),
                        'h4'         => esc_html__( 'h4', 'guto-toolkit' ),
                        'h5'         => esc_html__( 'h5', 'guto-toolkit' ),
                        'h6'         => esc_html__( 'h6', 'guto-toolkit' ),
                    ],
                    'default' => 'h2',
                ]
            );

			$this->add_control(
				'content',
				[
					'label' 	=> esc_html__( 'Content', 'guto-toolkit' ),
					'type'      =>Controls_Manager:: WYSIWYG,
					'default' 	=> esc_html__('Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Quis ipsum suspendisse.', 'guto-toolkit'),
				]
            );

			$this->add_control(
				'content_two',
				[
					'label' 	=> esc_html__( 'Content Second Part', 'guto-toolkit' ),
					'type'      =>Controls_Manager:: WYSIWYG,
					'default' 	=> esc_html__('Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industrys standard dummy text ever since the 1500s, when an unknown printer took a galley of type and scrambled it to make a type specimen book. It has survived not only five centuries.', 'guto-toolkit'),
				]
            );

            $this->add_control(
				'button_icon',
				[
					'label' => esc_html__( 'Button Icon', 'guto-toolkit' ),
                    'type' => Controls_Manager::ICON,
                    'label_block' => true,
                    'options' => guto_toolkit_icons(),
				]
            );

			$this->add_control(
				'button_text',
				[
					'label' 	=> esc_html__( 'Button Text', 'guto-toolkit' ),
					'type' 		=> Controls_Manager::TEXT,
					'default' 	=> esc_html__('Hire Me Now', 'guto-toolkit'),
				]
            );

            $this->add_control(
                'link_type',
                [
                    'label' 		=> esc_html__( 'Button Link Type', 'guto-toolkit' ),
                    'type' 			=> Controls_Manager::SELECT,
                    'label_block' 	=> true,
                    'options' => [
                        '1'  	=> esc_html__( 'Link To Page', 'guto-toolkit' ),
                        '2' 	=> esc_html__( 'External Link', 'guto-toolkit' ),
                    ],
                    'default' > '2'
                ]
            );

            $this->add_control(
                'link_to_page',
                [
                    'label' 		=> esc_html__( 'Button Link Page', 'guto-toolkit' ),
                    'type' 			=> Controls_Manager::SELECT,
                    'label_block' 	=> true,
                    'options' 		=> guto_toolkit_get_page_as_list(),
                    'condition' => [
                        'link_type' => '1',
                    ]
                ]
            );

            $this->add_control(
                'ex_link',
                [
                    'label'		=> esc_html__('Button External Link', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: URL,
                    'show_external' => true,
                    'default' => [
                        'url' => '#',
                        'is_external' => true,
                        'nofollow' => true,
                    ],
                    'condition' => [
                        'link_type' => '2',
                    ]
                ]
            );
        $this->end_controls_section();

        // Images
        $this->start_controls_section(
			'about_images',
			[
				'label' => esc_html__( 'Images', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

            $this->add_control(
                'image1',
                [
                    'label'		=> esc_html__('Image', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: MEDIA,
                ]
            );

        $this->end_controls_section();

        $this->start_controls_section(
			'funfacts_section',
			[
				'label' => esc_html__( 'Funfacts Control', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

            $repeater = new Repeater();

            $repeater->add_control(
                'number',
                [
                    'type'        => Controls_Manager::NUMBER,
                    'label'       => esc_html__( 'Number', 'guto-toolkit' ),
                    'label_block' => true,
                    'default'     => 1845,
                ]
            );
            $repeater->add_control(
                'counter_title',
                [
                    'label' => esc_html__( 'Counter Title', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default'       => esc_html__( 'Project Completed', 'guto-toolkit' ),
                    'label_block'   => true,
                ]
            );
            $repeater->add_control(
                'counter_sign',
                [
                    'label' => esc_html__( 'Counter Sign', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'label_block'   => true,
                ]
            );
            $this->add_control(
                'items',
                [
                    'label'   => esc_html__( 'Add Item', 'guto-toolkit' ),
                    'type' => Controls_Manager::REPEATER,
                    'fields' => $repeater->get_controls(),
                ]
            );

        $this->end_controls_section();


        $this->start_controls_section(
			'award_section',
			[
				'label' => esc_html__( 'Award Control', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

            $this->add_control(
                'award_title',
                [
                    'label' => esc_html__( 'Award Title', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default'       => esc_html__( 'AWARDS AND INDUSTRY RECOGNITION', 'guto-toolkit' ),
                    'label_block'   => true,
                ]
            );

            $repeater2 = new Repeater();

            $repeater2->add_control(
                'image2',
                [
                    'label'		=> esc_html__('Image', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: MEDIA,
                ]
            );

            $this->add_control(
                'image_items',
                [
                    'label'   => esc_html__( 'Add Image Item', 'guto-toolkit' ),
                    'type' => Controls_Manager::REPEATER,
                    'fields' => $repeater2->get_controls(),
                    'condition' => [
                        'choose_style' => '2',
                    ]
                ]
            );

        $this->end_controls_section();

        $this->start_controls_section(
			'about_sec_style',
			[
				'label' => esc_html__( 'Style', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
            $this->add_control(
                'top_title_color',
                [
                    'label' => esc_html__( 'Top Title Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .fl-about-content h2 span' => 'color: {{VALUE}}',
                    ],
                ]
            );

			$this->add_control(
				'title_color',
				[
					'label' => esc_html__( 'Title Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .fl-about-content h1, .fl-about-content h2, .fl-about-content h3, .fl-about-content h4, .fl-about-content h5, .fl-about-content h6' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'title_typography',
                    'label' => esc_html__( 'Title Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .fl-about-content h1, .fl-about-content h2, .fl-about-content h3, .fl-about-content h4, .fl-about-content h5, .fl-about-content h6',
                ]
            );

			$this->add_control(
				'content_color',
				[
					'label' => esc_html__( 'Content Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} p' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'content_typography',
                    'label' => esc_html__( 'Content Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .fl-about-content p',
                ]
            );

            $this->add_control(
				'button_color',
				[
					'label' => esc_html__( 'Button Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .fl-default-btn' => 'color: {{VALUE}}',
					],
				]
			);
			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'btn_typography',
                    'label' => esc_html__( 'Button Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .fl-default-btn',
                ]
            );

            $this->add_control(
                'counter_color',
                [
                    'label' => esc_html__( 'Number Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .fl-about-content .features-list li h3' => 'color: {{VALUE}}',
                    ],
                ]
			);

			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'number_typography',
                    'label' => esc_html__( 'Number Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .fl-about-content .features-list li h3',
                ]
            );

            $this->add_control(
                'counter_title_color',
                [
                    'label' => esc_html__( 'Counter Title Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .fl-about-content .features-list li p' => 'color: {{VALUE}}',
                    ],
                ]
			);

			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'counter_title_typography',
                    'label' => esc_html__( 'Counter Title Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .fl-about-content .features-list li p',
                ]
            );
            $this->add_control(
                'award_title_color',
                [
                    'label' => esc_html__( 'Award Title Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .fl-awards-list h4' => 'color: {{VALUE}}',
                    ],
                ]
			);

			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'award_title_typography',
                    'label' => esc_html__( 'Award Title Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .fl-awards-list h4',
                ]
            );
        $this->end_controls_section();

    }

	protected function render() {

		$settings = $this->get_settings_for_display();

        // Get Button Link
        if($settings['link_type'] == 1){
            $link = get_page_link( $settings['link_to_page'] );
        } elseif($settings['link_type'] == 2) {
            $link = $settings['ex_link']['url'];
            $target = $settings['ex_link']['is_external'] ? ' target="_blank"' : '';
		    $nofollow = $settings['ex_link']['nofollow'] ? ' rel="nofollow"' : '';
        }

        $button_text = $settings['button_text'];

        ?>

        <?php if( $settings['choose_style']  == '1' ) : ?>
            <div class="container">
                <div class="row align-items-center">
                    <?php if( $settings['image1']['url'] != '' ) : ?>
                        <div class="col-lg-6 col-md-12">
                            <div class="fl-about-image">
                                <img src="<?php echo esc_url($settings['image1']['url']); ?>" alt="<?php echo esc_attr__('image','guto-toolkit'); ?>">
                            </div>
                        </div>
                    <?php endif; ?>
                    <div class="col-lg-6 col-md-12">
                        <div class="fl-about-content">
                            <<?php echo esc_attr( $settings['title_tag'] ); ?>>
                                <?php echo wp_kses_post( $settings['title'] ); ?>
                            </<?php echo esc_attr( $settings['title_tag'] ); ?>>
                            <?php echo wp_kses_post( $settings['content'] ); ?>

                            <ul class="features-list">

                                <?php foreach( $settings['items'] as $item ): ?>
                                    <li>
                                        <h3><span class="odometer" data-count="<?php echo esc_attr( $item['number'] ); ?>">00</span><span class="sign"><?php echo esc_attr( $item['counter_sign'] ); ?></span></h3>
                                        <p><?php echo esc_html( $item['counter_title'] ); ?></p>
                                    </li>
                                <?php endforeach; ?>

                            </ul>

                            <?php echo wp_kses_post( $settings['content_two'] ); ?>

                            <?php if( $button_text != '' ): ?>
                                <?php if($settings['link_type'] == 1) : ?>
                                    <a href="<?php echo esc_url( $link ); ?>" class="fl-default-btn"><i class="<?php echo esc_attr( $settings['button_icon'] ); ?>"></i> <?php echo esc_html( $button_text ); ?></a>
                                <?php elseif($settings['link_type'] == 2) :
                                    echo '<a href="' .  $link . '" class="fl-default-btn" ' . $target . $nofollow . '> <i class="'.$settings['button_icon'].'"></i> ' . $button_text . '</a>';
                                endif; ?>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
            </div>
        <?php else: ?>
            <div class="container">
                <div class="row align-items-center">
                    <?php if( $settings['image1']['url'] != '' ) : ?>
                        <div class="col-lg-6 col-md-12">
                            <div class="fl-about-image">
                                <img src="<?php echo esc_url($settings['image1']['url']); ?>" alt="<?php echo esc_attr__('image','guto-toolkit'); ?>">
                            </div>
                        </div>
                    <?php endif; ?>
                    <div class="col-lg-6 col-md-12">
                        <div class="fl-about-content">
                            <<?php echo esc_attr( $settings['title_tag'] ); ?>>
                                <?php echo wp_kses_post( $settings['title'] ); ?>
                            </<?php echo esc_attr( $settings['title_tag'] ); ?>>
                            <?php echo wp_kses_post( $settings['content'] ); ?>
                            <ul class="features-list">
                                <?php foreach( $settings['items'] as $item ): ?>
                                    <li>
                                        <h3><span class="odometer" data-count="<?php echo esc_attr( $item['number'] ); ?>">00</span><span class="sign"><?php echo esc_attr( $item['counter_sign'] ); ?></span></h3>
                                        <p><?php echo esc_html( $item['counter_title'] ); ?></p>
                                    </li>
                                <?php endforeach; ?>
                            </ul>
                            <?php echo wp_kses_post( $settings['content_two'] ); ?>

                            <?php if( $button_text != '' ): ?>
                                <?php if($settings['link_type'] == 1) : ?>
                                    <a href="<?php echo esc_url( $link ); ?>" class="fl-default-btn"><i class="<?php echo esc_attr( $settings['button_icon'] ); ?>"></i> <?php echo esc_html( $button_text ); ?></a>
                                <?php elseif($settings['link_type'] == 2) :
                                    echo '<a href="' .  $link . '" class="fl-default-btn" ' . $target . $nofollow . '> <i class="'.$settings['button_icon'].'"></i> ' . $button_text . '</a>';
                                endif; ?>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
                <div class="fl-awards-list">
                    <h4><?php echo esc_html( $settings['award_title'] ); ?></h4>
                    <div class="row justify-content-center">

                        <?php foreach( $settings['image_items'] as $item2 ): ?>
                            <?php if( $item2['image2']['url'] != '' ) : ?>
                                <div class="col-lg-2 col-4 col-sm-4 col-md-3">
                                    <div class="fl-awards-box">
                                        <img src="<?php echo esc_url($item2['image2']['url']); ?>" alt="<?php echo esc_attr__('award image','guto-toolkit'); ?>">
                                    </div>
                                </div>
                            <?php endif; ?>
                        <?php endforeach; ?>

                    </div>
                </div>
            </div>
        <?php endif; ?>
        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_FR_About_Area );