<?php
/**
 * FR Contact Info Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_FR_Contact_Info extends Widget_Base {

	public function get_name() {
        return 'FR_Contact_Info';
    }

	public function get_title() {
        return esc_html__( 'FR Contact Info', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-handle';
    }

	public function get_categories() {
        return [ 'guto-freelancer' ];
    }

	protected function register_controls() {

        $this->start_controls_section(
            'Guto_Contact_Info',
            [
                'label' => esc_html__( 'Guto Contact Info', 'guto-toolkit' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

            $repeater = new Repeater();

            $repeater->add_control(
                'image1',
                [
                    'label'		=> esc_html__('Image', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: MEDIA,
                ]
            );

            $repeater->add_control(
                'content',
                [
                    'label'     => esc_html__( 'Info Content', 'guto-toolkit' ),
                    'type'      =>Controls_Manager:: WYSIWYG,
                ]
            );

            $this->add_control(
                'items',
                [
                    'label'   => esc_html__( 'Add Item', 'guto-toolkit' ),
                    'type' => Controls_Manager::REPEATER,
                    'fields' => $repeater->get_controls(),
                ]
            );

        $this->end_controls_section();

        $this->start_controls_section(
			'contact_style',
			[
				'label' => esc_html__( 'Style', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
            $this->add_group_control(
                Group_Control_Background::get_type(),
                [
                    'name' => 'background',
                    'label' => __( 'Card Background', 'guto-toolkit' ),
                    'types' => [ 'classic'],
                    'selector' => '{{WRAPPER}} .fl-contact-info-box',
                ]
            );

			$this->add_control(
				'title_color',
				[
					'label' => esc_html__( 'Info Title Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .fl-contact-info-box h3 a, .fl-contact-info-box h3' => 'color: {{VALUE}}',
					],
                    'separator' => 'before',
				]
			);
			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'title_typography',
                    'label' => esc_html__( 'Info Title Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .fl-contact-info-box h3 a, .fl-contact-info-box h3',
                ]
            );
        $this->end_controls_section();
    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        ?>
            <div class="fl-contact-info-area">
                <div class="container">
                    <div class="row justify-content-center">
                        <?php foreach( $settings['items'] as $item ): ?>
                            <div class="col-lg-4 col-sm-12 col-md-6">
                                <div class="fl-contact-info-box">
                                    <div class="d-table">
                                        <div class="d-table-cell">
                                            <?php if( $item['image1']['url'] != '' ) : ?>
                                                <div class="icon">
                                                    <img src="<?php echo esc_url($item['image1']['url']); ?>" alt="<?php echo esc_attr__('icon image','guto-toolkit'); ?>">
                                                </div>
                                            <?php endif; ?>
                                            <h3><?php echo wp_kses_post( $item['content'] ); ?></h3>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        <?php endforeach; ?>
                    </div>
                </div>
            </div>

        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_FR_Contact_Info );