<?php
/**
 * FR Feedback Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_FR_Feedback extends Widget_Base {

	public function get_name() {
        return 'FR Feedback';
    }

	public function get_title() {
        return esc_html__( 'FR Feedback', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-testimonial';
    }

	public function get_categories() {
        return [ 'guto-freelancer' ];
    }

	protected function register_controls() {

        $this->start_controls_section(
			'Guto_FR_Section_Area',
			[
				'label' => esc_html__( 'Section Controls', 'guto-toolkit' ),
				'tab' 	=> Controls_Manager::TAB_CONTENT,
			]
		);
			$this->add_control(
				'title',
				[
					'label' 	=> esc_html__( 'Title', 'guto-toolkit' ),
					'type'      =>Controls_Manager:: TEXT,
					'default' 	=> esc_html__('What Client Say About Me', 'guto-toolkit'),
				]
			);

			$this->add_control(
                'title_tag',
                [
                    'label' 	=> esc_html__( 'Title Tag', 'guto-toolkit' ),
                    'type' 		=> Controls_Manager::SELECT,
                    'options' 	=> [
                        'h1'         => esc_html__( 'h1', 'guto-toolkit' ),
                        'h2'         => esc_html__( 'h2', 'guto-toolkit' ),
                        'h3'         => esc_html__( 'h3', 'guto-toolkit' ),
                        'h4'         => esc_html__( 'h4', 'guto-toolkit' ),
                        'h5'         => esc_html__( 'h5', 'guto-toolkit' ),
                        'h6'         => esc_html__( 'h6', 'guto-toolkit' ),
                    ],
                    'default' => 'h2',
                ]
            );

			$this->add_control(
				'content',
				[
					'label' 	=> esc_html__( 'Content', 'guto-toolkit' ),
					'type'      =>Controls_Manager:: WYSIWYG,
					'default' 	=> esc_html__('Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Quis ipsum suspendisse.', 'guto-toolkit'),
				]
            );
        $this->end_controls_section();

        $this->start_controls_section(
			'content_section',
			[
				'label' => esc_html__( 'Feedback Content', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );
            $repeater = new Repeater();

            $repeater->add_control(
				'name',
				[
                    'label'       => esc_html__('Name', 'guto-toolkit'),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => esc_html__('Olivar Lucy', 'guto-toolkit'),
                    'label_block' => true,
				]
            );
            $repeater->add_control(
                'designation',
                [
                    'label'       => esc_html__('Designation', 'guto-toolkit'),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => esc_html__('Designer', 'guto-toolkit'),
                    'label_block' => true,
                ]
            );
            $repeater->add_control(
                'feedback',
                [
                    'label'       => esc_html__('Feedback Content', 'guto-toolkit'),
                    'type'        => Controls_Manager::TEXTAREA,
                    'default'     => esc_html__('Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Quis ipsum suspendisse ultrices gravida. Risus commodo viverra maecenas accumsan.', 'guto-toolkit'),
                    'label_block' => true,
                ]
            );
            $repeater->add_control(
                'image1',
                [
                    'label'		=> esc_html__('Image', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: MEDIA,
                ]
            );
            $repeater->add_control(
                'star_count',
                [
                    'label' => __( 'Choose Star', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'label_block' => true,
                    'options' => [
                        '1' => __( '1', 'guto-toolkit' ),
                        '2' => __( '2', 'guto-toolkit' ),
                        '3' => __( '3', 'guto-toolkit' ),
                        '4' => __( '4', 'guto-toolkit' ),
                        '5' => __( '5', 'guto-toolkit' ),
                    ],
                    'default' => '5',
                ]
            );
            $this->add_control(
                'guto_feedback_items',
                [
                    'label'  => esc_html__('Slider Item', 'guto-toolkit'),
                    'type'   => Controls_Manager::REPEATER,
                    'fields' => $repeater->get_controls(),
                ]
            );

        $this->end_controls_section();

        $this->start_controls_section(
            'style',
            [
                'label' => esc_html__( 'Style', 'guto-toolkit' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
            $this->add_control(
                'title_color',
                [
                    'label' => esc_html__( 'Title Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .fl-section-title h1, .fl-section-title h2, .fl-section-title h3, .fl-section-title h4, .fl-section-title h5, .fl-section-title h6' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'title_typography',
                    'label' => esc_html__( 'Title Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .fl-section-title h1, .fl-section-title h2, .fl-section-title h3, .fl-section-title h4, .fl-section-title h5, .fl-section-title h6',
                ]
            );

            $this->add_control(
				'content_color',
				[
					'label' => esc_html__( 'Content Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .fl-section-title p' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'content_typography',
                    'label' => esc_html__( 'Content Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .fl-section-title p',
                ]
            );

            $this->add_control(
                'name_color',
                [
                    'label' => esc_html__( 'Name Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .fl-feedback-box .client-info .title h3' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'name_typography',
                    'label' => esc_html__( 'Name Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .fl-feedback-box .client-info .title h3',
                ]
            );
            $this->add_control(
                'des_color',
                [
                    'label' => esc_html__( 'Designation Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .fl-feedback-box .client-info .title span' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'des_typography',
                    'label' => esc_html__( 'Designation Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .fl-feedback-box .client-info .title span',
                ]
            );

            $this->add_control(
                'feed_color',
                [
                    'label' => esc_html__( 'Feedback Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .fl-feedback-box p' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'feed_typography',
                    'label' => esc_html__( 'Feedback Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .fl-feedback-box p',
                ]
            );

        $this->end_controls_section();

    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        $slider = $settings['guto_feedback_items'];

        // Inline Editing
        $this-> add_inline_editing_attributes('title','none');

        ?>
            <div class="fl-feedback-area pb-100">
                <div class="container">
                    <div class="fl-section-title">
                        <<?php echo esc_attr( $settings['title_tag'] ); ?>>
                            <?php echo esc_html( $settings['title'] ); ?>
                        </<?php echo esc_attr( $settings['title_tag'] ); ?>>
                        <?php echo wp_kses_post( $settings['content'] ); ?>
                    </div>
                </div>
                <div class="container-fluid">
                    <div class="fl-feedback-slides owl-carousel owl-theme">
                        <?php foreach($slider as $key => $value) : ?>
                            <div class="fl-feedback-box">
                                <div class="rating">
                                    <?php if( $value['star_count'] == 1 ) { ?>
                                        <i class="bx bxs-star" aria-hidden="true"></i>
                                    <?php } elseif( $value['star_count'] == 2 ) { ?>
                                        <i class="bx bxs-star" aria-hidden="true"></i>
                                        <i class="bx bxs-star" aria-hidden="true"></i>
                                    <?php } elseif( $value['star_count'] == 3 ) { ?>
                                        <i class="bx bxs-star" aria-hidden="true"></i>
                                        <i class="bx bxs-star" aria-hidden="true"></i>
                                        <i class="bx bxs-star" aria-hidden="true"></i>
                                    <?php } elseif( $value['star_count'] == 4 ) { ?>
                                        <i class="bx bxs-star" aria-hidden="true"></i>
                                        <i class="bx bxs-star" aria-hidden="true"></i>
                                        <i class="bx bxs-star" aria-hidden="true"></i>
                                        <i class="bx bxs-star" aria-hidden="true"></i>
                                    <?php } elseif( $value['star_count'] == 5 ) { ?>
                                        <i class="bx bxs-star" aria-hidden="true"></i>
                                        <i class="bx bxs-star" aria-hidden="true"></i>
                                        <i class="bx bxs-star" aria-hidden="true"></i>
                                        <i class="bx bxs-star" aria-hidden="true"></i>
                                        <i class="bx bxs-star" aria-hidden="true"></i>
                                    <?php } ?>
                                </div>
                                <p><?php echo wp_kses_post( $value['feedback'] ); ?></p>
                                <div class="client-info d-flex align-items-center">
                                    <?php if( $value['image1']['url'] != '' ) : ?>
                                        <img src="<?php echo esc_url($value['image1']['url']); ?>" alt="<?php echo esc_attr__('user image','guto-toolkit'); ?>">
                                    <?php endif; ?>
                                    <div class="title">
                                        <h3><?php echo esc_html( $value['name'] ); ?></h3>
                                        <span><?php echo esc_html( $value['designation'] ); ?></span>
                                    </div>
                                </div>
                            </div>
                        <?php endforeach; ?>
                    </div>
                </div>
            </div>
        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_FR_Feedback );
