<?php
/**
 * FR Project Details Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_FR_Project_Details extends Widget_Base {

	public function get_name() {
        return 'FR Project Details';
    }

	public function get_title() {
        return esc_html__( 'FR Project Details', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-handle';
    }

	public function get_categories() {
        return [ 'guto-freelancer' ];
    }

	protected function register_controls() {

        $this->start_controls_section(
			'Guto_Section',
			[
				'label' => esc_html__( 'Guto Section', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

            $this->add_control(
                'sec_img',
                [
                    'label' => esc_html__( 'Image', 'guto-toolkit' ),
                    'type' => Controls_Manager::MEDIA,
                    'label_block' => true,
                ]
            );
            $this->add_control(
                'image2',
                [
                    'label' => esc_html__( 'Second Image', 'guto-toolkit' ),
                    'type' => Controls_Manager::MEDIA,
                    'label_block' => true,
                ]
            );

            $this->add_control(
                'title',
                [
                    'label' => esc_html__( 'Add Title', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default'       => esc_html__( 'Online Learning', 'guto-toolkit' ),
                    'label_block'   => true,
                ]
            );

            $this->add_control(
                'content',
                [
                    'label' => esc_html__( 'Content', 'guto-toolkit' ),
                    'type'      =>Controls_Manager:: WYSIWYG,
                ]
            );

            $this->add_control(
				'button_icon',
				[
					'label' => esc_html__( 'Button Icon', 'guto-toolkit' ),
                    'type' => Controls_Manager::ICON,
                    'label_block' => true,
                    'options' => guto_toolkit_icons(),
				]
            );

			$this->add_control(
				'button_text',
				[
					'label' 	=> esc_html__( 'Button Text', 'guto-toolkit' ),
					'type' 		=> Controls_Manager::TEXT,
					'default' 	=> esc_html__('Hire Me Now', 'guto-toolkit'),
				]
            );

            $this->add_control(
                'link_type',
                [
                    'label' 		=> esc_html__( 'Button Link Type', 'guto-toolkit' ),
                    'type' 			=> Controls_Manager::SELECT,
                    'label_block' 	=> true,
                    'options' => [
                        '1'  	=> esc_html__( 'Link To Page', 'guto-toolkit' ),
                        '2' 	=> esc_html__( 'External Link', 'guto-toolkit' ),
                    ],
                    'default' > '2'
                ]
            );

            $this->add_control(
                'link_to_page',
                [
                    'label' 		=> esc_html__( 'Button Link Page', 'guto-toolkit' ),
                    'type' 			=> Controls_Manager::SELECT,
                    'label_block' 	=> true,
                    'options' 		=> guto_toolkit_get_page_as_list(),
                    'condition' => [
                        'link_type' => '1',
                    ]
                ]
            );

            $this->add_control(
                'ex_link',
                [
                    'label'		=> esc_html__('Button External Link', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: URL,
                    'show_external' => true,
                    'default' => [
                        'url' => '#',
                        'is_external' => true,
                        'nofollow' => true,
                    ],
                    'condition' => [
                        'link_type' => '2',
                    ]
                ]
            );
        $this->end_controls_section();

        $this->start_controls_section(
			'social_section',
			[
				'label' => esc_html__( 'Social Control', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

            $repeater = new Repeater();

            $repeater->add_control(
                'social_url',
                [
                    'type'        => Controls_Manager::TEXT,
                    'label'       => esc_html__( 'Social URL', 'guto-toolkit' ),
                    'label_block' => true,
                ]
            );
            $repeater->add_control(
                'social_icon',
                [
                    'label' => esc_html__( 'Social Icon', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'label_block'   => true,
                ]
            );
            $this->add_control(
                'items',
                [
                    'label'   => esc_html__( 'Add Item', 'guto-toolkit' ),
                    'type' => Controls_Manager::REPEATER,
                    'fields' => $repeater->get_controls(),
                ]
            );

        $this->end_controls_section();

        $this->start_controls_section(
			'section_style',
			[
				'label' => esc_html__( 'Style', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
        );
            $this->add_control(
                'title_color',
                [
                    'label' => esc_html__( 'Title Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .fl-portfolio-details-desc .content h3' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'title_typography',
                    'label' => esc_html__( 'Title Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .fl-portfolio-details-desc .content h3',
                ]
            );

            $this->add_control(
                's_content_color',
                [
                    'label' => esc_html__( 'Strong Content Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .fl-portfolio-details-desc .content p strong, .fl-portfolio-details-desc .content .info li span' => 'color: {{VALUE}}',
                    ],
                ]
            );
            $this->add_control(
                'content_color',
                [
                    'label' => esc_html__( 'Content Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .fl-portfolio-details-desc .content p, .fl-portfolio-details-desc .content ol li, .fl-portfolio-details-desc .content ul li, .fl-portfolio-details-desc .content ol li, .fl-portfolio-details-desc .content ol li' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'con_typography',
                    'label' => esc_html__( 'Content Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .fl-portfolio-details-desc .content p, .fl-portfolio-details-desc .content p strong, .fl-portfolio-details-desc .content ol li, .fl-portfolio-details-desc .content ul li, .fl-portfolio-details-desc .content ol li, .fl-portfolio-details-desc .content ol li, .fl-portfolio-details-desc .content .info li span',
                ]
            );

        $this->end_controls_section();

    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        // Get Button Link
        if($settings['link_type'] == 1){
            $link = get_page_link( $settings['link_to_page'] );
        } elseif($settings['link_type'] == 2) {
            $link = $settings['ex_link']['url'];
            $target = $settings['ex_link']['is_external'] ? ' target="_blank"' : '';
		    $nofollow = $settings['ex_link']['nofollow'] ? ' rel="nofollow"' : '';
        }

        $button_text = $settings['button_text'];

        ?>
            <div class="fl-portfolio-details-area pb-100">
                <div class="container">
                    <div class="fl-portfolio-details-desc">
                        <div class="row">
                            <div class="col-lg-7 col-md-12">
                                <?php if( $settings['sec_img']['url'] != '' ): ?>
                                    <div class="image">
                                        <img src="<?php echo esc_url( $settings['sec_img']['url'] ); ?>" alt="<?php echo esc_attr('image', 'guto-toolkit'); ?>">
                                    </div>
                                <?php endif; ?>

                                <?php if( $settings['image2']['url'] != '' ): ?>
                                    <div class="image">
                                        <img src="<?php echo esc_url( $settings['image2']['url'] ); ?>" alt="<?php echo esc_attr('image', 'guto-toolkit'); ?>">
                                    </div>
                                <?php endif; ?>
                            </div>
                            <div class="col-lg-5 col-md-12">
                                <div class="fl-portfolio-details-sticky">
                                    <div class="content">
                                        <h3><?php echo esc_html( $settings['title'] ); ?></h3>
                                        <?php echo wp_kses_post( $settings['content'] ); ?>

                                        <ul class="social-links">
                                            <?php foreach( $settings['items'] as $item ): ?>
                                                <li><a href="<?php echo esc_attr( $item['social_url'] ); ?>" target="_blank"><i class='<?php echo esc_html( $item['social_icon'] ); ?>'></i></a></li>
                                            <?php endforeach; ?>
                                        </ul>

                                        <?php if( $button_text != '' ): ?>
                                            <?php if($settings['link_type'] == 1) : ?>
                                                <a href="<?php echo esc_url( $link ); ?>" class="fl-default-btn"><i class="<?php echo esc_attr( $settings['button_icon'] ); ?>"></i> <?php echo esc_html( $button_text ); ?></a>
                                            <?php elseif($settings['link_type'] == 2) :
                                                echo '<a href="' .  $link . '" class="fl-default-btn" ' . $target . $nofollow . '> <i class="'.$settings['button_icon'].'"></i> ' . $button_text . '</a>';
                                            endif; ?>
                                        <?php endif; ?>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_FR_Project_Details );