<?php
/**
 * FR Section Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_FR_Service_Details extends Widget_Base {

	public function get_name() {
        return 'FR Service Details';
    }

	public function get_title() {
        return esc_html__( 'FR Service Details', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-handle';
    }

	public function get_categories() {
        return [ 'guto-freelancer' ];
    }

	protected function register_controls() {

        $this->start_controls_section(
			'Guto_Service_Details',
			[
				'label' => esc_html__( 'Guto Service Details', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

            $repeater = new Repeater();

            //image controls
            $repeater->add_control(
                'image1',
                [
                    'label' => __('Add Image', 'etica-toolkit' ),
                    'type' => Controls_Manager::MEDIA,
                    'default' => [
                        'url' => Utils::get_placeholder_image_src(),
                    ]
                ]
            );

            $repeater->add_control(
                'top_title', [
                    'label' => __( 'Add Top Title', 'etica-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'label_block' => true,
                ]
            );

            $repeater->add_control(
                'title', [
                    'label' => __( 'Add Title', 'etica-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'label_block' => true,
                ]
            );

            $repeater->add_control(
                'desc', [
                    'label' => __( 'Add Single Description', 'etica-toolkit' ),
                    'type' => Controls_Manager::WYSIWYG,
                    'label_block' => true,
                ]
            );

            $repeater->add_control(
				'button_icon',
				[
					'label' => esc_html__( 'Button Icon', 'guto-toolkit' ),
                    'type' => Controls_Manager::ICON,
                    'label_block' => true,
                    'options' => guto_toolkit_icons(),
				]
            );

			$repeater->add_control(
				'button_text',
				[
					'label' 	=> esc_html__( 'Button Text', 'guto-toolkit' ),
					'type' 		=> Controls_Manager::TEXT,
					'default' 	=> esc_html__('Hire Me Now', 'guto-toolkit'),
				]
            );

            $repeater->add_control(
                'link_type',
                [
                    'label' 		=> esc_html__( 'Button Link Type', 'guto-toolkit' ),
                    'type' 			=> Controls_Manager::SELECT,
                    'label_block' 	=> true,
                    'options' => [
                        '1'  	=> esc_html__( 'Link To Page', 'guto-toolkit' ),
                        '2' 	=> esc_html__( 'External Link', 'guto-toolkit' ),
                    ],
                    'default' > '2'
                ]
            );

            $repeater->add_control(
                'link_to_page',
                [
                    'label' 		=> esc_html__( 'Button Link Page', 'guto-toolkit' ),
                    'type' 			=> Controls_Manager::SELECT,
                    'label_block' 	=> true,
                    'options' 		=> guto_toolkit_get_page_as_list(),
                    'condition' => [
                        'link_type' => '1',
                    ]
                ]
            );

            $repeater->add_control(
                'ex_link',
                [
                    'label'		=> esc_html__('Button External Link', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: URL,
                    'show_external' => true,
                    'default' => [
                        'url' => '#',
                        'is_external' => true,
                        'nofollow' => true,
                    ],
                    'condition' => [
                        'link_type' => '2',
                    ]
                ]
            );

            $this->add_control(
                'items',
                [
                    'label'   => esc_html__( 'Add Item', 'guto-toolkit' ),
                    'type' => Controls_Manager::REPEATER,
                    'fields' => $repeater->get_controls(),
                ]
            );

        $this->end_controls_section();

        $this->start_controls_section(
			'section_style',
			[
				'label' => esc_html__( 'Style', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
        );

            $this->add_control(
                'top_title_color',
                [
                    'label' => esc_html__( 'Top Title Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .fl-services-details-box .content .sub-title' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'top_title_typography',
                    'label' => esc_html__( 'Top Title Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .fl-services-details-box .content .sub-title',
                ]
            );

            $this->add_control(
                'title_color',
                [
                    'label' => esc_html__( 'Title Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .fl-services-details-box .content h1, .fl-services-details-box .content h2, .fl-services-details-box .content h3, .fl-services-details-box .content h4, .fl-services-details-box .content h5, .fl-services-details-box .content h6' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'title_typography',
                    'label' => esc_html__( 'Title Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .fl-services-details-box .content h1, .fl-services-details-box .content h2, .fl-services-details-box .content h3, .fl-services-details-box .content h4, .fl-services-details-box .content h5, .fl-services-details-box .content h6',
                ]
            );
            $this->add_control(
                'desc_color',
                [
                    'label' => esc_html__( 'Content Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .fl-services-details-box .content p' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'desc_typography',
                    'label' => esc_html__( 'Content Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .fl-services-details-box .content p',
                ]
            );
            $this->add_control(
                'btn_color',
                [
                    'label' => esc_html__( 'Button Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .fl-services-details-box .content .link-btn' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'btn_typography',
                    'label' => esc_html__( 'Button Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .fl-services-details-box .content .link-btn',
                ]
            );

        $this->end_controls_section();

    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        ?>

            <div class="fl-services-details-area">
                <?php if ( $settings['items']!='' ) :
                    $i = 1;
                    foreach ( $settings['items'] as $item ) :

                            // Get Button Link
                            if($item['link_type'] == 1){
                                $link = get_page_link( $item['link_to_page'] );
                            } elseif($item['link_type'] == 2) {
                                $link = $item['ex_link']['url'];
                                $target = $item['ex_link']['is_external'] ? ' target="_blank"' : '';
                                $nofollow = $item['ex_link']['nofollow'] ? ' rel="nofollow"' : '';
                            }

                            $button_text = $item['button_text'];

                        if( $item['top_title']!='' || $item['title']!='' ) :
                        ?>
                        <?php if($i % 2 != 0){ ?>
                            <div class="fl-services-details-box ptb-100">
                                <div class="container">
                                    <div class="row align-items-center">

                                        <?php if( $item['image1']['url'] != '' ) : ?>
                                            <div class="col-lg-6 col-md-12 image">
                                                <img src="<?php echo esc_url($item['image1']['url']); ?>" alt="<?php echo esc_attr__('image','guto-toolkit'); ?>">
                                            </div>
                                        <?php endif; ?>
                                        <div class="col-lg-6 col-md-12 content">
                                            <span class="sub-title"><?php echo esc_html($item['top_title']); ?></span>
                                            <h2><?php echo esc_html($item['title']); ?></h2>
                                            <?php echo wp_kses_post( $item['desc'] ); ?>

                                            <?php if( $button_text != '' ): ?>
                                                <?php if($item['link_type'] == 1) : ?>
                                                    <a href="<?php echo esc_url( $link ); ?>" class="link-btn"><i class="<?php echo esc_attr( $item['button_icon'] ); ?>"></i> <?php echo esc_html( $button_text ); ?></a>
                                                <?php elseif($item['link_type'] == 2) :
                                                    echo '<a href="' .  $link . '" class="link-btn" ' . $target . $nofollow . '> <i class="'.$item['button_icon'].'"></i> ' . $button_text . '</a>';
                                                endif; ?>
                                            <?php endif; ?>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        <?php }
                        else { ?>
                            <div class="fl-services-details-box ptb-100">
                                <div class="container">
                                    <div class="row align-items-center">
                                        <div class="col-lg-6 col-md-12 content">
                                            <span class="sub-title"><?php echo esc_html($item['top_title']); ?></span>
                                            <h2><?php echo esc_html($item['title']); ?></h2>
                                            <?php echo wp_kses_post( $item['desc'] ); ?>

                                            <?php if( $button_text != '' ): ?>
                                                <?php if($item['link_type'] == 1) : ?>
                                                    <a href="<?php echo esc_url( $link ); ?>" class="link-btn"><i class="<?php echo esc_attr( $item['button_icon'] ); ?>"></i> <?php echo esc_html( $button_text ); ?></a>
                                                <?php elseif($item['link_type'] == 2) :
                                                    echo '<a href="' .  $link . '" class="link-btn" ' . $target . $nofollow . '> <i class="'.$item['button_icon'].'"></i> ' . $button_text . '</a>';
                                                endif; ?>
                                            <?php endif; ?>

                                        </div>
                                        <?php if( $item['image1']['url'] != '' ) : ?>
                                            <div class="col-lg-6 col-md-12 image">
                                                <img src="<?php echo esc_url($item['image1']['url']); ?>" alt="<?php echo esc_attr__('image','guto-toolkit'); ?>">
                                            </div>
                                        <?php endif; ?>
                                    </div>
                                </div>
                            </div><?php
                            }
                            endif;
                            $i++;
                        endforeach;
                    endif; ?>
            </div>
            <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_FR_Service_Details );