<?php
/**
 * FR Services Widget
 */

namespace Elementor;
class Guto_FR_Services extends Widget_Base {

	public function get_name() {
        return 'FR_Services';
    }

	public function get_title() {
        return esc_html__( 'FR Services', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-tools';
    }

	public function get_categories() {
        return [ 'guto-freelancer' ];
    }

	protected function register_controls() {

        $this->start_controls_section(
			'services_section',
			[
				'label' => esc_html__( 'Services', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

        $this->add_control(
            'show_section',
            [
                'label'        => __( 'Section Hide/Show?', 'guto-toolkit' ),
                'type'         => Controls_Manager::SWITCHER,
                'label_on'     => __( 'Show', 'guto-toolkit' ),
                'label_off'    => __( 'Hide', 'guto-toolkit' ),
                'return_value' => 'yes',
                'default'      => 'yes',
            ]
        );

        $this->add_control(
            'card_style',
            [
                'label' => esc_html__( 'Choose Style', 'guto-toolkit' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    '1'   => esc_html__( 'Style One', 'guto-toolkit' ),
                    '2'   => esc_html__( 'Style Two', 'guto-toolkit' ),
                    '3'   => esc_html__( 'Style Three', 'guto-toolkit' ),
                ],
                'default' => '1',
            ]
        );

        $this->add_control(
            'columns',
            [
                'label' => esc_html__( 'Choose Columns', 'guto-toolkit' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    '1'   => esc_html__( '1', 'guto-toolkit' ),
                    '2'   => esc_html__( '2', 'guto-toolkit' ),
                    '3'   => esc_html__( '3', 'guto-toolkit' ),
                    '4'   => esc_html__( '4', 'guto-toolkit' ),
                ],
                'default' => '4',
                'condition' => [
                    'card_style' => ['1','3'],
                ]
            ]
        );

        $this->add_control(
            'cat',
            [
                'label' => __( 'Choose Category', 'guto-toolkit' ),
                'type' => Controls_Manager::SELECT,
                'options' => guto_toolkit_get_page_services_cat_el(),
            ]
        );

        $this->add_control(
            'order',
            [
                'label' => esc_html__( 'Services Order By', 'guto-toolkit' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'DESC'      => esc_html__( 'DESC', 'guto-toolkit' ),
                    'ASC'       => esc_html__( 'ASC', 'guto-toolkit' ),
                ],
                'default' => 'DESC',
            ]
        );

        $this->add_control(
            'count',
            [
                'label' => esc_html__( 'Post Per Page', 'guto-toolkit' ),
                'type' => Controls_Manager::NUMBER,
                'default' => 3,
            ]
        );
        $this->add_control(
            'button_text',
            [
                'label' 	=> esc_html__( 'Button Text', 'guto-toolkit' ),
                'type' 		=> Controls_Manager::TEXT,
                'default' 	=> esc_html__('View More', 'guto-toolkit'),
            ]
        );

        $this->add_control(
            'pagination_hide',
            [
                'label' => __( 'Hide Pagination?', 'guto-toolkit' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => __( 'Show', 'guto-toolkit' ),
                'label_off' => __( 'Hide', 'guto-toolkit' ),
                'return_value' => 'yes',
                'default' => 'no',
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
			'Guto_FR_section_Area',
			[
				'label' => esc_html__( 'Section Controls', 'guto-toolkit' ),
				'tab' 	=> Controls_Manager::TAB_CONTENT,
                'condition' => [
                    'show_section' => 'yes',
                ]
			]
		);
        $this->add_control(
            'title',
            [
                'label' 	=> esc_html__( 'Title', 'guto-toolkit' ),
                'type' 		=> Controls_Manager::TEXTAREA,
                'default' 	=> esc_html__('Provide Best Services', 'guto-toolkit'),
            ]
        );

        $this->add_control(
            'title_tag',
            [
                'label' 	=> esc_html__( 'Title Tag', 'guto-toolkit' ),
                'type' 		=> Controls_Manager::SELECT,
                'options' 	=> [
                    'h1'         => esc_html__( 'h1', 'guto-toolkit' ),
                    'h2'         => esc_html__( 'h2', 'guto-toolkit' ),
                    'h3'         => esc_html__( 'h3', 'guto-toolkit' ),
                    'h4'         => esc_html__( 'h4', 'guto-toolkit' ),
                    'h5'         => esc_html__( 'h5', 'guto-toolkit' ),
                    'h6'         => esc_html__( 'h6', 'guto-toolkit' ),
                ],
                'default' => 'h2',
            ]
        );

        $this->add_control(
            'content',
            [
                'label' 	=> esc_html__( 'Content', 'guto-toolkit' ),
                'type'      =>Controls_Manager:: WYSIWYG,
                'default' 	=> esc_html__('Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Quis ipsum suspendisse.', 'guto-toolkit'),
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
			'sec_style',
			[
				'label' => esc_html__( 'Section Style', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'show_section' => 'yes',
                ]
			]
		);

			$this->add_control(
				'title_color',
				[
					'label' => esc_html__( 'Title Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .fl-section-title h1, .fl-section-title h2, .fl-section-title h3, .fl-section-title h4, .fl-section-title h5, .fl-section-title h6' => 'color: {{VALUE}}',
					],
				]
			);
			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'title_typography',
                    'label' => esc_html__( 'Title Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .fl-section-title h1, .fl-section-title h2, .fl-section-title h3, .fl-section-title h4, .fl-section-title h5, .fl-section-title h6',
                ]
            );
            $this->add_control(
				'content_color',
				[
					'label' => esc_html__( 'Content Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .fl-section-title p' => 'color: {{VALUE}}',
					],
				]
			);
			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'content_typography',
                    'label' => esc_html__( 'Content Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .fl-section-title p',
                ]
            );
        $this->end_controls_section();

        $this->start_controls_section(
			'service_style',
			[
				'label' => esc_html__( 'Posts Style', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
        );

            $this->add_control(
                'icon_color',
                [
                    'label' => esc_html__( 'Icon Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .single-fl-features-box .icon, .fl-services-box .icon' => 'color: {{VALUE}}',
                    ],
                ]
            );
            $this->add_control(
                'post_title_color',
                [
                    'label' => esc_html__( 'Title Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .single-fl-features-box h3 a, .fl-services-box h3 a' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'posttitle_typography',
                    'label' => esc_html__( 'Title Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .single-fl-features-box h3 a, .fl-services-box h3 a',
                ]
            );

            $this->add_control(
                'post_content_color',
                [
                    'label' => esc_html__( 'Post Content Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .single-fl-features-box p, .fl-services-box p' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'post_content_typography',
                    'label' => esc_html__( 'Post Content Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .single-fl-features-box p, .fl-services-box p',
                ]
            );
            $this->add_control(
                'button_color',
                [
                    'label' => esc_html__( 'Button Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .single-fl-features-box .link-btn, .fl-services-box .link-btn' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'button_typography',
                    'label' => esc_html__( 'Button Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .single-fl-features-box .link-btn, .fl-services-box .link-btn',
                ]
            );

        $this->end_controls_section();

    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        // Card Columns
        $columns = $settings['columns'];
        if ($columns == '1') {
            $column = 'col-lg-12 col-md-6';
        }elseif ($columns == '2') {
            $column = 'col-lg-6 col-md-6';
        }elseif ($columns == '3') {
            $column = 'col-lg-4 col-md-6';
        }else {
            $column = 'col-lg-3 col-md-6';
        }

        // Services Query
        if( $settings['cat'] != '' ) {
            $args = array(
                'post_type'     => 'services',
                'posts_per_page'=> $settings['count'],
                'order'         => $settings['order'],
                'paged'         => get_query_var('paged') ? get_query_var('paged') : 1,
                'tax_query'     => array(
                    array(
                        'taxonomy'      => 'service_cat',
                        'field'         => 'slug',
                        'terms'         => $settings['cat'],
                        'hide_empty'    => false
                    )
                )
            );
        } else {
            $args = array(
                'post_type'         => 'services',
                'posts_per_page'    => $settings['count'],
                'order'             => $settings['order'],
                'paged'             => get_query_var('paged') ? get_query_var('paged') : 1,
            );
        }
        $services_array = new \WP_Query( $args );

        ?>

        <?php if( $settings['card_style']  == '1' ) : ?>
            <div class="container">
                <div class="row justify-content-center">
                    <?php while($services_array->have_posts()): $services_array->the_post();

                        // Card Icon
                        if ( defined( 'FW' ) ) {
                            $icon = fw_get_db_post_option( get_the_ID(), 'services_icon' );
                        }else{
                            $icon = '';
                        }
                    ?>
                        <div class="<?php echo esc_attr( $column ); ?>">
                            <div class="single-fl-features-box">
                                <?php if( $icon != '' ): ?>
                                    <div class="icon">
                                        <i class="<?php echo esc_attr($icon); ?>"></i>
                                    </div>
                                <?php endif; ?>
                                <h3><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>
                                <p><?php the_excerpt(); ?></p>
                                <a href="<?php the_permalink(); ?>" class="link-btn"> <?php echo esc_html( $settings['button_text'] ); ?></a>
                            </div>
                        </div>
                    <?php endwhile; ?>
                    <?php wp_reset_query(); ?>
                </div>
            </div>
        <?php elseif( $settings['card_style']  == '2' ) : ?>
            <div class="container">
                <?php if ( $settings['show_section'] == 'yes' ) : ?>
                    <?php if( !empty( $settings['content'] || $settings['title'] ) ): ?>
                        <div class="fl-section-title text-start">
                            <<?php echo esc_attr( $settings['title_tag'] ); ?>>
                                <?php echo esc_html( $settings['title'] ); ?>
                            </<?php echo esc_attr( $settings['title_tag'] ); ?>>

                            <?php echo wp_kses_post( $settings['content'] ); ?>
                        </div>
                    <?php endif; ?>
                <?php endif; ?>
                <div class="fl-services-slides owl-carousel owl-theme">
                    <?php while($services_array->have_posts()): $services_array->the_post();

                        // Card Icon
                        if ( defined( 'FW' ) ) {
                            $icon = fw_get_db_post_option( get_the_ID(), 'services_icon' );
                        }else{
                            $icon = '';
                        }
                    ?>
                        <div class="fl-services-box">
                            <?php if( $icon != '' ): ?>
                                <div class="icon">
                                    <i class="<?php echo esc_attr($icon); ?>"></i>
                                </div>
                            <?php endif; ?>
                            <h3><a href="<?php the_permalink(); ?>"><?php the_title(); ?></h3>
                            <p><?php the_excerpt(); ?></p>

                            <a href="<?php the_permalink(); ?>" class="link-btn"> <?php echo esc_html( $settings['button_text'] ); ?></a>

                        </div>
                    <?php endwhile; ?>
                    <?php wp_reset_query(); ?>

                </div>
            </div>
        <?php else: ?>
            <div class="container">
                <div class="row justify-content-center">
                    <?php while($services_array->have_posts()): $services_array->the_post();

                    // Card Icon
                    if ( defined( 'FW' ) ) {
                        $icon = fw_get_db_post_option( get_the_ID(), 'services_icon' );
                    }else{
                        $icon = '';
                    } ?>

                        <div class="col-lg-4">
                            <div class="fl-services-box">
                                <?php if( $icon != '' ): ?>
                                    <div class="icon">
                                        <i class="<?php echo esc_attr($icon); ?>"></i>
                                    </div>
                                <?php endif; ?>
                                <h3><a href="<?php the_permalink(); ?>"><?php the_title(); ?></h3>
                                <p><?php the_excerpt(); ?></p>
                                <?php if( $settings['button_text'] != '' ): ?>
                                    <a href="<?php the_permalink(); ?>" class="link-btn"> <?php echo esc_html( $settings['button_text'] ); ?></a>
                                <?php endif; ?>
                            </div>
                        </div>
                    <?php endwhile; ?>
                    <?php wp_reset_query(); ?>

                    <?php if ( 'yes' === $settings['pagination_hide'] ) { ?>
                        <div class="fl-pagination-area">
                            <nav aria-label="Page navigation">
                            <?php
                            $big = 999999999; // need an unlikely integer
                            echo paginate_links( array(
                                'base' => str_replace( $big, '%#%', get_pagenum_link( $big ) ),
                                'format' => '?paged=%#%',
                                'current' => max( 1, get_query_var('paged') ),
                                'total' => $services_array->max_num_pages,
                                //'format' => '?paged=%#%',
                                'prev_text' => '<i class="fas fa-chevron-left"></i>',
                                'next_text' => '<i class="fas fa-chevron-right"></i>',
                            ) ); ?>
                            </nav>
                        </div>
                    <?php } ?>
                </div>
            </div>
        <?php endif; ?>

        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_FR_Services );