<?php
/**
 * Insurance About Area Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_Insurance_About_Area extends Widget_Base {

	public function get_name() {
        return 'Insurance_About_Area';
    }

	public function get_title() {
        return esc_html__( 'Insurance About', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-info-box';
    }

	public function get_categories() {
        return [ 'guto-insurance' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'Insurance_About_Area',
			[
				'label' => esc_html__( 'Insurance About', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

            $this->add_control(
                'top_title',
                [
                    'label' => esc_html__( 'Top Title', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__('ABOUT US', 'guto-toolkit'),
                ]
            );

            $this->add_control(
                'title',
                [
                    'label' => esc_html__( 'Title', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__('We are award winning company', 'guto-toolkit'),
                ]
            );

            $this->add_control(
                'title_tag',
                [
                    'label' => esc_html__( 'Title Tag', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        'h1'         => esc_html__( 'h1', 'guto-toolkit' ),
                        'h2'         => esc_html__( 'h2', 'guto-toolkit' ),
                        'h3'         => esc_html__( 'h3', 'guto-toolkit' ),
                        'h4'         => esc_html__( 'h4', 'guto-toolkit' ),
                        'h5'         => esc_html__( 'h5', 'guto-toolkit' ),
                        'h6'         => esc_html__( 'h6', 'guto-toolkit' ),
                    ],
                    'default' => 'h2',
                ]
            );

            $this->add_control(
                'content',
                [
                    'label' => esc_html__( 'Content', 'guto-toolkit' ),
                    'type' => Controls_Manager::WYSIWYG,
                    'default' => esc_html__('Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Quis ipsum suspendisse ultrices gravida.', 'guto-toolkit'),
                ]
            );

            $this->add_control(
                'insurance_about_features',
                [
                    'label' => esc_html__('Features Item', 'guto-toolkit'),
                    'type' => Controls_Manager::REPEATER,
                    'default' => [
                        [ 'name' => esc_html__(' Item #1', 'guto-toolkit') ],

                    ],
                    'fields' => [
                        [
                            'name' => 'feature_name',
                            'label' => esc_html__('Item Name', 'guto-toolkit'),
                            'type' => Controls_Manager::TEXT,
                            'default' => esc_html__('Trustworthy company', 'guto-toolkit'),
                            'label_block' => true,
                        ],
                        [
                            'name' => 'feature_image',
                            'label' => esc_html__('Item Image', 'guto-toolkit'),
                            'type' => Controls_Manager::MEDIA,
                            'show_label' => true,
                        ],
                    ],
                ]
            );

            $this->add_control(
                'content_more',
                [
                    'label' => esc_html__( 'Content More', 'guto-toolkit' ),
                    'type' => Controls_Manager::WYSIWYG,
                    'default' => esc_html__('Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Quis ipsum.', 'guto-toolkit'),
                ]
            );

            $this->add_control(
				'button_text',
				[
					'label' 	=> esc_html__( 'Button Text', 'guto-toolkit' ),
					'type' 		=> Controls_Manager::TEXT,
					'default' 	=> esc_html__('More About Us', 'guto-toolkit'),
				]
            );

            $this->add_control(
                'link_type',
                [
                    'label' 		=> esc_html__( 'Button Link Type', 'guto-toolkit' ),
                    'type' 			=> Controls_Manager::SELECT,
                    'label_block' 	=> true,
                    'options' => [
                        '1'  	=> esc_html__( 'Link To Page', 'guto-toolkit' ),
                        '2' 	=> esc_html__( 'External Link', 'guto-toolkit' ),
                    ],
                    'default' => '2'
                ]
            );

            $this->add_control(
                'link_to_page',
                [
                    'label' 		=> esc_html__( 'Button Link Page', 'guto-toolkit' ),
                    'type' 			=> Controls_Manager::SELECT,
                    'label_block' 	=> true,
                    'options' 		=> guto_toolkit_get_page_as_list(),
                    'condition' => [
                        'link_type' => '1',
                    ]
                ]
            );

            $this->add_control(
                'ex_link',
                [
                    'label'		=> esc_html__('Button External Link', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: URL,
                    'show_external' => true,
                    'default' => [
                        'url' => '#',
                        'is_external' => true,
                        'nofollow' => true,
                    ],
                    'condition' => [
                        'link_type' => '2',
                    ]
                ]
            );

            $this->add_control(
                'image',
                [
                    'label' => esc_html__( 'About Image', 'guto-toolkit' ),
                    'type'	 => Controls_Manager::MEDIA,
                    'show_label' => true,
                ]
            );

        $this->end_controls_section();

    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        // Inline Editing
        $this-> add_inline_editing_attributes('title','none');
        $this-> add_inline_editing_attributes('content','none');

        $insurance_about_features = $settings['insurance_about_features'];

        // Get Button Link
        if($settings['link_type'] == 1){
            $link = get_page_link( $settings['link_to_page'] );
        } elseif($settings['link_type'] == 2) {
            $link = $settings['ex_link']['url'];
            $target = $settings['ex_link']['is_external'] ? ' target="_blank"' : '';
		    $nofollow = $settings['ex_link']['nofollow'] ? ' rel="nofollow"' : '';
        }

        $button_text = $settings['button_text'];

        ?>

        <!-- Start Insurance About Area -->
        <?php if( is_home() || is_front_page() ) : ?>
            <div class="insurance-about-area ptb-100">
        <?php else: ?>
            <div class="insurance-about-area pt-100">
        <?php endif; ?>
            <div class="container-lg">
                <div class="row align-items-center">
                    <div class="col-lg-6 col-md-12">
                        <?php if( $settings['image']['url'] != '' ): ?>
                            <div class="insurance-about-image">
                                <img src="<?php echo esc_url($settings['image']['url']); ?>" alt="<?php esc_attr_e('About Image', 'guto-toolkit'); ?>">
                            </div>
                        <?php endif; ?>
                    </div>

                    <div class="col-lg-6 col-md-12">
                        <div class="insurance-about-content">
                            <span class="sub-title"><?php echo esc_html( $settings['top_title'] ); ?></span>
                            <<?php echo esc_attr( $settings['title_tag'] ); ?> <?php echo $this-> get_render_attribute_string('title'); ?>><?php echo wp_kses_post( $settings['title'] ); ?></<?php echo esc_attr( $settings['title_tag'] ); ?>>

                            <p><?php echo wp_kses_post( $settings['content'] ); ?></p>
                            <ul class="features-list">
                                <?php foreach ($insurance_about_features as $key => $value): ?>
                                <li>
                                    <span>
                                        <img src="<?php echo esc_html( $value['feature_image']['url'] ); ?>" alt="check">
                                        <?php echo esc_html( $value['feature_name'] ); ?>
                                    </span>
                                </li>
                                <?php endforeach; ?>
                            </ul>
                            <p><?php echo wp_kses_post( $settings['content_more'] ); ?></p>
                            <?php if( $button_text != '' ): ?>
                                <?php if($settings['link_type'] == 1): ?>
                                    <a href="<?php echo esc_url( $link ); ?>" class="insurance-default-btn"><?php echo esc_html( $button_text ); ?></a>
                                <?php elseif($settings['link_type'] == 2):
                                    echo '<a href="' .  $link . '" class="insurance-default-btn" ' . $target . $nofollow . '>' . $button_text . ' </a>';
                                endif; ?>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
            </div>
        </div>

        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_Insurance_About_Area );
