<?php
/**
 * Insurance Contact Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

class Guto_Insurance_Contact extends Widget_Base {

    public function get_name() {
        return 'Insurance_Contact_Area';
    }

    public function get_title() {
        return esc_html__( 'Insurance Contact', 'guto-toolkit' );
    }

    public function get_icon() {
        return 'eicon-form-horizontal';
    }

    public function get_categories() {
        return [ 'guto-insurance' ];
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'Insurance_Contact_Area',
            [
                'label' => esc_html__( 'Insurance Contact', 'guto-toolkit' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

            $this->add_control(
                'contact_subtitle', [
                    'label' => esc_html__( 'Subtitle', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'label_block' => true,
                    'default' => 'SEND MESSAGE',
                ]
            );

            $this->add_control(
                'contact_title', [
                    'label' => esc_html__( 'Title', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'label_block' => true,
                    'default' => 'Drop us message for any query',
                ]
            );

            $this->add_control(
                'shortcode',
                [
                    'label' => esc_html__( 'Contact Shortcode', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                ]
            );

            $this->add_control(
                'list_items',
                [
                    'label' => esc_html__('List Item', 'guto-toolkit'),
                    'type' => Controls_Manager::REPEATER,
                    'separator' => 'before',
                    'fields' => [
                        [
                            'name'      => 'title',
                            'label'     => esc_html__( 'Title', 'guto-toolkit' ),
                            'type'      => Controls_Manager::TEXT,
                            'default'   => esc_html__('Address', 'guto-toolkit'),
                        ],
                        [
                            'name'  => 'icon',
                            'label' => esc_html__( 'Select Icon', 'guto-toolkit' ),
                            'type' => Controls_Manager::ICON,
                            'label_block' => true,
                            'options' => guto_toolkit_icons(),
                        ],
                        [
                            'name'      => 'content',
                            'label'     => esc_html__( 'Content', 'guto-toolkit' ),
                            'type'      => Controls_Manager::TEXTAREA,
                            'default'   => esc_html__('CA 560 Bush St & 20th Ave, Apt 5 San Francisco, 230909, Canada', 'guto-toolkit'),
                        ],
                    ],
                ]
            );

        $this->end_controls_section();
    }

    protected function render() {

        $settings = $this->get_settings_for_display();

        // Inline Editing
        $this-> add_inline_editing_attributes('title', 'none'); ?>

        <!-- Start Insurance Contact Area -->
        <div class="insurance-contact-area ptb-100">
            <div class="container-lg">
                <div class="insurance-section-title">
                    <span class="sub-title"><?php echo esc_html__( $settings['contact_subtitle']); ?></span>
                    <h2><?php echo esc_html__( $settings['contact_title']); ?></h2>
                </div>
                <div class="row">
                    <div class="col-lg-7 col-md-12">
                        <?php if($settings['shortcode']): ?>
                            <div class="insurance-contact-form">
                                <?php echo do_shortcode( $settings['shortcode'] ); ?>
                            </div>
                        <?php endif; ?>
                    </div>

                    <div class="col-lg-5 col-md-12">
                        <div class="insurance-contact-info">
                            <ul>
                                <?php foreach( $settings['list_items'] as $item ):
                                    // Icon
                                    $icon = $item['icon']; ?>
                                    <li>
                                        <div class="icon">
                                            <i class="<?php echo esc_attr( $icon ); ?>"></i>
                                        </div>
                                        <span><?php echo esc_html( $item['title'] ); ?></span>
                                        <?php echo wp_kses_post( $item['content'] ); ?>
                                    </li>
                                <?php endforeach; ?>
                            </ul>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <!-- End Insurance Contact Area -->

        <?php
    }



}

Plugin::instance()->widgets_manager->register( new Guto_Insurance_Contact );
