<?php
/**
 * Insurance FAQ Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

class Guto_Insurance_Faq extends Widget_Base {

    public function get_name() {
        return 'Insurance_FAQ';
    }

    public function get_title() {
        return esc_html__( 'Guto Insurance FAQ', 'guto-toolkit' );
    }

    public function get_icon() {
        return 'eicon-help-o';
    }

    public function get_categories() {
        return [ 'guto-insurance' ];
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'Guto_Faq',
            [
                'label' => esc_html__( 'Faq Control', 'guto-toolkit' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'faq_tabs',
            [
                'label' => esc_html__('Faq Tabs', 'guto-toolkit'),
                'type' => Controls_Manager::REPEATER,
                'separator' => 'before',
                'fields' => [
                    [
                        'name'  => 'title',
                        'label' => esc_html__( 'Title', 'guto-toolkit' ),
                        'type' => Controls_Manager::TEXT,
                        'default' => esc_html__( 'What is personal liability umbrella coverage?', 'guto-toolkit' ),
                    ],

                    [
                        'name'  => 'content',
                        'label' => esc_html__( 'Content', 'guto-toolkit' ),
                        'type' => Controls_Manager::WYSIWYG,
                        'label_block' => true,
                        'default' => __("Lorem Ipsum is simply dummy text of the printing and <strong>typesetting</strong> industry. Lorem Ipsum has been the industry's standard dummy text ever since the 1500s, when an unknown printer took a galley of type and scrambled it to make a type specimen book. It has survived not only five centuries, but also the leap into electronic typesetting, remaining essentially.", 'guto-toolkit'),
                    ],
                ],
            ]
        );

        $this->end_controls_section();

    }

    protected function render() {

        $settings = $this->get_settings_for_display(); ?>

            <!-- Start Insurance FAQ Area -->
            <div class="insurance-faq-area ptb-100">
                <div class="container">
                    <?php $i = 1; foreach( $settings['faq_tabs'] as $item ): ?>
                        <div class="insurance-faq-item">
                            <h3><?php echo esc_html( $item['title'] ); ?></h3>
                            <p><?php echo wp_kses_post( $item['content'] ); ?></p>
                        </div>
                    <?php $i++; endforeach; ?>
                </div>
            </div>
            <!-- End Insurance FAQ Area -->

        <?php
    }



}

Plugin::instance()->widgets_manager->register( new Guto_Insurance_Faq );
