<?php
/**
 * Insurance Newsletter Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_Insurance_Newsletter extends Widget_Base {

	public function get_name() {
        return 'Guto_Insurance_Newsletter';
    }

	public function get_title() {
        return __( 'Insurance Newsletter', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-email-field';
    }

	public function get_categories() {
        return [ 'guto-insurance' ];
    }

    public function get_keywords() {
        return [ 'mailchimp', 'form', 'newsletter' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'Guto_Newsletter',
			[
				'label' => esc_html__( 'Insurance Newsletter', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

            $this->add_control(
                'action_url', [
                    'label' => esc_html__( 'Action URL', 'guto-toolkit' ),
                    'description' => esc_html__( 'Enter here your MailChimp action URL. <a href="https://doc.gutotheme.com/docs/tips-guides-troubleshoots/get-mailchimp-newsletter-form-action-url/" target="_blank"> How to </a>', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'label_block' => true,
                ]
            );

            $this->add_control(
                'top_title', [
                    'label' => esc_html__( 'Top Title', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__( 'Newsletter', 'guto-toolkit' ),
                    'label_block' => true,
                ]
            );

            $this->add_control(
                'title', [
                    'label' => esc_html__( 'Title', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__( 'Get started today' , 'guto-toolkit' ),
                    'label_block' => true,
                ]
            );

            $this->add_control(
                'placeholder_text', [
                    'label' => esc_html__( 'Email Placeholder Text', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__( 'Enter your email address' , 'guto-toolkit' ),
                    'label_block' => true,
                ]
            );

            $this->add_control(
                'button_text', [
                    'label' => esc_html__( 'Button text', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__( 'Subscribe Now' , 'guto-toolkit' ),
                    'label_block' => true,
                ]
            );

            $this->add_control(
				'image',
				[
					'label' => esc_html__( 'Section Image', 'guto-toolkit' ),
					'type' => Controls_Manager::MEDIA,
				]
            );

            $this->add_control(
				'image2',
				[
					'label' => esc_html__( 'Section Image Two', 'guto-toolkit' ),
					'type' => Controls_Manager::MEDIA,
				]
            );

            $this->add_control(
                'image3',
                [
                    'label' => esc_html__( 'Section Image Three', 'guto-toolkit' ),
                    'type' => Controls_Manager::MEDIA,
                ]
            );

        $this->end_controls_section();

    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        // Inline Editing
        $this-> add_inline_editing_attributes('title', 'none'); ?>

        <!-- Start Insurance Subscribe Area -->
        <div class="insurance-subscribe-area pt-100">
            <div class="container-lg">
                <div class="insurance-subscribe-content">
                    <?php if($settings['top_title']): ?>
                        <span class="sub-title"><?php echo esc_html($settings['top_title']); ?></span>
                    <?php endif; ?>

                    <?php if($settings['title']): ?>
                        <h2><?php echo esc_html($settings['title']); ?></h2>
                    <?php endif; ?>

                    <form class="mailchimp newsletter-form" method="post">
                        <input type="email" class="input-newsletter memail" placeholder="<?php echo esc_attr($settings['placeholder_text']); ?>" name="EMAIL" required>

                        <?php if( $settings['button_text'] != '' ): ?>
                            <button type="submit" class="insurance-default-btn"><?php echo esc_html( $settings['button_text'] ); ?><span></span></button>
                        <?php endif; ?>

                        <p class="mchimp-errmessage" style="display: none;"></p>
                        <p class="mchimp-sucmessage" style="display: none;"></p>
                    </form>

                    <?php if($settings['image']['url']): ?>
                        <div class="i-shape3"><img src="<?php echo esc_url($settings['image']['url']);  ?>" alt="<?php echo esc_attr($settings['title']); ?>"></div>
                    <?php endif; ?>
                    <?php if($settings['image2']['url']): ?>
                        <div class="i-shape4"><img src="<?php echo esc_url($settings['image2']['url']);  ?>" alt="<?php echo esc_attr($settings['title']); ?>"></div>
                    <?php endif; ?>
                    <?php if($settings['image3']['url']): ?>
                        <div class="i-shape5"><img src="<?php echo esc_url($settings['image3']['url']);  ?>" alt="<?php echo esc_attr($settings['title']); ?>"></div>
                    <?php endif; ?>

                </div>
            </div>
        </div>
        <!-- End Insurance Subscribe Area -->

        <script>
            ;(function($){
                "use strict";
                $(document).ready(function () {
                    // MAILCHIMP
                    if ($(".mailchimp").length > 0) {
                        $(".mailchimp").ajaxChimp({
                            callback: mailchimpCallback,
                            url: "<?php echo esc_js($settings['action_url']) ?>"
                        });
                    }
                    if ($(".mailchimp_two").length > 0) {
                        $(".mailchimp_two").ajaxChimp({
                            callback: mailchimpCallback,
                            url: "<?php echo esc_js($settings['action_url']) ?>" //Replace this with your own mailchimp post URL. Don't remove the "". Just paste the url inside "".
                        });
                    }
                    $(".memail").on("focus", function () {
                        $(".mchimp-errmessage").fadeOut();
                        $(".mchimp-sucmessage").fadeOut();
                    });
                    $(".memail").on("keydown", function () {
                        $(".mchimp-errmessage").fadeOut();
                        $(".mchimp-sucmessage").fadeOut();
                    });
                    $(".memail").on("click", function () {
                        $(".memail").val("");
                    });

                    function mailchimpCallback(resp) {
                        if (resp.result === "success") {
                            $(".mchimp-errmessage").html(resp.msg).fadeIn(1000);
                            $(".mchimp-sucmessage").fadeOut(500);
                        } else if (resp.result === "error") {
                            $(".mchimp-errmessage").html(resp.msg).fadeIn(1000);
                        }
                    }
                });
            })(jQuery)
        </script>
    <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_Insurance_Newsletter );
