<?php
/**
 * Insurance Services Sidebar Widget
 */

namespace Elementor;
class Guto_Insurance_Services_Sidebar extends Widget_Base {

	public function get_name() {
        return 'Insurance_Services_Sidebar';
    }

	public function get_title() {
        return esc_html__( 'Insurance Services Sidebar', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-tools';
    }

	public function get_categories() {
        return [ 'guto-insurance' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'services_list_section',
			[
				'label' => esc_html__( 'Services List', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

        $this->add_control(
            'services_list_item_number',
            [
                'label' => esc_html__( 'Number Of Items', 'guto-toolkit' ),
                'type' => Controls_Manager::NUMBER,
                'default' => esc_html__('6', 'guto-toolkit'),
            ]
        );

        $this->add_control(
            'services_list_order',
            [
                'label' => esc_html__( 'Lists Order By', 'guto-toolkit' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    '1'   => esc_html__( 'Ascending', 'guto-toolkit' ),
                    '2'   => esc_html__( 'Descending', 'guto-toolkit' )
                ],
                'default' => '1',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'services_phone_section',
            [
                'label' => esc_html__( 'Phone Advanced', 'guto-toolkit' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'phone_number',
            [
                'label' => esc_html__( 'Phone Number', 'guto-toolkit' ),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('+44 587 154756', 'guto-toolkit'),
            ]
        );

        $this->add_control(
            'phone_number_link',
            [
                'label' => esc_html__( 'Phone Number Link', 'guto-toolkit' ),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('tel:+44587154756', 'guto-toolkit'),
            ]
        );

        $this->add_control(
            'image',
            [
                'label' => esc_html__( 'Section Image', 'guto-toolkit' ),
                'type' => Controls_Manager::MEDIA,
            ]
        );

        $this->end_controls_section();

    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        $services_list_item_number = $settings['services_list_item_number'];
        if( $settings['services_list_order'] == '1' ) :
            $services_list_order = 'asc';
        elseif( $settings['services_list_order'] == '2' ) :
            $services_list_order = 'desc';
        endif; ?>

        <div class="insurance-details-sidebar">
            <div class="contact-service-box">
                <ul class="insurance-list">
                    <?php
                     // Services Query
                    global $post;
                    $add_class_loop = $post->ID;
                    $args = array(
                        'post_type'       => 'services',
                        'posts_per_page'  => $services_list_item_number,
                        'order'           => $services_list_order
                    );
                    $services_array_list = new \WP_Query( $args ); ?>
                    <?php while($services_array_list->have_posts()): $services_array_list->the_post(); ?>
                        <li>
                            <a <?php if( is_single() && $add_class_loop == $post->ID) print 'style="color:#ffffff;background:#ff6377;border-color:#ff6377;"' ?> href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
                        </li>
                        <?php if( is_single() && $add_class_loop == $post->ID) { ?>
                            <style>
                                .insurance-details-sidebar .insurance-list li a::before {
                                    background: #ffffff;
                                }
                            </style>
                          <?php } ?>
                    <?php endwhile; ?>
                    <?php wp_reset_query(); ?>
                </ul>
            </div>
            <div class="insurance-contact-info-box">
                <?php if( ! $settings['image']['url'] == '' ) : ?>
                    <img src="<?php echo esc_url( $settings['image']['url'] ); ?>" alt="contact">
                <?php endif; ?>
                <div class="content">
                    <div class="icon">
                        <i class='bx bx-phone-call'></i>
                    </div>
                    <span>
                        <?php echo esc_html( $settings['phone_number'] ); ?></a>
                    </span>
                </div>
                <a href="<?php echo esc_url( $settings['phone_number_link'] ); ?>" class="link-btn"></a>
            </div>
         </div>

        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_Insurance_Services_Sidebar );
