<?php
/**
 * Insurance Feedback Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_Insurance_Feedback extends Widget_Base {

	public function get_name() {
        return 'Insurance Feedback';
    }

	public function get_title() {
        return esc_html__( 'Insurance Feedback', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-testimonial';
    }

	public function get_categories() {
        return [ 'guto-insurance' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'content_section',
			[
				'label' => esc_html__( 'Content', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

        $this->add_control(
            'top_title',
            [
                'label' => esc_html__( 'Top Title', 'guto-toolkit' ),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('TESTIMONIALS', 'guto-toolkit'),
            ]
        );

        $this->add_control(
            'title',
            [
                'label' => esc_html__( 'Title', 'guto-toolkit' ),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Our clients feedback', 'guto-toolkit'),
            ]
        );

        $this->add_control(
            'feedback_desc',
            [
                'label' => esc_html__( 'Description', 'guto-toolkit' ),
                'type' => Controls_Manager::TEXTAREA,
                'default' => esc_html__('Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Quis ipsum suspendisse ultrices.', 'guto-toolkit'),
            ]
        );

        $this->add_control(
            'title_tag',
            [
                'label' => esc_html__( 'Title Tag', 'guto-toolkit' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'h1'         => esc_html__( 'h1', 'guto-toolkit' ),
                    'h2'         => esc_html__( 'h2', 'guto-toolkit' ),
                    'h3'         => esc_html__( 'h3', 'guto-toolkit' ),
                    'h4'         => esc_html__( 'h4', 'guto-toolkit' ),
                    'h5'         => esc_html__( 'h5', 'guto-toolkit' ),
                    'h6'         => esc_html__( 'h6', 'guto-toolkit' ),
                ],
                'default' => 'h2',
            ]
        );

        $this->add_control(
            'feedback_featured_img',
            [
                'label' => esc_html__( 'Featured Image', 'guto-toolkit' ),
                'type' => Controls_Manager::MEDIA,
                'show_label' => true,
            ]
        );

		$this->add_control(
            'insurance_feedback_items',
            [
                'label' => esc_html__('Feedback Item', 'guto-toolkit'),
                'type' => Controls_Manager::REPEATER,
                'default' => [
                    [ 'name' => esc_html__(' Item #1', 'guto-toolkit') ],

                ],
                'fields' => [
                    [
                        'name' => 'feedback',
                        'label' => esc_html__('Feedback Content', 'guto-toolkit'),
                        'type' => Controls_Manager::TEXTAREA,
                        'default' => esc_html__('Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Quis ipsum suspendisse ultrices gravida. Risus commodo viverra maecenas accumsan lacus vel facilisis.', 'guto-toolkit'),
                        'label_block' => true,
                    ],
                    [
                        'name' => 'rating',
                        'label' => esc_html__('Feedback Rating', 'guto-toolkit'),
                        'type' => Controls_Manager::SELECT,
                        'options' => [
                            '5'         => esc_html__( '5', 'guto-toolkit' ),
                            '4'         => esc_html__( '4', 'guto-toolkit' ),
                            '3'         => esc_html__( '3', 'guto-toolkit' ),
                            '2'         => esc_html__( '2', 'guto-toolkit' ),
                            '1'         => esc_html__( '1', 'guto-toolkit' )
                        ],
                        'default' => '5',
                    ],
                    [
                        'name'  => 'image',
                        'label' => esc_html__( 'Image', 'guto-toolkit' ),
                        'type' => Controls_Manager::MEDIA,
                        'show_label' => true,
                    ],
                    [
                        'name' => 'author_name',
                        'label' => esc_html__('Name', 'guto-toolkit'),
                        'type' => Controls_Manager::TEXT,
                        'default' => esc_html__('John Smith', 'guto-toolkit'),
                        'label_block' => true,
                    ],
                    [
                        'name' => 'designation',
                        'label' => esc_html__('Designation', 'guto-toolkit'),
                        'type' => Controls_Manager::TEXT,
                        'default' => esc_html__('Web Developer', 'guto-toolkit'),
                        'label_block' => true,
                    ],
                ],
            ]
        );

        $this->add_control(
            'insurance_partner_items',
            [
                'label' => esc_html__('Partner Item', 'guto-toolkit'),
                'type' => Controls_Manager::REPEATER,
                'default' => [
                    [ 'name' => esc_html__(' Item #1', 'guto-toolkit') ],

                ],
                'fields' => [
                    [
                        'name'  => 'image2',
                        'label' => esc_html__( 'Image', 'guto-toolkit' ),
                        'type' => Controls_Manager::MEDIA,
                        'show_label' => true,
                    ],
                ],
            ]
        );

    $this->end_controls_section();

    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        $feedback_slider = $settings['insurance_feedback_items'];
        $partner_slider = $settings['insurance_partner_items'];

        // Inline Editing
        $this-> add_inline_editing_attributes('title', 'none'); ?>

        <!-- Start Insurance Feedback Area -->
        <?php if( get_post_type (get_the_ID()) == 'services' ) : ?>
            <div class="insurance-feedback-area ptb-100">
        <?php else : ?>
            <div class="insurance-feedback-area bg-fff6f7 pt-100">
        <?php endif; ?>
            <div class="container-lg">
                <div class="row">
                    <div class="col-lg-7 col-md-12">
                        <div class="insurance-feedback-content">
                            <div class="content">
                                <span class="sub-title">
                                    <?php echo esc_html( $settings['top_title'] ); ?>
                                </span>
                                <<?php echo esc_attr( $settings['title_tag'] ); ?> <?php echo $this-> get_render_attribute_string('title'); ?>>
                                    <?php echo esc_html( $settings['title'] ); ?>
                                </<?php echo esc_attr( $settings['title_tag'] ); ?>>
                                <p><?php echo wp_kses_post( $settings['feedback_desc'] ); ?></p>
                                <div class="insurance-feedback-slides owl-carousel owl-theme">
                                    <?php foreach ($feedback_slider as $key => $value): ?>
                                        <div class="single-insurance-feedback-box">
                                            <div class="rating">
                                                <?php if( $value['rating'] == '5' ) : ?>
                                                    <i class='bx bxs-star'></i>
                                                    <i class='bx bxs-star'></i>
                                                    <i class='bx bxs-star'></i>
                                                    <i class='bx bxs-star'></i>
                                                    <i class='bx bxs-star'></i>
                                                <?php elseif( $value['rating'] == '4' ) : ?>
                                                    <i class='bx bxs-star'></i>
                                                    <i class='bx bxs-star'></i>
                                                    <i class='bx bxs-star'></i>
                                                    <i class='bx bxs-star'></i>
                                                <?php elseif( $value['rating'] == '3' ) : ?>
                                                    <i class='bx bxs-star'></i>
                                                    <i class='bx bxs-star'></i>
                                                    <i class='bx bxs-star'></i>
                                                <?php elseif( $value['rating'] == '2' ) : ?>
                                                    <i class='bx bxs-star'></i>
                                                    <i class='bx bxs-star'></i>
                                                <?php elseif( $value['rating'] == '1' ) : ?>
                                                    <i class='bx bxs-star'></i>
                                                <?php endif; ?>
                                            </div>
                                            <p><?php echo wp_kses_post( $value['feedback'] ); ?></p>
                                            <div class="client-info">
                                                <div class="d-flex align-items-center">
                                                    <?php if( $value['image']['url'] != '' ): ?>
                                                        <img src="<?php echo esc_url( $value['image']['url'] ); ?>" alt="<?php echo esc_attr( $value['author_name'] ) ?>">
                                                    <?php endif; ?>
                                                    <div class="title">
                                                        <h5><?php echo esc_html( $value['author_name'] ); ?></h5>
                                                        <span><?php echo esc_html( $value['designation'] ); ?></span>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
                                    <?php endforeach; ?>
                                </div>
                            </div>
                            <div class="insurance-partner-slides owl-carousel owl-theme">
                                <?php foreach ($partner_slider as $key => $value): ?>
                                    <div class="item">
                                        <?php if( $value['image2']['url'] != '' ): ?>
                                            <img src="<?php echo esc_url( $value['image2']['url'] ); ?>" alt="Partner">
                                        <?php endif; ?>
                                    </div>
                                <?php endforeach; ?>
                            </div>
                        </div>
                    </div>
                    <div class="col-lg-5 col-md-12">
                        <div class="insurance-feedback-image">
                            <?php if( $settings['feedback_featured_img']['url'] != '' ): ?>
                                <img src="<?php echo esc_url( $settings['feedback_featured_img']['url'] ); ?>" alt="Feedback">
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <!-- End Insurance Feedback Area -->

        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_Insurance_Feedback );
