<?php
/**
 * LC About Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_LC_About_Area extends Widget_Base {

	public function get_name() {
        return 'Guto_LC_About';
    }

	public function get_title() {
        return esc_html__( 'LC About', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-info-box';
    }

	public function get_categories() {
        return [ 'guto-life-coaching' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'Guto_LC_About_Area',
			[
				'label' => esc_html__( 'About Controls', 'guto-toolkit' ),
				'tab' 	=> Controls_Manager::TAB_CONTENT,
			]
		);

            $this->add_control(
                'subtitle',
                [
                    'label'     => esc_html__( 'Subtitle', 'guto-toolkit' ),
                    'type'      =>Controls_Manager::TEXT,
                    'default'   => esc_html__('ABOUT ME', 'guto-toolkit'),
                ]
            );

			$this->add_control(
				'title',
				[
					'label' 	=> esc_html__( 'Title', 'guto-toolkit' ),
					'type'      =>Controls_Manager::TEXT,
					'default' 	=> esc_html__("I help individuals to become their best version", 'guto-toolkit'),
				]
			);

			$this->add_control(
                'title_tag',
                [
                    'label' 	=> esc_html__( 'Title Tag', 'guto-toolkit' ),
                    'type' 		=> Controls_Manager::SELECT,
                    'options' 	=> [
                        'h1'         => esc_html__( 'h1', 'guto-toolkit' ),
                        'h2'         => esc_html__( 'h2', 'guto-toolkit' ),
                        'h3'         => esc_html__( 'h3', 'guto-toolkit' ),
                        'h4'         => esc_html__( 'h4', 'guto-toolkit' ),
                        'h5'         => esc_html__( 'h5', 'guto-toolkit' ),
                        'h6'         => esc_html__( 'h6', 'guto-toolkit' ),
                    ],
                    'default' => 'h2',
                ]
            );

			$this->add_control(
				'content',
				[
					'label' 	=> esc_html__( 'Content', 'guto-toolkit' ),
					'type'      =>Controls_Manager:: WYSIWYG,
					'default' 	=> esc_html__('Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Quis ipsum suspendisse.', 'guto-toolkit'),
				]
            );

        $this->end_controls_section();

        $this->start_controls_section(
			'funfacts_section',
			[
				'label' => esc_html__( 'Funfacts Control', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

            $repeater = new Repeater();

            $repeater->add_control(
                'number',
                [
                    'label'       => esc_html__( 'Number', 'guto-toolkit' ),
                    'type'        => Controls_Manager::TEXT,
                    'label_block' => true,
                ]
            );

            $repeater->add_control(
                'counter_sign',
                [
                    'label' => esc_html__( 'Counter Sign', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'label_block'   => true,
                ]
            );

            $repeater->add_control(
                'counter_title',
                [
                    'label' => esc_html__( 'Counter Title', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'label_block'   => true,
                    'default'       => esc_html__( 'FINISHED PROJECTS', 'guto-toolkit' ),
                ]
            );

            $this->add_control(
                'items',
                [
                    'label'   => esc_html__( 'Add Item', 'guto-toolkit' ),
                    'type' => Controls_Manager::REPEATER,
                    'fields' => $repeater->get_controls(),
                ]
            );

        $this->end_controls_section();

        $this->start_controls_section(
            'banner_images',
            [
                'label' => esc_html__( 'Images', 'guto-toolkit' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

             $this->add_control(
                'about_image',
                [
                    'label'     => esc_html__('About Image', 'guto-toolkit'),
                    'type'      => Controls_Manager:: MEDIA,
                ]
            );

            $this->add_control(
                'bg_image',
                [
                    'label'     => esc_html__('Bg Image', 'guto-toolkit'),
                    'type'      => Controls_Manager:: MEDIA,
                ]
            );

        $this->end_controls_section();

    }

	protected function render() {

		$settings = $this->get_settings_for_display(); ?>

        <!-- Start About Area -->
        <div class="lc-about-area ptb-100" style="background-image: url(<?php echo esc_url( $settings['bg_image']['url']); ?> );">
            <div class="container-lg">
                <div class="row align-items-center">
                    <?php if( $settings['image']['url'] != '' ) : ?>
                        <div class="col-lg-6 col-md-12">
                            <div class="lc-about-image">
                                <img src="<?php echo esc_url($settings['about_image']['url']); ?>" alt="<?php echo esc_attr__('image', 'guto-toolkit'); ?>">
                            </div>
                        </div>
                    <?php endif; ?>
                    <div class="col-lg-6 col-md-12">
                        <div class="lc-about-content">
                            <span class="sub-title">
                                <?php echo esc_html( $settings['subtitle'] ); ?>
                            </span>

                            <<?php echo esc_attr( $settings['title_tag'] ); ?>>
                                <?php echo wp_kses_post( $settings['title'] ); ?>
                            </<?php echo esc_attr( $settings['title_tag'] ); ?>>

                            <p><?php echo wp_kses_post( $settings['content'] ); ?></p>

                            <ul class="features-list">
                                <?php foreach( $settings['items'] as $item ): ?>
                                    <li>
                                        <h3><span class="odometer" data-count="<?php echo esc_attr( $item['number'] ); ?>">00</span><span class="sign"><?php echo esc_attr( $item['counter_sign'] ); ?></span></h3>
                                        <p><?php echo esc_html( $item['counter_title'] ); ?></p>
                                    </li>
                                <?php endforeach; ?>
                            </ul>
                        </div>
                    </div>
                </div>
            </div>

        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_LC_About_Area );
