<?php
/**
 * LC Award Logo Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_LC_Award_Logo extends Widget_Base {

	public function get_name() {
        return 'Award Logo';
    }

	public function get_title() {
        return esc_html__( 'Award Logo', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-logo';
    }

	public function get_categories() {
        return [ 'guto-life-coaching' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'award_section',
			[
				'label' => esc_html__( 'Award Logo Control', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

            $this->add_control(
                'title',
                [
                    'label' => esc_html__( 'Title', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__('Awards & Industry Recognition', 'guto-toolkit'),
                ]
            );

            $this->add_control(
                'title_tag',
                [
                    'label' => esc_html__( 'Title Tag', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        'h1'         => esc_html__( 'h1', 'guto-toolkit' ),
                        'h2'         => esc_html__( 'h2', 'guto-toolkit' ),
                        'h3'         => esc_html__( 'h3', 'guto-toolkit' ),
                        'h4'         => esc_html__( 'h4', 'guto-toolkit' ),
                        'h5'         => esc_html__( 'h5', 'guto-toolkit' ),
                        'h6'         => esc_html__( 'h6', 'guto-toolkit' ),
                    ],
                    'default' => 'h2',
                ]
            );

            $this->add_control(
                'logos',
                [
                    'type'    => Controls_Manager::GALLERY,
                    'label'   => esc_html__( 'Add Award Logos', 'guto-toolkit' ),
                ]
            );

        $this->end_controls_section();

    }

	protected function render() {

        $settings = $this->get_settings_for_display(); ?>

            <!-- Start Awards Area -->
            <div class="lc-awards-area pt-100 pb-70">
                <div class="container-lg">
                    <div class="lc-section-title">
                        <<?php echo esc_attr( $settings['title_tag'] ); ?> <?php echo $this-> get_render_attribute_string('title'); ?>><?php echo wp_kses_post( $settings['title'] ); ?></<?php echo esc_attr( $settings['title_tag'] ); ?>>
                    </div>
                    <ul class="lc-awards-list">
                        <?php foreach ( $settings['logos'] as $image ) { ?>
                            <li>
                                <?php if($image['url'] != ''): ?>
                                    <img src="<?php echo esc_url($image['url']); ?>" alt="<?php echo esc_attr($settings['title']); ?>">
                                <?php endif; ?>
                            </li>
                        <?php } ?>
                    </ul>
                </div>
            </div>
            <!-- End Awards Area -->

        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_LC_Award_Logo );
