<?php
/**
 * LC Banner Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_LC_Banner extends Widget_Base {

	public function get_name() {
        return 'Guto_LC_Banner';
    }

	public function get_title() {
        return esc_html__( 'LC Banner', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-banner';
    }

	public function get_categories() {
        return [ 'guto-life-coaching' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'Guto_LC_Banner_Area',
			[
				'label' => esc_html__( 'Banner Controls', 'guto-toolkit' ),
				'tab' 	=> Controls_Manager::TAB_CONTENT,
			]
		);

            $this->add_control(
                'subtitle',
                [
                    'label'     => esc_html__( 'Subtitle', 'guto-toolkit' ),
                    'type'      => Controls_Manager::TEXT,
                    'default'   => __("I am A Life Coach", 'guto-toolkit'),
                ]
            );

			$this->add_control(
				'title',
				[
					'label' 	=> esc_html__( 'Title', 'guto-toolkit' ),
					'type' 		=> Controls_Manager::TEXT,
					'default' 	=> __("You’re Struggling <br>Right Now? <br>I can help.", 'guto-toolkit'),
				]
			);

			$this->add_control(
                'title_tag',
                [
                    'label' 	=> esc_html__( 'Title Tag', 'guto-toolkit' ),
                    'type' 		=> Controls_Manager::SELECT,
                    'options' 	=> [
                        'h1'         => esc_html__( 'h1', 'guto-toolkit' ),
                        'h2'         => esc_html__( 'h2', 'guto-toolkit' ),
                        'h3'         => esc_html__( 'h3', 'guto-toolkit' ),
                        'h4'         => esc_html__( 'h4', 'guto-toolkit' ),
                        'h5'         => esc_html__( 'h5', 'guto-toolkit' ),
                        'h6'         => esc_html__( 'h6', 'guto-toolkit' ),
                    ],
                    'default' => 'h1',
                ]
            );

			$this->add_control(
				'content',
				[
					'label' 	=> esc_html__( 'Content', 'guto-toolkit' ),
					'type' 		=> Controls_Manager::TEXTAREA,
					'default' 	=> esc_html__('Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Quis ipsum suspendisse.', 'guto-toolkit'),
				]
            );

			$this->add_control(
				'button_text',
				[
					'label' 	=> esc_html__( 'Button Text', 'guto-toolkit' ),
					'type' 		=> Controls_Manager::TEXT,
					'default' 	=> esc_html__('Get Your Free Guide Now', 'guto-toolkit'),
				]
            );

            $this->add_control(
                'link_type',
                [
                    'label' 		=> esc_html__( 'Button Link Type', 'guto-toolkit' ),
                    'type' 			=> Controls_Manager::SELECT,
                    'label_block' 	=> true,
                    'options' => [
                        '1'  	=> esc_html__( 'Link To Page', 'guto-toolkit' ),
                        '2' 	=> esc_html__( 'External Link', 'guto-toolkit' ),
                    ],
                    'default' => '2'
                ]
            );

            $this->add_control(
                'link_to_page',
                [
                    'label' 		=> esc_html__( 'Button Link Page', 'guto-toolkit' ),
                    'type' 			=> Controls_Manager::SELECT,
                    'label_block' 	=> true,
                    'options' 		=> guto_toolkit_get_page_as_list(),
                    'condition' => [
                        'link_type' => '1',
                    ]
                ]
            );

            $this->add_control(
                'ex_link',
                [
                    'label'		=> esc_html__('Button External Link', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: URL,
                    'show_external' => true,
                    'default' => [
                        'url' => '#',
                        'is_external' => true,
                        'nofollow' => true,
                    ],
                    'condition' => [
                        'link_type' => '2',
                    ]
                ]
            );

        $this->end_controls_section();

        $this->start_controls_section(
			'banner_images',
			[
				'label' => esc_html__( 'Images', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

            $this->add_control(
                'bg_image',
                [
                    'label'     => esc_html__('Banner Bg Image', 'guto-toolkit'),
                    'type'      => Controls_Manager:: MEDIA,
                    'show_label' => true,
                ]
            );

            $this->add_control(
                'image',
                [
                    'label'		=> esc_html__('Banner Image', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: MEDIA,
                    'show_label' => true,
                ]
            );

        $this->end_controls_section();

    }

	protected function render() {

		$settings = $this->get_settings_for_display();

        // Inline Editing
        $this-> add_inline_editing_attributes('title','none');
        $this-> add_inline_editing_attributes('content','none');

        // Get Button Link
        if($settings['link_type'] == 1){
            $link = get_page_link( $settings['link_to_page'] );
        } elseif($settings['link_type'] == 2) {
            $link = $settings['ex_link']['url'];
            $target = $settings['ex_link']['is_external'] ? ' target="_blank"' : '';
		    $nofollow = $settings['ex_link']['nofollow'] ? ' rel="nofollow"' : '';
        }

        $button_text = $settings['button_text']; ?>

        <!-- Start Main Banner Area -->
        <div class="lc-main-banner-area" style="background-image: url(<?php echo esc_url( $settings['bg_image']['url']); ?> );">
            <div class="container-lg">
                <div class="row align-items-center">
                    <div class="col-lg-6 col-md-12">
                        <div class="lc-main-banner-content">
                            <span class="sub-title"><?php echo esc_html( $settings['subtitle'] ); ?></span>
                            <<?php echo esc_attr( $settings['title_tag'] ); ?> <?php echo $this-> get_render_attribute_string('title'); ?>>
                                <?php echo wp_kses_post( $settings['title'] ); ?>
                            </<?php echo esc_attr( $settings['title_tag'] ); ?>>
                            <p <?php echo $this-> get_render_attribute_string('content'); ?>><?php echo wp_kses_post( $settings['content'] ); ?></p>

                            <?php if( $button_text != '' ): ?>
                                <?php if($settings['link_type'] == 1): ?>
                                    <a href="<?php echo esc_url( $link ); ?>" class="lc-default-btn"><i class='bx bx-paper-plane'></i><?php echo esc_html( $button_text ); ?></a>
                                <?php elseif($settings['link_type'] == 2):
                                    echo '<a href="' .  $link . '" class="lc-default-btn" ' . $target . $nofollow . '>' .'<i class="bx bx-paper-plane"></i>' . $button_text . ' </a>';
                                endif; ?>
                            <?php endif; ?>
                        </div>
                    </div>
                    <div class="col-lg-6 col-md-12">
                        <div class="lc-main-banner-image">
                            <?php if( $settings['image']['url'] != '' ): ?>
                                <img src="<?php echo esc_url($settings['image']['url']); ?>" alt="<?php echo esc_attr($settings['title']); ?>">
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <!-- End Main Banner Area -->
        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_LC_Banner );
