<?php
/**
 * LC Contact Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

class Guto_LC_Contact extends Widget_Base {

    public function get_name() {
        return 'LC_Contact_Area';
    }

    public function get_title() {
        return esc_html__( 'LC Contact', 'guto-toolkit' );
    }

    public function get_icon() {
        return 'eicon-form-horizontal';
    }

    public function get_categories() {
        return [ 'guto-life-coaching' ];
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'LC_Contact_Area',
            [
                'label' => esc_html__( 'Contact', 'guto-toolkit' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

            $this->add_control(
                'contact_info_enable',
                [
                    'label' => esc_html__( 'Enable Contact Info Area', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        '1'         => esc_html__( 'Enable', 'guto-toolkit' ),
                        '2'         => esc_html__( 'Disable', 'guto-toolkit' ),
                    ],
                    'default' => '1',
                ]
            );

            $this->add_control(
                'contact_form_enable',
                [
                    'label' => esc_html__( 'Enable Contact Form Area', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        '1'         => esc_html__( 'Enable', 'guto-toolkit' ),
                        '2'         => esc_html__( 'Disable', 'guto-toolkit' ),
                    ],
                    'default' => '1',
                ]
            );

            $this->add_control(
                'contact_form_subtitle', [
                    'label' => esc_html__( 'Form Subtitle', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'label_block' => true,
                    'default' => 'GET IN TOUCH',
                    'condition' => [
                        'contact_form_enable' => '1',
                    ]
                ]
            );

            $this->add_control(
                'contact_form_title', [
                    'label' => esc_html__( 'Form Title', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'label_block' => true,
                    'default' => 'Ready to Get Started?',
                    'condition' => [
                        'contact_form_enable' => '1',
                    ]
                ]
            );

            $this->add_control(
                'shortcode',
                [
                    'label' => esc_html__( 'Contact Shortcode', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'condition' => [
                        'contact_form_enable' => '1',
                    ]
                ]
            );

            $this->add_control(
                'guto_contact_info',
                [
                    'label' => esc_html__('List Item', 'guto-toolkit'),
                    'type' => Controls_Manager::REPEATER,
                    'separator' => 'before',
                    'fields' => [
                        [
                            'name'       => 'icon',
                            'label'      => esc_html__( 'Icon', 'guto-toolkit' ),
                            'type'       => Controls_Manager::MEDIA,
                            'show_label' => true,
                        ],
                        [
                            'name'      => 'content',
                            'label'     => esc_html__( 'Content', 'guto-toolkit' ),
                            'type'      => Controls_Manager::TEXTAREA,
                            'default'   => __('<a href="mailto:hello@guto.com">hello@guto.com</a>', 'guto-toolkit'),
                        ],
                    ],
                    'condition' => [
                        'contact_info_enable' => '1',
                    ]
                ]
            );

        $this->end_controls_section();
    }

    protected function render() {

        $settings = $this->get_settings_for_display();

        // Inline Editing
        $this-> add_inline_editing_attributes('title', 'none');
        $guto_contact_info = $settings['guto_contact_info'];

        ?>

        <?php if( $settings['contact_info_enable'] == '1' ) : ?>
        <!-- Start Contact Info Area -->
        <div class="lc-contact-info-area pt-100 pb-70">
            <div class="container-lg">
                <div class="row align-items-center justify-content-center">
                    <?php foreach ($guto_contact_info as $key => $value) : ?>
                        <div class="col-lg-4 col-sm-6 col-md-4">
                            <div class="lc-contact-info-box">
                                <div class="d-table">
                                    <div class="d-table-cell">
                                        <?php if( $value['icon']['url'] != '' ): ?>
                                            <div class="icon">
                                                <img src="<?php echo esc_url($value['icon']['url']); ?>" alt="<?php esc_attr_e('Icon', 'guto-toolkit'); ?>">
                                            </div>
                                        <?php endif; ?>
                                        <h3><?php echo wp_kses_post($value['content']); ?></h3>
                                    </div>
                                </div>
                            </div>
                        </div>
                    <?php endforeach; ?>
                </div>
            </div>
        </div>
        <!-- End Contact Info Area -->
        <?php endif; ?>

        <?php if( $settings['contact_form_enable'] == '1' ) : ?>
            <!-- Start Contact Form Area -->
            <div class="lc-contact-area pb-100">
                <div class="container-lg">
                    <div class="lc-section-title">
                        <span class="sub-title"><?php echo esc_html( $settings['contact_form_subtitle']); ?></span>
                        <h2><?php echo esc_html( $settings['contact_form_title']); ?></h2>
                    </div>
                    <?php if($settings['shortcode']): ?>
                        <div class="lc-contact-form">
                            <?php echo do_shortcode( $settings['shortcode'] ); ?>
                        </div>
                    <?php endif; ?>
                </div>
            </div>
            <!-- End Contact Form Area -->
        <?php endif; ?>

        <?php
    }



}

Plugin::instance()->widgets_manager->register( new Guto_LC_Contact );
