<?php
/**
 * LC Countdown Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

class Guto_LC_Countdown extends Widget_Base {

    public function get_name() {
        return 'LC Countdown';
    }

    public function get_title() {
        return esc_html__( 'LC Countdown', 'guto-toolkit' );
    }

    public function get_icon() {
        return 'eicon-form-horizontal';
    }

    public function get_categories() {
        return [ 'guto-life-coaching' ];
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'LC_Countdown_Area',
            [
                'label' => esc_html__( 'Countdown', 'guto-toolkit' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

            $this->add_control(
                'countdown_date', [
                    'label' => esc_html__( 'Date & Time', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'label_block' => true,
                    'default' => 'September 20, 2021 17:00:00',
                ]
            );

        $this->end_controls_section();

        $this->start_controls_section(
            'style',
            [
                'label' => esc_html__( 'Style', 'guto-toolkit' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

            $this->add_control(
                'bg_color',
                [
                    'label' => esc_html__( 'Background Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .lc-events-details-area.bg-f9f9f9' => 'background-color: {{VALUE}}',
                    ],
                ]
            );

        $this->end_controls_section();
    }

    protected function render() {

        global $post;

        $settings = $this->get_settings_for_display();
        global $EM_Event, $post;
        $hours_format = em_get_hour_format();
        $countdown_date = $settings['countdown_date']; ?>

        <div class="lc-events-details-area ptb-100 bg-f9f9f9">
            <div class="container-lg">
                <div class="row align-items-center">
                    <div class="col-lg-6 col-md-12">
                        <div class="lc-events-details-header">
                            <span class="date">
                                <?php the_time('d M, Y'); ?>
                            </span>
                            <h2><?php the_title(); ?></h2>
                            <?php
                            global $EM_Location;
                            if( $EM_Event->location_id !== 0 ){
                                $EM_Location = $EM_Event->get_location();
                            }elseif(get_option('dbem_default_location') > 0){
                                $EM_Location = em_get_location(get_option('dbem_default_location'));
                            }else{
                                $EM_Location = new EM_Location();
                            }
                            ?>
                            <ul class="time-location">
                                <li><i class='bx bx-time-five'></i>
                                    <?php echo esc_attr( $EM_Event->start()->format($hours_format) ); ?>
                                    <?php echo esc_attr( '- ' . $EM_Event->end()->format($hours_format) ); ?>
                                </li>
                                <li><i class='bx bx-map'></i><?php echo esc_attr($EM_Location->location_address); ?> </i></li>
                            </ul>
                            <div id="timer" class="flex-wrap d-flex">
                                <div id="event_days" class="align-items-center flex-column d-flex justify-content-center"></div>
                                <div id="event_hours" class="align-items-center flex-column d-flex justify-content-center"></div>
                                <div id="event_minutes" class="align-items-center flex-column d-flex justify-content-center"></div>
                                <div id="event_seconds" class="align-items-center flex-column d-flex justify-content-center"></div>
                            </div>
                        </div>
                    </div>
                    <div class="col-lg-6 col-md-12">
                        <div class="lc-events-details-image">
                            <?php the_post_thumbnail(); ?>
                        </div>
                    </div>
                </div>
            </div>
        </div>

        <script type="text/javascript">
            // Count Time
            function makeTimer() {
                var endTime = new Date("<?php echo esc_attr($countdown_date); ?> PDT");
                var endTime = (Date.parse(endTime)) / 1000;
                var now = new Date();
                var now = (Date.parse(now) / 1000);
                var timeLeft = endTime - now;
                var days = Math.floor(timeLeft / 86400);
                var hours = Math.floor((timeLeft - (days * 86400)) / 3600);
                var minutes = Math.floor((timeLeft - (days * 86400) - (hours * 3600 )) / 60);
                var seconds = Math.floor((timeLeft - (days * 86400) - (hours * 3600) - (minutes * 60)));
                if (hours < "10") { hours = "0" + hours; }
                if (minutes < "10") { minutes = "0" + minutes; }
                if (seconds < "10") { seconds = "0" + seconds; }
                jQuery("#event_days").html(days + "<span>Days</span>");
                jQuery("#event_hours").html(hours + "<span>Hours</span>");
                jQuery("#event_minutes").html(minutes + "<span>Minutes</span>");
                jQuery("#event_seconds").html(seconds + "<span>Seconds</span>");
            }
            setInterval(function() { makeTimer(); }, 0);

        </script>

        <?php
    }



}

Plugin::instance()->widgets_manager->register( new Guto_LC_Countdown );
