<?php

/**
 * Courses Widget
 */

namespace Elementor;

class Guto_LC_Courses extends Widget_Base {

	public function get_name() {
        return 'LC Courses';
    }

	public function get_title() {
        return esc_html__( 'LC Courses', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-lightbox';
    }

	public function get_categories() {
        return [ 'guto-life-coaching' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'courses_section',
			[
				'label' => esc_html__( 'Courses', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

            $this->add_control(
                'show_hide_course_details',
                [
                    'label'         => esc_html__( 'Show/Hide Course Details', 'guto-toolkit' ),
                    'type'          => Controls_Manager::SELECT,
                    'label_block'   => true,
                    'options' => [
                        '1'     => esc_html__( 'Show', 'guto-toolkit' ),
                        '2'     => esc_html__( 'Hide', 'guto-toolkit' ),
                    ],
                    'default' => '1'
                ]
            );

            $this->add_control(
                'subtitle',
                [
                    'label' => __( 'Subtitle', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__('MY COURSES', 'guto-toolkit'),
                    'condition' => [
                        'show_hide_course_details' => '1',
                    ]
                ]
            );

            $this->add_control(
                'title',
                [
                    'label' => __( 'Title', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__('Guto Popular Courses', 'guto-toolkit'),
                    'condition' => [
                        'show_hide_course_details' => '1',
                    ]
                ]
            );

            $this->add_control(
                'title_tag',
                [
                    'label' => esc_html__( 'Title Tag', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        'h1'         => esc_html__( 'h1', 'guto-toolkit' ),
                        'h2'         => esc_html__( 'h2', 'guto-toolkit' ),
                        'h3'         => esc_html__( 'h3', 'guto-toolkit' ),
                        'h4'         => esc_html__( 'h4', 'guto-toolkit' ),
                        'h5'         => esc_html__( 'h5', 'guto-toolkit' ),
                        'h6'         => esc_html__( 'h6', 'guto-toolkit' ),
                    ],
                    'default' => 'h2',
                    'condition' => [
                        'show_hide_course_details' => '1',
                    ]
                ]
            );

            $this->add_control(
                'content',
                [
                    'label' => esc_html__( 'Content', 'guto-toolkit' ),
                    'type' => Controls_Manager::WYSIWYG,
                    'default' => __('Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Quis ipsum suspendisse.', 'guto-toolkit'),
                    'condition' => [
                        'show_hide_course_details' => '1',
                    ]
                ]
            );

            $this->add_control(
                'columns',
                [
                    'label' => esc_html__( 'Choose Columns', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        '1'   => esc_html__( '1', 'guto-toolkit' ),
                        '2'   => esc_html__( '2', 'guto-toolkit' ),
                        '3'   => esc_html__( '3', 'guto-toolkit' ),
                        '4'   => esc_html__( '4', 'guto-toolkit' ),
                    ],
                    'default' => '3',
                ]
            );

            $this->add_control(
                'order',
                [
                    'label' => esc_html__( 'Courses Order By', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        'DESC'      => esc_html__( 'DESC', 'guto-toolkit' ),
                        'ASC'       => esc_html__( 'ASC', 'guto-toolkit' ),
                    ],
                    'default' => 'DESC',
                ]
            );

            $this->add_control(
                'count',
                [
                    'label' => esc_html__( 'Posts Per Page', 'guto-toolkit' ),
                    'type' => Controls_Manager::NUMBER,
                    'default' => 3,
                ]
            );

            $this->add_control(
                'button_icon',
                [
                    'label' => esc_html__( 'Button Icon', 'guto-toolkit' ),
                    'type' => Controls_Manager::ICON,
                    'label_block' => true,
                    'options' => guto_toolkit_icons(),
                    'default' => 'bx bx-book',
                    'condition' => [
                        'show_hide_pagination' => '2',
                    ]
                ]
            );

            $this->add_control(
                'button_text',
                [
                    'label'     => esc_html__( 'Button Text', 'guto-toolkit' ),
                    'type'      => Controls_Manager::TEXT,
                    'default'   => esc_html__('View All Courses', 'guto-toolkit'),
                    'condition' => [
                        'show_hide_pagination' => '2',
                    ]
                ]
            );

            $this->add_control(
                'link_type',
                [
                    'label'         => esc_html__( 'Button Link Type', 'guto-toolkit' ),
                    'type'          => Controls_Manager::SELECT,
                    'label_block'   => true,
                    'options' => [
                        '1'     => esc_html__( 'Link To Page', 'guto-toolkit' ),
                        '2'     => esc_html__( 'External Link', 'guto-toolkit' ),
                    ],
                    'default' => '2',
                    'condition' => [
                        'show_hide_pagination' => '2',
                    ]
                ]
            );

            $this->add_control(
                'link_to_page',
                [
                    'label'         => esc_html__( 'Button Link Page', 'guto-toolkit' ),
                    'type'          => Controls_Manager::SELECT,
                    'label_block'   => true,
                    'options'       => guto_toolkit_get_page_as_list(),
                    'condition' => [
                        'link_type' => '1',
                        'show_hide_pagination' => '2'
                    ]
                ]
            );

            $this->add_control(
                'ex_link',
                [
                    'label'     => esc_html__('Button External Link', 'guto-toolkit'),
                    'type'      => Controls_Manager:: URL,
                    'show_external' => true,
                    'default' => [
                        'url' => '#',
                        'is_external' => true,
                        'nofollow' => true,
                    ],
                    'condition' => [
                        'link_type' => '2',
                        'show_hide_pagination' => '2'
                    ]
                ]
            );

            $this->add_control(
                'show_hide_pagination',
                [
                    'label'         => esc_html__( 'Show/Hide Pagination', 'guto-toolkit' ),
                    'type'          => Controls_Manager::SELECT,
                    'label_block'   => true,
                    'options' => [
                        '1'     => esc_html__( 'Show', 'guto-toolkit' ),
                        '2'     => esc_html__( 'Hide', 'guto-toolkit' ),
                    ],
                    'default' => '2'
                ]
            );

        $this->end_controls_section();

    }

	protected function render() {

        $settings = $this->get_settings_for_display();

         // Get Button Link
        if($settings['link_type'] == 1){
            $link = get_page_link( $settings['link_to_page'] );
        } elseif($settings['link_type'] == 2) {
            $link = $settings['ex_link']['url'];
            $target = $settings['ex_link']['is_external'] ? ' target="_blank"' : '';
            $nofollow = $settings['ex_link']['nofollow'] ? ' rel="nofollow"' : '';
        }

        $button_text = $settings['button_text'];

        // Card Columns
        $columns = $settings['columns'];
        if ($columns == '1') {
            $column = 'col-lg-12 col-sm-6 col-md-6';
        }elseif ($columns == '2') {
            $column = 'col-lg-6 col-sm-6 col-md-6';
        }elseif ($columns == '3') {
            $column = 'col-lg-4 col-sm-6 col-md-6';
        }elseif ($columns == '4') {
            $column = 'col-lg-3 col-sm-6 col-md-6';
        }

        // Courses Query
        $paged = ( get_query_var( 'paged' ) ) ? get_query_var( 'paged' ) : 1;
        $args = array(
            'post_type'         => 'lp_course',
            'posts_per_page'    => $settings['count'],
            'order'             => $settings['order'],
            'paged' => $paged,
        );
        $courses_array = new \WP_Query( $args );

        ?>

        <!-- Start Courses Area -->
        <div class="lc-courses-area ptb-100">
            <div class="container-lg">
                <?php if( $settings['show_hide_course_details'] == '1' ) : ?>
                    <div class="lc-section-title">
                        <span class="sub-title"><?php echo esc_html( $settings['subtitle'] ); ?></span>
                        <<?php echo esc_attr( $settings['title_tag'] ); ?>>
                        <?php echo wp_kses_post( $settings['title'] ); ?>
                        </<?php echo esc_attr( $settings['title_tag'] ); ?>>
                        <p><?php echo wp_kses_post( $settings['content'] ); ?></p>
                    </div>
                <?php endif; ?>
                <div class="row justify-content-center">
                    <?php if ( guto_toolkit_plugin_active( 'learnpress/learnpress.php' ) ) { ?>
                    <?php while($courses_array->have_posts()): $courses_array->the_post(); ?>
                        <div class="<?php echo esc_attr( $column );?>">
                            <div class="single-lc-courses-box">
                                <?php if( get_the_post_thumbnail_url() ): ?>
                                    <a href="<?php the_permalink(); ?>" class="image d-block">
                                        <img src="<?php the_post_thumbnail_url(); ?>" alt="<?php the_title(); ?>">
                                    </a>
                                <?php endif; ?>
                                <div class="content">
                                    <h3><a href="<?php the_permalink(); ?>"><?php the_title(); ?></h3>
                                    <ul class="courses-box-list d-flex align-items-center justify-content-between">
                                        <li><i class='bx bx-book'></i> <?php global $course; learn_press_label_html( $course->count_items( LP_LESSON_CPT ) . ' Lessons' ); ?></li>
                                        <li><i class='bx bx-group'></i> <?php echo $course->get_students_html(); ?></li>
                                    </ul>
                                    <ul class="courses-box-footer d-flex align-items-center justify-content-between">
                                        <li>
                                            <div class="author">
                                                <div class="d-flex align-items-center justify-content-center">
                                                    <?php
                                                    $get_author_id = get_the_author_meta('ID');
                                                    $get_author_gravatar = get_avatar_url($get_author_id, array('size' => 50)); ?>
                                                    <img src="<?php echo esc_url($get_author_gravatar); ?>" alt="<?php echo esc_attr( get_the_author() ); ?>">
                                                    <span>
                                                        <?php if(get_the_author() == ''): ?>
                                                        <?php
                                                        $blogusers = get_users( array( 'fields' => array( 'display_name' )) );
                                                        // Array of stdClass objects.
                                                        foreach ( $blogusers as $user ) {
                                                            echo '<span>' . esc_html( $user->display_name ) . '</span>';
                                                        } ?>
                                                        <?php else: ?>
                                                            <?php printf($course->get_instructor_html()); ?>
                                                        <?php endif; ?>
                                                    </span>
                                                </div>
                                            </div>
                                        </li>
                                        <?php $price_html = $course->get_price_html(); if ( $price_html ) : ?>
                                            <li>
                                                <?php if ( $course->get_origin_price() != $course->get_price() ) : ?>
                                                    <div class="price-new">
                                                        <span class="origin-price"><?php echo esc_html( $course->get_origin_price_html() ); ?></span>
                                                        <span>
                                                            <del><?php echo esc_html( $price_html ); ?></del>
                                                        </span>
                                                    </div>
                                                <?php else : ?>
                                                    <div class="price">
                                                        <span><?php echo esc_html( $price_html ); ?></span>
                                                    </div>
                                                <?php endif; ?>
                                            </li>
                                        <?php endif; ?>
                                    </ul>
                                </div>
                            </div>
                        </div>
                    <?php endwhile; wp_reset_query(); ?>
                    <?php if( $settings['show_hide_pagination'] == '2' ) : ?>
                        <div class="col-lg-12 col-md-12">
                            <div class="lc-all-courses-btn">
                                <?php if( $button_text != '' ): ?>
                                    <?php if($settings['link_type'] == 1) : ?>
                                        <a href="<?php echo esc_url( $link ); ?>" class="lc-default-btn"><i class="<?php echo esc_attr( $settings['button_icon'] ); ?>"></i> <?php echo esc_html( $button_text ); ?></a>
                                    <?php elseif($settings['link_type'] == 2) :
                                        echo '<a href="' .  $link . '" class="lc-default-btn" ' . $target . $nofollow . '> <i class="'.$settings['button_icon'].'"></i> ' . $button_text . '</a>';
                                    endif; ?>
                                <?php endif; ?>
                            </div>
                        </div>
                    <?php endif; ?>
                </div>
                <?php if( $settings['show_hide_pagination'] == '1' ) : ?>
                    <div class="col-lg-12 col-md-12 col-sm-12">
                        <div class="lc-pagination-area">
                            <?php

                            global $wp_query;

                            if ( $courses_array->max_num_pages <= 1 ) {
                                return;
                            }
                            ?>

                            <nav class="nav-links">
                                <?php echo paginate_links( apply_filters( 'learn_press_pagination_args', array(
                                    'base'      => esc_url_raw( str_replace( 999999999, '%#%', get_pagenum_link( 999999999, false ) ) ),
                                    'format'    => '',
                                    'add_args'  => '',
                                    'current'   => max( 1, get_query_var( 'paged' ) ),
                                    'total'     => $courses_array->max_num_pages,
                                    'prev_text' => '<i class="bx bx-left-arrow-alt"></i>',
                                    'next_text' => '<i class="bx bx-right-arrow-alt"></i>',
                                    'end_size'  => 3,
                                    'mid_size'  => 3
                                ) ) );
                                ?>
                            </nav>
                        </div>
                    </div>
                <?php endif; ?>
                <?php }
                else {
                    echo wp_kses_post('<p class="course-empty-note">Please install and activate <a href="https://wordpress.org/plugins/learnpress/">LearnPress</a> to get courses.</p>', 'guto-toolkit');
                } ?>
            </div>
        </div>
        <!-- End Courses Area -->

        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_LC_Courses );
