<?php
/**
 * LC Feedback Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_LC_Feedback extends Widget_Base {

	public function get_name() {
        return 'LC Feedback';
    }

	public function get_title() {
        return esc_html__( 'LC Feedback', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-testimonial';
    }

	public function get_categories() {
        return [ 'guto-life-coaching' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'content_section',
			[
				'label' => esc_html__( 'Feedback Content', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

            $this->add_control(
				'name',
				[
                    'label'       => esc_html__('Name', 'guto-toolkit'),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => esc_html__('John Smith', 'guto-toolkit'),
                    'label_block' => true,
				]
            );

            $this->add_control(
                'designation',
                [
                    'label'       => esc_html__('Designation', 'guto-toolkit'),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => esc_html__('Web Developer', 'guto-toolkit'),
                    'label_block' => true,
                ]
            );

            $this->add_control(
                'feedback',
                [
                    'label'       => esc_html__('Feedback Content', 'guto-toolkit'),
                    'type'        => Controls_Manager::TEXTAREA,
                    'default'     => esc_html__('Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Quis ipsum suspendisse ultrices gravida. Risus commodo viverra maecenas acculcan.', 'guto-toolkit'),
                    'label_block' => true,
                ]
            );

            $this->add_control(
                'bg_image',
                [
                    'label'     => esc_html__('Bg Image', 'guto-toolkit'),
                    'type'      => Controls_Manager:: MEDIA,
                ]
            );

            $this->add_control(
                'feedback_image',
                [
                    'label'		=> esc_html__('Featured Image', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: MEDIA,
                ]
            );

            $this->add_control(
                'author_image',
                [
                    'label'     => esc_html__('Author Image', 'guto-toolkit'),
                    'type'      => Controls_Manager:: MEDIA,
                ]
            );

            $this->add_control(
                'star_count',
                [
                    'label' => __( 'Choose Star', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'label_block' => true,
                    'options' => [
                        '1' => __( '1', 'guto-toolkit' ),
                        '2' => __( '2', 'guto-toolkit' ),
                        '3' => __( '3', 'guto-toolkit' ),
                        '4' => __( '4', 'guto-toolkit' ),
                        '5' => __( '5', 'guto-toolkit' ),
                    ],
                    'default' => '5',
                ]
            );

        $this->end_controls_section();

        $this->start_controls_section(
            'style',
            [
                'label' => esc_html__( 'Style', 'guto-toolkit' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

            $this->add_control(
                'bg_color',
                [
                    'label' => esc_html__( 'Background Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .lc-feedback-area' => 'background-color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_control(
                'name_color',
                [
                    'label' => esc_html__( 'Name Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .lc-feedback-content .client-info .title h3' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'name_typography',
                    'label' => esc_html__( 'Name Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .lc-feedback-content .client-info .title h3',
                ]
            );
            $this->add_control(
                'des_color',
                [
                    'label' => esc_html__( 'Designation Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .lc-feedback-content .client-info .title span' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'des_typography',
                    'label' => esc_html__( 'Designation Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .lc-feedback-content .client-info .title span',
                ]
            );

            $this->add_control(
                'feed_color',
                [
                    'label' => esc_html__( 'Feedback Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .lc-feedback-content p' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'feed_typography',
                    'label' => esc_html__( 'Feedback Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .lc-feedback-content p',
                ]
            );

        $this->end_controls_section();

    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        // Inline Editing
        $this-> add_inline_editing_attributes('title', 'none'); ?>

        <!-- Start Feedback Area -->
        <div class="lc-feedback-area pt-100" style="background-image: url(<?php echo esc_url( $settings['bg_image']['url']); ?> );">
            <div class="container-lg">
                <div class="row align-items-center">
                    <div class="col-lg-4 col-md-12">
                        <div class="lc-feedback-image">
                            <?php if( $settings['feedback_image']['url'] ) : ?>
                                <img src="<?php echo esc_url( $settings['feedback_image']['url'] ); ?>" alt="feedback">
                            <?php endif; ?>
                        </div>
                    </div>
                    <div class="col-lg-8 col-md-12">
                        <div class="lc-feedback-content">
                            <div class="rating">
                                <?php if( $settings['star_count'] == 1 ) { ?>
                                    <i class="bx bxs-star" aria-hidden="true"></i>
                                <?php } elseif( $settings['star_count'] == 2 ) { ?>
                                    <i class="bx bxs-star" aria-hidden="true"></i>
                                    <i class="bx bxs-star" aria-hidden="true"></i>
                                <?php } elseif( $settings['star_count'] == 3 ) { ?>
                                    <i class="bx bxs-star" aria-hidden="true"></i>
                                    <i class="bx bxs-star" aria-hidden="true"></i>
                                    <i class="bx bxs-star" aria-hidden="true"></i>
                                <?php } elseif( $settings['star_count'] == 4 ) { ?>
                                    <i class="bx bxs-star" aria-hidden="true"></i>
                                    <i class="bx bxs-star" aria-hidden="true"></i>
                                    <i class="bx bxs-star" aria-hidden="true"></i>
                                    <i class="bx bxs-star" aria-hidden="true"></i>
                                <?php } elseif( $settings['star_count'] == 5 ) { ?>
                                    <i class="bx bxs-star" aria-hidden="true"></i>
                                    <i class="bx bxs-star" aria-hidden="true"></i>
                                    <i class="bx bxs-star" aria-hidden="true"></i>
                                    <i class="bx bxs-star" aria-hidden="true"></i>
                                    <i class="bx bxs-star" aria-hidden="true"></i>
                                <?php } ?>
                            </div>
                            <p><?php echo wp_kses_post( $settings['feedback'] ); ?></p>
                            <div class="client-info d-flex align-items-center">
                                <?php if( $settings['author_image']['url'] != '' ) : ?>
                                    <img src="<?php echo esc_url($settings['author_image']['url']); ?>" alt="<?php echo esc_attr__('user image','guto-toolkit'); ?>">
                                <?php endif; ?>
                                <div class="title">
                                    <h3><?php echo esc_html( $settings['name'] ); ?></h3>
                                    <span><?php echo esc_html( $settings['designation'] ); ?></span>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <!-- End Feedback Area -->
        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_LC_Feedback );
