<?php
/**
 * LC Newsletter Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

class Guto_LC_Newsletter extends Widget_Base {

    public function get_name() {
        return 'Guto_LC_Newsletter';
    }

    public function get_title() {
        return __( 'LC Newsletter', 'guto-toolkit' );
    }

    public function get_icon() {
        return 'eicon-email-field';
    }

    public function get_categories() {
        return [ 'guto-life-coaching' ];
    }

    public function get_keywords() {
        return [ 'mailchimp', 'form', 'newsletter' ];
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'Guto_Newsletter',
            [
                'label' => esc_html__( 'Guto Newsletter', 'guto-toolkit' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

            $this->add_control(
                'action_url', [
                    'label' => esc_html__( 'Action URL', 'guto-toolkit' ),
                    'description' => __( 'Enter here your MailChimp action URL. <a href="https://doc.gutotheme.com/docs/tips-guides-troubleshoots/get-mailchimp-newsletter-form-action-url/" target="_blank"> How to </a>', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'label_block' => true,
                ]
            );

            $this->add_control(
                'subtitle',
                [
                    'label' => __( 'Subtitle', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__('NEWSLETTER', 'guto-toolkit'),
                ]
            );

            $this->add_control(
                'title',
                [
                    'label' => __( 'Title', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__('Get Weekly Updates', 'guto-toolkit'),
                ]
            );

            $this->add_control(
                'title_tag',
                [
                    'label' => esc_html__( 'Title Tag', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        'h1'         => esc_html__( 'h1', 'guto-toolkit' ),
                        'h2'         => esc_html__( 'h2', 'guto-toolkit' ),
                        'h3'         => esc_html__( 'h3', 'guto-toolkit' ),
                        'h4'         => esc_html__( 'h4', 'guto-toolkit' ),
                        'h5'         => esc_html__( 'h5', 'guto-toolkit' ),
                        'h6'         => esc_html__( 'h6', 'guto-toolkit' ),
                    ],
                    'default' => 'h2',
                ]
            );

            $this->add_control(
                'content',
                [
                    'label' => esc_html__( 'Content', 'guto-toolkit' ),
                    'type' => Controls_Manager::WYSIWYG,
                    'default' => __('Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Quis ipsum suspendisse.', 'guto-toolkit'),
                ]
            );

            $this->add_control(
                'placeholder_text', [
                    'label' => esc_html__( 'Email Placeholder Text', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__( 'Enter your email address' , 'guto-toolkit' ),
                    'label_block' => true,
                ]
            );

            $this->add_control(
                'button_text', [
                    'label' => esc_html__( 'Button text', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__( 'Subscribe Now' , 'guto-toolkit' ),
                    'label_block' => true,
                ]
            );

            $this->add_control(
                'button_icon',
                [
                    'label' => esc_html__( 'Button Icon', 'guto-toolkit' ),
                    'type' => Controls_Manager::ICON,
                    'label_block' => true,
                    'options' => guto_toolkit_icons(),
                    'default' => 'bx bx-paper-plane'
                ]
            );

        $this->end_controls_section();

    }

    protected function render() {

        $settings = $this->get_settings_for_display();

        // Inline Editing
        $this-> add_inline_editing_attributes('title', 'none');
        $this-> add_inline_editing_attributes('content', 'none'); ?>

        <!-- Start LC Newsletter Area -->
        <div class="lc-subscribe-area pb-100">
            <div class="container-lg">
                <div class="lc-subscribe-content">
                    <span class="sub-title"><?php echo esc_html( $settings['subtitle'] ); ?></span>
                    <<?php echo esc_attr( $settings['title_tag'] ); ?> <?php echo $this-> get_render_attribute_string('title'); ?>>
                        <?php echo wp_kses_post( $settings['title'] ); ?>
                    </<?php echo esc_attr( $settings['title_tag'] ); ?>>
                    <p><?php echo wp_kses_post( $settings['content'] ); ?></p>
                    <form class="mailchimp newsletter-form" method="post">
                        <input type="email" class="input-newsletter" placeholder="<?php echo esc_attr( $settings['placeholder_text'] ); ?>" name="EMAIL" required>
                        <?php if( $settings['button_text'] != '' ): ?>
                            <button type="submit" class="lc-default-btn"><i class="<?php echo esc_attr( $settings['button_icon'] ); ?>"></i> <?php echo esc_html( $settings['button_text'] ); ?></button>
                        <?php endif; ?>
                        <p class="mchimp-errmessage" style="display: none;"></p>
                        <p class="mchimp-sucmessage" style="display: none;"></p>
                    </form>
                </div>
            </div>
        </div>
        <!-- End LC Newsletter Area -->

            <script>
                ;(function($){
                    "use strict";
                    $(document).ready(function () {
                        // MAILCHIMP
                        if ($(".mailchimp").length > 0) {
                            $(".mailchimp").ajaxChimp({
                                callback: mailchimpCallback,
                                url: "<?php echo esc_js($settings['action_url']) ?>"
                            });
                        }
                        $(".memail").on("focus", function () {
                            $(".mchimp-errmessage").fadeOut();
                            $(".mchimp-sucmessage").fadeOut();
                        });
                        $(".memail").on("keydown", function () {
                            $(".mchimp-errmessage").fadeOut();
                            $(".mchimp-sucmessage").fadeOut();
                        });
                        $(".memail").on("click", function () {
                            $(".memail").val("");
                        });

                        function mailchimpCallback(resp) {
                            if (resp.result === "success") {
                                $(".mchimp-errmessage").html(resp.msg).fadeIn(1000);
                                $(".mchimp-sucmessage").fadeOut(500);
                            } else if (resp.result === "error") {
                                $(".mchimp-errmessage").html(resp.msg).fadeIn(1000);
                            }
                        }
                    });
                })(jQuery)
            </script>
    <?php
    }



}

Plugin::instance()->widgets_manager->register( new Guto_LC_Newsletter );
