<?php
/**
 * FLS About Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_FLS_About_Area extends Widget_Base {

	public function get_name() {
        return 'Guto_FLS_About';
    }

	public function get_title() {
        return esc_html__( 'FLS About', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-info-box';
    }

	public function get_categories() {
        return [ 'guto-lifestyle-blog' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'Guto_FLS_About_Area',
			[
				'label' => esc_html__( 'About Controls', 'guto-toolkit' ),
				'tab' 	=> Controls_Manager::TAB_CONTENT,
			]
		);

			$this->add_control(
				'about_title',
				[
					'label' 	=> esc_html__( 'Add About Title', 'guto-toolkit' ),
					'type'      =>Controls_Manager:: TEXT,
					'default' 	=> esc_html__('You Are Welcome To My Blog', 'guto-toolkit'),
				]
			);

			$this->add_control(
				'about_content',
				[
					'label' 	=> esc_html__( 'About Content', 'guto-toolkit' ),
					'type'      =>Controls_Manager:: WYSIWYG,
					'default' 	=> esc_html__('Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Quis ipsum suspendisse.', 'guto-toolkit'),
				]
            );

			$this->add_control(
				'about_desc_content',
				[
					'label' 	=> esc_html__( 'Content First Part', 'guto-toolkit' ),
					'type'      =>Controls_Manager:: WYSIWYG,
					'default' 	=> esc_html__('Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industrys standard dummy text ever since the 1500s, when an unknown printer took a galley of type and scrambled it to make a type specimen book. It has survived not only five centuries.', 'guto-toolkit'),
				]
            );

            $this->add_control(
				'about_describe_title',
				[
					'label' 	=> esc_html__( 'Add About Describe Title', 'guto-toolkit' ),
					'type'      =>Controls_Manager:: TEXT,
					'default' 	=> esc_html__('Get In Touch To Get Best Blog From Our Site', 'guto-toolkit'),
				]
			);

            $this->add_control(
				'about_desc_content_two',
				[
					'label' 	=> esc_html__( 'Content Second Part', 'guto-toolkit' ),
					'type'      =>Controls_Manager:: WYSIWYG,
					'default' 	=> esc_html__('Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industrys standard dummy text ever since the 1500s, when an unknown printer took a galley of type and scrambled it to make a type specimen book. It has survived not only five centuries.', 'guto-toolkit'),
				]
            );
            $this->add_control(
				'about_desc',
				[
					'label' 	=> esc_html__( 'Add Description', 'guto-toolkit' ),
					'type'      =>Controls_Manager:: WYSIWYG,
					'default' 	=> esc_html__('Lorem Ipsum is simply dummy text of the printing and typesetting industry. Lorem Ipsum has been the industrys standard dummy text ever since the 1500s, when an unknown printer took a galley of type and scrambled it to make a type specimen book. It has survived not only five centuries.', 'guto-toolkit'),
				]
            );
        $this->end_controls_section();

        // Images
        $this->start_controls_section(
			'about_images',
			[
				'label' => esc_html__( 'Images', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

            $this->add_control(
                'image1',
                [
                    'label'		=> esc_html__('Left Image', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: MEDIA,
                ]
            );
            $this->add_control(
                'image2',
                [
                    'label'		=> esc_html__('Right Image', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: MEDIA,
                ]
            );

        $this->end_controls_section();

        $this->start_controls_section(
			'about_sec_style',
			[
				'label' => esc_html__( 'Style', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
            $this->add_control(
                'title_color',
                [
                    'label' => esc_html__( 'Add Title Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .fls-about-area .fls-about-content h2' => 'color: {{VALUE}}',
                    ],
                ]
            );

			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'title_typography',
                    'label' => esc_html__( 'Title Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .fls-about-area .fls-about-content h2',
                ]
            );

			$this->add_control(
				'content_color',
				[
					'label' => esc_html__( 'Content Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} p' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'content_typography',
                    'label' => esc_html__( 'Content Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} p',
                ]
            );

            $this->add_control(
				'middle_title_color',
				[
					'label' => esc_html__( 'Middle Title Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .fls-about-area .fls-about-describe h3' => 'color: {{VALUE}}',
					],
				]
			);
			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'middle_title_typography',
                    'label' => esc_html__( 'Middle Title Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .fls-about-area .fls-about-describe h3',
                ]
            );
        $this->end_controls_section();

    }

	protected function render() {

		$settings = $this->get_settings_for_display();

        ?>
        <div class="fls-about-area pt-100 pb-70">
            <div class="container">
                <div class="row align-items-center">
                    <?php if( $settings['image1']['url'] != '' ) : ?>
                        <div class="col-sm-6 col-lg-5">
                            <div class="fls-about-img">
                                <img src="<?php echo esc_url($settings['image1']['url']); ?>" alt="<?php echo esc_attr__('about image','guto-toolkit'); ?>">
                            </div>
                        </div>
                    <?php endif; ?>
                    <div class="col-sm-6 col-lg-7">
                        <div class="fls-about-content">
                            <h2><?php echo esc_html( $settings['about_title'] ); ?></h2>
                            <?php echo wp_kses_post( $settings['about_content'] ); ?>
                        </div>
                    </div>
                </div>

                <div class="fls-about-describe">
                    <?php echo wp_kses_post( $settings['about_desc_content'] ); ?>
                    <h3><?php echo esc_html( $settings['about_describe_title'] ); ?></h3>
                    <?php echo wp_kses_post( $settings['about_desc_content_two'] ); ?>
                    <div class="row">
                        <div class="col-sm-8 col-lg-9">
                            <div class="content">
                                <?php echo wp_kses_post( $settings['about_desc'] ); ?>
                            </div>
                        </div>

                        <?php if( $settings['image2']['url'] != '' ) : ?>
                            <div class="col-sm-4 col-lg-3">
                                <div class="img">
                                    <img src="<?php echo esc_url($settings['image2']['url']); ?>" alt="<?php echo esc_attr__('about image','guto-toolkit'); ?>">
                                </div>
                            </div>
                        <?php endif; ?>
                    </div>
                </div>

            </div>
        </div>
        <?php
	}

	protected function _content_template() {}

}

Plugin::instance()->widgets_manager->register( new Guto_FLS_About_Area );