<?php
/**
 * FLS Banner Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_FLS_Banner extends Widget_Base {

	public function get_name() {
        return 'Guto_FLS_Banner';
    }

	public function get_title() {
        return esc_html__( 'Banner', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-banner';
    }

	public function get_categories() {
        return [ 'guto-lifestyle-blog' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'Guto_FLS_Banner_Area',
			[
				'label' => esc_html__( 'Banner Controls', 'guto-toolkit' ),
				'tab' 	=> Controls_Manager::TAB_CONTENT,
			]
		);
            $this->add_control(
                'cat', [
                    'label' => esc_html__( 'Category', 'guto-toolkit' ),
                    'description' => esc_html__( 'Enter the category slugs separated by commas (Eg. cat1, cat2)', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'label_block' => true,
                ]
            );

            $this->add_control(
                'order',
                [
                    'label' => esc_html__( 'Posts Order By', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        'DESC'      => esc_html__( 'DESC', 'guto-toolkit' ),
                        'ASC'       => esc_html__( 'ASC', 'guto-toolkit' ),
                    ],
                    'default' => 'DESC',
                ]
            );

            $this->add_control(
                'count',
                [
                    'label' => esc_html__( 'Item', 'guto-toolkit' ),
                    'type' => Controls_Manager::NUMBER,
                    'default' => 3,
                ]
            );

            $this->add_control(
                'read_more',
                [
                    'label' => esc_html__( 'Read More Button', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                ]
            );

        $this->end_controls_section();

        $this->start_controls_section(
			'banner_style',
			[
				'label' => esc_html__( 'Style', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

            $this->add_control(
                'tag_color',
                [
                    'label' => esc_html__( 'Tag Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .fls-banner-area .fls-banner-item .fls-banner-content .title' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'tag_typography',
                    'label' => esc_html__( 'Tag Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .fls-banner-area .fls-banner-item .fls-banner-content .title',
                ]
            );

			$this->add_control(
				'title_color',
				[
					'label' => esc_html__( 'Title Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .fls-banner-area .fls-banner-item .fls-banner-content h1' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'title_typography',
                    'label' => esc_html__( 'Title Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .fls-banner-area .fls-banner-item .fls-banner-content h1',
                ]
            );
			$this->add_control(
				'content_color',
				[
					'label' => esc_html__( 'Content Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .fls-banner-area .fls-banner-item .fls-banner-content p' => 'color: {{VALUE}}',
					],
				]
			);
			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'content_typography',
                    'label' => esc_html__( 'Content Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .fls-banner-area .fls-banner-item .fls-banner-content p',
                ]
            );
            $this->add_control(
				'button_color',
				[
					'label' => esc_html__( 'Button Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .fls-banner-area .fls-banner-item .fls-banner-content .inner .left a' => 'color: {{VALUE}}',
					],
				]
			);
            
			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'btn_typography',
                    'label' => esc_html__( 'Button Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .fls-banner-area .fls-banner-item .fls-banner-content .inner .left a',
                ]
            );

            $this->add_control(
                'icon_color',
                [
                    'label' => esc_html__( 'Icon Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .fls-banner-area .fls-banner-item .fls-banner-content .inner .right i' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_control(
                'post_meta_color',
                [
                    'label' => esc_html__( 'Post Meta Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .fls-banner-area .fls-banner-item .fls-banner-content .inner .right span' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'post_meta_typography',
                    'label' => esc_html__( 'Post Meta Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .fls-banner-area .fls-banner-item .fls-banner-content .inner .right span',
                ]
            );
        $this->end_controls_section();

    }

	protected function render() {

		$settings = $this->get_settings_for_display();

        // Post Query
        if( $settings['cat'] != '' ) {
            $args = array(
                'post_type'     => 'post',
                'posts_per_page'=> $settings['count'],
                'order'         => $settings['order'],
                'tax_query'     => array(
                    array(
                        'taxonomy'      => 'category',
                        'field'         => 'slug',
                        'terms'         => $settings['cat'],
                        'hide_empty'    => false
                    )
                )
            );
        } else {
            $args = array(
                'post_type'         => 'post',
                'posts_per_page'    => $settings['count'],
                'order'             => $settings['order']
            );
        }
        $post_array = new \WP_Query( $args );

        ?>

            <!-- Banner -->
            <div class="fls-banner-area">
                <div class="container">
                    <?php while($post_array->have_posts()): $post_array->the_post(); ?>
                        <div class="fls-banner-item" style="background-image: url(<?php echo get_the_post_thumbnail_url( get_the_ID(), 'guto_lite_banner_thumb_size' ); ?> ) ">

                            <div class="d-table">
                                <div class="d-table-cell">
                                    <div class="fls-banner-content">
                                        <?php if ( get_the_tags() ) {  ?>

                                            <span class="title">
                                                <?php $post_tags = get_the_tags();
                                                    foreach ($post_tags as $post_tag ) {  ?>
                                                        <?php echo esc_html($post_tag->name) ?>
                                                    <?php
                                                } ?>
                                            </span>

                                        <?php } ?>
                                        <h1><?php the_title(); ?></h1>
                                        <?php the_excerpt(); ?>
                                        <div class="inner align-items-center">

                                            <?php if( $settings['read_more'] != '' ): ?>
                                                <div class="left">
                                                    <a href="<?php the_permalink(); ?>" class="link-btn">
                                                        <?php echo esc_html( $settings['read_more'] ); ?>
                                                    </a>
                                                </div>
                                            <?php endif; ?>
                                            <div class="right">
                                                <i class='bx bx-calendar'></i>
                                                <span><?php echo esc_html(get_the_date()); ?></span>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>

                        </div>
                    <?php endwhile; ?>
                    <?php wp_reset_query(); ?>
                </div>
            </div>
            <!-- End Banner -->
        <?php
	}

	protected function _content_template() {}

}

Plugin::instance()->widgets_manager->register( new Guto_FLS_Banner );