<?php
/**
 * FLS Feature Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_FLS_Feature_Area extends Widget_Base {

	public function get_name() {
        return 'Guto_FLS_Feature';
    }

	public function get_title() {
        return esc_html__( 'FLS Feature', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-info-box';
    }

	public function get_categories() {
        return [ 'guto-lifestyle-blog' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'feature_section',
			[
				'label' => esc_html__( 'Feature Controls', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

            $this->add_control(
                'cat', [
                    'label' => esc_html__( 'Category', 'guto-toolkit' ),
                    'description' => esc_html__( 'Enter the category slugs separated by commas (Eg. cat1, cat2)', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'label_block' => true,
                ]
            );

            $this->add_control(
                'order',
                [
                    'label' => esc_html__( 'Posts Order By', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        'DESC'      => esc_html__( 'DESC', 'guto-toolkit' ),
                        'ASC'       => esc_html__( 'ASC', 'guto-toolkit' ),
                    ],
                    'default' => 'DESC',
                ]
            );

            $this->add_control(
                'count',
                [
                    'label' => esc_html__( 'Item', 'guto-toolkit' ),
                    'type' => Controls_Manager::NUMBER,
                    'default' => 3,
                ]
            );

        $this->end_controls_section();

        $this->start_controls_section(
			'feature_sec_style',
			[
				'label' => esc_html__( 'Style', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_control(
				'title_color',
				[
					'label' => esc_html__( 'Title Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .fls-common-content h3 a' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'title_typography',
                    'label' => esc_html__( 'Title Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .fls-common-content h3',
                ]
            );

			$this->add_control(
				'post_meta_color',
				[
					'label' => esc_html__( 'Post Meta Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .fls-common-content ul li' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'post_meta_typography',
                    'label' => esc_html__( 'Post Meta Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .fls-common-content ul li',
                ]
            );

            $this->add_control(
				'author_color',
				[
					'label' => esc_html__( 'Author Meta Info Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .fls-common-content .bottom span, .fls-common-content .bottom a' => 'color: {{VALUE}}',
					],
				]
			);
			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'author_typography',
                    'label' => esc_html__( 'Author Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .fls-common-content .bottom span, .fls-common-content .bottom a',
                ]
            );
        $this->end_controls_section();

    }

	protected function render() {

		$settings = $this->get_settings_for_display();

        // Post Query
        if( $settings['cat'] != '' ) {
            $args = array(
                'post_type'     => 'post',
                'posts_per_page'=> $settings['count'],
                'order'         => $settings['order'],
                'tax_query'     => array(
                    array(
                        'taxonomy'      => 'category',
                        'field'         => 'slug',
                        'terms'         => $settings['cat'],
                        'hide_empty'    => false
                    )
                )
            );
        } else {
            $args = array(
                'post_type'         => 'post',
                'posts_per_page'    => $settings['count'],
                'order'             => $settings['order']
            );
        }
        $post_array = new \WP_Query( $args );

        ?>
        
         <!-- Features -->
         <div class="fls-feature-area pt-100 pb-70">
            <div class="container">
                <div class="row justify-content-center">

                    <?php while($post_array->have_posts()): $post_array->the_post(); ?>

                        <div class="col-sm-6 col-lg-4">
                            <div class="fls-common-content">
                                <ul>

                                    <?php if ( get_the_tags() ) {  ?>

                                        <li>
                                            <?php $post_tags = get_the_tags();
                                                foreach ($post_tags as $post_tag ) {  ?>
                                                    <?php echo esc_html($post_tag->name) ?>
                                                <?php
                                            } ?>
                                        </li>

                                    <?php } ?>
                                    <li><?php echo esc_html(get_the_date()); ?></li>
                                </ul>
                                <h3>
                                    <a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
                                </h3>
                                <div class="bottom">
                                    <span><?php _e( 'By: ', 'lifestyle-blog' ); ?></span>
                                    <a href="<?php the_permalink(); ?>"><?php the_author(); ?></a>
                                </div>
                            </div>
                        </div>

                    <?php endwhile; ?>
                    <?php wp_reset_query(); ?>

                </div>
            </div>
        </div>
        <!-- End Features -->

        <?php
	}

	protected function _content_template() {}

}

Plugin::instance()->widgets_manager->register( new Guto_FLS_Feature_Area );