<?php
/**
 * Newsletter Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_FLS_Newsletter extends Widget_Base {

	public function get_name() {
        return 'Guto_FLS_Newsletter';
    }

	public function get_title() {
        return __( 'Newsletter', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-email-field';
    }

	public function get_categories() {
        return [ 'guto-lifestyle-blog' ];
    }

    public function get_keywords() {
        return [ 'mailchimp', 'form', 'newsletter' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'Guto_Newsletter',
			[
				'label' => esc_html__( 'Guto Newsletter', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );
            $this->add_control(
                'action_url', [
                    'label' => esc_html__( 'Action URL', 'guto-toolkit' ),
                    'description' => esc_html__( 'Enter here your MailChimp action URL. <a href="https://doc.gutotheme.com/docs/tips-guides-troubleshoots/get-mailchimp-newsletter-form-action-url/" target="_blank"> How to </a>', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'label_block' => true,
                ]
            );

            $this->add_control(
                'title', [
                    'label' => esc_html__( 'Title', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__( 'Subscribe To Newsletter', 'guto-toolkit' ),
                    'label_block' => true,
                ]
            );

            $this->add_control(
                'desc', [
                    'label' => esc_html__( 'Description', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__( 'News and exclusive offers direct to your inbox' , 'guto-toolkit' ),
                    'label_block' => true,
                ]
            );

            $this->add_control(
                'placeholder_text', [
                    'label' => esc_html__( 'Email Placeholder Text', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__( 'Enter your email address' , 'guto-toolkit' ),
                    'label_block' => true,
                ]
            );

            $this->add_control(
                'button_text', [
                    'label' => esc_html__( 'Button text', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__( 'Subscribe' , 'guto-toolkit' ),
                    'label_block' => true,
                ]
            );
        $this->end_controls_section();

        $this->start_controls_section(
            'Guto_Contact_Area',
            [
                'label' => esc_html__( 'Guto Contact Area', 'guto-toolkit' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

            $this->add_control(
                'contact_title', [
                    'label' => esc_html__( 'Contact Title', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__( 'Contact', 'guto-toolkit' ),
                    'label_block' => true,
                ]
            );

            $repeater = new Repeater();

            $repeater->add_control(
                'info_title',
                [
                    'label' => esc_html__( 'Info Title', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default'       => esc_html__('Phone', 'guto-toolkit'),
                    'label_block'   => true,
                ]
            );
            $repeater->add_control(
                'content',
                [
                    'label'     => esc_html__( 'Content', 'guto-toolkit' ),
                    'type' => Controls_Manager::WYSIWYG,
                ]
            );
            $this->add_control(
                'list_items',
                [
                    'label' => esc_html__('List Item', 'guto-toolkit'),
                    'type' => Controls_Manager::REPEATER,
                    'fields' => $repeater->get_controls(),
                ]
            );
        $this->end_controls_section();

        $this->start_controls_section(
			'newsletter_style',
			[
				'label' => esc_html__( 'Style', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

            $this->add_control(
				'title_color',
				[
					'label' => esc_html__( 'Title Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .fls-subscribe-left .subscribe-title h2' => 'color: {{VALUE}}',
					],
				]
			);
            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'title_typography',
                    'label' => esc_html__( 'Title Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .fls-subscribe-area .fls-subscribe-wrap .fls-subscribe-left .subscribe-title h2',
                ]
            );

            $this->add_control(
				'desc_color',
				[
					'label' => esc_html__( 'Description Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .subscribe-title span' => 'color: {{VALUE}}',
					],
				]
			);

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'desc_typography',
                    'label' => esc_html__( 'Description Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .subscribe-title span',
                ]
            );
            $this->add_control(
                'con_title_color',
                [
                    'label' => esc_html__( 'Contact Title Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .fls-subscribe-contact h2' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'con_title_typography',
                    'label' => esc_html__( 'Contact Title Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .fls-subscribe-contact h2',
                ]
            );
            $this->add_control(
                'info_title_color',
                [
                    'label' => esc_html__( 'Contact Info Title Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .fls-subscribe-contact ul li span' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'con_info_typography',
                    'label' => esc_html__( 'Contact Info Title Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .fls-subscribe-area .fls-subscribe-contact ul li span',
                ]
            );
            $this->add_control(
                'info_content_color',
                [
                    'label' => esc_html__( 'Contact Info Content Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .fls-subscribe-contact ul li a' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'con_content_typography',
                    'label' => esc_html__( 'Contact Info Content Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .fls-subscribe-area .fls-subscribe-contact ul li a',
                ]
            );
        $this->end_controls_section();
    }

	protected function render() {

        $settings = $this->get_settings_for_display();
        ?>
            <div class="container">
                <div class="fls-subscribe-wrap pt-100 pb-70">
                    <div class="row align-items-center">

                        <div class="col-lg-7">
                            <div class="fls-subscribe-left">
                                <div class="subscribe-title">
                                    <?php if($settings['title']): ?>
                                        <h2><?php echo esc_html($settings['title']); ?></h2>
                                    <?php endif; ?>

                                    <?php if($settings['desc']): ?>
                                        <span><?php echo esc_html($settings['desc']); ?></span>
                                    <?php endif; ?>
                                </div>
                                <form class="mailchimp newsletter-form" method="post">
                                    <input type="email" class="form-control" placeholder="<?php echo esc_attr($settings['placeholder_text']); ?>" name="EMAIL" required>

                                    <?php if( $settings['button_text'] != '' ): ?>
                                        <button type="submit" class="fls-default-btn"><?php echo esc_html( $settings['button_text'] ); ?></button>
                                    <?php endif; ?>

                                    <p class="mchimp-errmessage" style="display: none;"></p>
                                    <p class="mchimp-sucmessage" style="display: none;"></p>
                                </form>
                            </div>
                        </div>

                        <div class="col-lg-5">
                            <div class="fls-subscribe-contact">
                                <?php if($settings['contact_title']): ?>
                                    <h2><?php echo esc_html($settings['contact_title']); ?></h2>
                                <?php endif; ?>
                                <ul>

                                    <?php foreach( $settings['list_items'] as $item ) : ?>
                                        <li>
                                            <span><?php echo esc_html( $item['info_title'] ); ?></span>
                                            <?php echo wp_kses_post( $item['content'] ); ?>
                                        </li>
                                    <?php endforeach; ?>
                                </ul>
                            </div>
                        </div>
                        
                    </div>
                </div>
            </div>

            <script>
                ;(function($){
                    "use strict";
                    $(document).ready(function () {
                        // MAILCHIMP
                        if ($(".mailchimp").length > 0) {
                            $(".mailchimp").ajaxChimp({
                                callback: mailchimpCallback,
                                url: "<?php echo esc_js($settings['action_url']) ?>"
                            });
                        }
                        if ($(".mailchimp_two").length > 0) {
                            $(".mailchimp_two").ajaxChimp({
                                callback: mailchimpCallback,
                                url: "<?php echo esc_js($settings['action_url']) ?>" //Replace this with your own mailchimp post URL. Don't remove the "". Just paste the url inside "".
                            });
                        }
                        $(".memail").on("focus", function () {
                            $(".mchimp-errmessage").fadeOut();
                            $(".mchimp-sucmessage").fadeOut();
                        });
                        $(".memail").on("keydown", function () {
                            $(".mchimp-errmessage").fadeOut();
                            $(".mchimp-sucmessage").fadeOut();
                        });
                        $(".memail").on("click", function () {
                            $(".memail").val("");
                        });

                        function mailchimpCallback(resp) {
                            if (resp.result === "success") {
                                $(".mchimp-errmessage").html(resp.msg).fadeIn(1000);
                                $(".mchimp-sucmessage").fadeOut(500);
                            } else if (resp.result === "error") {
                                $(".mchimp-errmessage").html(resp.msg).fadeIn(1000);
                            }
                        }
                    });
                })(jQuery)
            </script>
    <?php
	}

	protected function _content_template() {}

}

Plugin::instance()->widgets_manager->register( new Guto_FLS_Newsletter );