<?php
/**
 * FLS Story Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_FLS_Story extends Widget_Base {

	public function get_name() {
        return 'Guto_FLS_Story';
    }

	public function get_title() {
        return esc_html__( 'Story', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-help-o';
    }

	public function get_categories() {
        return [ 'guto-lifestyle-blog' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'Guto_FLS_Story',
			[
				'label' => esc_html__( 'Story Controls', 'guto-toolkit' ),
				'tab' 	=> Controls_Manager::TAB_CONTENT,
			]
		);

            $this->add_control(
                'show_section',
                [
                    'label'        => __( 'Section Hide/Show?', 'guto-toolkit' ),
                    'type'         => Controls_Manager::SWITCHER,
                    'label_on'     => __( 'Show', 'guto-toolkit' ),
                    'label_off'    => __( 'Hide', 'guto-toolkit' ),
                    'return_value' => 'yes',
                    'default'      => 'yes',
                ]
            );

        $this->end_controls_section();

        $this->start_controls_section(
			'Guto_FLS_Story_One',
			[
				'label' => esc_html__( 'Order One Story Controls', 'guto-toolkit' ),
				'tab' 	=> Controls_Manager::TAB_CONTENT,
			]
		);

            $this->add_control(
                'left-cat', [
                    'label' => esc_html__( 'Left Category', 'guto-toolkit' ),
                    'description' => esc_html__( 'Enter the category slugs separated by commas (Eg. cat1, cat2)', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'label_block' => true,
                ]
            );

            $this->add_control(
                'left-order',
                [
                    'label' => esc_html__( 'Left Posts Order By', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        'DESC'      => esc_html__( 'DESC', 'guto-toolkit' ),
                        'ASC'       => esc_html__( 'ASC', 'guto-toolkit' ),
                    ],
                    'default' => 'DESC',
                ]
            );

            $this->add_control(
                'left-count',
                [
                    'label' => esc_html__( 'Left Item', 'guto-toolkit' ),
                    'type' => Controls_Manager::NUMBER,
                    'default' => 2,
                ]
            );

        $this->end_controls_section();

        $this->start_controls_section(
			'Guto_FLS_Story_Two',
			[
				'label' => esc_html__( 'Order Two Story Controls', 'guto-toolkit' ),
				'tab' 	=> Controls_Manager::TAB_CONTENT,
			]
		);

            $this->add_control(
                'middle-cat', [
                    'label' => esc_html__( 'Middle Category', 'guto-toolkit' ),
                    'description' => esc_html__( 'Enter the category slugs separated by commas (Eg. cat1, cat2)', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'label_block' => true,
                ]
            );

            $this->add_control(
                'middle-order',
                [
                    'label' => esc_html__( 'Middle Posts Order By', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        'DESC'      => esc_html__( 'DESC', 'guto-toolkit' ),
                        'ASC'       => esc_html__( 'ASC', 'guto-toolkit' ),
                    ],
                    'default' => 'DESC',
                ]
            );

            $this->add_control(
                'middle-count',
                [
                    'label' => esc_html__( 'Middle Item', 'guto-toolkit' ),
                    'type' => Controls_Manager::NUMBER,
                    'default' => 2,
                ]
            );

        $this->end_controls_section();

        
        $this->start_controls_section(
			'Guto_FLS_Story_Three',
			[
				'label' => esc_html__( 'Order Three Story Controls', 'guto-toolkit' ),
				'tab' 	=> Controls_Manager::TAB_CONTENT,
			]
		);

            $this->add_control(
                'right-cat', [
                    'label' => esc_html__( 'Right Category', 'guto-toolkit' ),
                    'description' => esc_html__( 'Enter the category slugs separated by commas (Eg. cat1, cat2)', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'label_block' => true,
                ]
            );

            $this->add_control(
                'right-order',
                [
                    'label' => esc_html__( 'Right Posts Order By', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        'DESC'      => esc_html__( 'DESC', 'guto-toolkit' ),
                        'ASC'       => esc_html__( 'ASC', 'guto-toolkit' ),
                    ],
                    'default' => 'DESC',
                ]
            );

            $this->add_control(
                'right-count',
                [
                    'label' => esc_html__( 'Right Item', 'guto-toolkit' ),
                    'type' => Controls_Manager::NUMBER,
                    'default' => 2,
                ]
            );

        $this->end_controls_section();

        $this->start_controls_section(
			'title_section',
			[
				'label' => esc_html__( 'Title Control', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
                'condition' => [
                    'show_section' => 'yes',
                ]
			]
		);

            $this->add_control(
                'title',
                [
                    'label' 	=> esc_html__( 'Title', 'guto-toolkit' ),
                    'type'      =>Controls_Manager::TEXT,
                    'default' 	=> esc_html__('Latest Stories', 'guto-toolkit'),
                ]
            );

            $this->add_control(
                'title_tag',
                [
                    'label' 	=> esc_html__( 'Title Tag', 'guto-toolkit' ),
                    'type' 		=> Controls_Manager::SELECT,
                    'options' 	=> [
                        'h1'         => esc_html__( 'h1', 'guto-toolkit' ),
                        'h2'         => esc_html__( 'h2', 'guto-toolkit' ),
                        'h3'         => esc_html__( 'h3', 'guto-toolkit' ),
                        'h4'         => esc_html__( 'h4', 'guto-toolkit' ),
                        'h5'         => esc_html__( 'h5', 'guto-toolkit' ),
                        'h6'         => esc_html__( 'h6', 'guto-toolkit' ),
                    ],
                    'default' => 'h2',
                ]
            );

        $this->end_controls_section();

        $this->start_controls_section(
			'sec_style',
			[
				'label' => esc_html__( 'Section Style', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'show_section' => 'yes',
                ]
			]
		);
			$this->add_control(
				'title_color',
				[
					'label' => esc_html__( 'Title Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .fls-section-title h1, .fls-section-title h2, .fls-section-title h3, .fls-section-title h4, .fls-section-title h5, .fls-section-title h6' => 'color: {{VALUE}}',
					],
				]
			);
			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'title_typography',
                    'label' => esc_html__( 'Title Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .fls-section-title h1, .fls-section-title h2, .fls-section-title h3, .fls-section-title h4, .fls-section-title h5, .fls-section-title h6',
                ]
            );
        $this->end_controls_section();

        $this->start_controls_section(
			'latest-story_style',
			[
				'label' => esc_html__( 'Style', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

            $this->add_control(
                'tag_color',
                [
                    'label' => esc_html__( 'Tag Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .fls-common-content ul li' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'tag_typography',
                    'label' => esc_html__( 'Tag Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .fls-common-content ul li',
                ]
            );

			$this->add_control(
				'post_title_color',
				[
					'label' => esc_html__( 'Post Title Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .fls-common-content h3 a' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'post_title_typography',
                    'label' => esc_html__( 'Post Title Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .fls-common-content h3',
                ]
            );
			$this->add_control(
				'author_color',
				[
					'label' => esc_html__( 'Author Meta Info Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .fls-common-content .bottom span, .fls-common-content .bottom a' => 'color: {{VALUE}}',
					],
				]
			);
			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'author_typography',
                    'label' => esc_html__( 'Author Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .fls-common-content .bottom span, .fls-common-content .bottom a',
                ]
            );

        $this->end_controls_section();

    }

	protected function render() {

		$settings = $this->get_settings_for_display();

        ?>
            <!-- Story -->
            <section class="fls-story-area pt-100 pb-70">
                <div class="container">

                    <?php if ( $settings['show_section'] == 'yes' ) : ?>
                        <div class="fls-section-title">
                            <<?php echo esc_attr( $settings['title_tag'] ); ?>>
                                <?php echo esc_html( $settings['title'] ); ?>
                            </<?php echo esc_attr( $settings['title_tag'] ); ?>>
                        </div>
                    <?php endif; ?>

                    <div class="row justify-content-center">
                       
                        <div class="col-sm-6 col-lg-3">
                            <?php 

                            // Post Query
                            if( $settings['left-cat'] != '' ) {
                                $args = array(
                                    'post_type'     => 'post',
                                    'posts_per_page'=> $settings['left-count'],
                                    'order'         => $settings['left-order'],
                                    'tax_query'     => array(
                                        array(
                                            'taxonomy'      => 'category',
                                            'field'         => 'slug',
                                            'terms'         => $settings['left-cat'],
                                            'hide_empty'    => false
                                        )
                                    )
                                );
                            } else {
                                $args = array(
                                    'post_type'         => 'post',
                                    'posts_per_page'    => $settings['left-count'],
                                    'order'             => $settings['left-order']
                                );
                            }
                            $post_array = new \WP_Query( $args );

                            while($post_array->have_posts()): $post_array->the_post(); 

                            ?>
                                <div class="fls-story-item">
                                    <?php if(get_the_post_thumbnail_url() != ''): ?>
                                        <div class="top">
                                            <a href="<?php the_permalink(); ?>">
                                                <img src="<?php echo get_the_post_thumbnail_url( get_the_ID(), 'guto_lite_fls_thumb_550*400' ); ?>" alt="<?php the_post_thumbnail_caption();  ?>">
                                            </a>
                                        </div>
                                    <?php endif; ?>

                                    <div class="fls-common-content">
                                        <ul>
                                            <?php if ( get_the_tags() ) {  ?>

                                                <li>
                                                    <?php $post_tags = get_the_tags();
                                                        foreach ($post_tags as $post_tag ) {  ?>
                                                            <?php echo esc_html($post_tag->name) ?>
                                                        <?php
                                                    } ?>
                                                </li>

                                            <?php } ?>
                                            <li><?php echo esc_html(get_the_date()); ?></li>
                                        </ul>
                                        <h3>
                                            <a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
                                        </h3>
                                    </div>
                                </div>
                            <?php endwhile; ?>
                            <?php wp_reset_query(); ?>
                        </div>

                        <?php 

                        // Post Query
                        if( $settings['middle-cat'] != '' ) {
                            $args = array(
                                'post_type'     => 'post',
                                'posts_per_page'=> $settings['middle-count'],
                                'order'         => $settings['middle-order'],
                                'tax_query'     => array(
                                    array(
                                        'taxonomy'      => 'category',
                                        'field'         => 'slug',
                                        'terms'         => $settings['middle-cat'],
                                        'hide_empty'    => false
                                    )
                                )
                            );
                        } else {
                            $args = array(
                                'post_type'         => 'post',
                                'posts_per_page'    => $settings['middle-count'],
                                'order'             => $settings['middle-order']
                            );
                        }
                        $post_array = new \WP_Query( $args );

                        while($post_array->have_posts()): $post_array->the_post(); 

                        ?>
                            <div class="col-sm-6 col-lg-6">
                                <div class="fls-story-item three">
                                    <?php if(get_the_post_thumbnail_url() != ''): ?>
                                        <div class="top">
                                            <a href="<?php the_permalink(); ?>">
                                                <img src="<?php echo get_the_post_thumbnail_url( get_the_ID(), 'guto_lite_fls_thumb_640*710' ); ?>" alt="<?php the_post_thumbnail_caption();  ?>">
                                            </a>
                                        </div>
                                     <?php endif; ?>

                                    <div class="fls-common-content">
                                        <ul>
                                            <?php if ( get_the_tags() ) {  ?>

                                                <li>
                                                    <?php $post_tags = get_the_tags();
                                                        foreach ($post_tags as $post_tag ) {  ?>
                                                            <?php echo esc_html($post_tag->name) ?>
                                                        <?php
                                                    } ?>
                                                </li>

                                            <?php } ?>
                                            <li><?php echo esc_html(get_the_date()); ?></li>
                                        </ul>

                                        <h3>
                                            <a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
                                        </h3>
                                    </div>
                                </div>
                            </div>
                        <?php endwhile; ?>
                        <?php wp_reset_query(); ?>

                        <div class="col-sm-6 col-lg-3">
                            <?php 

                            // Post Query
                            if( $settings['right-cat'] != '' ) {
                                $args = array(
                                    'post_type'     => 'post',
                                    'posts_per_page'=> $settings['right-count'],
                                    'order'         => $settings['right-order'],
                                    'tax_query'     => array(
                                        array(
                                            'taxonomy'      => 'category',
                                            'field'         => 'slug',
                                            'terms'         => $settings['right-cat'],
                                            'hide_empty'    => false
                                        )
                                    )
                                );
                            } else {
                                $args = array(
                                    'post_type'         => 'post',
                                    'posts_per_page'    => $settings['right-count'],
                                    'order'             => $settings['right-order']
                                );
                            }
                            $post_array = new \WP_Query( $args );

                            while($post_array->have_posts()): $post_array->the_post(); 

                            ?>
                                <div class="fls-story-item">
                                    <div class="top">
                                        <a href="<?php the_permalink(); ?>">
                                            <img src="<?php echo get_the_post_thumbnail_url( get_the_ID(), 'guto_lite_fls_thumb_550*400' ); ?>" alt="<?php the_post_thumbnail_caption();  ?>">
                                        </a>
                                    </div>

                                    <div class="fls-common-content">
                                        <ul>
                                            <?php if ( get_the_tags() ) {  ?>

                                                <li>
                                                    <?php $post_tags = get_the_tags();
                                                        foreach ($post_tags as $post_tag ) {  ?>
                                                            <?php echo esc_html($post_tag->name) ?>
                                                        <?php
                                                    } ?>
                                                </li>

                                            <?php } ?>
                                            <li><?php echo esc_html(get_the_date()); ?></li>
                                        </ul>
                                        <h3>
                                            <a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
                                        </h3>
                                    </div>
                                </div>
                            <?php endwhile; ?>
                            <?php wp_reset_query(); ?>
                        </div>

                    </div>
                </div>
            </section>
            <!-- Ens Story -->
        <?php
	}

	protected function _content_template() {}

}

Plugin::instance()->widgets_manager->register( new Guto_FLS_Story );