<?php
/**
 * FLS Video Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_FLS_Video extends Widget_Base {

	public function get_name() {
        return 'Guto_FLS_Video';
    }

	public function get_title() {
        return esc_html__( 'Video', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-handle';
    }

	public function get_categories() {
        return [ 'guto-lifestyle-blog' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'Guto_FLS_Video_Area',
			[
				'label' => esc_html__( 'Video Controls', 'guto-toolkit' ),
				'tab' 	=> Controls_Manager::TAB_CONTENT,
			]
		);
            $this->add_control(
                'cat', [
                    'label' => esc_html__( 'Category', 'guto-toolkit' ),
                    'description' => esc_html__( 'Enter the category slugs separated by commas (Eg. cat1, cat2)', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'label_block' => true,
                ]
            );

            $this->add_control(
                'order',
                [
                    'label' => esc_html__( 'Posts Order By', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        'DESC'      => esc_html__( 'DESC', 'guto-toolkit' ),
                        'ASC'       => esc_html__( 'ASC', 'guto-toolkit' ),
                    ],
                    'default' => 'DESC',
                ]
            );

            $this->add_control(
                'count',
                [
                    'label' => esc_html__( 'Item', 'guto-toolkit' ),
                    'type' => Controls_Manager::NUMBER,
                    'default' => 3,
                ]
            );

            $this->add_control(
                'video_link',
                [
                    'label' => esc_html__( 'Video Link', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                ]
            );

        $this->end_controls_section();

    }

	protected function render() {

		$settings = $this->get_settings_for_display();

        // Post Query
        if( $settings['cat'] != '' ) {
            $args = array(
                'post_type'     => 'post',
                'posts_per_page'=> $settings['count'],
                'order'         => $settings['order'],
                'tax_query'     => array(
                    array(
                        'taxonomy'      => 'category',
                        'field'         => 'slug',
                        'terms'         => $settings['cat'],
                        'hide_empty'    => false
                    )
                )
            );
        } else {
            $args = array(
                'post_type'         => 'post',
                'posts_per_page'    => $settings['count'],
                'order'             => $settings['order']
            );
        }
        $post_array = new \WP_Query( $args );

        ?>
            <!-- Video -->
            <div class="fls-video-area">
                <div class="container">

                    <?php while($post_array->have_posts()): $post_array->the_post(); ?>

                        <div class="fls-video-content">
                            <?php if(get_the_post_thumbnail_url() != ''): ?>
                                <img src="<?php echo get_the_post_thumbnail_url( get_the_ID(), 'guto_lite_fls_thumb_size_1920*900' ); ?>" alt="<?php the_post_thumbnail_caption();  ?>">
                            <?php endif; ?>

                            <div class="fls-common-content">
                                <ul>
                                    <?php if ( get_the_tags() ) {  ?>

                                        <li>
                                            <?php $post_tags = get_the_tags();
                                                foreach ($post_tags as $post_tag ) {  ?>
                                                    <?php echo esc_html($post_tag->name) ?>
                                                <?php
                                            } ?>
                                        </li>

                                    <?php } ?>
                                    <li><?php echo esc_html(get_the_date()); ?></li>
                                </ul>
                                <h3>
                                    <a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
                                </h3>
                            </div>
                            <div class="fls-banner-video">
                                <a href="<?php echo esc_url( $settings['video_link'] ); ?>" class="video-btn popup-youtube"><i class='bx bx-play'></i></a>
                            </div>
                        </div>
                    <?php endwhile; ?>
                    <?php wp_reset_query(); ?>

                </div>
            </div>
            <!-- Ens Video -->
        <?php
	}

	protected function _content_template() {}

}

Plugin::instance()->widgets_manager->register( new Guto_FLS_Video );