<?php
/**
 * MS About Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_MS_About_Area extends Widget_Base {

	public function get_name() {
        return 'Guto_MS_About';
    }

	public function get_title() {
        return esc_html__( 'MS About', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-info-box';
    }

	public function get_categories() {
        return [ 'guto-motivational-speaker' ];
    }

	protected function register_controls() {

        $this->start_controls_section(
			'Guto_MS_About_Area',
			[
				'label' => esc_html__( 'About Controls', 'guto-toolkit' ),
				'tab' 	=> Controls_Manager::TAB_CONTENT,
			]
		);

            $this->add_control(
                'subtitle',
                [
                    'label'     => esc_html__( 'Subtitle', 'guto-toolkit' ),
                    'type'      =>Controls_Manager::TEXT,
                    'default'   => esc_html__('ABOUT ME', 'guto-toolkit'),
                ]
            );

			$this->add_control(
				'title',
				[
					'label' 	=> esc_html__( 'Title', 'guto-toolkit' ),
					'type'      =>Controls_Manager::TEXT,
					'default' 	=> esc_html__("It's a weird and wonderful world", 'guto-toolkit'),
				]
			);

			$this->add_control(
                'title_tag',
                [
                    'label' 	=> esc_html__( 'Title Tag', 'guto-toolkit' ),
                    'type' 		=> Controls_Manager::SELECT,
                    'options' 	=> [
                        'h1'         => esc_html__( 'h1', 'guto-toolkit' ),
                        'h2'         => esc_html__( 'h2', 'guto-toolkit' ),
                        'h3'         => esc_html__( 'h3', 'guto-toolkit' ),
                        'h4'         => esc_html__( 'h4', 'guto-toolkit' ),
                        'h5'         => esc_html__( 'h5', 'guto-toolkit' ),
                        'h6'         => esc_html__( 'h6', 'guto-toolkit' ),
                    ],
                    'default' => 'h2',
                ]
            );

			$this->add_control(
				'content',
				[
					'label' 	=> esc_html__( 'Content', 'guto-toolkit' ),
					'type'      =>Controls_Manager:: WYSIWYG,
					'default' 	=> esc_html__('Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Quis ipsum suspendisse.', 'guto-toolkit'),
				]
            );

			$this->add_control(
				'content_two',
				[
					'label' 	=> esc_html__( 'Content Second Part', 'guto-toolkit' ),
					'type'      =>Controls_Manager:: WYSIWYG,
					'default' 	=> esc_html__('Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Quis ipsum suspendisse.', 'guto-toolkit'),
				]
            );

            $this->add_control(
				'button_icon',
				[
					'label' => esc_html__( 'Button Icon', 'guto-toolkit' ),
                    'type' => Controls_Manager::ICON,
                    'label_block' => true,
                    'options' => guto_toolkit_icons(),
                    'default' => 'bx bx-paper-plane'
				]
            );

			$this->add_control(
				'button_text',
				[
					'label' 	=> esc_html__( 'Button Text', 'guto-toolkit' ),
					'type' 		=> Controls_Manager::TEXT,
					'default' 	=> esc_html__('Start for Free', 'guto-toolkit'),
				]
            );

            $this->add_control(
                'link_type',
                [
                    'label' 		=> esc_html__( 'Button Link Type', 'guto-toolkit' ),
                    'type' 			=> Controls_Manager::SELECT,
                    'label_block' 	=> true,
                    'options' => [
                        '1'  	=> esc_html__( 'Link To Page', 'guto-toolkit' ),
                        '2' 	=> esc_html__( 'External Link', 'guto-toolkit' ),
                    ],
                    'default' > '2'
                ]
            );

            $this->add_control(
                'link_to_page',
                [
                    'label' 		=> esc_html__( 'Button Link Page', 'guto-toolkit' ),
                    'type' 			=> Controls_Manager::SELECT,
                    'label_block' 	=> true,
                    'options' 		=> guto_toolkit_get_page_as_list(),
                    'condition' => [
                        'link_type' => '1',
                    ]
                ]
            );

            $this->add_control(
                'ex_link',
                [
                    'label'		=> esc_html__('Button External Link', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: URL,
                    'show_external' => true,
                    'default' => [
                        'url' => '#',
                        'is_external' => true,
                        'nofollow' => true,
                    ],
                    'condition' => [
                        'link_type' => '2',
                    ]
                ]
            );

            $this->add_control(
                'image',
                [
                    'label'     => esc_html__('Image', 'guto-toolkit'),
                    'type'      => Controls_Manager:: MEDIA,
                ]
            );

        $this->end_controls_section();

        $this->start_controls_section(
			'funfacts_section',
			[
				'label' => esc_html__( 'Funfacts Control', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

            $repeater = new Repeater();

            $repeater->add_control(
                'number',
                [
                    'label'       => esc_html__( 'Number', 'guto-toolkit' ),
                    'type'        => Controls_Manager::NUMBER,
                    'label_block' => true,
                    'default'     => 1926,
                ]
            );

            $repeater->add_control(
                'counter_sign',
                [
                    'label' => esc_html__( 'Counter Sign', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'label_block'   => true,
                ]
            );

            $repeater->add_control(
                'counter_title',
                [
                    'label' => esc_html__( 'Counter Title', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'label_block'   => true,
                    'default'       => esc_html__( 'FINISHED SESSIONS', 'guto-toolkit' ),
                ]
            );

            $this->add_control(
                'items',
                [
                    'label'   => esc_html__( 'Add Item', 'guto-toolkit' ),
                    'type' => Controls_Manager::REPEATER,
                    'fields' => $repeater->get_controls(),
                ]
            );

        $this->end_controls_section();

    }

	protected function render() {

		$settings = $this->get_settings_for_display();

        // Get Button Link
        if($settings['link_type'] == 1){
            $link = get_page_link( $settings['link_to_page'] );
        } elseif($settings['link_type'] == 2) {
            $link = $settings['ex_link']['url'];
            $target = $settings['ex_link']['is_external'] ? ' target="_blank"' : '';
		    $nofollow = $settings['ex_link']['nofollow'] ? ' rel="nofollow"' : '';
        }

        $button_text = $settings['button_text'];

        ?>

        <!-- Start About Area -->
        <div class="ms-about-area pb-100">
            <div class="container-lg">
                <div class="row align-items-center">
                    <?php if( $settings['image']['url'] != '' ) : ?>
                        <div class="col-lg-5 col-md-12">
                            <div class="ms-about-image">
                                <img src="<?php echo esc_url($settings['image']['url']); ?>" alt="<?php echo esc_attr__('image','guto-toolkit'); ?>">
                            </div>
                        </div>
                    <?php endif; ?>
                    <div class="col-lg-7 col-md-12 align-self-end">
                        <div class="ms-about-content">
                            <span class="sub-title">
                                <?php echo esc_html( $settings['subtitle'] ); ?>
                            </span>

                            <<?php echo esc_attr( $settings['title_tag'] ); ?>>
                                <?php echo wp_kses_post( $settings['title'] ); ?>
                            </<?php echo esc_attr( $settings['title_tag'] ); ?>>

                            <p><?php echo wp_kses_post( $settings['content'] ); ?></p>

                            <ul class="features-list">
                                <?php foreach( $settings['items'] as $item ): ?>
                                    <li>
                                        <div class="div">
                                            <h3><span class="odometer" data-count="<?php echo esc_attr( $item['number'] ); ?>">00</span><span class="sign"><?php echo esc_attr( $item['counter_sign'] ); ?></span></h3>
                                            <p><?php echo esc_html( $item['counter_title'] ); ?></p>
                                        </div>
                                    </li>
                                <?php endforeach; ?>
                            </ul>

                            <p><?php echo wp_kses_post( $settings['content_two'] ); ?></p>

                            <?php if( $button_text != '' ): ?>
                                <?php if($settings['link_type'] == 1) : ?>
                                    <a href="<?php echo esc_url( $link ); ?>" class="ms-default-btn"><i class="<?php echo esc_attr( $settings['button_icon'] ); ?>"></i> <?php echo esc_html( $button_text ); ?></a>
                                <?php elseif($settings['link_type'] == 2) :
                                    echo '<a href="' .  $link . '" class="ms-default-btn" ' . $target . $nofollow . '> <i class="'.$settings['button_icon'].'"></i> ' . $button_text . '</a>';
                                endif; ?>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
            </div>

        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_MS_About_Area );
