<?php
/**
 * MS Posts Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_MS_Posts extends Widget_Base {

	public function get_name() {
        return 'Guto_MS_Posts';
    }

	public function get_title() {
        return esc_html__( 'MS Posts', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-post-slider';
    }

	public function get_categories() {
        return [ 'guto-motivational-speaker' ];
	}
	protected function register_controls() {

        $this->start_controls_section(
			'Guto_Posts',
			[
				'label' => esc_html__( 'Guto Posts', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

            $this->add_control(
                'post_subtitle', [
                    'label' => esc_html__( 'Subtitle', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'label_block' => true,
                    'default' => 'NEWS & BLOG',
                ]
            );

            $this->add_control(
                'post_title', [
                    'label' => esc_html__( 'Title', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'label_block' => true,
                    'default' => 'My Latest Blog Post',
                ]
            );

            $this->add_control(
                'post_desc', [
                    'label' => esc_html__( 'Description', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXTAREA,
                    'label_block' => true,
                    'default' => 'Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Quis ipsum suspendisse.',
                ]
            );

            $this->add_control(
                'cat', [
                    'label' => esc_html__( 'Category', 'guto-toolkit' ),
                    'description' => esc_html__( 'Enter the category slugs separated by commas (Eg. cat1, cat2)', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'label_block' => true,
                ]
            );

            $this->add_control(
                'order',
                [
                    'label' => esc_html__( 'Posts Order By', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        'DESC'      => esc_html__( 'DESC', 'guto-toolkit' ),
                        'ASC'       => esc_html__( 'ASC', 'guto-toolkit' ),
                    ],
                    'default' => 'DESC',
                ]
            );

            $this->add_control(
                'columns',
                [
                    'label' => esc_html__( 'Choose Columns', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        '1'   => esc_html__( '1', 'guto-toolkit' ),
                        '2'   => esc_html__( '2', 'guto-toolkit' ),
                        '3'   => esc_html__( '3', 'guto-toolkit' ),
                        '4'   => esc_html__( '4', 'guto-toolkit' ),
                    ],
                    'default' => '3',
                ]
            );

            $this->add_control(
                'count',
                [
                    'label' => esc_html__( 'Item', 'guto-toolkit' ),
                    'type' => Controls_Manager::NUMBER,
                    'default' => 3,
                ]
            );

            $this->add_control(
                'read_more',
                [
                    'label' => esc_html__( 'Read More Button', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default'   => esc_html__('Read More', 'guto-toolkit'),
                ]
            );

        $this->end_controls_section();

    }

	protected function render() {

        $settings = $this->get_settings_for_display();


         // Card Columns
        $columns = $settings['columns'];
        if ($columns == '1') {
            $column = 'col-lg-12 col-sm-6 col-md-6';
        }elseif ($columns == '2') {
            $column = 'col-lg-6 col-sm-6 col-md-6';
        }elseif ($columns == '3') {
            $column = 'col-lg-4 col-sm-6 col-md-6';
        }elseif ($columns == '4') {
            $column = 'col-lg-3 col-sm-6 col-md-6';
        }

        // Post Query
        if( $settings['cat'] != '' ) {
            $paged = ( get_query_var( 'paged' ) ) ? get_query_var( 'paged' ) : 1;
            $args = array(
                'post_type'     => 'post',
                'posts_per_page'=> $settings['count'],
                'order'         => $settings['order'],
                'paged' => $paged,
                'tax_query'     => array(
                    array(
                        'taxonomy'      => 'category',
                        'field'         => 'slug',
                        'terms'         => $settings['cat'],
                        'hide_empty'    => false,
                    )
                )
            );
        } else {
            $paged = ( get_query_var( 'paged' ) ) ? get_query_var( 'paged' ) : 1;
            $args = array(
                'post_type'         => 'post',
                'posts_per_page'    => $settings['count'],
                'order'             => $settings['order'],
                'paged' => $paged
            );
        }
        $wp_query = new \WP_Query( $args ); ?>

        <!-- Start MS Blog Area -->
        <div class="ms-blog-area ms-date pt-100 pb-70">
            <div class="container-lg">
                <?php if( is_home() || is_front_page() ) : ?>
                    <div class="ms-section-title">
                        <?php if( ! $settings['post_subtitle'] == '' ) : ?>
                        <span class="sub-title"><?php echo esc_html__( $settings['post_subtitle']); ?></span>
                        <?php endif; ?>
                        <?php if( ! $settings['post_title'] == '' ) : ?>
                            <h2><?php echo esc_html__( $settings['post_title'] ); ?></h2>
                        <?php endif; ?>
                        <?php if( ! $settings['post_desc'] == '' ) : ?>
                            <p><?php echo esc_html__( $settings['post_desc'] ); ?></p>
                        <?php endif; ?>
                    </div>
                <?php endif; ?>
                <div class="row justify-content-center">
                    <?php while( $wp_query->have_posts() ) : $wp_query->the_post();
                        $get_author_id          = get_the_author_meta('ID');
                        $get_author_gravatar    = get_avatar_url($get_author_id, array('size' => 50));
                        ?>
                        <div class="<?php echo esc_attr( $column );?>">
                            <div class="single-ms-blog-post">
                                <?php if( get_the_post_thumbnail_url() != '' ) : ?>
                                    <div class="image">
                                        <a href="<?php the_permalink(); ?>" class="d-block">
                                            <img src="<?php echo get_the_post_thumbnail_url( get_the_ID(), 'guto_lite_post_thumb' ); ?>" alt="<?php the_post_thumbnail_caption();  ?>">
                                        </a>
                                        <span class="date"><?php echo esc_html(get_the_date()); ?></span>
                                    </div>
                                <?php endif; ?>
                                <div class="content">
                                    <h3>
                                        <a href="<?php the_permalink(); ?>">
                                            <?php the_title(); ?>
                                        </a>
                                    </h3>
                                    <p><?php the_excerpt(); ?></p>
                                    <?php if( $settings['read_more'] != '' ): ?>
                                        <a href="<?php the_permalink(); ?>" class="link-btn">
                                            <?php echo esc_html( $settings['read_more'] ); ?>
                                        </a>
                                    <?php endif; ?>
                                </div>
                            </div>
                        </div>
                    <?php endwhile; ?>
                    <?php wp_reset_query(); ?>
                </div>
            </div>
        </div>
        <!-- End MS Blog Area -->

        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_MS_Posts );
