<?php
/**
 * MS Event Widget
 */

namespace Elementor;

class Guto_MS_Event extends Widget_Base {

    public function get_name() {
        return 'MS_Events';
    }

    public function get_title() {
        return esc_html__( 'MS Event Grid', 'guto-toolkit' );
    }

    public function get_icon() {
        return 'eicon-product-description';
    }

    public function get_categories() {
        return [ 'guto-motivational-speaker' ];
    }

    protected function register_controls() {

        $this->start_controls_section(
            'event_section',
            [
                'label' => esc_html__( 'Event', 'guto-toolkit' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

            $this->add_control(
                'columns',
                [
                    'label' => esc_html__( 'Choose Columns', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        '1'   => esc_html__( '1', 'guto-toolkit' ),
                        '2'   => esc_html__( '2', 'guto-toolkit' ),
                        '3'   => esc_html__( '3', 'guto-toolkit' ),
                        '4'   => esc_html__( '4', 'guto-toolkit' ),
                    ],
                    'default' => '3',
                ]
            );

            $this->add_control(
                'order',
                [
                    'label' => esc_html__( 'Event Order By', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        'DESC'      => esc_html__( 'DESC', 'guto-toolkit' ),
                        'ASC'       => esc_html__( 'ASC', 'guto-toolkit' ),
                    ],
                    'default' => 'DESC',
                ]
            );

            $this->add_control(
                'count',
                [
                    'label' => esc_html__( 'Event Per Page', 'guto-toolkit' ),
                    'type' => Controls_Manager::NUMBER,
                    'default' => 6,
                ]
            );

        $this->end_controls_section();

    }

    protected function render() {

        $settings = $this->get_settings_for_display();

        // Card Columns
        $columns = $settings['columns'];
        if ($columns == '1') {
            $column = 'col-lg-12 col-sm-6 col-md-6';
        }elseif ($columns == '2') {
            $column = 'col-lg-6 col-sm-6 col-md-6';
        }elseif ($columns == '3') {
            $column = 'col-lg-4 col-sm-6 col-md-6';
        }elseif ($columns == '4') {
            $column = 'col-lg-3 col-sm-6 col-md-6';
        }

        // Events Query
        $args = array(
            'post_type'         => 'event',
            'posts_per_page'    => $settings['count'],
            'order'             => $settings['order']
        );

        $events_array = new \WP_Query( $args ); ?>

        <!-- Start MS Events Area -->
        <div class="ms-events-area pt-100 pb-70">
            <div class="container-lg">
                <div class="row justify-content-center">
                    <?php while($events_array->have_posts()) : $events_array->the_post(); ?>
                        <div class="<?php echo esc_attr( $column );?>">
                            <div class="single-ms-events-box">
                                <a href="<?php the_permalink(); ?>" class="d-block image">
                                    <?php the_post_thumbnail(); ?>
                                </a>
                                <div class="content">
                                    <span class="date">
                                        <?php the_time('M'); ?>
                                        <span><?php the_time('d'); ?></span>
                                    </span>
                                    <h3><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>
                                    <?php
                                        $get_author_id = get_the_author_meta('ID');
                                        $get_author_gravatar = get_avatar_url($get_author_id, array('size' => 50)); ?>
                                        <img src="<?php echo esc_url($get_author_gravatar); ?>" alt="<?php echo esc_attr( get_the_author() ); ?>">
                                        <span>
                                            <?php if(get_the_author() == ''): ?>
                                            <?php
                                            $blogusers = get_users( array( 'fields' => array( 'display_name' )) );
                                            // Array of stdClass objects.
                                            foreach ( $blogusers as $user ) {
                                                echo '<span>' . esc_html( $user->display_name ) . '</span>';
                                            } ?>
                                            <?php else: ?>
                                                <?php the_author(); ?>
                                            <?php endif; ?>
                                        </span>
                                </div>
                            </div>
                        </div>
                    <?php endwhile; ?>
                    <?php wp_reset_query(); ?>
                </div>
            </div>
        </div>
        <!-- End MS Events Area -->

        <?php
    }



}

Plugin::instance()->widgets_manager->register( new Guto_MS_Event );
