<?php
/**
 * MS Feedback Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_MS_Feedback extends Widget_Base {

	public function get_name() {
        return 'MS Feedback';
    }

	public function get_title() {
        return esc_html__( 'MS Feedback', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-testimonial';
    }

	public function get_categories() {
        return [ 'guto-motivational-speaker' ];
    }

	protected function register_controls() {

        $this->start_controls_section(
			'Guto_MS_Section_Area',
			[
				'label' => esc_html__( 'Section Controls', 'guto-toolkit' ),
				'tab' 	=> Controls_Manager::TAB_CONTENT,
			]
		);
			$this->add_control(
				'title',
				[
					'label' 	=> esc_html__( 'Title', 'guto-toolkit' ),
					'type'      =>Controls_Manager:: TEXT,
					'default' 	=> esc_html__('What Client Say About Me', 'guto-toolkit'),
				]
			);

			$this->add_control(
                'title_tag',
                [
                    'label' 	=> esc_html__( 'Title Tag', 'guto-toolkit' ),
                    'type' 		=> Controls_Manager::SELECT,
                    'options' 	=> [
                        'h1'         => esc_html__( 'h1', 'guto-toolkit' ),
                        'h2'         => esc_html__( 'h2', 'guto-toolkit' ),
                        'h3'         => esc_html__( 'h3', 'guto-toolkit' ),
                        'h4'         => esc_html__( 'h4', 'guto-toolkit' ),
                        'h5'         => esc_html__( 'h5', 'guto-toolkit' ),
                        'h6'         => esc_html__( 'h6', 'guto-toolkit' ),
                    ],
                    'default' => 'h2',
                ]
            );

			$this->add_control(
				'content',
				[
					'label' 	=> esc_html__( 'Content', 'guto-toolkit' ),
					'type'      =>Controls_Manager:: WYSIWYG,
					'default' 	=> esc_html__('Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Quis ipsum suspendisse.', 'guto-toolkit'),
				]
            );

            $this->add_control(
                'feedback_img',
                [
                    'label'     => esc_html__('Feedback Image', 'guto-toolkit'),
                    'type'      => Controls_Manager:: MEDIA,
                ]
            );

        $this->end_controls_section();

        $this->start_controls_section(
			'content_section',
			[
				'label' => esc_html__( 'Feedback Content', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

            $this->add_control(
				'name',
				[
                    'label'       => esc_html__('Name', 'guto-toolkit'),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => esc_html__('John Smith', 'guto-toolkit'),
                    'label_block' => true,
				]
            );

            $this->add_control(
                'designation',
                [
                    'label'       => esc_html__('Designation', 'guto-toolkit'),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => esc_html__('Web Developer', 'guto-toolkit'),
                    'label_block' => true,
                ]
            );

            $this->add_control(
                'feedback',
                [
                    'label'       => esc_html__('Feedback Content', 'guto-toolkit'),
                    'type'        => Controls_Manager::TEXTAREA,
                    'default'     => esc_html__('Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Quis ipsum suspendisse ultrices gravida. Risus commodo viverra maecenas accumsan.', 'guto-toolkit'),
                    'label_block' => true,
                ]
            );

            $this->add_control(
                'image',
                [
                    'label'		=> esc_html__('Image', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: MEDIA,
                ]
            );

            $this->add_control(
                'star_count',
                [
                    'label' => __( 'Choose Star', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'label_block' => true,
                    'options' => [
                        '1' => __( '1', 'guto-toolkit' ),
                        '2' => __( '2', 'guto-toolkit' ),
                        '3' => __( '3', 'guto-toolkit' ),
                        '4' => __( '4', 'guto-toolkit' ),
                        '5' => __( '5', 'guto-toolkit' ),
                    ],
                    'default' => '5',
                ]
            );

        $this->end_controls_section();

        $this->start_controls_section(
            'style',
            [
                'label' => esc_html__( 'Style', 'guto-toolkit' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

            $this->add_control(
                'bg_color',
                [
                    'label' => esc_html__( 'Background Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .ms-feedback-area' => 'background-color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_control(
                'name_color',
                [
                    'label' => esc_html__( 'Name Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .ms-feedback-content .client-info .title h3' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'name_typography',
                    'label' => esc_html__( 'Name Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .ms-feedback-content .client-info .title h3',
                ]
            );
            $this->add_control(
                'des_color',
                [
                    'label' => esc_html__( 'Designation Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .ms-feedback-content .client-info .title span' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'des_typography',
                    'label' => esc_html__( 'Designation Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .ms-feedback-content .client-info .title span',
                ]
            );

            $this->add_control(
                'feed_color',
                [
                    'label' => esc_html__( 'Feedback Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .ms-feedback-content p' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'feed_typography',
                    'label' => esc_html__( 'Feedback Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .ms-feedback-content p',
                ]
            );

        $this->end_controls_section();

    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        // Inline Editing
        $this-> add_inline_editing_attributes('title', 'none'); ?>

        <!-- Start Feedback Area -->
        <div class="ms-feedback-area pt-100">
            <div class="container-lg">
                <div class="row align-items-center">
                    <div class="col-lg-8 col-md-12">
                        <div class="ms-feedback-content">
                            <div class="rating">
                                <?php if( $settings['star_count'] == 1 ) { ?>
                                    <i class="bx bxs-star" aria-hidden="true"></i>
                                <?php } elseif( $settings['star_count'] == 2 ) { ?>
                                    <i class="bx bxs-star" aria-hidden="true"></i>
                                    <i class="bx bxs-star" aria-hidden="true"></i>
                                <?php } elseif( $settings['star_count'] == 3 ) { ?>
                                    <i class="bx bxs-star" aria-hidden="true"></i>
                                    <i class="bx bxs-star" aria-hidden="true"></i>
                                    <i class="bx bxs-star" aria-hidden="true"></i>
                                <?php } elseif( $settings['star_count'] == 4 ) { ?>
                                    <i class="bx bxs-star" aria-hidden="true"></i>
                                    <i class="bx bxs-star" aria-hidden="true"></i>
                                    <i class="bx bxs-star" aria-hidden="true"></i>
                                    <i class="bx bxs-star" aria-hidden="true"></i>
                                <?php } elseif( $settings['star_count'] == 5 ) { ?>
                                    <i class="bx bxs-star" aria-hidden="true"></i>
                                    <i class="bx bxs-star" aria-hidden="true"></i>
                                    <i class="bx bxs-star" aria-hidden="true"></i>
                                    <i class="bx bxs-star" aria-hidden="true"></i>
                                    <i class="bx bxs-star" aria-hidden="true"></i>
                                <?php } ?>
                            </div>
                            <p><?php echo wp_kses_post( $settings['feedback'] ); ?></p>
                            <div class="client-info d-flex align-items-center">
                                <?php if( $settings['image']['url'] != '' ) : ?>
                                    <img src="<?php echo esc_url($settings['image']['url']); ?>" alt="<?php echo esc_attr__('user image','guto-toolkit'); ?>">
                                <?php endif; ?>
                                <div class="title">
                                    <h3><?php echo esc_html( $settings['name'] ); ?></h3>
                                    <span><?php echo esc_html( $settings['designation'] ); ?></span>
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="col-lg-4 col-md-12">
                        <div class="ms-feedback-image">
                            <?php if( $settings['feedback_img']['url'] ) : ?>
                                <img src="<?php echo esc_url( $settings['feedback_img']['url'] ); ?>" alt="feedback">
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <!-- End Feedback Area -->
        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_MS_Feedback );
