<?php
/**
 * MS Services Widget
 */

namespace Elementor;
class Guto_MS_Services extends Widget_Base {

    public function get_name() {
        return 'MS_Services';
    }

    public function get_title() {
        return esc_html__( 'MS Services', 'guto-toolkit' );
    }

    public function get_icon() {
        return 'eicon-tools';
    }

    public function get_categories() {
        return [ 'guto-motivational-speaker' ];
    }

    protected function register_controls() {

        $this->start_controls_section(
            'services_section',
            [
                'label' => esc_html__( 'Services', 'guto-toolkit' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

            $this->add_control(
                'columns',
                [
                    'label' => esc_html__( 'Choose Columns', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        '1'   => esc_html__( '1', 'guto-toolkit' ),
                        '2'   => esc_html__( '2', 'guto-toolkit' ),
                        '3'   => esc_html__( '3', 'guto-toolkit' ),
                        '4'   => esc_html__( '4', 'guto-toolkit' ),
                    ],
                    'default' => '3',
                ]
            );

            $this->add_control(
                'services_title',
                [
                    'label' => esc_html__( 'Title', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__('My Featured Services', 'guto-toolkit'),
                ]
            );

            $this->add_control(
                'services_desc',
                [
                    'label' => esc_html__( 'Description', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXTAREA,
                    'default' => esc_html__('Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Quis ipsum suspendisse.', 'guto-toolkit'),
                ]
            );

            $this->add_control(
                'title_tag',
                [
                    'label' => esc_html__( 'Title Tag', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        'h1'         => esc_html__( 'h1', 'guto-toolkit' ),
                        'h2'         => esc_html__( 'h2', 'guto-toolkit' ),
                        'h3'         => esc_html__( 'h3', 'guto-toolkit' ),
                        'h4'         => esc_html__( 'h4', 'guto-toolkit' ),
                        'h5'         => esc_html__( 'h5', 'guto-toolkit' ),
                        'h6'         => esc_html__( 'h6', 'guto-toolkit' ),
                    ],
                    'default' => 'h2',
                ]
            );

            $this->add_control(
                'read_more',
                [
                    'label' => esc_html__( 'Read More Text', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__('View More', 'guto-toolkit'),
                ]
            );

            $this->add_control(
                'cat', [
                    'label' => esc_html__( 'Category', 'guto-toolkit' ),
                    'description' => esc_html__( 'Enter the category slugs separated by commas (Eg. cat1, cat2)', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'label_block' => true,
                ]
            );

            $this->add_control(
                'order',
                [
                    'label' => esc_html__( 'Services Order By', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        'DESC'      => esc_html__( 'DESC', 'guto-toolkit' ),
                        'ASC'       => esc_html__( 'ASC', 'guto-toolkit' ),
                    ],
                    'default' => 'DESC',
                ]
            );

            $this->add_control(
                'count',
                [
                    'label' => esc_html__( 'Post Per Page', 'guto-toolkit' ),
                    'type' => Controls_Manager::NUMBER,
                    'default' => 6,
                ]
            );

        $this->end_controls_section();

    }

    protected function render() {

        $settings = $this->get_settings_for_display();

        // Card Columns
        $columns = $settings['columns'];
        if ($columns == '1') {
            $column = 'col-lg-12 col-sm-6 col-md-6';
        }elseif ($columns == '2') {
            $column = 'col-lg-6 col-sm-6 col-md-6';
        }elseif ($columns == '3') {
            $column = 'col-lg-4 col-sm-6 col-md-6';
        }elseif ($columns == '4') {
            $column = 'col-lg-3 col-sm-6 col-md-6';
        }

        // Services Query
        if( $settings['cat'] != '' ) {
            $args = array(
                'post_type'     => 'services',
                'posts_per_page'=> $settings['count'],
                'order'         => $settings['order'],
                'tax_query'     => array(
                    array(
                        'taxonomy'      => 'service_cat',
                        'field'         => 'slug',
                        'terms'         => $settings['cat'],
                        'hide_empty'    => false
                    )
                )
            );
        } else {
            $args = array(
                'post_type'         => 'services',
                'posts_per_page'    => $settings['count'],
                'order'             => $settings['order']
            );
        }
        $services_array = new \WP_Query( $args ); ?>

        <!-- Start MS Services Area -->
        <div class="ms-services-area pt-100 pb-70">
            <div class="container-lg">
                <div class="ms-section-title">
                    <<?php echo esc_attr( $settings['title_tag'] ); ?> <?php echo $this-> get_render_attribute_string('title'); ?>>
                        <?php echo esc_html( $settings['services_title'] ); ?>
                    </<?php echo esc_attr( $settings['title_tag'] ); ?>>
                    <p><?php echo wp_kses_post( $settings['services_desc'] ); ?></p>
                </div>
                <div class="row justify-content-center">
                    <?php while($services_array->have_posts()): $services_array->the_post(); ?>
                        <div class="<?php echo esc_attr( $column );?>">
                            <div class="single-ms-services-box">
                                <?php // Card Icon
                                if ( defined( 'FW' ) ) {
                                    $icon = fw_get_db_post_option( get_the_ID(), 'services_icon' );
                                }else{
                                    $icon = '';
                                } ?>
                                <?php if( $icon != '' ): ?>
                                    <div class="icon">
                                        <i class='<?php echo esc_attr($icon); ?>'></i>
                                    </div>
                                <?php endif; ?>
                                <?php if( get_the_post_thumbnail() ): ?>
                                    <?php the_post_thumbnail(); ?>
                                <?php endif; ?>
                                <h3><a href="<?php the_permalink(); ?>"><?php the_title(); ?></h3>
                                <p><?php the_excerpt(); ?></p>
                                <?php if( $settings['read_more'] != '' ): ?>
                                    <a href="<?php the_permalink(); ?>" class="link-btn"><?php echo esc_html( $settings['read_more'] ); ?></a>
                                <?php endif; ?>
                            </div>
                        </div>
                    <?php endwhile; ?>
                    <?php wp_reset_query(); ?>
                </div>
            </div>
        </div>
        <!-- End MS Services Area -->

        <?php
    }



}

Plugin::instance()->widgets_manager->register( new Guto_MS_Services );
