<?php
/**
 * Single Event Widget
 */

namespace Elementor;

class Guto_Single_Event extends Widget_Base {

	public function get_name() {
        return 'MS Single Event';
    }

	public function get_title() {
        return esc_html__( 'MS Single Event', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-product-description';
    }

	public function get_categories() {
        return [ 'guto-motivational-speaker' ];
    }

	protected function register_controls() {

        $this->start_controls_section(
			'single_event_section',
			[
				'label' => esc_html__( 'Single Event', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

            $this->add_control(
                'single_event_map',
                [
                    'label' => esc_html__( 'Map', 'guto-toolkit' ),
                    'type' => Controls_Manager::WYSIWYG,
                    'default' => __('<iframe src="https://www.google.com/maps/embed?pb=!1m18!1m12!1m3!1d83327.357758289!2d-123.19394338208338!3d49.25782631996712!2m3!1f0!2f0!3f0!3m2!1i1024!2i768!4f13.1!3m3!1m2!1s0x548672b3db30ffad%3A0xf6711cf4e0ad84e3!2sMuseum%20of%20Anthropology!5e0!3m2!1sen!2sbd!4v1614529191338!5m2!1sen!2sbd"></iframe>', 'guto-toolkit'),
                ]
            );

            $this->add_control(
                'single_event_desc',
                [
                    'label' => esc_html__( 'Description', 'guto-toolkit' ),
                    'type' => Controls_Manager::WYSIWYG,
                    'default' => __('', 'guto-toolkit'),
                ]
            );

            $this->add_control(
                'price_label',
                [
                    'label'     => esc_html__( 'Price Label', 'guto-toolkit' ),
                    'type'      => Controls_Manager::TEXT,
                    'default'   => esc_html__('Cost:', 'guto-toolkit'),
                ]
            );

            $this->add_control(
                'total_slot_label',
                [
                    'label'     => esc_html__( 'Total Slot Label', 'guto-toolkit' ),
                    'type'      => Controls_Manager::TEXT,
                    'default'   => esc_html__('Total Slot:', 'guto-toolkit'),
                ]
            );

            $this->add_control(
                'booked_slot_label',
                [
                    'label'     => esc_html__( 'Booked Slot Label', 'guto-toolkit' ),
                    'type'      => Controls_Manager::TEXT,
                    'default'   => esc_html__('Booked Slot:', 'guto-toolkit'),
                ]
            );

            $this->add_control(
                'button_text',
                [
                    'label'     => esc_html__( 'Button Text', 'guto-toolkit' ),
                    'type'      => Controls_Manager::TEXT,
                    'default'   => esc_html__('Book Now', 'guto-toolkit'),
                ]
            );

            $this->add_control(
                'single_event_login_notes',
                [
                    'label'     => esc_html__( 'Login Notes', 'guto-toolkit' ),
                    'type'      => Controls_Manager::WYSIWYG,
                    'default'   => __('', 'guto-toolkit'),
                ]
            );

            $this->add_control(
                'single_event_logout_notes',
                [
                    'label'     => esc_html__( 'Logout Notes', 'guto-toolkit' ),
                    'type'      => Controls_Manager::WYSIWYG,
                    'default'   => __('', 'guto-toolkit'),
                ]
            );

        $this->end_controls_section();

    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        $button_text = $settings['button_text'];

        global $EM_Event;

        $available_spaces = $EM_Event->get_bookings()->get_available_spaces();
        $booked_spaces = $EM_Event->get_bookings()->get_booked_spaces();
        //$EM_Tickets = $EM_Event->get_bookings()->get_tickets(); ?>

        <!-- Start Single Event Area -->
        <div class="ms-events-details-area ptb-100">
            <div class="container-lg">
                <div class="row">
                    <div class="col-lg-8 col-md-12">
                        <?php if( ! $settings['single_event_map'] == '' ) : ?>
                            <div class="ms-events-details-location">
                                <?php echo __( $settings['single_event_map'] ); ?>
                            </div>
                        <?php endif; ?>
                        <div class="ms-events-details-desc">
                            <?php echo wp_kses_post( $settings['single_event_desc'] ); ?>
                        </div>
                    </div>
                    <div class="col-lg-4 col-md-12">
                        <div class="ms-events-details-info">
                            <ul class="info">
                                <li class="price">
                                    <div class="d-flex justify-content-between align-items-center">
                                        <span>
                                            <?php echo esc_html( $settings['price_label'] ); ?>
                                        </span>
                                        <?php
                                            global $allowedposttags;
                                            $EM_Tickets = $EM_Event->get_bookings()->get_tickets();
                                            $collumns = $EM_Tickets->get_ticket_collumns();
                                            ?>
                                            <?php foreach( $EM_Tickets->tickets as $EM_Ticket ) : ?>
                                                <?php if( $EM_Ticket->is_displayable() ): ?>
                                                    <?php echo $EM_Ticket->get_price(true); ?>
                                                <?php endif; ?>
                                            <?php endforeach; ?>
                                    </div>
                                </li>
                                <li>
                                    <div class="d-flex justify-content-between align-items-center">
                                        <span><?php echo esc_html( $settings['total_slot_label'] ); ?></span>
                                        <?php echo esc_attr( $EM_Event->get_bookings()->get_available_spaces() ); ?>
                                    </div>
                                </li>
                                <li>
                                    <div class="d-flex justify-content-between align-items-center">
                                        <span><?php echo esc_html( $settings['booked_slot_label'] ); ?></span>
                                        <?php
                                            echo esc_attr( $EM_Event->get_bookings()->get_booked_spaces() );
                                        ?>
                                    </div>
                                </li>
                            </ul>
                                <?php
                                    global $EM_Notices;
                                    //count tickets and available tickets
                                    $tickets_count = count($EM_Event->get_bookings()->get_tickets()->tickets);
                                    $available_tickets_count = count($EM_Event->get_bookings()->get_available_tickets());
                                    //decide whether user can book, event is open for bookings etc.
                                    $can_book = is_user_logged_in() || (get_option('dbem_bookings_anonymous') && !is_user_logged_in());
                                    $is_open = $EM_Event->get_bookings()->is_open(); //whether there are any available tickets right now
                                    $show_tickets = true;
                                    //if user is logged out, check for member tickets that might be available, since we should ask them to log in instead of saying 'bookings closed'
                                    if( !$is_open && !is_user_logged_in() && $EM_Event->get_bookings()->is_open(true) ){
                                        $is_open = true;
                                        $can_book = false;
                                        $show_tickets = get_option('dbem_bookings_tickets_show_unavailable') && get_option('dbem_bookings_tickets_show_member_tickets');
                                    }
                                    ?>
                            <div id="em-booking" class="em-booking <?php if( get_option('dbem_css_rsvp') ) echo 'css-booking'; ?>">
                                        <?php
                                    // We are firstly checking if the user has already booked a ticket at this event, if so offer a link to view their bookings.
                                    $EM_Booking = $EM_Event->get_bookings()->has_booking();
                                    do_action('em_booking_form_top', $EM_Event);
                                ?>
                                <?php if( is_object($EM_Booking) && !get_option('dbem_bookings_double') ): //Double bookings not allowed ?>
                                    <p>
                                        <?php echo get_option('dbem_bookings_form_msg_attending'); ?>
                                        <a href="<?php echo em_get_my_bookings_url(); ?>"><?php echo get_option('dbem_bookings_form_msg_bookings_link'); ?></a>
                                    </p>
                                <?php elseif( !$EM_Event->event_rsvp ): //bookings not enabled ?>
                                    <p><?php echo get_option('dbem_bookings_form_msg_disabled'); ?></p>
                                <?php elseif( $EM_Event->get_bookings()->get_available_spaces() <= 0 ): ?>
                                    <p><?php echo get_option('dbem_bookings_form_msg_full'); ?></p>
                                <?php elseif( !$is_open ): //event has started ?>
                                    <p><?php echo get_option('dbem_bookings_form_msg_closed');  ?></p>
                                <?php else: ?>
                                    <?php echo $EM_Notices; ?>
                                    <?php if( $tickets_count > 0) : ?>
                                        <?php //Tickets exist, so we show a booking form. ?>
                                        <form class="em-booking-form" name='booking-form' method='post' action='<?php echo apply_filters('em_booking_form_action_url',''); ?>#em-booking'>
                                            <?php do_action('em_booking_form_header', $EM_Event); ?>
                                            <input type='hidden' name='action' value='booking_add'/>
                                            <input type='hidden' name='event_id' value='<?php echo $EM_Event->get_bookings()->event_id; ?>'/>
                                            <input type='hidden' name='_wpnonce' value='<?php echo wp_create_nonce('booking_add'); ?>'/>
                                            <?php
                                                // Tickets Form
                                                if( $show_tickets && ($can_book || get_option('dbem_bookings_tickets_show_loggedout')) && ($tickets_count > 1 || get_option('dbem_bookings_tickets_single_form')) ){ //show if more than 1 ticket, or if in forced ticket list view mode
                                                    do_action('em_booking_form_before_tickets', $EM_Event); //do not delete
                                                    //Show multiple tickets form to user, or single ticket list if settings enable this
                                                    //If logged out, can be allowed to see this in settings witout the register form
                                                    em_locate_template('forms/bookingform/tickets-list.php',true, array('EM_Event'=>$EM_Event));
                                                    do_action('em_booking_form_after_tickets', $EM_Event); //do not delete
                                                    $show_tickets = false;
                                                }
                                            ?>
                                            <?php if( $can_book ): ?>
                                                <div class='em-booking-form'>
                                                    <?php
                                                        if( $show_tickets && $available_tickets_count == 1 && !get_option('dbem_bookings_tickets_single_form') ){
                                                            do_action('em_booking_form_before_tickets', $EM_Event); //do not delete
                                                            //show single ticket form, only necessary to show to users able to book (or guests if enabled)
                                                            $EM_Ticket = $EM_Event->get_bookings()->get_available_tickets()->get_first();
                                                            em_locate_template('forms/bookingform/ticket-single.php',true, array('EM_Event'=>$EM_Event, 'EM_Ticket'=>$EM_Ticket));
                                                            do_action('em_booking_form_after_tickets', $EM_Event); //do not delete
                                                        }
                                                    ?>
                                                    <?php
                                                        do_action('em_booking_form_before_user_details', $EM_Event);
                                                        if( has_action('em_booking_form_custom') ){
                                                            //Pro Custom Booking Form. You can create your own custom form by hooking into this action and setting the option above to true
                                                            do_action('em_booking_form_custom', $EM_Event); //do not delete
                                                        }else{
                                                            //If you just want to modify booking form fields, you could do so here
                                                            em_locate_template('forms/bookingform/booking-fields.php',true, array('EM_Event'=>$EM_Event));
                                                        }
                                                        do_action('em_booking_form_after_user_details', $EM_Event);
                                                    ?>
                                                    <?php do_action('em_booking_form_footer', $EM_Event); //do not delete ?>
                                                    <div class="btn-box">
                                                        <?php if( preg_match('/https?:\/\//',get_option('dbem_bookings_submit_button')) ): //Settings have an image url (we assume). Use it here as the button.?>
                                                        <input type="image" src="<?php echo get_option('dbem_bookings_submit_button'); ?>" class="em-booking-submit" id="em-booking-submit" />
                                                        <?php else: //Display normal submit button ?>
                                                        <input type="submit" class="<?php if(is_admin()) echo 'button-primary '; ?>em-booking-submit ms-default-btn" id="em-booking-submit" value="<?php echo esc_attr(get_option('dbem_bookings_submit_button')); ?>" />
                                                        <?php endif; ?>
                                                    </div>
                                                    <?php do_action('em_booking_form_footer_after_buttons', $EM_Event); //do not delete ?>
                                                </div>
                                            <?php else: ?>
                                                <p class="em-booking-form-details"><?php echo get_option('dbem_booking_feedback_log_in'); ?></p>
                                            <?php endif; ?>
                                        </form>
                                        <?php
                                        if( !is_user_logged_in() && get_option('dbem_bookings_login_form') ){
                                            //User is not logged in, show login form (enabled on settings page)
                                            em_locate_template('forms/bookingform/login.php',true, array('EM_Event'=>$EM_Event));
                                        }
                                        ?>
                                        <br class="clear" style="clear:left;" />
                                    <?php endif; ?>
                                <?php endif; ?>
                                <?php
                                do_action('em_booking_form_bottom', $EM_Event);
                                ?>
                            </div>
                            <?php if( ! is_user_logged_in() ) : ?>
                                <p>
                                    <?php echo wp_kses_post( $settings['single_event_login_notes'] ); ?>
                                </p>
                            <?php else : ?>
                                <p>
                                    <?php echo wp_kses_post( $settings['single_event_logout_notes'] ); ?>
                                </p>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <!-- End Single Event Area -->

        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_Single_Event );
