<?php

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

use Guto_Bootstrap_Navwalker;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class OHC_Navbar extends Widget_Base {

    public function get_name() {
        return 'ohc-navbar';
    }

    public function get_title() {
        return __( 'Online Health Coach Navbar', 'guto-toolkit' );
    }

    public function get_icon() {
        return 'eicon-logo';
    }

    public function get_keywords() {
        return [ 'Menu', 'Navigation' ];
    }

    public function get_categories() {
        return [ 'guto-nav' ];
    }

    protected function _register_controls() {

        // Menu
        $this->start_controls_section(
            'menu_settings',
            [
                'label' => __( 'Menu', 'guto-toolkit' ),
            ]
        );

            $this->add_control(
                'menu', [
                    'label' => __( 'Menu', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => guto_get_menu_array()
                ]
            );
            $this->add_control(
				'navbar_bg',
				[
					'label' => esc_html__( 'Navbar Background Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ohc-navbar-area' => 'background-color: {{VALUE}} !important',
					],
				]
            );

            $this->add_control(
				'sticky_navbar_bg',
				[
					'label' => esc_html__( 'Sticky Navbar Background Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ohc-navbar-area.is-sticky' => 'background-color: {{VALUE}} !important',
					],
				]
            );

            $this->add_control(
                'sec_padding', [
                    'label' => __( 'Navbar Padding', 'guto-toolkit' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                        '{{WRAPPER}} .ohc-navbar-area' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                    'default' => [
                        'unit' => 'px', // The selected CSS Unit. 'px', '%', 'em',

                    ],
                ]
            );

        $this->end_controls_section();


        // Logo settings
        $this->start_controls_section(
            'section_logo',
            [
                'label' => __( 'Logo', 'guto-toolkit' ),
            ]
        );

            $this->add_control(
                'main_logo',
                [
                    'label' => __( 'Main Logo', 'guto-toolkit' ),
                    'type' => Controls_Manager::MEDIA,
                ]
            );

        $this->end_controls_section();

        // Mobile Logo
        $this->start_controls_section(
            'section_mobile_logo',
            [
                'label' => __( 'Mobile Logo', 'guto-toolkit' ),
            ]
        );

            $this->add_control(
                'mobile_logo',
                [
                    'label' => __( 'Main Logo', 'guto-toolkit' ),
                    'type' => Controls_Manager::MEDIA,
                ]
            );

            $this->add_control(
                'mobile_logomax_width',
                [
                    'label' => __( 'Max Width', 'guto-toolkit' ),
                    'type' => Controls_Manager::SLIDER,
                    'size_units' => [ 'px', '%', 'rem' ],
                    'range' => [
                        'px' => [
                            'min' => 0,
                            'max' => 500,
                            'step' => 1,
                        ],
                        '%' => [
                            'min' => 0,
                            'max' => 100,
                        ],
                    ],
                    'selectors' => [
                        '{{WRAPPER}} .guto-responsive-menu>.logo>a>img' => 'max-width: {{SIZE}}{{UNIT}};',
                    ],
                ]
            );

        $this->end_controls_section();

        // Layout Settings
        $this->start_controls_section(
            'layout_settings',
            [
                'label' => __( 'Layout Settings', 'guto-toolkit' ),
            ]
        );

            $this->add_control(
                'nav_box_layout', [
                    'label' => __( 'Navbar box layout', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'default' => 'container',
                    'options' => [
                        'container' => esc_html__( 'Wide', 'guto-toolkit' ),
                        'container-fluid' => esc_html__( 'Full Width', 'guto-toolkit' ),
                    ]
                ]
            );

            $this->add_control(
                'menu_alignment', [
                    'label' => __( 'Menu Alignment', 'guto-toolkit' ),
                    'type' => Controls_Manager::CHOOSE,
                    'default' => 'right',
                    'options' => [
                        'left' => [
                            'title' => __( 'Left', 'guto-toolkit' ),
                            'icon' => 'eicon-text-align-left',
                        ],
                        'center' => [
                            'title' => __( 'Center', 'guto-toolkit' ),
                            'icon' => 'eicon-text-align-center',
                        ],
                        'right' => [
                            'title' => __( 'Right', 'guto-toolkit' ),
                            'icon' => 'eicon-text-align-right',
                        ],
                    ]
                ]
            );

        $this->end_controls_section();

        // Navbar Settings
        $this->start_controls_section(
            'navbar_settings',
            [
                'label' => __( 'Navbar Settings', 'guto-toolkit' ),
            ]
        );
            $this->add_control(
                'is_sticky',
                [
                    'label' => __( 'Sticky', 'guto-toolkit' ),
                    'type' => Controls_Manager::SWITCHER,
                    'label_on' => __( 'Yes', 'guto-toolkit' ),
                    'label_off' => __( 'No', 'guto-toolkit' ),
                    'return_value' => 'yes',
                    'default' => 'yes'
                ]
            );
            $this->add_group_control(
                Group_Control_Typography::get_type(), [
                    'label' => __( 'Menu Item Typography', 'guto-toolkit' ),
                    'name' => 'typography_menu_item',
                    'selector' => '{{WRAPPER}} .ohc-guto-nav .navbar .navbar-nav .nav-item a',
                ]
            );
            $this->add_control(
				'menu_item_color',
				[
					'label' => esc_html__( 'Menu Item Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ohc-guto-nav .navbar .navbar-nav .nav-item a, .ohc-guto-nav .navbar .navbar-nav .nav-item .dropdown-menu li a, .ohc-guto-nav .navbar .navbar-nav .nav-item .dropdown-menu li .dropdown-menu li a, .ohc-guto-nav .others-option .cart-btn a, .others-option-for-responsive .option-inner .others-option .cart-btn a' => 'color: {{VALUE}} !important',
					],
				]
            );
            $this->add_control(
				'menu_item_hover_color',
				[
					'label' => esc_html__( 'Menu Item Active/Hover Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ohc-guto-nav .navbar .navbar-nav .nav-item a:hover, .ohc-guto-nav .navbar .navbar-nav .nav-item a:focus, .ohc-guto-nav .navbar .navbar-nav .nav-item a.active, .ohc-guto-nav .navbar .navbar-nav .nav-item:hover a, .ohc-guto-nav .navbar .navbar-nav .nav-item.active a, .ohc-guto-nav .navbar .navbar-nav .nav-item .dropdown-menu li a:hover, .ohc-guto-nav .navbar .navbar-nav .nav-item .dropdown-menu li a:focus, .ohc-guto-nav .navbar .navbar-nav .nav-item .dropdown-menu li a.active, .ohc-guto-nav .navbar .navbar-nav .nav-item .dropdown-menu li .dropdown-menu li a:hover, .ohc-guto-nav .navbar .navbar-nav .nav-item .dropdown-menu li .dropdown-menu li a:focus, .ohc-guto-nav .navbar .navbar-nav .nav-item .dropdown-menu li .dropdown-menu li a.active, .ohc-guto-nav .navbar .navbar-nav .nav-item .dropdown-menu li .dropdown-menu li .dropdown-menu li a:hover, .ohc-guto-nav .navbar .navbar-nav .nav-item .dropdown-menu li .dropdown-menu li .dropdown-menu li a:focus, .ohc-guto-nav .navbar .navbar-nav .nav-item .dropdown-menu li .dropdown-menu li .dropdown-menu li a.active, .ohc-guto-nav .navbar .navbar-nav .nav-item .dropdown-menu li .dropdown-menu li .dropdown-menu li .dropdown-menu li a:hover, .ohc-guto-nav .navbar .navbar-nav .nav-item .dropdown-menu li .dropdown-menu li .dropdown-menu li .dropdown-menu li a:focus, .ohc-guto-nav .navbar .navbar-nav .nav-item .dropdown-menu li .dropdown-menu li .dropdown-menu li .dropdown-menu li a.active, .ohc-guto-nav .navbar .navbar-nav .nav-item .dropdown-menu li .dropdown-menu li .dropdown-menu li .dropdown-menu li .dropdown-menu li a:hover, .ohc-guto-nav .navbar .navbar-nav .nav-item .dropdown-menu li .dropdown-menu li .dropdown-menu li .dropdown-menu li .dropdown-menu li a:focus, .ohc-guto-nav .navbar .navbar-nav .nav-item .dropdown-menu li .dropdown-menu li .dropdown-menu li .dropdown-menu li .dropdown-menu li a.active, .ohc-guto-nav .navbar .navbar-nav .nav-item .dropdown-menu li .dropdown-menu li .dropdown-menu li .dropdown-menu li .dropdown-menu li .dropdown-menu li a:hover, .ohc-guto-nav .navbar .navbar-nav .nav-item .dropdown-menu li .dropdown-menu li .dropdown-menu li .dropdown-menu li .dropdown-menu li .dropdown-menu li a:focus, .ohc-guto-nav .navbar .navbar-nav .nav-item .dropdown-menu li .dropdown-menu li .dropdown-menu li .dropdown-menu li .dropdown-menu li .dropdown-menu li a.active, .ohc-guto-nav .navbar .navbar-nav .nav-item .dropdown-menu li .dropdown-menu li .dropdown-menu li .dropdown-menu li .dropdown-menu li .dropdown-menu li .dropdown-menu li a:hover, .ohc-guto-nav .navbar .navbar-nav .nav-item .dropdown-menu li .dropdown-menu li .dropdown-menu li .dropdown-menu li .dropdown-menu li .dropdown-menu li .dropdown-menu li a:focus, .ohc-guto-nav .navbar .navbar-nav .nav-item .dropdown-menu li .dropdown-menu li .dropdown-menu li .dropdown-menu li .dropdown-menu li .dropdown-menu li .dropdown-menu li a.active, .ohc-guto-nav .navbar .navbar-nav .nav-item .dropdown-menu li .dropdown-menu li .dropdown-menu li .dropdown-menu li .dropdown-menu li .dropdown-menu li.active a, .ohc-guto-nav .navbar .navbar-nav .nav-item .dropdown-menu li .dropdown-menu li .dropdown-menu li .dropdown-menu li .dropdown-menu li.active a, .ohc-guto-nav .navbar .navbar-nav .nav-item .dropdown-menu li .dropdown-menu li .dropdown-menu li .dropdown-menu li.active a, .ohc-guto-nav .navbar .navbar-nav .nav-item .dropdown-menu li .dropdown-menu li .dropdown-menu li.active a, .ohc-guto-nav .navbar .navbar-nav .nav-item .dropdown-menu li .dropdown-menu li.active a, .ohc-guto-nav .navbar .navbar-nav .nav-item .dropdown-menu li.active a, .ohc-guto-nav .others-option .cart-btn a:hover' => 'color: {{VALUE}} !important',
						'{{WRAPPER}} .ohc-guto-nav .others-option .cart-btn a span, .others-option-for-responsive .option-inner .others-option .cart-btn a span' => 'background-color: {{VALUE}} !important',
					],
				]
            );

            $this->add_control(
				'dropdown_menu_border_color',
				[
					'label' => esc_html__( 'Dropdown Menu Border Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ohc-guto-nav .navbar .navbar-nav .nav-item .dropdown-menu' => 'border-color: {{VALUE}} !important',
					],
				]
            );
            $this->add_group_control(
                Group_Control_Typography::get_type(), [
                    'label' => __( 'Mobile Menu Item Typography', 'guto-toolkit' ),
                    'name' => 'typography_mobile_menu_item',
                    'selector' => '{{WRAPPER}} .mean-container .mean-nav ul li a, .mean-container .mean-nav ul li li a',
                ]
            );
            $this->add_control(
				'mobile_menu_item_color',
				[
					'label' => esc_html__( 'Mobile Menu Item Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .mean-container .mean-nav ul li a, .mean-container .mean-nav ul li li a' => 'color: {{VALUE}} !important',
					],
				]
            );
            $this->add_control(
				'mobile_menu_item_hover_color',
				[
					'label' => esc_html__( 'Mobile Menu Item Active/Hover Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .mean-container .mean-nav ul li a:hover, .mean-container .mean-nav ul li li a:hover, .guto-responsive-nav .mean-container a.meanmenu-reveal' => 'color: {{VALUE}} !important',
						'{{WRAPPER}} .guto-responsive-nav .mean-container a.meanmenu-reveal span' => 'background: {{VALUE}} !important',
						'{{WRAPPER}} .others-option-for-responsive .dot-menu .inner .circle' => 'background-color: {{VALUE}} !important',
					],
				]
            );

        $this->end_controls_section();

        // Addisonian Settings
        $this->start_controls_section(
            'navbar_optional_settings',
            [
                'label' => __( 'Search Settings', 'guto-toolkit' ),
            ]
        );
            $this->add_control(
                'is_search',
                [
                    'label' => __( 'Enable Search', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        '1'             => __( 'Yes', 'guto-toolkit' ),
                        '2'            => __( 'NO', 'guto-toolkit' ),
                    ],
                    'default' => '1',
                ]
            );
            $this->add_control(
                'search_placeholder',
                [
                    'label' => __( 'Search Placeholder Text', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default' => __( 'Search for anything', 'guto-toolkit' ),
                    'condition' => [
                        'is_search' => '1',
                    ],
                ]
            );

            $this->add_control(
				'bg_placeholder',
				[
					'label' => esc_html__( 'Search Placeholder Background Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .search-overlay .search-overlay-form form .input-search' => 'background-color: {{VALUE}}',
					],
                    'condition' => [
                        'is_search' => '1',
                    ],
				]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(), [
                    'label' => __( 'Search Placeholder Typography', 'guto-toolkit' ),
                    'name' => 'typography_placeholder',
                    'selector' => '{{WRAPPER}} .search-overlay .search-overlay-form form .input-search',
                    'condition' => [
                        'is_search' => '1',
                    ],
                ]
            );
            $this->add_control(
				'color_placeholder',
				[
					'label' => esc_html__( 'Search Placeholder Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .search-overlay .search-overlay-form form .input-search' => 'color: {{VALUE}}',
					],
                    'condition' => [
                        'is_search' => '1',
                    ],
				]
            );
            $this->add_control(
				'icon_color_placeholder',
				[
					'label' => esc_html__( 'Search Placeholder Icon Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .search-overlay .search-overlay-form form button' => 'color: {{VALUE}}',
					],
                    'condition' => [
                        'is_search' => '1',
                    ],
				]
            );
        $this->end_controls_section();

        // Button
        $this->start_controls_section(
            'nav_button',
            [
                'label' => __( 'Button', 'guto-toolkit' ),
            ]
        );
            $this->add_control(
                'is_cart',
                [
                    'label' => __( 'Enable Cart', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        '1'             => __( 'Yes', 'guto-toolkit' ),
                        '2'            => __( 'NO', 'guto-toolkit' ),
                    ],
                    'default' => '1',
                ]
            );
            $this->add_control(
                'button_text',
                [
                    'label' => __( 'Button Text', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default' => __( 'Login/Register', 'guto-toolkit' ),
                ]
            );
            $this->add_control(
                'button_icon',
                [
                    'label' => __( 'Button Icon', 'guto-toolkit' ),
                    'type' => Controls_Manager::ICON,
                    'options' => guto_toolkit_icons(),
                ]
            );

            $this->add_control(
                'link_type',
                [
                    'label' => esc_html__( 'Button Link Type', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'label_block' => true,
                    'options' => [
                        '1'  => esc_html__( 'Link To Page', 'guto-toolkit' ),
                        '2' => esc_html__( 'External Link', 'guto-toolkit' ),
                    ],
                ]
            );

            $this->add_control(
                'link_to_page',
                [
                    'label' => esc_html__( 'Button Link Page', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'label_block' => true,
                    'options' => guto_toolkit_get_page_as_list(),
                    'condition' => [
                        'link_type' => '1',
                    ]
                ]
            );

            $this->add_control(
                'ex_link',
                [
                    'label'=>esc_html__('Button External Link', 'guto-toolkit'),
                    'type'=>Controls_Manager:: TEXT,
                    'condition' => [
                        'link_type' => '2',
                    ]
                ]
            );

            $this->add_control(
                'button_padding', [
                    'label' => __( 'Button Padding', 'guto-toolkit' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                        '{{WRAPPER}} .ohc-default-btn' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                    'default' => [
                        'unit' => 'px', // The selected CSS Unit. 'px', '%', 'em',

                    ],
                ]
            );
            $this->add_control(
				'button_bg',
				[
					'label' => esc_html__( 'Button Background Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ohc-default-btn' => 'background-color: {{VALUE}}',
					],
				]
            );

            $this->add_control(
                'button_top',
                [
                    'label' => __( 'Top', 'guto-toolkit' ),
                    'type' => Controls_Manager::SLIDER,
                    'size_units' => [ 'px', '%' ],
                    'range' => [
                        'px' => [
                            'min' => 0,
                            'max' => 100,
                            'step' => 5,
                        ],
                        '%' => [
                            'min' => 0,
                            'max' => 100,
                        ],
                    ],
                    'selectors' => [
                        '{{WRAPPER}} .ohc-default-btn i' => 'top: {{SIZE}}{{UNIT}};',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(), [
                    'label' => __( 'Button Text Typography', 'guto-toolkit' ),
                    'name' => 'typography_button',
                    'selector' => '{{WRAPPER}} .ohc-default-btn',
                ]
            );
            $this->add_control(
				'button_color',
				[
					'label' => esc_html__( 'Button Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ohc-default-btn' => 'color: {{VALUE}}',
					],
				]
            );

            $this->add_control(
				'hover_button_bg',
				[
					'label' => esc_html__( 'Hover Button Background Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ohc-default-btn:hover' => 'background-color: {{VALUE}}',
					],
				]
            );
            $this->add_control(
				'hover_button_color',
				[
					'label' => esc_html__( 'Hover Button Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ohc-default-btn:hover' => 'color: {{VALUE}}',
					],
				]
            );

        $this->end_controls_section();
    }

    /**
     * Render the widget output on the frontend.
     *
     * Written in PHP and used to generate the final HTML.
     *
     * @since 1.0.0
     *
     * @access protected
     */
    protected function render() {
        $settings = $this->get_settings();

        $is_sticky = ( $settings['is_sticky'] != 'yes' ) ? ' no-sticky' : '';

        $logo           = !empty($settings['main_logo']['url']) ? $settings['main_logo']['url'] : '';
        $mobile_logo    = !empty($settings['mobile_logo']['url']) ? $settings['mobile_logo']['url'] : '';

        $hide_adminbar = 'hide-adminbar';

        switch ( $settings['menu_alignment'] ) {
            case 'right':
                $ul_class = 'navbar-nav ms-auto';
                break;
            case 'left':
                $ul_class = 'navbar-nav me-auto left';
                break;
            case 'center':
                $ul_class = 'navbar-nav ms-auto me-auto';
                break;
        }
        ?>

		<div class="ohc-navbar-area <?php echo $is_sticky; ?>">
            <div class="guto-responsive-nav">
                <div class="container">
                    <div class="guto-responsive-menu">
                        <div class="logo">
							<a href="<?php echo esc_url( home_url( '/' ) );?>">
								<?php if( $mobile_logo != '' ): ?>
                                    <img src="<?php echo esc_url( $mobile_logo ); ?>" alt="<?php bloginfo( 'name' ); ?>">
								<?php elseif( $logo != '' ): ?>
                                    <img src="<?php echo esc_url( $logo ); ?>" alt="<?php bloginfo( 'name' ); ?>">
								<?php else: ?>
									<h2><?php bloginfo( 'name' ); ?></h2>
								<?php endif; ?>
							</a>
                        </div>
                    </div>
                </div>
            </div>

            <div class="ohc-guto-nav">
                <div class="<?php echo esc_attr( $settings['nav_box_layout'] ); ?>">
                    <nav class="navbar navbar-expand-md navbar-light">
						<a class="navbar-brand" href="<?php echo esc_url( home_url( '/' ) ); ?>">
							<?php if( $logo != '' ): ?>
                                <img src="<?php echo esc_url( $logo ); ?>" alt="<?php bloginfo( 'name' ); ?>">
							<?php else: ?>
								<h2><?php bloginfo( 'name' ); ?></h2>
							<?php endif; ?>
						</a>

                        <div class="collapse navbar-collapse mean-menu">
                            <?php
                            $menu = !empty($settings['menu']) ? $settings['menu'] : '';
                            $primary_nav_arg = [
                                'menu'            => $menu,
                                'theme_location'  => 'primary',
                                'container'       => null,
                                'menu_class'      => $ul_class,
                                'depth'           => 3,
                                'walker'          => new Guto_Bootstrap_Navwalker(),
                                'fallback_cb'     => 'Guto_Bootstrap_Navwalker::fallback',
                            ];
							if(has_nav_menu('primary')){ wp_nav_menu( $primary_nav_arg );  }
							?>

							<div class="others-option d-flex align-items-center">
                                <?php if( $settings['is_search'] == '1' ): ?>
                                    <div class="option-item">
                                        <div class="search-box">
                                            <i class='bx bx-search'></i>
                                        </div>
                                    </div>
                                <?php endif; ?>

                                <?php if (class_exists('WooCommerce')): ?>
                                    <?php if($settings['is_cart'] == '1'): ?>
                                        <div class="option-item">
                                            <a href="<?php echo esc_url(wc_get_cart_url()) ?>" class="cart-btn">
                                                <i class='bx bx-shopping-bag'></i>
                                                <span class="mini-cart-count"></span>
                                            </a>
                                        </div>
                                    <?php endif; ?>
                                <?php endif; ?>

                                <?php
                                // Button Icon
                                if( $settings['button_icon'] != '' ):
                                    $icon = $settings['button_icon'];
                                else:
                                    $icon = '';
                                endif;

                                // Get Button Link
                                $link = '';
                                if($settings['link_type'] == 1){
                                    $link = get_page_link($settings['link_to_page']);
                                } else {
                                    $link = $settings['ex_link'];
                                }
                                if( $settings['button_text'] != '' ): ?>
                                    <div class="option-item">
                                        <a href="<?php echo esc_url(  $link ); ?>" class="ohc-default-btn">
                                            <i class="<?php echo esc_attr($icon); ?>"></i>
                                            <?php echo esc_html( $settings['button_text'] ); ?>
                                        </a>
                                    </div>
                                <?php endif; ?>
                    
							</div>

                        </div>
                    </nav>
                </div>
            </div>

            <div class="others-option-for-responsive">
                <div class="container">
                    <div class="dot-menu">
                        <div class="inner">
                            <div class="circle circle-one"></div>
                            <div class="circle circle-two"></div>
                            <div class="circle circle-three"></div>
                        </div>
                    </div>
                    <div class="container">
                        <div class="option-inner">
                            <div class="others-option">
                                <?php if( $settings['is_search'] == '1' ): ?>
                                    <div class="option-item">
                                        <div class="search-box">
                                            <i class='bx bx-search'></i>
                                        </div>
                                    </div>
                                <?php endif; ?>

                                
                                <?php if (class_exists('WooCommerce')): ?>
                                    <?php if($settings['is_cart'] == '1'): ?>
                                        <div class="option-item">
                                            <a href="<?php echo esc_url(wc_get_cart_url()) ?>" class="cart-btn">
                                                <i class='bx bx-shopping-bag'></i>
                                                <span class="mini-cart-count"></span>
                                            </a>
                                        </div>
                                    <?php endif; ?>
                                <?php endif; ?>

                                <div class="option-item">
                                    <!-- Normal Button -->
                                    <?php
                                    // Button Icon
                                    if( $settings['button_icon'] != '' ):
                                        $icon = $settings['button_icon'];
                                    else:
                                        $icon = '';
                                    endif;

                                    // Get Button Link
                                    $link = '';
                                    if($settings['link_type'] == 1){
                                        $link = get_page_link($settings['link_to_page']);
                                    } else {
                                        $link = $settings['ex_link'];
                                    }
                                    if( $settings['button_text'] != '' ): ?>
                                        <div class="option-item">
                                            <a href="<?php echo esc_url(  $link ); ?>" class="ohc-default-btn">
                                                <i class="<?php echo esc_attr($icon); ?>"></i>
                                                <?php echo esc_html( $settings['button_text'] ); ?>
                                            </a>
                                        </div>
                                    <?php endif; ?>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>

        <div class="search-overlay">
            <div class="d-table">
                <div class="d-table-cell">
                    <div class="search-overlay-layer"></div>
                    <div class="search-overlay-layer"></div>
                    <div class="search-overlay-layer"></div>
                    
                    <div class="search-overlay-close">
                        <span class="search-overlay-close-line"></span>
                        <span class="search-overlay-close-line"></span>
                    </div>

                    <div class="search-overlay-form">
                        <form method="get" action="<?php echo site_url( '/' ); ?>">
                            <input type="text" value="" name="s" class="input-search" placeholder="<?php echo esc_attr( $settings['search_placeholder'] ); ?>">
                            <input type="hidden" value="course" name="ref" />
                            <input type="hidden" name="post_type" value="lp_course">
                            <button type="submit"><i class="bx bx-search"></i></button>
                        </form>
                    </div>
                </div>
            </div>
        </div>

        <?php
    }

}
Plugin::instance()->widgets_manager->register( new OHC_Navbar );