<?php
/**
 * News Banner Area Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_News_Banner_Area extends Widget_Base {

	public function get_name() {
        return 'News_Banner_Area';
    }

	public function get_title() {
        return esc_html__( 'NM Banner', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-banner';
    }

	public function get_categories() {
        return [ 'guto-elements', 'guto-news-and-magazine' ];
    }

	protected function register_controls() {

        $this->start_controls_section(
			'Guto_News_Area',
			[
				'label' => esc_html__( 'Guto News Banner', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

            $this->add_control(
                'show', [
                    'label'       => __( 'Show post count', 'guto-toolkit' ),
                    'type'        => Controls_Manager::NUMBER,
                    'label_block' => true,
                    'default'     => 5,
                    'description'  => __( 'Show post count will work for right side post. In left show 1 post', 'guto-toolkit' ),
                ]
            );

            $this->add_control(
                'order', [
                    'label'     => __( 'Order', 'guto-toolkit' ),
                    'type'      => Controls_Manager::SELECT,
                    'options'   => [
                        'ASC'  => 'ASC',
                        'DESC' => 'DESC'
                    ],
                    'default' => 'ASC'
                ]
            );

            $this->add_control(
                'cat', [
                    'label'        => __( 'Category', 'guto-toolkit' ),
                    'description'  => __( 'Enter the category slugs separated by commas (Eg. cat1, cat2)', 'guto-toolkit' ),
                    'type'         => Controls_Manager::TEXT,
                    'label_block'  => true,
                ]
            );

            $this->add_control(
                'show_meta',
                [
                    'label'        => __( 'Post Meta Hide/Show?', 'guto-toolkit' ),
                    'type'         => Controls_Manager::SWITCHER,
                    'label_on'     => __( 'Show', 'guto-toolkit' ),
                    'label_off'    => __( 'Hide', 'guto-toolkit' ),
                    'return_value' => 'yes',
                    'default'      => 'yes',
                ]
            );

        $this->end_controls_section();

        $this->start_controls_section(
			'section_style',
			[
				'label' => esc_html__( 'Style', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
        );
            $this->add_control(
                'cat_color', [
                    'label'     => __( 'Category Color', 'puva-toolkit' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .nm-single-blog-post-style-one .nm-single-blog-post-content span' => 'color: {{VALUE}};',
                    ],
                ]
            );
            $this->add_group_control(
                Group_Control_Typography::get_type(), [
                    'label'    => __( 'Category Typography', 'puva-toolkit' ),
                    'name'     => 'typography_cat',
                    'scheme'   => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '
                    {{WRAPPER}} .nm-single-blog-post-style-one .nm-single-blog-post-content span',
                ]
            );
            $this->add_control(
                'title_color', [
                    'label'     => __( 'Title Color', 'puva-toolkit' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .nm-single-blog-post-style-one .nm-single-blog-post-content h3 a' => 'color: {{VALUE}};',
                    ],
                ]
            );
            $this->add_group_control(
                Group_Control_Typography::get_type(), [
                    'label'    => __( 'Title Typography', 'puva-toolkit' ),
                    'name'     => 'typography_title',
                    'scheme'   => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '
                    {{WRAPPER}} .nm-single-blog-post-style-one .nm-single-blog-post-content h3 a',
                ]
            );
            $this->add_control(
                'meta_color', [
                    'label'     => __( 'Meta Color', 'puva-toolkit' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .nm-single-blog-post-style-one .nm-single-blog-post-content ul li a, .nm-single-blog-post-style-one .nm-single-blog-post-content ul li' => 'color: {{VALUE}};',
                    ],
                ]
            );
            $this->add_group_control(
                Group_Control_Typography::get_type(), [
                    'label'    => __( 'Meta Typography', 'puva-toolkit' ),
                    'name'     => 'typography_meta',
                    'scheme'   => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '
                    {{WRAPPER}} .nm-single-blog-post-style-one .nm-single-blog-post-content ul li a, .nm-single-blog-post-style-one .nm-single-blog-post-content ul li',
                ]
            );
        $this->end_controls_section();
    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        $post_show = $settings['show'];

        // Left Post Arg
        if ( !empty($settings['cat']) ) {
            $post_array = new \WP_Query(array(
                'post_type'         => 'post',
                'posts_per_page'    => 1,
                'order'             => $settings['order'],
                'meta_key'          => '_thumbnail_id',
                'tax_query'         => array(
                    array(
                        'taxonomy' => 'category',
                        'field'    => 'slug',
                        'terms'    => explode( ',', str_replace( ' ', '', $settings['cat'])),
                    ),
                ),
            ));
        } else {
            $post_array = new \WP_Query(array(
                'post_type'        => 'post',
                'posts_per_page'   => 1,
                'order'            => $settings['order'],
                'meta_key'         => '_thumbnail_id',
            ));
        } ?>


        <!-- Start NM Banner BLog Post Area -->
        <div class="nm-banner-blog-post-area pb-80">
            <div class="container">
                <div class="row">
                    <?php
                        $not_in = array();
                        while($post_array->have_posts()): $post_array->the_post();
                        $categories = get_the_category();
                    ?>
                    <div class="col-lg-6">
                        <div class="nm-single-blog-post-style-one bg-5" style="background-image:url(<?php echo esc_url( get_the_post_thumbnail_url() ); ?>);">
                            <div class="nm-single-blog-post-content">

                                <?php if ( ! empty( $categories ) ) { ?>
                                    <a href="<?php echo esc_url( get_category_link( $categories[0]->term_id ) ) ?>"><span><?php echo esc_html( $categories[0]->name ) ?></span></a>
                                <?php } ?>

                                <h3><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>

                                <?php if ( $settings['show_meta'] == 'yes' ) : ?>
                                    <ul>
                                        <li>
                                            <a href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ), get_the_author_meta( 'user_nicename' ) ) ) ?>">
                                                <?php the_author() ?>
                                            </a>
                                        </li>
                                        <li> <?php echo esc_html(get_the_date('M d, Y')) ?> </li>
                                    </ul>
                                <?php endif; ?>

                            </div>
                        </div>
                    </div>

                    <?php
                        $not_in[] = get_the_ID();
                        $not_in;
                        endwhile;
                        wp_reset_postdata();
                    ?>

                    <div class="col-lg-6">
                        <div class="row">
                            <!-- Second Arg -->
                            <?php if ( !empty($settings['cat']) ) {
                                $post_array2 = new \WP_Query(array(
                                    'post_type'         => 'post',
                                    'posts_per_page'    => !empty($post_show) ? $post_show : 4,
                                    'order'             => $settings['order'],
                                    'meta_key'          => '_thumbnail_id',
                                    'post__not_in'      => $not_in,
                                    'tax_query'         => array(
                                        array(
                                            'taxonomy' => 'category',
                                            'field'    => 'slug',
                                            'terms'    => explode( ',', str_replace( ' ', '', $settings['cat'])),
                                        ),
                                    ),
                                ));

                            } else {
                                $post_array2 = new \WP_Query(array(
                                    'post_type'         => 'post',
                                    'posts_per_page'    => !empty($post_show) ? $post_show : 4,
                                    'order'             => $settings['order'],
                                    'meta_key'          => '_thumbnail_id',
                                    'post__not_in'      => $not_in,
                                ));
                            } ?>

                            <?php
                                while($post_array2->have_posts()): $post_array2->the_post();
                                $categories = get_the_category();
                            ?>
                            <div class="col-lg-6 col-md-6">
                                <div class="nm-single-blog-post-style-one bg-1"  style="background-image:url(<?php echo esc_url( get_the_post_thumbnail_url() ); ?>);">

                                    <div class="nm-single-blog-post-content">
                                        <?php if ( ! empty( $categories ) ) { ?>
                                            <a href="<?php echo esc_url( get_category_link( $categories[0]->term_id ) ) ?>"><span><?php echo esc_html( $categories[0]->name ) ?></span></a>
                                        <?php } ?>

                                        <h3><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>
                                        <?php if ( $settings['show_meta'] == 'yes' ) : ?>
                                            <ul>
                                                <li>
                                                    <a href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ), get_the_author_meta( 'user_nicename' ) ) ) ?>">
                                                        <?php the_author() ?>
                                                    </a>
                                                </li>
                                                <li> <?php echo esc_html(get_the_date('M d, Y')) ?> </li>
                                            </ul>
                                        <?php endif; ?>
                                    </div>
                                </div>
                            </div>

                            <?php
                                $not_in[] = get_the_ID();
                                $not_in;
                                endwhile;
                                wp_reset_postdata();
                            ?>
                        </div>
                    </div>

                </div>
            </div>
        </div>
        <!-- End NM Banner BLog Post Area -->


        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_News_Banner_Area );