<?php
/**
 * NM Fashion Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_Fashion extends Widget_Base {

	public function get_name() {
        return 'NM_Fashion_Area';
    }

	public function get_title() {
        return esc_html__( 'NM Fashion', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-theme-builder';
    }

	public function get_categories() {
        return [ 'guto-elements', 'guto-news-and-magazine' ];
    }

	protected function register_controls() {

        $this->start_controls_section(
			'Guto_NM_Fashion_Area',
			[
				'label' => esc_html__( 'Guto Fashion', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );
            $this->add_control(
                'section_title',
                [
                    'label' => esc_html__( 'Section Title', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__('Fashion', 'guto-toolkit'),
                ]
            );

            $this->add_control(
                'columns',
                [
                    'label' => esc_html__( 'Choose Columns', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        '1'   => esc_html__( '1', 'guto-toolkit' ),
                        '2'   => esc_html__( '2', 'guto-toolkit' ),
                        '3'   => esc_html__( '3', 'guto-toolkit' ),
                        '4'   => esc_html__( '4', 'guto-toolkit' ),
                    ],
                    'default' => '3',
                ]
            );

            $this->add_control(
                'show', [
                    'label'       => __( 'Show post count', 'guto-toolkit' ),
                    'type'        => Controls_Manager::NUMBER,
                    'label_block' => true,
                    'default'     => 3,
                ]
            );

            $this->add_control(
                'order', [
                    'label'     => __( 'Order', 'guto-toolkit' ),
                    'type'      => Controls_Manager::SELECT,
                    'options'   => [
                        'ASC'  => 'ASC',
                        'DESC' => 'DESC'
                    ],
                    'default' => 'ASC'
                ]
            );

            $this->add_control(
                'cat', [
                    'label'        => __( 'Category', 'guto-toolkit' ),
                    'description'  => __( 'Enter the category slugs separated by commas (Eg. cat1, cat2)', 'guto-toolkit' ),
                    'type'         => Controls_Manager::TEXT,
                    'label_block'  => true,
                ]
            );
            $this->add_control(
                'show_meta',
                [
                    'label'        => __( 'Post Meta Hide/Show?', 'guto-toolkit' ),
                    'type'         => Controls_Manager::SWITCHER,
                    'label_on'     => __( 'Show', 'guto-toolkit' ),
                    'label_off'    => __( 'Hide', 'guto-toolkit' ),
                    'return_value' => 'yes',
                    'default'      => 'yes',
                ]
            );

        $this->end_controls_section();

        $this->start_controls_section(
			'section_style',
			[
				'label' => esc_html__( 'Style', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
        );
            $this->add_control(
                'sec_title_color',
                [
                    'label'     => esc_html__( 'Section Title Color', 'guto-toolkit' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .nm-section-title h2' => 'color: {{VALUE}}',
                    ],
                ]
            );
            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name'     => 'sec_title_typography',
                    'label'    => esc_html__( 'Section Title Typography', 'guto-toolkit' ),
                    'scheme'   => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .nm-section-title h2',
                ]
            );
            $this->add_control(
                'cat_color', [
                    'label'     => __( 'Category Color', 'puva-toolkit' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .nm-single-blog-post-style-two .nm-single-blog-post-content span' => 'color: {{VALUE}};',
                    ],
                ]
            );
            $this->add_group_control(
                Group_Control_Typography::get_type(), [
                    'label'    => __( 'Category Typography', 'puva-toolkit' ),
                    'name'     => 'typography_cat',
                    'scheme'   => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '
                    {{WRAPPER}} .nm-single-blog-post-style-two .nm-single-blog-post-content span',
                ]
            );
            $this->add_control(
                'title_color', [
                    'label'     => __( 'Title Color', 'puva-toolkit' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .nm-single-blog-post-style-two .nm-single-blog-post-content h3 a' => 'color: {{VALUE}};',
                    ],
                ]
            );
            $this->add_group_control(
                Group_Control_Typography::get_type(), [
                    'label'    => __( 'Title Typography', 'puva-toolkit' ),
                    'name'     => 'typography_title',
                    'scheme'   => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '
                    {{WRAPPER}} .nm-single-blog-post-style-two .nm-single-blog-post-content h3 a',
                ]
            );
            $this->add_control(
                'meta_color', [
                    'label'     => __( 'Meta Color', 'puva-toolkit' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .nm-single-blog-post-style-two .nm-single-blog-post-content ul li, .nm-single-blog-post-style-two .nm-single-blog-post-content ul li a' => 'color: {{VALUE}};',
                    ],
                ]
            );
            $this->add_group_control(
                Group_Control_Typography::get_type(), [
                    'label'    => __( 'Meta Typography', 'puva-toolkit' ),
                    'name'     => 'typography_meta',
                    'scheme'   => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '
                    {{WRAPPER}} .nm-single-blog-post-style-two .nm-single-blog-post-content ul li, .nm-single-blog-post-style-two .nm-single-blog-post-content ul li a',
                ]
            );

        $this->end_controls_section();
    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        // Card Columns
        $columns = $settings['columns'];
        if ($columns == '1') {
            $column = 'col-lg-12 col-md-6';
        }elseif ($columns == '2') {
            $column = 'col-lg-6 col-md-6';
        }elseif ($columns == '3') {
            $column = 'col-lg-4 col-md-6';
        }elseif ($columns == '4') {
            $column = 'col-lg-3 col-md-6';
        }

        if ( !empty($settings['cat']) ) {
            $post_array = new \WP_Query(array(
                'post_type'         => 'post',
                'posts_per_page'    => $settings['show'],
                'order'             => $settings['order'],
                'meta_key'          => '_thumbnail_id',
                'tax_query'         => array(
                    array(
                        'taxonomy' => 'category',
                        'field'    => 'slug',
                        'terms'    => explode( ',', str_replace( ' ', '', $settings['cat'])),
                    ),
                ),
            ));
        } else {
            $post_array = new \WP_Query(array(
                'post_type'        => 'post',
                'posts_per_page'   => $settings['show'],
                'order'            => $settings['order'],
                'meta_key'         => '_thumbnail_id',
            ));
        } ?>

        <div class="nm-fashion-blog-post pb-50">
            <?php if( !empty( $settings['section_title'] ) ): ?>
                <div class="nm-section-title">
                    <h2><?php echo esc_html( $settings['section_title'] ); ?></h2>
                </div>
            <?php endif; ?>

            <div class="row justify-content-center">

            <?php while($post_array->have_posts()): $post_array->the_post();
            $categories = get_the_category(); ?>
                <div class="<?php echo esc_attr( $column );?>">
                    <div class="nm-single-blog-post-style-two">
                        <?php if( get_the_post_thumbnail_url() != '' ): ?>
                            <a href="<?php the_permalink(); ?>">
                                <img src="<?php echo get_the_post_thumbnail_url( get_the_ID(), 'full' ); ?>" alt="<?php the_post_thumbnail_caption();  ?>">
                            </a>
                        <?php endif; ?>

                        <div class="nm-single-blog-post-content">
                            <?php if ( ! empty( $categories ) ) { ?>
                                <a href="<?php echo esc_url( get_category_link( $categories[0]->term_id ) ) ?>"><span><?php echo esc_html( $categories[0]->name ) ?></span></a>
                            <?php } ?>
                            <h3><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>
                            <?php if ( $settings['show_meta'] == 'yes' ) : ?>
                                <ul>
                                    <li>
                                        <a href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ), get_the_author_meta( 'user_nicename' ) ) ) ?>">
                                            <?php the_author() ?>
                                        </a>
                                    </li>
                                    <li> <?php echo esc_html(get_the_date('M d, Y')) ?> </li>
                                </ul>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
            <?php endwhile;
            wp_reset_query(); ?>
            </div>
        </div>
        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_Fashion );