<?php
/**
 * NM Fitness Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_NM_Fitness extends Widget_Base {

	public function get_name() {
        return 'NM_Fitness_Area';
    }

	public function get_title() {
        return esc_html__( 'NM Fitness', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-theme-builder';
    }

	public function get_categories() {
        return [ 'guto-elements', 'guto-news-and-magazine' ];
    }

	protected function register_controls() {

        $this->start_controls_section(
			'Guto_NM_Fitness_Area',
			[
				'label' => esc_html__( 'Guto Fitness', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );
            $this->add_control(
                'section_title',
                [
                    'label' => esc_html__( 'Section Title', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__('Lifestyle', 'guto-toolkit'),
                ]
            );

            $this->add_control(
                'show', [
                    'label'       => __( 'Show post count', 'guto-toolkit' ),
                    'type'        => Controls_Manager::NUMBER,
                    'label_block' => true,
                    'default'     => 3,
                ]
            );

            $this->add_control(
                'order', [
                    'label'     => __( 'Order', 'guto-toolkit' ),
                    'type'      => Controls_Manager::SELECT,
                    'options'   => [
                        'ASC'  => 'ASC',
                        'DESC' => 'DESC'
                    ],
                    'default' => 'ASC'
                ]
            );

            $this->add_control(
                'cat', [
                    'label'        => __( 'Category', 'guto-toolkit' ),
                    'description'  => __( 'Enter the category slugs separated by commas (Eg. cat1, cat2)', 'guto-toolkit' ),
                    'type'         => Controls_Manager::TEXT,
                    'label_block'  => true,
                ]
            );
            $this->add_control(
                'show_meta',
                [
                    'label'        => __( 'Post Meta Hide/Show?', 'guto-toolkit' ),
                    'type'         => Controls_Manager::SWITCHER,
                    'label_on'     => __( 'Show', 'guto-toolkit' ),
                    'label_off'    => __( 'Hide', 'guto-toolkit' ),
                    'return_value' => 'yes',
                    'default'      => 'yes',
                ]
            );

            $this->add_control(
				'pagination_show',
				[
					'label'        => __( 'Show Pagination?', 'guto-toolkit' ),
					'type'         => Controls_Manager::SWITCHER,
					'label_on'     => __( 'Show', 'guto-toolkit' ),
					'label_off'    => __( 'Hide', 'guto-toolkit' ),
					'return_value' => 'yes',
                    'default'      => 'no',
				]
            );

        $this->end_controls_section();

        $this->start_controls_section(
			'section_style',
			[
				'label' => esc_html__( 'Style', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
        );
            $this->add_control(
                'sec_title_color',
                [
                    'label'     => esc_html__( 'Section Title Color', 'guto-toolkit' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .nm-section-title h2' => 'color: {{VALUE}}',
                    ],
                ]
            );
            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name'     => 'sec_title_typography',
                    'label'    => esc_html__( 'Section Title Typography', 'guto-toolkit' ),
                    'scheme'   => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .nm-section-title h2',
                ]
            );
            $this->add_control(
                'cat_color', [
                    'label'     => __( 'Category Color', 'guto-toolkit' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .nm-fitness-blog-post .nm-single-blog-post-content span' => 'color: {{VALUE}};',
                    ],
                ]
            );
            $this->add_group_control(
                Group_Control_Typography::get_type(), [
                    'label'    => __( 'Category Typography', 'guto-toolkit' ),
                    'name'     => 'typography_cat',
                    'scheme'   => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '
                    {{WRAPPER}} .nm-fitness-blog-post .nm-single-blog-post-content span',
                ]
            );
            $this->add_control(
                'title_color', [
                    'label'     => __( 'Title Color', 'guto-toolkit' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .nm-fitness-blog-post .nm-single-blog-post-content h3 a' => 'color: {{VALUE}};',
                    ],
                ]
            );
            $this->add_group_control(
                Group_Control_Typography::get_type(), [
                    'label'    => __( 'Title Typography', 'guto-toolkit' ),
                    'name'     => 'typography_title',
                    'scheme'   => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '
                    {{WRAPPER}} .nm-fitness-blog-post .nm-single-blog-post-content h3 a',
                ]
            );
            $this->add_control(
                'meta_color', [
                    'label'     => __( 'Meta Color', 'guto-toolkit' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .nm-fitness-blog-post .nm-single-blog-post-content ul li, .nm-fitness-blog-post .nm-single-blog-post-content ul li a' => 'color: {{VALUE}};',
                    ],
                ]
            );
            $this->add_group_control(
                Group_Control_Typography::get_type(), [
                    'label'    => __( 'Meta Typography', 'guto-toolkit' ),
                    'name'     => 'typography_meta',
                    'scheme'   => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '
                    {{WRAPPER}} .nm-fitness-blog-post .nm-single-blog-post-content ul li, .nm-fitness-blog-post .nm-single-blog-post-content ul li a',
                ]
            );

        $this->end_controls_section();
    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        if ( !empty($settings['cat']) ) {
            $post_array = new \WP_Query(array(
                'post_type'         => 'post',
                'posts_per_page'    => $settings['show'],
                'order'             => $settings['order'],
                'paged'             => get_query_var('paged') ? get_query_var('paged') : 1,
                'meta_key'          => '_thumbnail_id',
                'tax_query'         => array(
                    array(
                        'taxonomy' => 'category',
                        'field'    => 'slug',
                        'terms'    => explode( ',', str_replace( ' ', '', $settings['cat'])),
                    ),
                ),
            ));
        } else {
            $post_array = new \WP_Query(array(
                'post_type'        => 'post',
                'posts_per_page'   => $settings['show'],
                'order'            => $settings['order'],
                'meta_key'         => '_thumbnail_id',
                'paged'            => get_query_var('paged') ? get_query_var('paged') : 1
            ));
        } ?>

        <div class="nm-fitness-blog-post pb-50">
            <?php if( !empty( $settings['section_title'] ) ): ?>
                <div class="nm-section-title">
                    <h2><?php echo esc_html( $settings['section_title'] ); ?></h2>
                </div>
            <?php endif; ?>

            <?php while($post_array->have_posts()): $post_array->the_post();
                $categories = get_the_category(); ?>
                <div class="row align-items-center">
                    <?php if( get_the_post_thumbnail_url() != '' ): ?>
                        <div class="col-lg-6 col-md-6">
                            <div class="nm-single-blog-post-style-two">
                                <a href="<?php the_permalink(); ?>">
                                    <img src="<?php echo get_the_post_thumbnail_url( get_the_ID(), 'full' ); ?>" alt="<?php the_post_thumbnail_caption();  ?>">
                                </a>
                            </div>
                        </div>
                    <?php endif; ?>

                    <div class="col-lg-6 col-md-6">
                        <div class="nm-single-blog-post-content">
                            <?php if ( ! empty( $categories ) ) { ?>
                                <a href="<?php echo esc_url( get_category_link( $categories[0]->term_id ) ) ?>"><span><?php echo esc_html( $categories[0]->name ) ?></span></a>
                            <?php } ?>

                            <h3><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>

                            <?php the_excerpt() ?>

                            <?php if ( $settings['show_meta'] == 'yes' ) : ?>
                                <ul>
                                    <li>
                                        <a href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ), get_the_author_meta( 'user_nicename' ) ) ) ?>">
                                            <?php the_author() ?>
                                        </a>
                                    </li>
                                    <li> <?php echo esc_html(get_the_date('M d, Y')) ?> </li>
                                </ul>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
            <?php endwhile;
            wp_reset_query(); ?>
        </div>

        <?php if ( $settings['pagination_show'] == 'yes' ) { ?>
            <div class="nm-pagination-area">
                <nav aria-label="navigation">
                <?php
                $big = 999999999; // need an unlikely integer
                echo paginate_links( array(
                    'base' => str_replace( $big, '%#%', get_pagenum_link( $big ) ),
                    'format' => '?paged=%#%',
                    'current' => max(1, get_query_var('paged') ),
                    'total' => $post_array->max_num_pages,
                    //'format' => '?paged=%#%',
                    'prev_text' => '<i class="flaticon-left-arrow"></i>',
				    'next_text' => '<i class="flaticon-right-arrow-1"></i>',
                ) ); ?>
                </nav>
            </div>
        <?php } ?>

        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_NM_Fitness );