<?php
/**
 * NM Popular Posts Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_NM_Popular_Posts extends Widget_Base {

	public function get_name() {
        return 'NM_Popular_Posts_Area';
    }

	public function get_title() {
        return esc_html__( 'NM Popular Posts', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-theme-builder';
    }

	public function get_categories() {
        return [ 'guto-elements', 'guto-news-and-magazine' ];
    }

	protected function register_controls() {

        $this->start_controls_section(
			'Guto_NM_Popular_Area',
			[
				'label' => esc_html__( 'Guto Popular Posts', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

            $this->add_control(
                'show', [
                    'label'       => __( 'Show post count', 'guto-toolkit' ),
                    'type'        => Controls_Manager::NUMBER,
                    'label_block' => true,
                    'default'     => 5,
                ]
            );

            $this->add_control(
                'order', [
                    'label'     => __( 'Order', 'guto-toolkit' ),
                    'type'      => Controls_Manager::SELECT,
                    'options'   => [
                        'ASC'  => 'ASC',
                        'DESC' => 'DESC'
                    ],
                    'default' => 'ASC'
                ]
            );

            $this->add_control(
                'cat', [
                    'label'        => __( 'Category', 'guto-toolkit' ),
                    'description'  => __( 'Enter the category slugs separated by commas (Eg. cat1, cat2)', 'guto-toolkit' ),
                    'type'         => Controls_Manager::TEXT,
                    'label_block'  => true,
                ]
            );
            $this->add_control(
                'show_meta',
                [
                    'label'        => __( 'Post Meta Hide/Show?', 'guto-toolkit' ),
                    'type'         => Controls_Manager::SWITCHER,
                    'label_on'     => __( 'Show', 'guto-toolkit' ),
                    'label_off'    => __( 'Hide', 'guto-toolkit' ),
                    'return_value' => 'yes',
                    'default'      => 'yes',
                ]
            );
            $this->add_control(
                'read_text',
                [
                    'label' => esc_html__( 'Post Reading Time Text', 'guto-toolkit' ),
                    'type'  => Controls_Manager::TEXT,
                ]
            );
        $this->end_controls_section();

        $this->start_controls_section(
			'section_style',
			[
				'label' => esc_html__( 'Style', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
        );
            $this->add_control(
                'title_color', [
                    'label'     => __( 'Title Color', 'guto-toolkit' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .nm-widget-area .widget_guto_posts_thumb .item .info .title a' => 'color: {{VALUE}};',
                    ],
                ]
            );
            $this->add_group_control(
                Group_Control_Typography::get_type(), [
                    'label'    => __( 'Title Typography', 'guto-toolkit' ),
                    'name'     => 'typography_small_title',
                    'scheme'   => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '
                    {{WRAPPER}} .nm-widget-area .widget_guto_posts_thumb .item .info .title a',
                ]
            );
            $this->add_control(
                'meta_color', [
                    'label'     => __( 'Meta Color', 'guto-toolkit' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .nm-single-blog-post-style-two .nm-single-blog-post-content ul li, .nm-single-blog-post-style-two .nm-single-blog-post-content ul li a, .nm-widget-area .widget_guto_posts_thumb .item .info .meta li' => 'color: {{VALUE}};',
                    ],
                ]
            );
            $this->add_group_control(
                Group_Control_Typography::get_type(), [
                    'label'    => __( 'Meta Typography', 'guto-toolkit' ),
                    'name'     => 'typography_meta',
                    'scheme'   => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '
                    {{WRAPPER}} .nm-single-blog-post-style-two .nm-single-blog-post-content ul li, .nm-single-blog-post-style-two .nm-single-blog-post-content ul li a, .nm-widget-area .widget_guto_posts_thumb .item .info .meta li',
                ]
            );
        $this->end_controls_section();
    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        if ( !empty($settings['cat']) ) {
            $post_array = new \WP_Query(array(
                'post_type'         => 'post',
                'posts_per_page'    => $settings['show'],
                'order'             => $settings['order'],
                'meta_key'          => '_thumbnail_id',
                'tax_query'         => array(
                    array(
                        'taxonomy' => 'category',
                        'field'    => 'slug',
                        'terms'    => explode( ',', str_replace( ' ', '', $settings['cat'])),
                    ),
                ),
            ));
        } else {
            $post_array = new \WP_Query(array(
                'post_type'        => 'post',
                'posts_per_page'   => $settings['show'],
                'order'            => $settings['order'],
                'meta_key'         => '_thumbnail_id',
            ));
        } ?>

        <div class="widget widget_guto_posts_thumb">
            <?php while($post_array->have_posts()): $post_array->the_post();
            $categories = get_the_category(); ?>
                <article class="item">
                    <a href="<?php the_permalink(); ?>" class="thumb">
                        <span class="fullimage cover bg1" role="img" style="background-image:url(<?php echo esc_url( get_the_post_thumbnail_url() ); ?>);"></span>
                    </a>

                    <div class="info">
                        <h4 class="title usmall">
                            <a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
                        </h4>

                        <?php if ( $settings['show_meta'] == 'yes' ) : ?>
                            <ul class="meta">
                                <li>
                                    <i class='bx bx-calendar'></i>
                                    <?php echo esc_html(get_the_date('M d, Y')) ?>
                                </li>
                                <li>
                                    <i class='bx bx-time'></i>
                                    <?php echo esc_html(guto_lite_reading_time()) ?>
                                    <?php echo esc_html($settings['read_text']); ?>
                                </li>
                            </ul>
                        <?php endif; ?>
                    </div>
                </article>
            <?php endwhile;
            wp_reset_query(); ?>
        </div>

        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_NM_Popular_Posts );