<?php
/**
 * News Breaking Area Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_News_Breaking_Area extends Widget_Base {

	public function get_name() {
        return 'News_Breaking_Area';
    }

	public function get_title() {
        return esc_html__( 'NM Breaking News', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-info-box';
    }

	public function get_categories() {
        return [ 'guto-elements' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'Guto_News_Area',
			[
				'label' => esc_html__( 'Guto News Breaking', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

            $this->add_control(
                'breaking_title',
                [
                    'label' => esc_html__( 'Breaking News Title', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__('Breaking News', 'guto-toolkit'),
                ]
            );

            $repeater = new Repeater();
            $repeater->add_control(
                'news_content', [
                    'label' => esc_html__('News Content', 'guto-toolkit'),
                    'type' => Controls_Manager::TEXTAREA,
                    'default' => esc_html__('Lorem, ipsum dolor sit amet consectetur adipisicing elit. Rerum Latest Post et veritatis, consectetur aliquam neque aliquid explicabo vitae', 'guto-toolkit'),
                    'label_block' => true,
                ]
            );
            $this->add_control(
                'guto_news_items',
                [
                    'label' => esc_html__('News Item', 'guto-toolkit'),
                    'type' => Controls_Manager::REPEATER,
                    'fields' => $repeater->get_controls(),
                ]
            );

        $this->end_controls_section();

        $this->start_controls_section(
			'section_style',
			[
				'label' => esc_html__( 'Style', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
        );
            $this->add_control(
                'title_color',
                [
                    'label' => esc_html__( 'Title Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .nm-baking-news-content span' => 'color: {{VALUE}}',
                    ],
                ]
            );
            $this->add_control(
                'title_bgcolor',
                [
                    'label' => esc_html__( 'Title Background Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .nm-baking-news-content span' => 'background-color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'title_typography',
                    'label' => esc_html__( 'Title Typography', 'guto-toolkit' ),
                    'scheme' => Scheme_Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .nm-baking-news-content span',
                ]
            );

            $this->add_control(
                'content_color',
                [
                    'label' => esc_html__( 'Content Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .nm-baking-news-content p' => 'color: {{VALUE}}',
                    ],
                ]
            );
            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'content_typography',
                    'label' => esc_html__( 'Content Typography', 'guto-toolkit' ),
                    'scheme' => Scheme_Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .nm-baking-news-content p',
                ]
            );

            $this->add_control(
                'content_linktext_color',
                [
                    'label' => esc_html__( 'Content Link Text Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .nm-baking-news-content p a' => 'color: {{VALUE}}',
                    ],
                ]
            );

        $this->end_controls_section();
    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        $slider = $settings['guto_news_items'];
        ?>
            <div class="nm-baking-news-area">
                <div class="container">
                    <div class="nm-baking-news-content">
                        <?php if( !empty( $settings['breaking_title'] ) ): ?>
                            <span><?php echo esc_html( $settings['breaking_title'] ); ?></span>
                        <?php endif; ?>

                        <div class="nm-baking-news-slider owl-carousel owl-theme">
                            <!-- Repeater -->
                            <?php foreach ($slider as $key => $value): ?>
                                <?php echo wp_kses_post( $value['news_content'] ); ?>
                            <?php endforeach; ?>
                        </div>
                    </div>
                </div>
            </div>

        <?php
	}

	protected function _content_template() {}

}

Plugin::instance()->widgets_manager->register( new Guto_News_Breaking_Area );