<?php
/**
 * NM Newsletter Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_NM_Newsletter extends Widget_Base {

	public function get_name() {
        return 'Guto_NM_Newsletter';
    }

	public function get_title() {
        return __( 'NM Newsletter', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-email-field';
    }

	public function get_categories() {
        return [ 'guto-elements' ];
    }

    public function get_keywords() {
        return [ 'mailchimp', 'form', 'newsletter' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'Guto_Newsletter',
			[
				'label' => esc_html__( 'Guto NM Newsletter', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

            $this->add_control(
                'action_url', [
                    'label' => esc_html__( 'Action URL', 'guto-toolkit' ),
                    'description' => esc_html__( 'Enter here your MailChimp action URL. <a href="https://doc.gutotheme.com/docs/tips-guides-troubleshoots/get-mailchimp-newsletter-form-action-url/" target="_blank"> How to </a>', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'label_block' => true,
                ]
            );
            $this->add_control(
                'title', [
                    'label' => esc_html__( 'Title', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__( 'Subscribe to our newsletter to stay up to date' , 'guto-toolkit' ),
                    'label_block' => true,
                ]
            );
            $this->add_control(
                'desc', [
                    'label' => esc_html__( 'Description', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__( 'Subscribe to our newsletter to get the new updates!', 'guto-toolkit' ),
                    'label_block' => true,
                ]
            );

            $this->add_control(
                'placeholder_text', [
                    'label' => esc_html__( 'Email Placeholder Text', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__( 'Enter your email address' , 'guto-toolkit' ),
                    'label_block' => true,
                ]
            );

            $this->add_control(
                'button_text', [
                    'label' => esc_html__( 'Button text', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__( 'Subscribe Now' , 'guto-toolkit' ),
                    'label_block' => true,
                ]
            );
        $this->end_controls_section();

        $this->start_controls_section(
			'newsletter_style',
			[
				'label' => esc_html__( 'Style', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
        );
            $this->add_control(
                'card_bg_color',
                [
                    'label' => esc_html__( 'Card Background Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .nm-newsletter-box' => 'background-color: {{VALUE}}',
                    ],
                ]
            );
            $this->add_control(
                'title_color',
                [
                    'label' => esc_html__( 'Title Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .nm-newsletter-box h3' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'title_typography',
                    'label' => esc_html__( 'Title Typography', 'guto-toolkit' ),
                    'scheme' => Scheme_Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .nm-newsletter-box h3',
                ]
            );

            $this->add_control(
                'desc_color',
                [
                    'label' => esc_html__( 'Description Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .nm-newsletter-box p' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'desc_typography',
                    'label' => esc_html__( 'Description Typography', 'guto-toolkit' ),
                    'scheme' => Scheme_Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .nm-newsletter-box p',
                ]
            );

        $this->end_controls_section();
    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        // Inline Editing
        $this-> add_inline_editing_attributes('title','none');

        ?>

            <div class="nm-newsletter-box">
                <?php if($settings['title']): ?>
                    <h3><?php echo esc_html($settings['title']); ?></h3>
                <?php endif; ?>

                <?php if($settings['desc']): ?>
                    <p><?php echo esc_html($settings['desc']); ?></p>
                <?php endif; ?>

                <form class="mailchimp newsletter-form restaurant-newsletter-form" method="post">
                    <input type="email" class="form-control memail" placeholder="<?php echo esc_attr($settings['placeholder_text']); ?>" name="EMAIL" required>

                    <?php if( $settings['button_text'] != '' ): ?>
                        <button type="submit" class="default-btn"><?php echo esc_html( $settings['button_text'] ); ?><span></span></button>
                    <?php endif; ?>

                    <p class="mchimp-errmessage" style="display: none;"></p>
                    <p class="mchimp-sucmessage" style="display: none;"></p>
                </form>
            </div>

            <script>
                ;(function($){
                    "use strict";
                    $(document).ready(function () {
                        // MAILCHIMP
                        if ($(".mailchimp").length > 0) {
                            $(".mailchimp").ajaxChimp({
                                callback: mailchimpCallback,
                                url: "<?php echo esc_js($settings['action_url']) ?>"
                            });
                        }
                        if ($(".mailchimp_two").length > 0) {
                            $(".mailchimp_two").ajaxChimp({
                                callback: mailchimpCallback,
                                url: "<?php echo esc_js($settings['action_url']) ?>" //Replace this with your own mailchimp post URL. Don't remove the "". Just paste the url inside "".
                            });
                        }
                        $(".memail").on("focus", function () {
                            $(".mchimp-errmessage").fadeOut();
                            $(".mchimp-sucmessage").fadeOut();
                        });
                        $(".memail").on("keydown", function () {
                            $(".mchimp-errmessage").fadeOut();
                            $(".mchimp-sucmessage").fadeOut();
                        });
                        $(".memail").on("click", function () {
                            $(".memail").val("");
                        });

                        function mailchimpCallback(resp) {
                            if (resp.result === "success") {
                                $(".mchimp-errmessage").html(resp.msg).fadeIn(1000);
                                $(".mchimp-sucmessage").fadeOut(500);
                            } else if (resp.result === "error") {
                                $(".mchimp-errmessage").html(resp.msg).fadeIn(1000);
                            }
                        }
                    });
                })(jQuery)
            </script>
    <?php
	}

	protected function _content_template() {}

}

Plugin::instance()->widgets_manager->register( new Guto_NM_Newsletter );