<?php
/**
 * NM Post Tag Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_NM_Post_Tag extends Widget_Base {

	public function get_name() {
        return 'Guto_NM_Post_Tag';
    }

	public function get_title() {
        return __( 'NM Post Tag', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-tags';
    }

	public function get_categories() {
        return [ 'guto-elements' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'Guto_Post_Tag',
			[
				'label' => esc_html__( 'Guto NM Post Tag', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );
            $this->add_control(
                'title', [
                    'label' => esc_html__( 'Title', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__( 'Tags' , 'guto-toolkit' ),
                    'label_block' => true,
                ]
            );
        $this->end_controls_section();

        $this->start_controls_section(
			'newsletter_style',
			[
				'label' => esc_html__( 'Style', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
        );
            $this->add_control(
                'title_color',
                [
                    'label' => esc_html__( 'Title Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .widget_tag_cloud .widget-title' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'title_typography',
                    'label' => esc_html__( 'Title Typography', 'guto-toolkit' ),
                    'scheme' => Scheme_Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .widget_tag_cloud .widget-title',
                ]
            );

            $this->add_control(
                'tag_color',
                [
                    'label' => esc_html__( 'Tag Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .tagcloud a' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'tag_typography',
                    'label' => esc_html__( 'Tag Typography', 'guto-toolkit' ),
                    'scheme' => Scheme_Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .tagcloud a',
                ]
            );

        $this->end_controls_section();
    }

	protected function render() {

        $settings = $this->get_settings_for_display(); ?>

        <div class="widget widget_tag_cloud">
            <?php if($settings['title']): ?>
                <h3 class="widget-title"><?php echo esc_html($settings['title']); ?></h3>
            <?php endif; ?>
            
            <div class="tagcloud">
                <?php 
                $post_tags = get_tags(array(
                    'hide_empty' => false
                ));
                foreach ($post_tags as $post_tag ) { ?>
                    <a href="<?php echo esc_url(get_tag_link($post_tag->term_id)); ?>">
                        <?php echo esc_html($post_tag->name) ?> 
                        <span class="tag-link-count"> <?php echo esc_html__('(','guto-toolkit'); ?><?php echo esc_html($post_tag->count) ?><?php echo esc_html__(')','guto-toolkit'); ?></span>
                    </a>
                <?php } ?>
            </div>
        </div>
    <?php
	}

	protected function _content_template() {}

}

Plugin::instance()->widgets_manager->register( new Guto_NM_Post_Tag );