<?php
/**
 * NM Stay Connected Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_NM_StayConnected_Area extends Widget_Base {

	public function get_name() {
        return 'NM_Stay_Connected_Area';
    }

	public function get_title() {
        return esc_html__( 'NM Stay Connected', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-social-icons';
    }

	public function get_categories() {
        return [ 'guto-elements' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'Guto_nm_StayConnected',
			[
				'label' => esc_html__( 'Guto Stay Connected', 'guto-toolkit' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
        );

            $this->add_control(
                'section_title',
                [
                    'label'   => esc_html__( 'Section Title', 'guto-toolkit' ),
                    'type'    => Controls_Manager::TEXT,
                    'default' => esc_html__('Stay connected', 'guto-toolkit'),
                ]
            );

            $repeater = new Repeater();
            $repeater->add_control(
                'social_link', [
                    'label'       => esc_html__('Social Link', 'guto-toolkit'),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => '#',
                    'label_block' => true,
                ]
            );
            $repeater->add_control(
                'social_text', [
                    'label'       => esc_html__('Social Text', 'guto-toolkit'),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => esc_html__('Facebook', 'guto-toolkit'),
                    'label_block' => true,
                ]
            );
            $repeater->add_control(
                'social_status_num', [
                    'label'       => esc_html__('Social Status Number', 'guto-toolkit'),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => '21,655',
                    'label_block' => true,
                ]
            );
            $repeater->add_control(
                'social_status_text', [
                    'label'       => esc_html__('Social Status Text', 'guto-toolkit'),
                    'type'        => Controls_Manager::TEXT,
                    'default'     => esc_html__('Followers', 'guto-toolkit'),
                    'label_block' => true,
                ]
            );
            $repeater->add_control(
                'choose_card_color',
                [
                    'label' => esc_html__( 'Card Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'label_block' => true,
                    'options' => [
                        'fb'  => esc_html__( 'Facebook', 'guto-toolkit' ),
                        'tw'  => esc_html__( 'Twitter', 'guto-toolkit' ),
                        'ld'  => esc_html__( 'LinkedIn', 'guto-toolkit' ),
                        'yt'  => esc_html__( 'YouTube', 'guto-toolkit' ),
                        'ig'  => esc_html__( 'Instagram', 'guto-toolkit' ),
                        'rss' => esc_html__( 'RSS', 'guto-toolkit' ),
                    ], 
                    'default' => '1'
                ]
            );
            $this->add_control(
                'guto_social_items',
                [
                    'label'  => esc_html__('Add Social Item', 'guto-toolkit'),
                    'type'   => Controls_Manager::REPEATER,
                    'fields' => $repeater->get_controls(),
                ]
            );

        $this->end_controls_section();

        $this->start_controls_section(
			'section_style',
			[
				'label' => esc_html__( 'Style', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
        );
            $this->add_control(
                'card_bgcolor',
                [
                    'label'     => esc_html__( 'Card Background Color', 'guto-toolkit' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .social-card' => 'background-color: {{VALUE}} !important',
                    ],
                ]
            );
            $this->add_control(
                'title_color',
                [
                    'label'     => esc_html__( 'Title Color', 'guto-toolkit' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .nm-section-title h2' => 'color: {{VALUE}}',
                    ],
                ]
            );
            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name'     => 'title_typography',
                    'label'    => esc_html__( 'Title Typography', 'guto-toolkit' ),
                    'scheme'   => Scheme_Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .nm-section-title h2',
                ]
            );

            $this->add_control(
                'social_title_color',
                [
                    'label'     => esc_html__( 'Social Title Color', 'guto-toolkit' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .social-card h3' => 'color: {{VALUE}}',
                    ],
                ]
            );
            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name'     => 'social_title_typography',
                    'label'    => esc_html__( 'Social Title Typography', 'guto-toolkit' ),
                    'scheme'   => Scheme_Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .social-card h3',
                ]
            );
            $this->add_control(
                'social_status_color',
                [
                    'label'     => esc_html__( 'Status Color', 'guto-toolkit' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .social-card span' => 'color: {{VALUE}}',
                    ],
                ]
            );
            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name'     => 'social_status_typography',
                    'label'    => esc_html__( 'Status Typography', 'guto-toolkit' ),
                    'scheme'   => Scheme_Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .social-card span',
                ]
            );

        $this->end_controls_section();
    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        $slider = $settings['guto_social_items'];
        ?>

            <?php if( !empty( $settings['section_title'] ) ): ?>
                <div class="nm-section-title">
                    <h2><?php echo esc_html( $settings['section_title'] ); ?></h2>
                </div>
            <?php endif; ?>

            <div class="row">
                <?php foreach ($slider as $key => $value) :
                    if( $value['choose_card_color'] == 'fb' ) :
                        $card_color = ' bg-1777f0';
                    elseif($value['choose_card_color'] == 'tw') :
                        $card_color = ' bg-1da0f2';
                    elseif($value['choose_card_color'] == 'ld') :
                        $card_color = ' bg-2767af';
                    elseif($value['choose_card_color'] == 'yt') :
                        $card_color = ' bg-fe0000';
                    elseif($value['choose_card_color'] == 'ig') :
                        $card_color = ' bg-e92452';
                    else:
                        $card_color = ' bg-f78422';
                    endif;
                ?>
                    <div class="col-lg-6 col-sm-6">
                        <a href="<?php echo esc_url( $value['social_link'] ); ?>" class="social-card <?php echo esc_attr( $card_color ); ?>">
                            <h3><?php echo esc_html( $value['social_text'] ); ?></h3>
                            <span><?php echo esc_html( $value['social_status_num'] ); ?></span>
                            <span><?php echo esc_html( $value['social_status_text'] ); ?></span>
                        </a>
                    </div>
                <?php endforeach; ?>
            </div>
        <?php
	}

	protected function _content_template() {}

}

Plugin::instance()->widgets_manager->register( new Guto_NM_StayConnected_Area );