<?php
/**
 * NM Video Area Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_NM_Video_Area extends Widget_Base {

	public function get_name() {
        return 'News_Video_Area';
    }

	public function get_title() {
        return esc_html__( 'NM Video Posts', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-video-playlist';
    }

	public function get_categories() {
        return [ 'guto-elements' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'Guto_Video_Area',
			[
				'label' => esc_html__( 'Guto Video', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );
            $this->add_control(
                'section_title',
                [
                    'label' => esc_html__( 'Section Title', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__('Videos', 'guto-toolkit'),
                ]
            );

            $this->add_control(
                'show', [
                    'label'       => __( 'Show post count', 'guto-toolkit' ),
                    'type'        => Controls_Manager::NUMBER,
                    'label_block' => true,
                    'default'     => 5,
                    'description'  => __( 'Show post count will work for right side post. In left show 1 post', 'guto-toolkit' ),
                ]
            );

            $this->add_control(
                'order', [
                    'label'     => __( 'Order', 'guto-toolkit' ),
                    'type'      => Controls_Manager::SELECT,
                    'options'   => [
                        'ASC'  => 'ASC',
                        'DESC' => 'DESC'
                    ],
                    'default' => 'ASC'
                ]
            );

            $this->add_control(
                'cat', [
                    'label'        => __( 'Category', 'guto-toolkit' ),
                    'description'  => __( 'Enter the category slugs separated by commas (Eg. cat1, cat2)', 'guto-toolkit' ),
                    'type'         => Controls_Manager::TEXT,
                    'label_block'  => true,
                ]
            );

            $this->add_control(
                'show_meta',
                [
                    'label'        => __( 'Post Meta Hide/Show?', 'guto-toolkit' ),
                    'type'         => Controls_Manager::SWITCHER,
                    'label_on'     => __( 'Show', 'guto-toolkit' ),
                    'label_off'    => __( 'Hide', 'guto-toolkit' ),
                    'return_value' => 'yes',
                    'default'      => 'yes',
                ]
            );

            $this->add_control(
                'read_text',
                [
                    'label' => esc_html__( 'Post Reading Time Text', 'guto-toolkit' ),
                    'type'  => Controls_Manager::TEXT,
                ]
            );

        $this->end_controls_section();

        $this->start_controls_section(
			'section_style',
			[
				'label' => esc_html__( 'Style', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
        );
            $this->add_control(
                'cat_color', [
                    'label'     => __( 'Category Color', 'guto-toolkit' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .nm-single-blog-post-style-one .nm-single-blog-post-content span' => 'color: {{VALUE}};',
                    ],
                ]
            );
            $this->add_group_control(
                Group_Control_Typography::get_type(), [
                    'label'    => __( 'Category Typography', 'guto-toolkit' ),
                    'name'     => 'typography_cat',
                    'scheme'   => Scheme_Typography::TYPOGRAPHY_1,
                    'selector' => '
                    {{WRAPPER}} .nm-single-blog-post-style-one .nm-single-blog-post-content span',
                ]
            );
            $this->add_control(
                'title_color', [
                    'label'     => __( 'Title Color', 'guto-toolkit' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .nm-single-blog-post-style-one .nm-single-blog-post-content h3 a, .nm-widget-area .widget_guto_posts_thumb .item .info .title a' => 'color: {{VALUE}};',
                    ],
                ]
            );
            $this->add_group_control(
                Group_Control_Typography::get_type(), [
                    'label'    => __( 'Title Typography', 'guto-toolkit' ),
                    'name'     => 'typography_title',
                    'scheme'   => Scheme_Typography::TYPOGRAPHY_1,
                    'selector' => '
                    {{WRAPPER}} .nm-single-blog-post-style-one .nm-single-blog-post-content h3 a, .nm-widget-area .widget_guto_posts_thumb .item .info .title a',
                ]
            );
            $this->add_group_control(
                Group_Control_Typography::get_type(), [
                    'label'    => __( 'Small Title Typography', 'guto-toolkit' ),
                    'name'     => 'typography_small_title',
                    'scheme'   => Scheme_Typography::TYPOGRAPHY_1,
                    'selector' => '
                    {{WRAPPER}} .nm-widget-area .widget_guto_posts_thumb .item .info .title a',
                ]
            );
            $this->add_control(
                'meta_color', [
                    'label'     => __( 'Meta Color', 'guto-toolkit' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .nm-single-blog-post-style-one .nm-single-blog-post-content ul li, .nm-single-blog-post-style-one .nm-single-blog-post-content ul li a, .nm-widget-area .widget_guto_posts_thumb .item .info .meta li' => 'color: {{VALUE}};',
                    ],
                ]
            );
            $this->add_group_control(
                Group_Control_Typography::get_type(), [
                    'label'    => __( 'Meta Typography', 'guto-toolkit' ),
                    'name'     => 'typography_meta',
                    'scheme'   => Scheme_Typography::TYPOGRAPHY_1,
                    'selector' => '
                    {{WRAPPER}} .nm-single-blog-post-style-one .nm-single-blog-post-content ul li, .nm-single-blog-post-style-one .nm-single-blog-post-content ul li a, .nm-widget-area .widget_guto_posts_thumb .item .info .meta li',
                ]
            );
        $this->end_controls_section();
    }

	protected function render() {

        $settings = $this->get_settings_for_display();
        $post_show = $settings['show'];

        // Left Post Arg
        if ( !empty($settings['cat']) ) {
            $post_array = new \WP_Query(array(
                'post_type'         => 'post',
                'posts_per_page'    => 1,
                'order'             => $settings['order'],
                'meta_key'          => '_thumbnail_id',
                'tax_query'         => array(
                    array(
                        'taxonomy' => 'category',
                        'field'    => 'slug',
                        'terms'    => explode( ',', str_replace( ' ', '', $settings['cat'])),
                    ),
                ),
            ));
        } else {
            $post_array = new \WP_Query(array(
                'post_type'        => 'post',
                'posts_per_page'   => 1,
                'order'            => $settings['order'],
                'meta_key'         => '_thumbnail_id',
            ));
        } ?>

        <div class="nm-top-video-area pb-80">
            <div class="container">
                <?php if( !empty( $settings['section_title'] ) ): ?>
                    <div class="nm-section-title">
                        <h2><?php echo esc_html( $settings['section_title'] ); ?></h2>
                    </div>
                <?php endif; ?>

                <div class="row">
                    <?php $not_in = array();
                        while($post_array->have_posts()): $post_array->the_post();
                        $categories = get_the_category();

                        $video_link  = fw_get_db_post_option( get_the_ID(), 'post_video_link' );
                    ?>
                        <div class="col-lg-8">
                            <div class="nm-single-blog-post-style-one bg-6" style="background-image:url(<?php echo esc_url( get_the_post_thumbnail_url() ); ?>);">
                                <div class="nm-single-blog-post-content">
                                    <?php if( !empty($video_link) ) : ?>
                                    <div class="nm-video-button">
                                        <a href="<?php echo esc_url( $video_link ); ?>" class="nm-video-btn popup-youtube">
                                            <i class='bx bx-play'></i>
                                        </a>
                                    </div>
                                    <?php endif; ?>

                                    <?php if ( ! empty( $categories ) ) { ?>
                                        <a href="<?php echo esc_url( get_category_link( $categories[0]->term_id ) ) ?>"><span><?php echo esc_html( $categories[0]->name ) ?></span></a>
                                    <?php } ?>

                                    <h3><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>

                                    <?php if ( $settings['show_meta'] == 'yes' ) : ?>
                                        <ul>
                                            <li>
                                                <a href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ), get_the_author_meta( 'user_nicename' ) ) ) ?>">
                                                    <?php the_author() ?>
                                                </a>
                                            </li>
                                            <li> <?php echo esc_html(get_the_date('M d, Y')) ?> </li>
                                        </ul>
                                    <?php endif; ?>
                                </div>
                            </div>
                        </div>
                    <?php 
                        $not_in[] = get_the_ID();
                        $not_in;
                        endwhile; 
                        wp_reset_postdata(); 
                    ?>

                    <div class="col-lg-4">
                        <div class="nm-widget-area pl-0">
                            <div class="widget widget_guto_posts_thumb">
                                <!-- Second Arg -->
                                <?php if ( !empty($settings['cat']) ) {
                                    $post_array2 = new \WP_Query(array(
                                        'post_type'         => 'post',
                                        'posts_per_page'    => !empty($post_show) ? $post_show : 5,
                                        'order'             => $settings['order'],
                                        'meta_key'          => '_thumbnail_id',
                                        'post__not_in'      => $not_in,
                                        'tax_query'         => array(
                                            array(
                                                'taxonomy' => 'category',
                                                'field'    => 'slug',
                                                'terms'    => explode( ',', str_replace( ' ', '', $settings['cat'])),
                                            ),
                                        ),
                                    ));

                                } else {
                                    $post_array2 = new \WP_Query(array(
                                        'post_type'         => 'post',
                                        'posts_per_page'    => !empty($post_show) ? $post_show : 5,
                                        'order'             => $settings['order'],
                                        'meta_key'          => '_thumbnail_id',
                                        'post__not_in'      => $not_in,
                                    ));
                                }

                                while($post_array2->have_posts()): $post_array2->the_post();
                                $categories = get_the_category();
                                $video_link  = fw_get_db_post_option( get_the_ID(), 'post_video_link' );
                                ?>

                                <article class="item">
                                    <a href="<?php echo esc_url( $video_link ); ?>" class="thumb popup-youtube">
                                        <span class="fullimage cover bg1" role="img" style="background-image:url(<?php echo esc_url( get_the_post_thumbnail_url() ); ?>);"></span>
                                        <i class='bx bx-play'></i>
                                    </a>

                                    <div class="info">
                                        <h4 class="title usmall">
                                            <a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
                                        </h4>

                                        <?php if ( $settings['show_meta'] == 'yes' ) : ?>
                                            <ul class="meta">
                                                <li>
                                                    <i class='bx bx-calendar'></i> 
                                                    <?php echo esc_html(get_the_date('M d, Y')) ?>
                                                </li>
                                                <li>
                                                    <i class='bx bx-time'></i> 
                                                    <?php echo esc_html(guto_lite_reading_time()) ?> 
                                                    <?php echo esc_html($settings['read_text']); ?>
                                                </li>
                                            </ul>
                                        <?php endif; ?>
                                    </div>
                                </article>

                                <?php $not_in[] = get_the_ID();
                                    $not_in;
                                    endwhile; 
                                    wp_reset_postdata(); 
                                ?>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>

        <?php
	}

	protected function _content_template() {}

}

Plugin::instance()->widgets_manager->register( new Guto_NM_Video_Area );