<?php

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

class Footer extends Widget_Base {

    public function get_name() {
        return 'guto_footer';
    }

    public function get_title() {
        return __( 'Website Footer', 'guto-toolkit' );
    }

    public function get_icon() {
        return 'eicon-call-to-action';
    }

    public function get_categories() {
        return [ 'guto-elements', 'guto-online-education' ];
    }

    protected function _register_controls() {

        $this->start_controls_section(
			'Guto_Footer',
			[
				'label' => esc_html__( 'Footer Content', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

        $this->add_control(
            'title_note', [
                'label' => '',
                'type' => Controls_Manager::RAW_HTML,
                'raw' => __( 'Set the widgets from Appearance > Widgets', 'guto-toolkit' ),
                'content_classes' => 'elementor-warning',
            ]
        );

        $this->add_control(
            'main_logo',
            [
                'label' => __( 'Main Logo', 'guto-toolkit' ),
                'type' => Controls_Manager::MEDIA,
            ]
        );

        $this->add_control(
            'logomax_width',
            [
                'label' => __( 'Max Width', 'guto-toolkit' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%', 'rem' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 500,
                        'step' => 1,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .single-footer-widget .logo img' => 'max-width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'desc',
            [
                'label' => esc_html__( 'Footer Description', 'guto-toolkit' ),
                'type' => Controls_Manager::TEXTAREA,
                'default' => esc_html__('Quis ipsum suspendisse ultrices gravida. Risus commodo viverra maecenas accumsan.', 'guto-toolkit'),
            ]
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'icon',
            [
                'label' => esc_html__( 'Icon', 'guto-toolkit' ),
                'type' => Controls_Manager::ICON,
                'options' => guto_toolkit_icons(),
            ]
        );
        $repeater->add_control(
            'link',
            [
                'label' => esc_html__( 'Link', 'guto-toolkit' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' => "#",
            ]
        );

        $this->add_control(
            'social_icons',
            [
                'label' => esc_html__('Social Icons', 'guto-toolkit'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
            ]
        );

        $this->add_control(
            'widget_par',
            [
                'label' => esc_html__( 'Footer Widget Per Row', 'guto-toolkit' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    '12'         => esc_html__( '1', 'guto-toolkit' ),
                    '6'         => esc_html__( '2', 'guto-toolkit' ),
                    '4'         => esc_html__( '3', 'guto-toolkit' ),
                    '3'         => esc_html__( '4', 'guto-toolkit' ),
                ],
                'default' => '3',
            ]
        );

        $this->add_control(
            'widget_md_par',
            [
                'label' => esc_html__( 'Footer Widget Per Row Tab Device', 'guto-toolkit' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    '12'        => esc_html__( '1', 'guto-toolkit' ),
                    '6'         => esc_html__( '2', 'guto-toolkit' ),
                    '4'         => esc_html__( '3', 'guto-toolkit' ),
                    '3'         => esc_html__( '4', 'guto-toolkit' ),
                ],
                'default' => '6',
            ]
        );

        $this->add_control(
            'copyright_text',
            [
                'label' => esc_html__( 'Copyright Text', 'guto-toolkit' ),
                'type' => Controls_Manager::TEXTAREA,
                'default' => esc_html__('<p>Copyright @2021 <strong>Guto</strong> is Proudly Powered by <a href="https://gutotheme.com/" target="_blank">GutoTheme</a></p>', 'guto-toolkit'),
            ]
        );

        $this->add_control(
            'copyright_bg_color',
            [
                'label' => esc_html__( 'Copyright Area Background Color', 'guto-toolkit' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .os-footer-area, .footer-bottom-area, .footer-bottom-area.bottom-footer-light, .restaurant-copy-right-area, .nm-copy-right-area, .dm-copyright-area, .insurance-footer-bottom-area, .oet-footer-bottom-area' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'copyright_text_color',
            [
                'label' => esc_html__( 'Copyright Text Color', 'guto-toolkit' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .oet-footer-bottom-area p' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'copyright_text_typo',
                'label' => esc_html__( 'Copyright Text Typography', 'guto-toolkit' ),
                'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                'selector' => '{{WRAPPER}} .oet-footer-bottom-area p',
            ]
        );

        $this->add_control(
            'copyright_text_link_color',
            [
                'label' => esc_html__( 'Copyright Text Link Color', 'guto-toolkit' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .oet-footer-bottom-area p a' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'bg_color',
            [
                'label' => esc_html__( 'Background Color', 'guto-toolkit' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .oet-footer-area' => 'background-color: {{VALUE}}',
                ],
            ]
        );

        $this->add_control(
            'sec_padding', [
                'label' => __( 'Section Padding', 'guto-toolkit' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .oet-footer-area' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'default' => [
                    'unit' => 'px', // The selected CSS Unit. 'px', '%', 'em',

                ],
            ]
        );

        $this->add_control(
            'widget_title_color',
            [
                'label' => esc_html__( 'Widget Title Color', 'guto-toolkit' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .footer-area .single-footer-widget h3, .footer-area.footer-light .single-footer-widget h3, .restaurant-footer-area .single-footer-widget h3, .nm-footer-area .single-footer-widget h3, .dm-footer-area .single-footer-widget h3, insurance-footer-area .single-footer-widget h3, .insurance-footer-area .single-footer-widget h3, .oet-footer-area .single-footer-widget h3' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'widget_title_typo',
                'label' => esc_html__( 'Widget Title Typography', 'guto-toolkit' ),
                'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                'selector' => '{{WRAPPER}} .footer-area .single-footer-widget h3, .footer-area.footer-light .single-footer-widget h3, .restaurant-footer-area .single-footer-widget h3, .nm-footer-area .single-footer-widget h3, .dm-footer-area .single-footer-widget h3, insurance-footer-area .single-footer-widget h3, .insurance-footer-area .single-footer-widget h3, .oet-footer-area .single-footer-widget h3',
            ]
        );

        $this->add_control(
            'text_color',
            [
                'label' => esc_html__( 'Footer Text Color', 'guto-toolkit' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .footer-area  .single-footer-widget ul li, .footer-area  .single-footer-widget ul li a, .footer-area  .single-footer-widget ul li p, .single-footer-widget p, .footer-area  .single-footer-widget .footer-contact-info li, .footer-area.footer-light .single-footer-widget p, .footer-area.footer-light .single-footer-widget ul li a, .footer-area.footer-light .single-footer-widget ul li a, .restaurant-footer-area .single-footer-widget ul li a, .restaurant-footer-area .single-footer-widget ul li, .restaurant-footer-area .single-footer-widget .restaurant-address li a, .nm-footer-area .single-footer-widget ul li, .nm-footer-area .single-footer-widget ul li a, .dm-footer-area .single-footer-widget .footer-contact-info li a, .dm-footer-area .single-footer-widget .footer-contact-info li span, .dm-footer-area .single-footer-widget ul li a, .dm-footer-area .single-footer-widget p, insurance-footer-area .single-footer-widget ul li a, .insurance-footer-area .single-footer-widget .menu li a, .insurance-footer-area .single-footer-widget .footer-contact-info li a' => 'color: {{VALUE}}',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'widget_text_typo',
                'label' => esc_html__( 'Footer Text  Typography', 'guto-toolkit' ),
                'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                'selector' => '{{WRAPPER}} .footer-area  .single-footer-widget ul li, .footer-area  .single-footer-widget ul li a, .footer-area  .single-footer-widget ul li p, .single-footer-widget p, .footer-area  .single-footer-widget .footer-contact-info li, .footer-area.footer-light .single-footer-widget p, .footer-area.footer-light .single-footer-widget ul li a, .footer-area.footer-light .single-footer-widget ul li a, .restaurant-footer-area .single-footer-widget ul li a, .restaurant-footer-area .single-footer-widget ul li, .restaurant-footer-area .single-footer-widget .restaurant-address li a, .nm-footer-area .single-footer-widget ul li, .nm-footer-area .single-footer-widget ul li a, .dm-footer-area .single-footer-widget .footer-contact-info li a, .dm-footer-area .single-footer-widget .footer-contact-info li span, .dm-footer-area .single-footer-widget ul li a, .dm-footer-area .single-footer-widget p, insurance-footer-area .single-footer-widget ul li a, .insurance-footer-area .single-footer-widget .menu li a, .insurance-footer-area .single-footer-widget .footer-contact-info li a',
            ]
        );
        $this->end_controls_section();

    }

    protected function render()
    {
        $settings = $this->get_settings();
        $default_logo = guto_lite_option('site_logo');
        if ($default_logo != ''):
            $logo = guto_lite_option('site_logo');
        else:
            $logo           = !empty($settings['main_logo']['url']) ? $settings['main_logo']['url'] : '';
        endif;
        ?>
        <footer class="oet-footer-area">
            <?php if (is_active_sidebar('footer-widget-1') || is_active_sidebar('footer-widget-2') || is_active_sidebar('footer-widget-3') || is_active_sidebar('footer-widget-4')): ?>
                <div class="container">
                    <div class="row justify-content-center">
                        <?php
                        if ($settings['widget_par'] == 12) {
                            $footer_column = 1;
                        } elseif ($settings['widget_par'] == 6) {
                            $footer_column = 2;
                        } elseif ($settings['widget_par'] == 4) {
                            $footer_column = 3;
                        } elseif ($settings['widget_par'] == 3) {
                            $footer_column = 4;
                        }

                        if ($settings['widget_md_par'] == 12) {
                            $footer_md_column = 1;
                        } elseif ($settings['widget_md_par'] == 6) {
                            $footer_md_column = 2;
                        } elseif ($settings['widget_md_par'] == 4) {
                            $footer_md_column = 3;
                        } elseif ($settings['widget_md_par'] == 3) {
                            $footer_md_column = 4;
                        }
                        ?>
                        <?php if( $settings['main_logo']['url'] != '' || $settings['desc'] != '' ): ?>
                            <div class="col-lg-<?php echo esc_attr($settings['widget_par']); ?> col-md-<?php echo esc_attr($settings['widget_md_par']); ?>">
                                <div class="oet-single-footer-widget">
                                    <a href="<?php echo esc_url( home_url( '/' ) ); ?>" class="logo">
                                        <?php if( $logo != '' ): ?>
                                            <img src="<?php echo esc_url( $logo ); ?>" alt="<?php bloginfo( 'name' ); ?>">
                                        <?php else: ?>
                                            <h2><?php bloginfo( 'name' ); ?></h2>
                                        <?php endif; ?>
                                    </a>
                                    <?php echo wp_kses_post( $settings['desc'] ); ?>

                                    <ul class="social-links">
                                        <?php foreach( $settings['social_icons'] as $item ): ?>
                                            <li><a href="<?php echo esc_url($item['link']); ?>" target="_blank"><i class='<?php echo esc_attr($item['icon']); ?>'></i></a></li>
                                        <?php endforeach; ?>
                                    </ul>
                                </div>
                            </div>
                        <?php endif; ?>

                        <?php
                        for ($i = 2; $i <= $footer_column; $i++): ?>
                            <div class="col-lg-<?php echo esc_attr($settings['widget_par']); ?>  col-md-<?php echo esc_attr($settings['widget_md_par']); ?>">
                                <?php
                                if (is_active_sidebar('footer-widget-' . esc_html($i))):
                                    dynamic_sidebar('footer-widget-' . esc_html($i));
                                endif;
                                ?>
                            </div>
                        <?php endfor; ?>
                    </div>
                </div>
    	    <?php endif; ?>

            <div class="oet-footer-bottom-area">
                <div class="container">
                    <?php if($settings['copyright_text'] ): ?>
                        <p><?php echo wp_kses_post( $settings['copyright_text'] ); ?></p>
                    <?php endif; ?>
                </div>
            </div>
        </footer>
        <?php
    }
}


Plugin::instance()->widgets_manager->register( new Footer );