<?php
/**
 * OE About Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_OE_About_Area extends Widget_Base {

	public function get_name() {
        return 'Guto_OE_About';
    }

	public function get_title() {
        return esc_html__( 'OE About', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-info-box';
    }

	public function get_categories() {
        return [ 'guto-online-education' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'Guto_OE_About_Area',
			[
				'label' => esc_html__( 'About Controls', 'guto-toolkit' ),
				'tab' 	=> Controls_Manager::TAB_CONTENT,
			]
		);
            $this->add_control(
                'about_us_style',
                    [
                        'label' => esc_html__( 'About Style', 'guto-toolkit' ),
                        'type' => Controls_Manager::SELECT,
                        'options' => [
                            '1'         => esc_html__( 'Style One', 'guto-toolkit' ),
                            '2'         => esc_html__( 'Style Two', 'guto-toolkit' ),
                        ],
                        'default' => '1',
                    ]
            );

            $this->add_control(
                'top_title',
                [
                    'label' 	=> esc_html__( 'Top Title', 'guto-toolkit' ),
                    'type' 		=> Controls_Manager::TEXTAREA,
                    'default' 	=> esc_html__('ABOUT US', 'guto-toolkit'),
                ]
            );
			$this->add_control(
				'title',
				[
					'label' 	=> esc_html__( 'Title', 'guto-toolkit' ),
					'type' 		=> Controls_Manager::TEXTAREA,
					'default' 	=> esc_html__('Access To 9500+ Courses from 750 Instructors & Institutions', 'guto-toolkit'),
				]
			);

			$this->add_control(
                'title_tag',
                [
                    'label' 	=> esc_html__( 'Title Tag', 'guto-toolkit' ),
                    'type' 		=> Controls_Manager::SELECT,
                    'options' 	=> [
                        'h1'         => esc_html__( 'h1', 'guto-toolkit' ),
                        'h2'         => esc_html__( 'h2', 'guto-toolkit' ),
                        'h3'         => esc_html__( 'h3', 'guto-toolkit' ),
                        'h4'         => esc_html__( 'h4', 'guto-toolkit' ),
                        'h5'         => esc_html__( 'h5', 'guto-toolkit' ),
                        'h6'         => esc_html__( 'h6', 'guto-toolkit' ),
                    ],
                    'default' => 'h2',
                ]
            );

			$this->add_control(
				'content',
				[
					'label' 	=> esc_html__( 'Content', 'guto-toolkit' ),
					'type' 		=> Controls_Manager::TEXTAREA,
					'default' 	=> esc_html__('Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Quis ipsum suspendisse.', 'guto-toolkit'),
				]
            );

			$this->add_control(
				'search_post',
				[
					'label' 	=> esc_html__( 'Search Post Name', 'guto-toolkit' ),
					'type' 		=> Controls_Manager::TEXT,
					'default' 	=> esc_html__('lp_course', 'guto-toolkit'),
                    'condition' => [
                        'about_us_style' => '1',
                    ]
				]
            );
			$this->add_control(
				'search_place',
				[
					'label' 	=> esc_html__( 'Search Placeholder Text', 'guto-toolkit' ),
					'type' 		=> Controls_Manager::TEXT,
					'default' 	=> esc_html__('Search what you need', 'guto-toolkit'),
                    'condition' => [
                        'about_us_style' => '1',
                    ]
				]
            );

            $this->add_control(
                'button_text',
                [
                    'label' 	=> esc_html__( 'Button Text', 'guto-toolkit' ),
                    'type' 		=> Controls_Manager::TEXT,
                    'default' 	=> __('View All Courses', 'guto-toolkit'),
                    'condition' => [
                        'about_us_style' => '2',
                    ]
                ]
            );

            $this->add_control(
                'button_icon',
                [
                    'label' => esc_html__( 'Button Icon', 'guto-toolkit' ),
                    'type' => Controls_Manager::ICON,
                    'label_block' => true,
                    'options' => guto_toolkit_icons(),
                    'condition' => [
                        'about_us_style' => '2',
                    ]
                ]
            );

            $this->add_control(
                'btn_link_type',
                [
                    'label' 		=> esc_html__( 'Button Link Type', 'guto-toolkit' ),
                    'type' 			=> Controls_Manager::SELECT,
                    'label_block' 	=> true,
                    'options' => [
                        '1'  	=> esc_html__( 'Link To Page', 'guto-toolkit' ),
                        '2' 	=> esc_html__( 'External Link', 'guto-toolkit' ),
                    ],
                    'condition' => [
                        'about_us_style' => '2',
                    ]
                ]
            );

            $this->add_control(
                'btn_link_to_page',
                [
                    'label' 		=> esc_html__( 'Button Link Page', 'guto-toolkit' ),
                    'type' 			=> Controls_Manager::SELECT,
                    'label_block' 	=> true,
                    'options' 		=> guto_toolkit_get_page_as_list(),
                    'condition' => [
                        'btn_link_type' => '1',
                        'about_us_style' => '2',
                    ]
                ]
            );

            $this->add_control(
                'btn_ex_link',
                [
                    'label'		=> esc_html__('Button External Link', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: TEXT,
                    'condition' => [
                        'btn_link_type' => '2',
                        'about_us_style' => '2',
                    ]
                ]
            );

        $this->end_controls_section();

        // Images
        $this->start_controls_section(
			'about_images',
			[
				'label' => esc_html__( 'Images', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

            $this->add_control(
                'image',
                [
                    'label'		=> esc_html__('Image', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: MEDIA,
                ]
            );
            $this->add_control(
                'shape1',
                [
                    'label'		=> esc_html__('Shape Image 1', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: MEDIA,
                ]
            );
            $this->add_control(
                'shape2',
                [
                    'label'		=> esc_html__('Shape Image 2', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: MEDIA,
                ]
            );

        $this->end_controls_section();

        $this->start_controls_section(
			'about_sec_style',
			[
				'label' => esc_html__( 'Style', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
            $this->add_control(
                'bg_color',
                [
                    'label' => esc_html__( 'Background Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} ..oet-about-area.ptb-100.bg-FEF7F2' => 'background-color: {{VALUE}}',
                    ],
                ]
            );
            $this->add_control(
                'top_title_color',
                [
                    'label' => esc_html__( 'Top Title Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .oet-about-content .sub-title' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'top_title_typography',
                    'label' => esc_html__( 'Top Title Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .oet-about-content .sub-title',
                ]
            );
			$this->add_control(
				'title_color',
				[
					'label' => esc_html__( 'Title Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .oet-about-content h3, .oet-about-content h1, .oet-about-content h2, .oet-about-content h4, .oet-about-content h5, .oet-about-content h6' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'title_typography',
                    'label' => esc_html__( 'Title Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .oet-about-content h3, .oet-about-content h1, .oet-about-content h2, .oet-about-content h4, .oet-about-content h5, .oet-about-content h6',
                ]
            );

			$this->add_control(
				'content_color',
				[
					'label' => esc_html__( 'Content Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .oet-about-content p' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'content_typography',
                    'label' => esc_html__( 'Content Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .oet-about-content p',
                ]
            );
        $this->end_controls_section();

    }

	protected function render() {

		$settings = $this->get_settings_for_display();

        ?>

        <div class="oet-about-area ptb-100 bg-FEF7F2">
            <div class="container">
                <div class="row align-items-center">
                    <div class="col-lg-6 col-md-12">
                        <div class="oet-about-image">
                            <?php if( $settings['image']['url'] != '' ) : ?>
                                <img src="<?php echo esc_url($settings['image']['url']); ?>" alt="<?php echo esc_attr( $settings['title'] ); ?>">
                            <?php endif; ?>

                            <?php if( $settings['shape1']['url'] != '' ) : ?>
                                <img class="oet-shape2" src="<?php echo esc_url($settings['shape1']['url']); ?>" alt="<?php echo esc_attr( $settings['title'] ); ?>">
                            <?php endif; ?>
                        </div>
                    </div>
                    <div class="col-lg-6 col-md-12">
                        <div class="oet-about-content">
                            <span class="sub-title"><?php echo esc_html( $settings['top_title'] ); ?></span>
                            <<?php echo esc_attr( $settings['title_tag'] ); ?>>
                                <?php echo esc_html( $settings['title'] ); ?>
                            </<?php echo esc_attr( $settings['title_tag'] ); ?>>

                            <p><?php echo wp_kses_post( $settings['content'] ); ?></p>


                            <?php if($settings['about_us_style'] == '1'): ?>
                                <?php if($settings['search_place'] != ''): ?>
                                    <form class="search-box" method="get" action="<?php echo site_url( '/' ); ?>">
                                        <input type="text" value="" name="search" class="input-search" placeholder="<?php echo esc_attr( $settings['search_place'] ); ?>">
                                        <input type="hidden" value="course" name="ref" />
                                        <input type="hidden" name="post_type" value="<?php echo esc_attr($settings['search_post']); ?>">
                                        <button type="submit"><i class='bx bx-search-alt'></i></button>
                                    </form>
                                <?php endif; ?>
                            <?php elseif($settings['about_us_style'] == '2'):
                                // Get Button Link
                                if($settings['btn_link_type'] == 1){
                                    $link = get_page_link( $settings['btn_link_to_page'] );
                                } else {
                                    $link = $settings['btn_ex_link'];
                                }
                                ?>
                                <?php if( $settings['button_text'] != '' ): ?>
                                    <a href="<?php echo esc_url( $link ); ?>" class="oet-default-btn"><i class='<?php echo esc_attr( $settings['button_icon'] ); ?>'></i> <?php echo esc_html( $settings['button_text'] ); ?></a>
                                <?php endif; ?>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
            </div>

            <?php if( $settings['shape2']['url'] != '' ) : ?>
                <div class="oet-shape3"><img src="<?php echo esc_url($settings['shape2']['url']); ?>" alt="<?php echo esc_attr__('Shape Two','guto-toolkit'); ?>"></div>
            <?php endif; ?>
        </div>

        <?php
	}

	protected function _content_template() {}

}

Plugin::instance()->widgets_manager->register( new Guto_OE_About_Area );