<?php
/**
 * Banner Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class OE_Banner extends Widget_Base {

	public function get_name() {
        return 'OE_Banner_One';
    }

	public function get_title() {
        return esc_html__( 'Online Education Banner', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-banner';
    }

	public function get_categories() {
        return [ 'guto-online-education' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'OE_Banner_Area',
			[
				'label' => esc_html__( 'Banner Controls', 'guto-toolkit' ),
				'tab' 	=> Controls_Manager::TAB_CONTENT,
			]
        );

			$this->add_control(
				'bg_image',
				[
					'label' => esc_html__( 'Section Background Image', 'guto-toolkit' ),
					'type'	 => Controls_Manager::MEDIA,
				]
			);

			$this->add_control(
				'image',
				[
					'label' => esc_html__( 'Section Image', 'guto-toolkit' ),
					'type'	 => Controls_Manager::MEDIA,
				]
			);

			$this->add_control(
				'title',
				[
					'label' 	=> esc_html__( 'Title', 'guto-toolkit' ),
					'type' 		=> Controls_Manager::TEXT,
					'default' 	=> __('The world’s leading distance-learning provider', 'guto-toolkit'),
				]
			);

			$this->add_control(
                'title_tag',
                [
                    'label' 	=> esc_html__( 'Title Tag', 'guto-toolkit' ),
                    'type' 		=> Controls_Manager::SELECT,
                    'options' 	=> [
                        'h1'         => esc_html__( 'h1', 'guto-toolkit' ),
                        'h2'         => esc_html__( 'h2', 'guto-toolkit' ),
                        'h3'         => esc_html__( 'h3', 'guto-toolkit' ),
                        'h4'         => esc_html__( 'h4', 'guto-toolkit' ),
                        'h5'         => esc_html__( 'h5', 'guto-toolkit' ),
                        'h6'         => esc_html__( 'h6', 'guto-toolkit' ),
                    ],
                    'default' => 'h1',
                ]
            );

			$this->add_control(
				'content',
				[
					'label' 	=> esc_html__( 'Content', 'guto-toolkit' ),
					'type' 		=> Controls_Manager::TEXTAREA,
					'default' 	=> __('Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua quis ipsum suspendisse.', 'guto-toolkit'),
				]
			);

			$this->add_control(
				'button_text',
				[
					'label' 	=> esc_html__( 'Button Text', 'guto-toolkit' ),
					'type' 		=> Controls_Manager::TEXT,
					'default' 	=> __('Join For Free', 'guto-toolkit'),
				]
            );

            $this->add_control(
				'user_button_text',
				[
					'label' 	=> esc_html__( 'User Logged in Button Text', 'guto-toolkit' ),
					'type' 		=> Controls_Manager::TEXT,
					'default' 	=> __('Profile', 'guto-toolkit'),
				]
			);

            $this->add_control(
				'button_icon',
				[
					'label' => esc_html__( 'Button Icon', 'guto-toolkit' ),
                    'type' => Controls_Manager::ICON,
                    'label_block' => true,
                    'options' => guto_toolkit_icons(),
				]
            );

            $this->add_control(
                'link_type',
                [
                    'label' 		=> esc_html__( 'Button Link Type', 'guto-toolkit' ),
                    'type' 			=> Controls_Manager::SELECT,
                    'label_block' 	=> true,
                    'options' => [
                        '1'  	=> esc_html__( 'Link To Page', 'guto-toolkit' ),
                        '2' 	=> esc_html__( 'External Link', 'guto-toolkit' ),
                    ],
                ]
            );

            $this->add_control(
                'link_to_page',
                [
                    'label' 		=> esc_html__( 'Button Link Page', 'guto-toolkit' ),
                    'type' 			=> Controls_Manager::SELECT,
                    'label_block' 	=> true,
                    'options' 		=> guto_toolkit_get_page_as_list(),
                    'condition' => [
                        'link_type' => '1',
                    ]
                ]
            );

            $this->add_control(
                'ex_link',
                [
                    'label'		=> esc_html__('Button External Link', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: TEXT,
                    'condition' => [
                        'link_type' => '2',
                    ]
                ]
            );

            $this->add_control(
                'first_course',
                [
                    'label' 		=> esc_html__( 'Banner First Course', 'guto-toolkit' ),
                    'type' 			=> Controls_Manager::SELECT,
                    'label_block' 	=> true,
                    'options' 		=> guto_toolkit_get_course_as_list(),
                ]
            );

            $this->add_control(
                'second_course',
                [
                    'label' 		=> esc_html__( 'Banner Second Course', 'guto-toolkit' ),
                    'type' 			=> Controls_Manager::SELECT,
                    'label_block' 	=> true,
                    'options' 		=> guto_toolkit_get_course_as_list(),
                ]
            );

			$this->add_control(
                'shape1',
                [
                    'label'		=> esc_html__('Shape Image One', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: MEDIA,
                ]
			);

            $this->add_control(
				'lessons_title',
				[
					'label' 	=> esc_html__( 'Lessons Title', 'guto-toolkit' ),
					'type' 		=> Controls_Manager::TEXT,
					'default' 	=> __('Lessons', 'guto-toolkit'),
				]
            );

            $this->add_control(
				'students_title',
				[
					'label' 	=> esc_html__( 'Students Title', 'guto-toolkit' ),
					'type' 		=> Controls_Manager::TEXT,
					'default' 	=> __('Students', 'guto-toolkit'),
				]
			);

        $this->end_controls_section();

        $this->start_controls_section(
			'banner_style',
			[
				'label' => esc_html__( 'Style', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_control(
				'title_color',
				[
					'label' => esc_html__( 'Title Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .oet-banner-content h1, .oet-banner-content h2, .oet-banner-content h3, .oet-banner-content h4, .oet-banner-content h5, .oet-banner-content h6' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'title_typography',
                    'label' => __( 'Title Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .oet-banner-content h1, .oet-banner-content h2, .oet-banner-content h3, .oet-banner-content h4, .oet-banner-content h5, .oet-banner-content h6',
                ]
            );

			$this->add_control(
				'content_color',
				[
					'label' => esc_html__( 'Content Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .oet-banner-content p' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'content_typography',
                    'label' => __( 'Content Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .oet-banner-content p',
                ]
            );

        $this->end_controls_section();

    }

	protected function render() {

		$settings = $this->get_settings_for_display();

        // Inline Editing
        $this-> add_inline_editing_attributes('title','none');
        $this-> add_inline_editing_attributes('content','none');


        if ( !guto_plugin_active( 'learnpress/learnpress.php' ) ) {
            if( is_user_logged_in() ):
                ?>
                <div class="container">
                    <div class="alert alert-danger" role="alert">
                        <?php echo esc_html__( 'Please Install and activate the LearnPress plugin', 'guto-toolkit' ); ?>
                    </div>
                </div>
                <?php
            endif;
            return;
        }

		// Button Icon
        if( $settings['button_icon'] != '' ):
            $icon = $settings['button_icon'];
        endif;

        // Get Button Link
        if($settings['link_type'] == 1){
            $link = get_page_link( $settings['link_to_page'] );
        } else {
            $link = $settings['ex_link'];
        }

        if ( is_user_logged_in() ):
            $button_text = $settings['user_button_text'];
        else:
            $button_text = $settings['button_text'];
        endif;
        ?>
        <div class="oet-banner-area" style="background-image:url(<?php echo esc_url( $settings['bg_image']['url'] ); ?>);">
            <div class="container-fluid">
                <div class="oet-courses-list">
                    <?php if( $settings['first_course'] != '' ): ?>
                        <div class="single-oet-courses-box">
                            <div class="row m-0">
                                <?php
                                $args = array(
                                    'p'          => $settings['first_course'],
                                    'post_type'  => 'lp_course',
                                );
                                $post_array = new \WP_Query( $args );

                                ?>
                                <?php while($post_array->have_posts()): $post_array->the_post();  $course  = LP()->global['course']; ?>
                                    <div class="col-lg-4 col-md-4 p-0">
                                        <div class="image" style="background-image:url(<?php the_post_thumbnail_url('guto_banner_course'); ?>);">
                                            <img src="<?php the_post_thumbnail_url('guto_banner_course'); ?>" alt="<?php the_post_thumbnail_caption(); ?>">
                                            <a href="<?php the_permalink(); ?>" class="link-btn"></a>
                                        </div>
                                    </div>
                                    <div class="col-lg-8 col-md-8 p-0">
                                        <div class="content">
                                            <h3><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>
                                            <ul class="courses-box-list d-flex align-items-center justify-content-between">
                                                <?php if($settings['lessons_title'] != ''): ?>
                                                    <li><i class='bx bx-book'></i> <?php echo $course->get_curriculum_items( 'lp_lesson' ) ? count( $course->get_curriculum_items( 'lp_lesson' ) ) : 0; ?> <?php echo esc_html( $settings['lessons_title'] ); ?></li>
                                                <?php endif; ?>

                                                <?php if($settings['students_title'] != ''): ?>
                                                    <?php $user_count = $course->get_users_enrolled() ? $course->get_users_enrolled() : 0; ?>
                                                    <li><i class='bx bx-group'></i> <?php echo esc_html( $user_count ); ?>  <?php echo esc_html( $settings['students_title'] ); ?></li>
                                                <?php endif; ?>
                                            </ul>
                                            <ul class="courses-box-footer d-flex align-items-center justify-content-between">
                                                <li>
                                                    <div class="author">
                                                        <div class="d-flex align-items-center justify-content-center">
                                                            <?php echo $course->get_instructor()->get_profile_picture(); ?>
                                                            <span><?php echo $course->get_instructor_html(); ?></span>
                                                        </div>
                                                    </div>
                                                </li>
                                                <li>
                                                    <?php learn_press_courses_loop_item_price(); ?>
                                                </li>
                                            </ul>
                                        </div>
                                    </div>
                                <?php endwhile; ?>
                                <?php wp_reset_query(); ?>
                            </div>
                        </div>
                    <?php endif; ?>

                    <?php if( $settings['first_course'] != '' ): ?>
                        <div class="single-oet-courses-box">
                            <div class="row m-0">
                                <?php
                                $args = array(
                                    'p'          => $settings['second_course'],
                                    'post_type'  => 'lp_course',
                                );
                                $post_array = new \WP_Query( $args );

                                ?>
                                <?php while($post_array->have_posts()): $post_array->the_post();  $course  = LP()->global['course']; ?>
                                    <div class="col-lg-4 col-md-4 p-0">
                                        <div class="image" style="background-image:url(<?php the_post_thumbnail_url('guto_banner_course'); ?>);">
                                            <img src="<?php the_post_thumbnail_url('guto_banner_course'); ?>" alt="<?php the_post_thumbnail_caption(); ?>">
                                            <a href="<?php the_permalink(); ?>" class="link-btn"></a>
                                        </div>
                                    </div>
                                    <div class="col-lg-8 col-md-8 p-0">
                                        <div class="content">
                                            <h3><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>
                                            <ul class="courses-box-list d-flex align-items-center justify-content-between">
                                                <?php if($settings['lessons_title'] != ''): ?>
                                                    <li><i class='bx bx-book'></i> <?php echo $course->get_curriculum_items( 'lp_lesson' ) ? count( $course->get_curriculum_items( 'lp_lesson' ) ) : 0; ?> <?php echo esc_html( $settings['lessons_title'] ); ?></li>
                                                <?php endif; ?>

                                                <?php if($settings['students_title'] != ''): ?>
                                                    <?php $user_count = $course->get_users_enrolled() ? $course->get_users_enrolled() : 0; ?>
                                                    <li><i class='bx bx-group'></i> <?php echo esc_html( $user_count ); ?>  <?php echo esc_html( $settings['students_title'] ); ?></li>
                                                <?php endif; ?>
                                            </ul>
                                            <ul class="courses-box-footer d-flex align-items-center justify-content-between">
                                                <li>
                                                    <div class="author">
                                                        <div class="d-flex align-items-center justify-content-center">
                                                            <?php echo $course->get_instructor()->get_profile_picture(); ?>
                                                            <span><?php echo $course->get_instructor_html(); ?></span>
                                                        </div>
                                                    </div>
                                                </li>
                                                <li>
                                                    <?php learn_press_courses_loop_item_price(); ?>
                                                </li>
                                            </ul>
                                        </div>
                                    </div>
                                <?php endwhile; ?>
                                <?php wp_reset_query(); ?>
                            </div>
                        </div>
                    <?php endif; ?>
                </div>
                <div class="row align-items-center">
                    <div class="col-xl-5 col-lg-12 col-md-12">
                        <div class="oet-banner-content">
                            <<?php echo esc_attr( $settings['title_tag'] ); ?> <?php echo $this-> get_render_attribute_string('title'); ?>>
                                <?php echo esc_html( $settings['title'] ); ?>
                            </<?php echo esc_attr( $settings['title_tag'] ); ?>>

                            <p><?php echo wp_kses_post( $settings['content'] ); ?></p>

                            <?php if( $button_text != '' ): ?>
                                <a href="<?php echo esc_url( $link ); ?>" class="oet-default-btn"><i class="<?php echo esc_attr( $icon ); ?>"></i><?php echo esc_html( $button_text ); ?></a>
                            <?php endif; ?>
                        </div>
                    </div>
                    <div class="col-xl-6 col-lg-6 col-md-12">
                        <?php if($settings['image']['url']): ?>
                            <div class="oet-banner-image">
                                <img src="<?php echo esc_url( $settings['image']['url'] ); ?>" alt="<?php esc_attr($settings['title']); ?>">
                            </div>
                        <?php endif; ?>
                    </div>
                </div>
            </div>

            <?php if( $settings['shape1']['url'] != '' ): ?>
                <div class="oet-shape1"><img src="<?php echo esc_url( $settings['shape1']['url'] ); ?>" alt="<?php echo esc_attr__( 'Shape Image', 'guto-toolkit' ); ?>"></div>
            <?php endif; ?>
        </div>
        <?php
	}

	protected function _content_template() {}

}

Plugin::instance()->widgets_manager->register( new OE_Banner );