<?php
/**
 * Contact Area Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

class Guto_OE_Contact_Area extends Widget_Base {

    public function get_name() {
        return 'OE_Contact_Area';
    }

    public function get_title() {
        return esc_html__( 'OE Contact Area', 'guto-toolkit' );
    }

    public function get_icon() {
        return 'eicon-form-horizontal';
    }

    public function get_categories() {
        return [ 'guto-online-education' ];
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'Guto_OE_Contact_Area',
            [
                'label' => esc_html__( 'Guto Contact Area', 'guto-toolkit' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

            $this->add_control(
                'shortcode',
                [
                    'label' => esc_html__( 'Contact Shortcode', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                ]
            );
            $this->add_control(
                'title',
                [
                    'label' => esc_html__( 'Title', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__('Get in Touch', 'guto-toolkit'),
                ]
            );
            $this->add_control(
                'desc',
                [
                    'label' => esc_html__( 'Content', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXTAREA,
                    'default' => esc_html__('Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Quis ipsum suspendisse ultrices gravida. Risus commodo viverra.', 'guto-toolkit'),
                ]
            );

            $this->add_control(
                'list_items',
                [
                    'label' => esc_html__('List Item', 'guto-toolkit'),
                    'type' => Controls_Manager::REPEATER,
                    'separator' => 'before',
                    'fields' => [
                        [
                            'name'      => 'title',
                            'label'     => esc_html__( 'Title', 'guto-toolkit' ),
                            'type'      => Controls_Manager::TEXT,
                            'default'   => esc_html__('Our Address', 'guto-toolkit'),
                        ],
                        [
                            'name'  => 'icon',
                            'label' => esc_html__( 'Select Icon', 'guto-toolkit' ),
                            'type' => Controls_Manager::ICON,
                            'label_block' => true,
                            'options' => guto_toolkit_icons(),
                        ],
                        [
                            'name'      => 'content',
                            'label'     => esc_html__( 'Content', 'guto-toolkit' ),
                            'type'      => Controls_Manager::TEXTAREA,
                            'default'   => esc_html__('175 5th Ave, New York, NY 10010, United States', 'guto-toolkit'),
                        ],
                    ],
                ]
            );

        $this->end_controls_section();
    }

    protected function render() {

        $settings = $this->get_settings_for_display();

        // Inline Editing
        $this-> add_inline_editing_attributes('title','none');

        ?>
        <div class="oet-contact-area ptb-100">
            <div class="container">
                <div class="row align-items-center">
                    <div class="col-lg-6 col-md-12">
                        <div class="oet-contact-info">
                            <h2><?php echo esc_html($settings['title']); ?></h2>
                            <p><?php echo wp_kses_post($settings['desc']); ?></p>
                            <ul>
                                <?php foreach( $settings['list_items'] as $item ):
                                    // Icon
                                    $icon = $item['icon'];
                                    ?>
                                    <li>
                                        <div class="icon">
                                            <i class="<?php echo esc_attr( $icon ); ?>"></i>
                                        </div>
                                        <h3><?php echo esc_html( $item['title'] ); ?></h3>
                                        <?php echo wp_kses_post( $item['content'] ); ?>
                                    </li>
                                <?php endforeach; ?>
                            </ul>
                        </div>
                    </div>
                    <div class="col-lg-6 col-md-12">
                        <?php if($settings['shortcode']): ?>
                            <?php echo do_shortcode( $settings['shortcode'] ); ?>
                        <?php endif; ?>
                    </div>
                </div>
            </div>
        </div>

        <?php
    }

    protected function _content_template() {}

}

Plugin::instance()->widgets_manager->register( new Guto_OE_Contact_Area );
