<?php
/**
 * OE Courses Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_OE_Courses extends Widget_Base {

	public function get_name() {
        return 'OE Courses';
    }

	public function get_title() {
        return esc_html__( 'Online Education Courses', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-image-box';
    }

	public function get_categories() {
        return [ 'guto-elements', 'guto-online-education' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'Guto_Section',
			[
				'label' => esc_html__( 'OE Courses', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );
            $this->add_control(
                'cat_name',
                [
                    'label' => __( 'Choose Category', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => guto_toolkit_get_courses_cat_list(),
                ]
            );

            $this->add_control(
                'filter',
                [
                    'label' => __( 'Courses Filter By', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        'popular'               => __( 'Featured', 'guto-toolkit' ),
                        'recent'                => __( 'Recent', 'guto-toolkit' ),
                    ],
                    'default' => 'recent',
                ]
            );

            $this->add_control(
                'order',
                [
                    'label' => __( 'Courses Order By', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        'DESC'      => __( 'DESC', 'guto-toolkit' ),
                        'ASC'       => __( 'ASC', 'guto-toolkit' ),
                    ],
                    'default' => 'DESC',
                ]
            );

            $this->add_control(
                'count',
                [
                    'label' => __( 'Count', 'guto-toolkit' ),
                    'type' => Controls_Manager::NUMBER,
                    'default' => 6,
                ]
            );

            $this->add_control(
				'lessons_title',
				[
					'label' 	=> esc_html__( 'Lessons Title', 'guto-toolkit' ),
					'type' 		=> Controls_Manager::TEXT,
					'default' 	=> __('Lessons', 'guto-toolkit'),
				]
            );

            $this->add_control(
				'students_title',
				[
					'label' 	=> esc_html__( 'Students Title', 'guto-toolkit' ),
					'type' 		=> Controls_Manager::TEXT,
					'default' 	=> __('Students', 'guto-toolkit'),
				]
			);

            $this->add_control(
                'button_text',
                [
                    'label' 	=> esc_html__( 'Button Text', 'guto-toolkit' ),
                    'type' 		=> Controls_Manager::TEXT,
                    'default' 	=> __('View All Courses', 'guto-toolkit'),
                ]
            );

            $this->add_control(
                'button_icon',
                [
                    'label' => esc_html__( 'Button Icon', 'guto-toolkit' ),
                    'type' => Controls_Manager::ICON,
                    'label_block' => true,
                    'options' => guto_toolkit_icons(),
                ]
            );

            $this->add_control(
                'btn_link_type',
                [
                    'label' 		=> esc_html__( 'Button Link Type', 'guto-toolkit' ),
                    'type' 			=> Controls_Manager::SELECT,
                    'label_block' 	=> true,
                    'options' => [
                        '1'  	=> esc_html__( 'Link To Page', 'guto-toolkit' ),
                        '2' 	=> esc_html__( 'External Link', 'guto-toolkit' ),
                    ],
                ]
            );

            $this->add_control(
                'btn_link_to_page',
                [
                    'label' 		=> esc_html__( 'Button Link Page', 'guto-toolkit' ),
                    'type' 			=> Controls_Manager::SELECT,
                    'label_block' 	=> true,
                    'options' 		=> guto_toolkit_get_page_as_list(),
                    'condition' => [
                        'btn_link_type' => '1',
                    ]
                ]
            );

            $this->add_control(
                'btn_ex_link',
                [
                    'label'		=> esc_html__('Button External Link', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: TEXT,
                    'condition' => [
                        'btn_link_type' => '2',
                    ]
                ]
            );

        $this->end_controls_section();

        $this->start_controls_section(
			'section_style',
			[
				'label' => esc_html__( 'Style', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
        );
            $this->add_control(
                'title_color',
                [
                    'label' => esc_html__( 'Title Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .single-oet-courses-box .content h3' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'title_typography',
                    'label' => esc_html__( 'Title Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .single-oet-courses-box .content h3',
                ]
            );

            $this->add_control(
                'info_color',
                [
                    'label' => esc_html__( 'Info Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .single-oet-courses-box .content .courses-box-list li' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'info_typography',
                    'label' => esc_html__( 'Top Title Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .single-oet-courses-box .content .courses-box-list li',
                ]
            );



        $this->end_controls_section();

    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        if ( !guto_plugin_active( 'learnpress/learnpress.php' ) ) {
            if( is_user_logged_in() ):
                ?>
                <div class="container">
                    <div class="alert alert-danger" role="alert">
                        <?php echo esc_html__( 'Please Install and activate the LearnPress plugin', 'guto-toolkit' ); ?>
                    </div>
                </div>
                <?php
            endif;
			return;
		}
        // Post Query
        if( $settings['cat_name'] != '' ) {
            if( $settings['filter'] == 'popular' ):
                $args = array(
                    'post_type'         => 'lp_course',
                    'posts_per_page'    => $settings['count'],
                    'order'             => $settings['order'],
                    'meta_key'          => '_thumbnail_id',
                    'tax_query'         => array(
                        array(
                            'taxonomy'      => 'course_category',
                            'field'         => 'slug',
                            'terms'         => $settings['cat_name'],
                            'hide_empty'    => false,
                        )
                    ),
                    'ignore_sticky_posts' => true,
                    'meta_query'          => array(
                        array(
                            'key'   => '_lp_featured',
                            'value' => 'yes',
                        )
                    ),
                );
            else:
                $args = array(
                    'post_type'         => 'lp_course',
                    'posts_per_page'    => $settings['count'],
                    'order'             => $settings['order'],
                    'meta_key'          => '_thumbnail_id',
                    'tax_query'         => array(
                        array(
                            'taxonomy'      => 'course_category',
                            'field'         => 'slug',
                            'terms'         => $settings['cat_name'],
                            'hide_empty'    => false,
                        )
                    )
                );
            endif;
        } else {
            if( $settings['filter'] == 'popular' ):
                $args = array(
                    'post_type'         => 'lp_course',
                    'posts_per_page'    => $settings['count'],
                    'order'             => $settings['order'],
                    'meta_key'          => '_thumbnail_id',
                    'ignore_sticky_posts' => true,
                    'meta_query'          => array(
                        array(
                            'key'   => '_lp_featured',
                            'value' => 'yes',
                        )
                    ),
                );
            else:
                $args = array(
                    'post_type'         => 'lp_course',
                    'posts_per_page'    => $settings['count'],
                    'order'             => $settings['order'],
                    'meta_key'          => '_thumbnail_id',
                );
            endif;
        }

        $post_array = new \WP_Query( $args );

        // Get Button Link
        if($settings['btn_link_type'] == 1){
            $link = get_page_link( $settings['btn_link_to_page'] );
        } else {
            $link = $settings['btn_ex_link'];
        }

        // Inline Editing
        $this-> add_inline_editing_attributes('title','none');
        ?>
            <div class="container">
                <div class="row justify-content-center">
                    <?php while($post_array->have_posts()): $post_array->the_post();  $course  = LP()->global['course']; ?>
                        <div class="col-lg-6 col-md-12">
                            <div class="single-oet-courses-box">
                                <div class="row m-0">
                                    <div class="col-lg-4 col-md-4 p-0">
                                        <div class="image" style="background-image:url(<?php the_post_thumbnail_url('guto_banner_course'); ?>);">
                                            <img src="<?php the_post_thumbnail_url('guto_banner_course'); ?>" alt="<?php the_post_thumbnail_caption(); ?>">
                                            <a href="<?php the_permalink(); ?>" class="link-btn"></a>
                                        </div>
                                    </div>
                                    <div class="col-lg-8 col-md-8 p-0">
                                        <div class="content">
                                            <h3><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>
                                            <ul class="courses-box-list d-flex align-items-center justify-content-between">
                                                <?php if($settings['lessons_title'] != ''): ?>
                                                    <li><i class='bx bx-book'></i> <?php echo $course->get_curriculum_items( 'lp_lesson' ) ? count( $course->get_curriculum_items( 'lp_lesson' ) ) : 0; ?> <?php echo esc_html( $settings['lessons_title'] ); ?></li>
                                                <?php endif; ?>

                                                <?php if($settings['students_title'] != ''): ?>
                                                    <?php $user_count = $course->get_users_enrolled() ? $course->get_users_enrolled() : 0; ?>
                                                    <li><i class='bx bx-group'></i> <?php echo esc_html( $user_count ); ?>  <?php echo esc_html( $settings['students_title'] ); ?></li>
                                                <?php endif; ?>
                                            </ul>
                                            <ul class="courses-box-footer d-flex align-items-center justify-content-between">
                                                <li>
                                                    <div class="author">
                                                        <div class="d-flex align-items-center justify-content-center">
                                                            <?php echo $course->get_instructor()->get_profile_picture(); ?>
                                                            <span><?php echo $course->get_instructor_html(); ?></span>
                                                        </div>
                                                    </div>
                                                </li>
                                                <li>
                                                    <?php learn_press_courses_loop_item_price(); ?>
                                                </li>
                                            </ul>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    <?php endwhile; ?>
                    <?php wp_reset_query(); ?>

                    <?php if( $settings['button_text'] != '' ): ?>
                        <div class="col-lg-12 col-md-12">
                            <div class="oet-all-courses-box">
                                <a href="<?php echo esc_url( $link ); ?>" class="oet-default-btn"><i class='<?php echo esc_attr( $settings['button_icon'] ); ?>'></i> <?php echo esc_html( $settings['button_text'] ); ?></a>
                            </div>
                        </div>
                    <?php endif; ?>

                </div>
            </div>
        <?php
	}

	protected function _content_template() {}

}

Plugin::instance()->widgets_manager->register( new Guto_OE_Courses );