<?php

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

class OF_Features_Area extends Widget_Base {

    public function get_name() {
        return 'guto_oe_features_area';
    }

    public function get_title() {
        return __( 'Online Education Features Area', 'guto-toolkit' );
    }

    public function get_icon() {
        return 'eicon-info-box';
    }

    public function get_categories() {
        return [ 'guto-online-education' ];
    }

    protected function _register_controls() {

        $this->start_controls_section(
			'Guto_OF_Features_Area',
			[
				'label' => esc_html__( 'Features Content', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'image',
            [
                'label' => esc_html__( 'Image', 'guto-toolkit' ),
                'type' => Controls_Manager::MEDIA,
            ]
        );
        $repeater->add_control(
            'title',
            [
                'label' => esc_html__( 'Title', 'guto-toolkit' ),
                'type' => Controls_Manager::TEXT,
                'label_block' => true,
                'default' =>  esc_html__( 'Learn The Latest Skills', 'guto-toolkit' ),
            ]
        );
        $repeater->add_control(
            'desc',
            [
                'label' => esc_html__( 'Description', 'guto-toolkit' ),
                'type' => Controls_Manager::TEXTAREA,
                'label_block' => true,
                'default' =>  esc_html__( 'Lorem ipsum dolor sit amet, elit, sed do eiusmod tempor incididunt ut labore et dolore magna ajgtliqua quis ipsum.', 'guto-toolkit' ),
            ]
        );
        $repeater->add_control(
            'link_text',
            [
                'label' 	=> esc_html__( 'Link Text', 'guto-toolkit' ),
                'type' 		=> Controls_Manager::TEXT,
                'default' 	=> __('Register Now', 'guto-toolkit'),
            ]
        );
        $repeater->add_control(
            'user_link_text',
            [
                'label' 	=> esc_html__( 'User Logged in Link Text', 'guto-toolkit' ),
                'type' 		=> Controls_Manager::TEXT,
                'default' 	=> __('Profile', 'guto-toolkit'),
            ]
        );
        $repeater->add_control(
            'link_type',
            [
                'label' 		=> esc_html__( 'Link Type', 'guto-toolkit' ),
                'type' 			=> Controls_Manager::SELECT,
                'label_block' 	=> true,
                'options' => [
                    '1'  	=> esc_html__( 'Link To Page', 'guto-toolkit' ),
                    '2' 	=> esc_html__( 'External Link', 'guto-toolkit' ),
                ],
            ]
        );
        $repeater->add_control(
            'link_to_page',
            [
                'label' 		=> esc_html__( 'Link Page', 'guto-toolkit' ),
                'type' 			=> Controls_Manager::SELECT,
                'label_block' 	=> true,
                'options' 		=> guto_toolkit_get_page_as_list(),
                'condition' => [
                    'link_type' => '1',
                ]
            ]
        );
        $repeater->add_control(
            'ex_link',
            [
                'label'		=> esc_html__('External Link', 'guto-toolkit'),
                'type'		=> Controls_Manager:: TEXT,
                'condition' => [
                    'link_type' => '2',
                ]
            ]
        );

        $this->add_control(
            'cards',
            [
                'label' => esc_html__('Add Card', 'guto-toolkit'),
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
            ]
        );


        $this->end_controls_section();

        $this->start_controls_section(
			'fa_style',
			[
				'label' => esc_html__( 'Style', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_control(
				'title_color',
				[
					'label' => esc_html__( 'Title Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .single-oet-features-box h3' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'title_typography',
                    'label' => __( 'Title Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .single-oet-features-box h3',
                ]
            );

			$this->add_control(
				'content_color',
				[
					'label' => esc_html__( 'Content Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .single-oet-features-box p' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'content_typography',
                    'label' => __( 'Content Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .single-oet-features-box p',
                ]
            );

			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'link_typography',
                    'label' => __( 'Link Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .single-oet-features-box .link-btn',
                ]
            );

        $this->end_controls_section();

    }

    protected function render()
    {
        $settings = $this->get_settings();
        ?>
        <div class="container">
            <div class="row justify-content-center align-items-center">
                <?php foreach( $settings['cards'] as $item ): ?>
                    <div class="col-lg-4 col-md-6 col-sm-6">
                        <div class="single-oet-features-box">
                            <?php if($item['image']['url'] != ''): ?>
                                <img src="<?php echo esc_url($item['image']['url']); ?>" alt="<?php echo esc_attr($item['title']); ?>">
                            <?php endif; ?>
                            <h3><?php echo esc_html($item['title']); ?></h3>
                            <p><?php echo wp_kses_post($item['desc']); ?></p>

                            <?php if($item['link_text'] != ''):
                                if ( is_user_logged_in() ):
                                    $button_text = $item['user_link_text'];
                                else:
                                    $button_text = $item['link_text'];
                                endif;
                                // Get Button Link
                                if($item['link_type'] == 1){
                                    $link = get_page_link( $item['link_to_page'] );
                                } else {
                                    $link = $item['ex_link'];
                                }
                                ?>
                                <a href="<?php echo esc_url($link); ?>" class="link-btn"><?php echo esc_html($button_text); ?></a>
                            <?php endif; ?>
                        </div>
                    </div>
                <?php endforeach; ?>
            </div>
        </div>
        <?php
    }
}


Plugin::instance()->widgets_manager->register( new OF_Features_Area );