<?php
/**
 * OE Feedback Box Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_OE_Feedback_Box extends Widget_Base {

	public function get_name() {
        return 'Guto_OE_Feedback_Box';
    }

	public function get_title() {
        return esc_html__( 'OE Feedback Box', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-apps';
    }

	public function get_categories() {
        return [ 'guto-online-education' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'Feedback_section',
			[
				'label' => esc_html__( 'Feedback Control', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
            $this->add_control(
                'columns',
                [
                    'label' => esc_html__( 'Choose Columns', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        '1'   => esc_html__( '1', 'guto-toolkit' ),
                        '2'   => esc_html__( '2', 'guto-toolkit' ),
                        '3'   => esc_html__( '3', 'guto-toolkit' ),
                        '4'   => esc_html__( '4', 'guto-toolkit' ),
                    ],
                    'default' => '3',
                ]
            );

            $repeater = new Repeater();

            $repeater->add_control(
                'section_class',
                [
                    'type'        => Controls_Manager::TEXT,
                    'label'       => esc_html__( 'Card Class', 'guto-toolkit' ),
                ]
            );
            $repeater->add_control(
                'rating',
                [
                    'type'        => Controls_Manager::NUMBER,
                    'label'       => esc_html__( 'Rating', 'guto-toolkit' ),
                    'label_block' => true,
                    'default'     => 5,
                ]
            );
            $repeater->add_control(
                'feedback',
                [
                    'type'        => Controls_Manager::TEXTAREA,
                    'label'       => esc_html__( 'Feedback', 'guto-toolkit' ),
                    'label_block'   => true,
                ]
            );
            $repeater->add_control(
                'image',
                [
                    'label' => esc_html__( 'Image', 'guto-toolkit' ),
                    'type' => Controls_Manager::MEDIA,
                    'label_block'   => true,
                ]
            );
            $repeater->add_control(
                'name',
                [
                    'label' => esc_html__( 'Name', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default'       => esc_html__( 'John Smith', 'guto-toolkit' ),
                    'label_block'   => true,
                ]
            );
            $repeater->add_control(
                'designation',
                [
                    'label' => esc_html__( 'Designation', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default'       => esc_html__( 'Designer', 'guto-toolkit' ),
                    'label_block'   => true,
                ]
            );
            $this->add_control(
                'items',
                [
                    'label'   => esc_html__( 'Add Item', 'guto-toolkit' ),
                    'type' => Controls_Manager::REPEATER,
                    'fields' => $repeater->get_controls(),
                ]
            );

        $this->end_controls_section();

        $this->start_controls_section(
			'counter_style',
			[
				'label' => esc_html__( 'Style', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

            $this->add_control(
                'rating_color',
                [
                    'label' => esc_html__( 'Rating Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .single-oet-feedback-box .rating i' => 'color: {{VALUE}}',
                    ],
                ]
			);

            $this->add_control(
				'feedback_color',
				[
					'label' => esc_html__( 'Feedback Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .single-oet-feedback-box p' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'feedback_typography',
                    'label' => esc_html__( 'Feedback Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .single-oet-feedback-box p',
                ]
            );
            $this->add_control(
				'name_color',
				[
					'label' => esc_html__( 'Name Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .single-oet-feedback-box .client-info .title h4' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'name_typography',
                    'label' => esc_html__( 'Name Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .single-oet-feedback-box .client-info .title h4',
                ]
            );
            $this->add_control(
				'designation_color',
				[
					'label' => esc_html__( 'Designation Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .single-oet-feedback-box .client-info .title span' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'designation_typography',
                    'label' => esc_html__( 'Designation Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .single-oet-feedback-box .client-info .title span',
                ]
            );

        $this->end_controls_section();
    }

	protected function render() {
		$settings = $this->get_settings_for_display();

        // Card Columns
        $columns = $settings['columns'];
        if ($columns == '1') {
            $column = 'col-lg-12 col-md-6';
        }elseif ($columns == '2') {
            $column = 'col-lg-6 col-md-6';
        }elseif ($columns == '3') {
            $column = 'col-lg-4 col-md-6';
        }elseif ($columns == '4') {
            $column = 'col-lg-3 col-md-6';
        } ?>
        <div class="oet-feedback-area pb-70">
            <div class="container">
                <div class="row justify-content-center">
                    <?php foreach( $settings['items'] as $item ): ?>
                        <div class="<?php echo esc_attr( $column ) ?>">
                            <div class="single-oet-feedback-box <?php echo esc_attr($item['section_class']); ?>">
                                <div class="rating">
                                    <?php for ($i = 1; $i <= $item['rating']; $i++): ?>
                                        <i class='bx bxs-star'></i>
                                    <?php endfor; ?>
                                </div>
                                <p><?php echo wp_kses_post( $item['feedback'] ); ?></p>
                                <div class="client-info d-flex align-items-center">
                                    <?php if( $item['image']['url'] != '' ): ?>
                                        <img class="client-img" src="<?php echo esc_url( $item['image']['url'] ); ?>" alt="<?php echo esc_attr( $item['name'] ) ?>">
                                    <?php endif; ?>
                                    <div class="title">
                                        <h4><?php echo esc_html( $item['name'] ); ?></h4>
                                        <span><?php echo esc_html( $item['designation'] ); ?></span>
                                    </div>
                                </div>
                            </div>
                        </div>
                    <?php endforeach; ?>
                </div>
            </div>
        </div>

        <?php
	}
	protected function _content_template() {}

}

Plugin::instance()->widgets_manager->register( new Guto_OE_Feedback_Box );