<?php
/**
 * OE Instructor Area Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_OE_Instructor_Area extends Widget_Base {

	public function get_name() {
        return 'Guto_OE_Instructor_Area';
    }

	public function get_title() {
        return esc_html__( 'OE Instructor Area', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-gallery-masonry';
    }

	public function get_categories() {
        return [ 'guto-online-education' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'Instructor_section',
			[
				'label' => esc_html__( 'Instructor Control', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

            $this->add_control(
                'instructor_style',
                    [
                        'label' => esc_html__( 'Instructor Style', 'guto-toolkit' ),
                        'type' => Controls_Manager::SELECT,
                        'options' => [
                            '1'         => esc_html__( 'Style One', 'guto-toolkit' ),
                            '2'         => esc_html__( 'Style Two', 'guto-toolkit' ),
                        ],
                        'default' => '1',
                    ]
            );

            $this->add_control(
                'top_title',
                [
                    'label' => esc_html__( 'Top Title', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__('OUR COURSES', 'guto-toolkit'),
                    'condition' => [
                        'instructor_style' => '1',
                    ]
                ]
            );
            $this->add_control(
                'title',
                [
                    'label' => esc_html__( 'Title', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__('Guto Popular Courses', 'guto-toolkit'),
                    'condition' => [
                        'instructor_style' => '1',
                    ]
                ]
            );

            $this->add_control(
                'button_text',
                [
                    'label' 	=> esc_html__( 'Button Text', 'guto-toolkit' ),
                    'type' 		=> Controls_Manager::TEXT,
                    'default' 	=> __('View All Courses', 'guto-toolkit'),
                    'condition' => [
                        'instructor_style' => '1',
                    ]
                ]
            );

            $this->add_control(
                'button_icon',
                [
                    'label' => esc_html__( 'Button Icon', 'guto-toolkit' ),
                    'type' => Controls_Manager::ICON,
                    'label_block' => true,
                    'options' => guto_toolkit_icons(),
                    'condition' => [
                        'instructor_style' => '1',
                    ]
                ]
            );

            $this->add_control(
                'btn_link_type',
                [
                    'label' 		=> esc_html__( 'Button Link Type', 'guto-toolkit' ),
                    'type' 			=> Controls_Manager::SELECT,
                    'label_block' 	=> true,
                    'options' => [
                        '1'  	=> esc_html__( 'Link To Page', 'guto-toolkit' ),
                        '2' 	=> esc_html__( 'External Link', 'guto-toolkit' ),
                    ],
                    'condition' => [
                        'instructor_style' => '1',
                    ]
                ]
            );

            $this->add_control(
                'btn_link_to_page',
                [
                    'label' 		=> esc_html__( 'Button Link Page', 'guto-toolkit' ),
                    'type' 			=> Controls_Manager::SELECT,
                    'label_block' 	=> true,
                    'options' 		=> guto_toolkit_get_page_as_list(),
                    'condition' => [
                        'btn_link_type' => '1',
                        'instructor_style' => '1',
                    ]
                ]
            );

            $this->add_control(
                'btn_ex_link',
                [
                    'label'		=> esc_html__('Button External Link', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: TEXT,
                    'condition' => [
                        'btn_link_type' => '2',
                        'instructor_style' => '2',
                    ]
                ]
            );

            $repeater = new Repeater();

            $repeater->add_control(
                'image',
                [
                    'label' => esc_html__( 'Image', 'guto-toolkit' ),
                    'type' => Controls_Manager::MEDIA,
                    'label_block'   => true,
                ]
            );
            $repeater->add_control(
                'name',
                [
                    'label' => esc_html__( 'Name', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default'       => esc_html__( 'John Smith', 'guto-toolkit' ),
                    'label_block'   => true,
                ]
            );
            $repeater->add_control(
                'designation',
                [
                    'label' => esc_html__( 'Designation', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default'       => esc_html__( 'Designer', 'guto-toolkit' ),
                    'label_block'   => true,
                ]
            );
            $this->add_control(
                'items',
                [
                    'label'   => esc_html__( 'Add Item', 'guto-toolkit' ),
                    'type' => Controls_Manager::REPEATER,
                    'fields' => $repeater->get_controls(),
                ]
            );

            $this->add_control(
				'shape_image1',
				[
					'label' => esc_html__( 'Shape Image 1', 'guto-toolkit' ),
					'type' => Controls_Manager::MEDIA,
                    'condition' => [
                        'instructor_style' => '1',
                    ]
				]
			);

            $this->add_control(
				'shape_image2',
				[
					'label' => esc_html__( 'Shape Image 2', 'guto-toolkit' ),
					'type' => Controls_Manager::MEDIA,
                    'condition' => [
                        'instructor_style' => '1',
                    ]
				]
			);

        $this->end_controls_section();

        $this->start_controls_section(
			'counter_style',
			[
				'label' => esc_html__( 'Style', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

            $this->add_control(
                'top_title_color',
                [
                    'label' => esc_html__( 'Top Title Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .oet-instructor-content .sub-title' => 'color: {{VALUE}}',
                    ],
                    'condition' => [
                        'instructor_style' => '1',
                    ]
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'top_title_typography',
                    'label' => esc_html__( 'Top Title Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .oet-instructor-content .sub-title',
                    'condition' => [
                        'instructor_style' => '1',
                    ]
                ]
            );

            $this->add_control(
                'title_color',
                [
                    'label' => esc_html__( 'Title Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .oet-instructor-content h2' => 'color: {{VALUE}}',
                        'condition' => [
                            'instructor_style' => '1',
                        ]
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'title_typography',
                    'label' => esc_html__( 'Title Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .oet-instructor-content h2',
                    'condition' => [
                        'instructor_style' => '1',
                    ]
                ]
            );

            $this->add_control(
				'name_color',
				[
					'label' => esc_html__( 'Name Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .instructor-list ul li .content h3, .single-oet-instructor-box .content h3' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'name_typography',
                    'label' => esc_html__( 'Name Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .instructor-list ul li .content h3, .single-oet-instructor-box .content h3',
                ]
            );
            $this->add_control(
				'designation_color',
				[
					'label' => esc_html__( 'Designation Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .instructor-list ul li .content span, .single-oet-instructor-box .content span' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'designation_typography',
                    'label' => esc_html__( 'Designation Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .instructor-list ul li .content span, .single-oet-instructor-box .content span',
                ]
            );

        $this->end_controls_section();
    }

	protected function render() {
		$settings = $this->get_settings_for_display();

        if($settings['instructor_style'] == '1'):
            // Get Button Link
            if($settings['btn_link_type'] == 1){
                $link = get_page_link( $settings['btn_link_to_page'] );
            } else {
                $link = $settings['btn_ex_link'];
            }
            ?>
            <div class="oet-instructor-area pb-100">
                <div class="container">
                    <div class="row">
                        <div class="col-lg-5 col-md-12">
                            <div class="oet-instructor-content">
                                <span class="sub-title"><?php echo wp_kses_post( $settings['top_title'] ); ?></span>
                                <h2><?php echo wp_kses_post( $settings['title'] ); ?></h2>

                                <?php if( $settings['button_text'] != '' ): ?>
                                    <a href="<?php echo esc_url( $link ); ?>" class="oet-default-btn"><i class='<?php echo esc_attr( $settings['button_icon'] ); ?>'></i> <?php echo esc_html( $settings['button_text'] ); ?></a>
                                <?php endif; ?>
                            </div>
                        </div>
                        <div class="col-lg-7 col-md-12">
                            <div class="instructor-list">
                                <ul>
                                    <?php foreach( $settings['items'] as $item ): ?>
                                        <li>
                                            <?php if( $item['image']['url'] != '' ): ?>
                                                <img src="<?php echo esc_url( $item['image']['url'] ); ?>" alt="<?php echo esc_attr( $item['name'] ) ?>">
                                            <?php endif; ?>
                                            <div class="content">
                                                <h3><?php echo esc_html( $item['name'] ); ?></h3>
                                                <span><?php echo esc_html( $item['designation'] ); ?></span>
                                            </div>
                                        </li>
                                    <?php endforeach; ?>
                                </ul>
                            </div>
                        </div>
                    </div>
                </div>
                <?php if( $settings['shape_image1']['url'] != '' ): ?>
                    <div class="oet-shape1"><img src="<?php echo esc_url( $settings['shape_image1']['url'] ); ?>" alt="<?php echo esc_attr__( 'shape', 'guto-toolkit' ) ?>"></div>
                <?php endif; ?>
                <?php if( $settings['shape_image2']['url'] != '' ): ?>
                    <div class="oet-shape4"><img src="<?php echo esc_url( $settings['shape_image2']['url'] ); ?>" alt="<?php echo esc_attr__( 'shape', 'guto-toolkit' ) ?>"></div>
                <?php endif; ?>
            </div>
        <?php elseif($settings['instructor_style'] == '2'): ?>
            <div class="container">
                <div class="row justify-content-center">
                    <?php foreach( $settings['items'] as $item ): ?>
                        <div class="col-lg-3 col-md-4 col-sm-6">
                            <div class="single-oet-instructor-box">
                                <?php if( $item['image']['url'] != '' ): ?>
                                    <img src="<?php echo esc_url( $item['image']['url'] ); ?>" alt="<?php echo esc_attr( $item['name'] ) ?>">
                                <?php endif; ?>

                                <div class="content">
                                    <h3><?php echo esc_html( $item['name'] ); ?></h3>
                                    <span><?php echo esc_html( $item['designation'] ); ?></span>
                                </div>
                            </div>
                        </div>
                    <?php endforeach; ?>
                </div>
            </div>
        <?php endif;
	}
	protected function _content_template() {}

}

Plugin::instance()->widgets_manager->register( new Guto_OE_Instructor_Area );