<?php
/**
 * OHC About Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_OHC_About_Area extends Widget_Base {

	public function get_name() {
        return 'Guto_OHC_About';
    }

	public function get_title() {
        return esc_html__( 'About Area', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-info-box';
    }

	public function get_categories() {
        return [ 'guto-online-health-coach' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'Guto_OHC_About_Area',
			[
				'label' => esc_html__( 'About Controls', 'guto-toolkit' ),
				'tab' 	=> Controls_Manager::TAB_CONTENT,
			]
		);
            $this->add_control(
                'subtitle',
                [
                    'label'     => esc_html__( 'Subtitle', 'guto-toolkit' ),
                    'type'      =>Controls_Manager::TEXT,
                    'default'   => esc_html__('ABOUT ME', 'guto-toolkit'),
                ]
            );

			$this->add_control(
				'title',
				[
					'label' 	=> esc_html__( 'Title', 'guto-toolkit' ),
					'type'      =>Controls_Manager::TEXT,
					'default' 	=> esc_html__("It's a weird and wonderful world", 'guto-toolkit'),
				]
			);

			$this->add_control(
				'content',
				[
					'label' 	=> esc_html__( 'Content', 'guto-toolkit' ),
					'type'      =>Controls_Manager:: TEXTAREA,
					'default' 	=> esc_html__('Lorem ipsum dolor sit amet consectetur adipiscing elit sed do eiusmod tempor incididunt ut labore et dolore magna aliqua quis ipsum suspendisse.', 'guto-toolkit'),
				]
            );
        $this->end_controls_section();

        // Images
        $this->start_controls_section(
			'funfacts_images_section',
			[
				'label' => esc_html__( 'Funfacts Images', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
            $this->add_control(
                'image',
                [
                    'label'     => esc_html__('Featured Image', 'guto-toolkit'),
                    'type'      => Controls_Manager:: MEDIA,
                ]
            );
            $this->add_control(
                'shape1',
                [
                    'label'     => esc_html__('Shape One', 'guto-toolkit'),
                    'type'      => Controls_Manager:: MEDIA,
                ]
            );
            $this->add_control(
                'shape2',
                [
                    'label'     => esc_html__('Shape Two', 'guto-toolkit'),
                    'type'      => Controls_Manager:: MEDIA,
                ]
            );
        $this->end_controls_section();

        // Funfacts Counter
        $this->start_controls_section(
			'funfacts_section',
			[
				'label' => esc_html__( 'Funfacts Control', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

            $repeater = new Repeater();
            $repeater->add_control(
                'number',
                [
                    'label'       => esc_html__( 'Number', 'guto-toolkit' ),
                    'type'        => Controls_Manager::NUMBER,
                    'label_block' => true,
                    'default'     => 1926,
                ]
            );
            $repeater->add_control(
                'counter_sign',
                [
                    'label' => esc_html__( 'Counter Sign', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'label_block'   => true,
                ]
            );
            $repeater->add_control(
                'counter_title',
                [
                    'label' => esc_html__( 'Counter Title', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'label_block'   => true,
                    'default'       => esc_html__( 'FINISHED SESSIONS', 'guto-toolkit' ),
                ]
            );
            $this->add_control(
                'items',
                [
                    'label'  => esc_html__( 'Add Item', 'guto-toolkit' ),
                    'type'   => Controls_Manager::REPEATER,
                    'fields' => $repeater->get_controls(),
                ]
            );
        $this->end_controls_section();

        $this->start_controls_section(
			'banner_style',
			[
				'label' => esc_html__( 'Style', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
			$this->add_control(
				'sec_bg_color',
				[
					'label' => esc_html__( 'Section Background Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ohc-about-area' => 'background-color: {{VALUE}}',
					],
                    'separator' => 'before',
				]
			);

            $this->add_control(
				'top_title_color',
				[
					'label' => esc_html__( 'Top Title Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ohc-about-content b' => 'color: {{VALUE}}',
					],
                    'separator' => 'before',
				]
			);
			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'top_title_typography',
                    'label' => esc_html__( 'Top Title Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .ohc-about-content b',
                ]
            );

			$this->add_control(
				'title_color',
				[
					'label' => esc_html__( 'Title Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ohc-about-content h3' => 'color: {{VALUE}}',
					],
                    'separator' => 'before',
				]
			);
			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'title_typography',
                    'label' => esc_html__( 'Title Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .ohc-about-content h3',
                ]
            );
			$this->add_control(
				'content_color',
				[
					'label' => esc_html__( 'Content Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ohc-about-content p' => 'color: {{VALUE}}',
					],
				]
			);
			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'content_typography',
                    'label' => esc_html__( 'Content Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .ohc-about-content p',
                ]
            );

            $this->add_control(
				'counter_color',
				[
					'label' => esc_html__( 'Counter Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ohc-about-content .funfacts-box h3' => 'color: {{VALUE}}',
					],
				]
			);
			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'counter_typography',
                    'label' => esc_html__( 'Counter Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .ohc-about-content .funfacts-box h3',
                ]
            );
            $this->add_control(
				'counter_titlecolor',
				[
					'label' => esc_html__( 'Counter Title Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ohc-about-content .funfacts-box p' => 'color: {{VALUE}}',
					],
				]
			);
			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'counter_title_typography',
                    'label' => esc_html__( 'Counter Title Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .ohc-about-content .funfacts-box p',
                ]
            );
        $this->end_controls_section();

    }

	protected function render() {

		$settings = $this->get_settings_for_display();
        ?>

            <div class="ohc-about-area">
                <div class="container">
                    <div class="row align-items-center">
                        <div class="col-lg-5 col-md-12">
                            <div class="ohc-about-image">
                                <?php if( $settings['image']['url'] != '' ): ?>
                                    <img src="<?php echo esc_url($settings['image']['url']); ?>" alt="<?php esc_attr_e('Image', 'guto-toolkit'); ?>">
                                <?php endif; ?>

                                <?php if( $settings['shape1']['url'] != '' ): ?>
                                    <div class="ohc-image-shape">
                                        <img src="<?php echo esc_url($settings['shape1']['url']); ?>" alt="<?php esc_attr_e('Shape Image', 'guto-toolkit'); ?>">
                                    </div>
                                <?php endif; ?>
                            </div>
                        </div>

                        <div class="col-lg-7 col-md-12">
                            <div class="ohc-about-content">
                                <b>
                                    <?php echo esc_html( $settings['subtitle'] ); ?>
                                </b>

                                <h3>
                                    <?php echo wp_kses_post( $settings['title'] ); ?>
                                </h3>

                                <p><?php echo wp_kses_post( $settings['content'] ); ?></p>

                                <div class="row justify-content-center">
                                    <?php foreach( $settings['items'] as $item ): ?>
                                        <div class="col-lg-4 col-md-6">
                                            <div class="funfacts-box">
                                                <h3><span class="odometer" data-count="<?php echo esc_attr( $item['number'] ); ?>">00</span><span class="sign"><?php echo esc_html( $item['counter_sign'] ); ?></span></h3>
                                                <p><?php echo esc_html( $item['counter_title'] ); ?></p>
                                            </div>
                                        </div>
                                    <?php endforeach; ?>
                                </div>

                            </div>
                        </div>
                    </div>
                </div>

                <?php if( $settings['shape2']['url'] != '' ): ?>
                    <div class="ohc-about-shape">
                        <img src="<?php echo esc_url($settings['shape2']['url']); ?>" alt="<?php esc_attr_e('Shape Image', 'guto-toolkit'); ?>">
                    </div>
                <?php endif; ?>
            </div>

        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_OHC_About_Area );
