<?php
/**
 * OHC Banner Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_OHC_Banner extends Widget_Base {

	public function get_name() {
        return 'Guto_OHC_Banner';
    }

	public function get_title() {
        return esc_html__( 'Banner', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-banner';
    }

	public function get_categories() {
        return [ 'guto-online-health-coach' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'Guto_OHC_Banner_Area',
			[
				'label' => esc_html__( 'Banner Controls', 'guto-toolkit' ),
				'tab' 	=> Controls_Manager::TAB_CONTENT,
			]
		);
            $this->add_control(
                'top_title',
                [
                    'label' 	=> esc_html__( 'Top Title', 'guto-toolkit' ),
                    'type' 		=> Controls_Manager::TEXT,
                    'default' 	=> esc_html__('I am a Life Coach', 'guto-toolkit'),
                ]
            );
			$this->add_control(
				'title',
				[
					'label' 	=> esc_html__( 'Title', 'guto-toolkit' ),
					'type' 		=> Controls_Manager::TEXTAREA,
					'default' 	=> esc_html__('We Are Creative Digital Marketing Expert!', 'guto-toolkit'),
				]
			);

			$this->add_control(
                'title_tag',
                [
                    'label' 	=> esc_html__( 'Title Tag', 'guto-toolkit' ),
                    'type' 		=> Controls_Manager::SELECT,
                    'options' 	=> [
                        'h1'         => esc_html__( 'h1', 'guto-toolkit' ),
                        'h2'         => esc_html__( 'h2', 'guto-toolkit' ),
                        'h3'         => esc_html__( 'h3', 'guto-toolkit' ),
                        'h4'         => esc_html__( 'h4', 'guto-toolkit' ),
                        'h5'         => esc_html__( 'h5', 'guto-toolkit' ),
                        'h6'         => esc_html__( 'h6', 'guto-toolkit' ),
                    ],
                    'default' => 'h1',
                ]
            );

			$this->add_control(
				'content',
				[
					'label' 	=> esc_html__( 'Content', 'guto-toolkit' ),
					'type' 		=> Controls_Manager::TEXTAREA,
					'default' 	=> esc_html__('Lorem ipsum dolor sit amet consectetur adipiscing elit sed do eiusmod tempor incididunt labore et dolore magna aliqua.', 'guto-toolkit'),
				]
            );

            $this->add_control(
				'button_icon',
				[
					'label' => esc_html__( 'Button Icon', 'guto-toolkit' ),
                    'type' => Controls_Manager::ICON,
                    'label_block' => true,
                    'options' => guto_toolkit_icons(),
				]
            );

			$this->add_control(
				'button_text',
				[
					'label' 	=> esc_html__( 'Button Text', 'guto-toolkit' ),
					'type' 		=> Controls_Manager::TEXT,
					'default' 	=> esc_html__('Get Started', 'guto-toolkit'),
				]
            );

            $this->add_control(
                'link_type',
                [
                    'label' 		=> esc_html__( 'Button Link Type', 'guto-toolkit' ),
                    'type' 			=> Controls_Manager::SELECT,
                    'label_block' 	=> true,
                    'options' => [
                        '1'  	=> esc_html__( 'Link To Page', 'guto-toolkit' ),
                        '2' 	=> esc_html__( 'External Link', 'guto-toolkit' ),
                    ],
                    'default' => '2'
                ]
            );

            $this->add_control(
                'link_to_page',
                [
                    'label' 		=> esc_html__( 'Button Link Page', 'guto-toolkit' ),
                    'type' 			=> Controls_Manager::SELECT,
                    'label_block' 	=> true,
                    'options' 		=> guto_toolkit_get_page_as_list(),
                    'condition' => [
                        'link_type' => '1',
                    ]
                ]
            );

            $this->add_control(
                'ex_link',
                [
                    'label'		=> esc_html__('Button External Link', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: URL,
                    'show_external' => true,
                    'default' => [
                        'url' => '#',
                        'is_external' => true,
                        'nofollow' => true,
                    ],
                    'condition' => [
                        'link_type' => '2',
                    ]
                ]
            );
        $this->end_controls_section();

        // Images
        $this->start_controls_section(
			'banner_images',
			[
				'label' => esc_html__( 'Images', 'guto-toolkit' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
        );
            $this->add_control(
                'image1',
                [
                    'label'		=> esc_html__('Banner Image One', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: MEDIA,
                ]
            );
            $this->add_control(
                'image2',
                [
                    'label'		=> esc_html__('Banner Image Two', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: MEDIA,
                ]
            );

            $this->add_control(
                'shape1',
                [
                    'label'		=> esc_html__('White Shape', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: MEDIA,
                ]
            );
            $this->add_control(
                'shape2',
                [
                    'label'		=> esc_html__('Shape One', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: MEDIA,
                ]
            );
            $this->add_control(
                'shape3',
                [
                    'label'		=> esc_html__('Shape Two', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: MEDIA,
                ]
            );
            $this->add_control(
                'shape4',
                [
                    'label'		=> esc_html__('Shape Three', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: MEDIA,
                ]
            );
        $this->end_controls_section();

        $this->start_controls_section(
			'banner_style',
			[
				'label' => esc_html__( 'Style', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_control(
				'sec_bg_color',
				[
					'label' => esc_html__( 'Section Background Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ohc-main-banner-area' => 'background-color: {{VALUE}}',
					],
                    'separator' => 'before',
				]
			);

            $this->add_control(
				'top_title_bg_color',
				[
					'label' => esc_html__( 'Top Title Background Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ohc-main-banner-content .sub-title' => 'background-color: {{VALUE}}',
					],
                    'separator' => 'before',
				]
			);
            $this->add_control(
				'top_title_color',
				[
					'label' => esc_html__( 'Top Title Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ohc-main-banner-content .sub-title' => 'color: {{VALUE}}',
					],
                    'separator' => 'before',
				]
			);
			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'top_title_typography',
                    'label' => esc_html__( 'Top Title Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .ohc-main-banner-content .sub-title',
                ]
            );

			$this->add_control(
				'title_color',
				[
					'label' => esc_html__( 'Title Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ohc-main-banner-content h1, .ohc-main-banner-content h2, .ohc-main-banner-content h3, .ohc-main-banner-content h4, .ohc-main-banner-content h5, .ohc-main-banner-content h6' => 'color: {{VALUE}}',
					],
                    'separator' => 'before',
				]
			);

			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'title_typography',
                    'label' => esc_html__( 'Title Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .ohc-main-banner-content h1, .ohc-main-banner-content h2, .ohc-main-banner-content h3, .ohc-main-banner-content h4, .ohc-main-banner-content h5, .ohc-main-banner-content h6',
                ]
            );
			$this->add_control(
				'content_color',
				[
					'label' => esc_html__( 'Content Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ohc-main-banner-content p' => 'color: {{VALUE}}',
					],
				]
			);
			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'content_typography',
                    'label' => esc_html__( 'Content Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .ohc-main-banner-content p',
                ]
            );
            $this->add_control(
				'button_color',
				[
					'label' => esc_html__( 'Button Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ohc-default-btn' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'btn_typography',
                    'label' => esc_html__( 'Button Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .ohc-default-btn',
                ]
            );
        $this->end_controls_section();

    }

	protected function render() {

		$settings = $this->get_settings_for_display();

        // Get Button Link
        if($settings['link_type'] == 1){
            $link = get_page_link( $settings['link_to_page'] );
        } elseif($settings['link_type'] == 2) {
            $link = $settings['ex_link']['url'];
            $target = $settings['ex_link']['is_external'] ? ' target="_blank"' : '';
		    $nofollow = $settings['ex_link']['nofollow'] ? ' rel="nofollow"' : '';
        }

        $button_text = $settings['button_text']; ?>

            <div class="ohc-main-banner-area">
                <div class="container">
                    <div class="row align-items-center">
                        <div class="col-lg-5 col-md-12">
                            <div class="ohc-main-banner-content">
                                <?php if($settings['top_title'] !='' ) : ?>
                                    <span class="sub-title wow fadeInRight" data-wow-delay="300ms" data-wow-duration="1500ms"> <?php echo esc_html( $settings['top_title'] ); ?></span>
                                <?php endif; ?>

                                <<?php echo esc_attr( $settings['title_tag'] ); ?> class="wow fadeInLeft"  data-wow-delay="100ms" data-wow-duration="1000ms">
                                    <?php echo esc_html( $settings['title'] ); ?>
                                </<?php echo esc_attr( $settings['title_tag'] ); ?>>

                                <p class="wow fadeInLeft" data-wow-delay="300ms" data-wow-duration="1500ms"><?php echo wp_kses_post( $settings['content'] ); ?></p>

                                <?php if( $button_text != '' ): ?>
                                    <?php if($settings['link_type'] == 1) : ?>
                                        <div class="banner-btn wow fadeInRight" data-wow-delay="300ms" data-wow-duration="1500ms">
                                            <a href="<?php echo esc_url( $link ); ?>" class="ohc-default-btn"> <i class="<?php echo esc_attr( $settings['button_icon'] ); ?>"></i><?php echo esc_html( $button_text ); ?></a>
                                        </div>
                                    <?php elseif($settings['link_type'] == 2) :
                                        echo '<div class="banner-btn wow fadeInRight" data-wow-delay="300ms" data-wow-duration="1500ms"><a href="' .  $link . '" class="ohc-default-btn" ' . $target . $nofollow . '>  <i class="'.$settings['button_icon'].'"></i> ' . $button_text . ' </a></div>';
                                    endif; ?>
                                <?php endif; ?>

                            </div>
                        </div>

                        <div class="col-lg-7 col-md-12">
                            <div class="ohc-main-banner-image wow fadeInRight" data-wow-delay="300ms" data-wow-duration="1500ms">
                                <?php if( $settings['image1']['url'] != '' ): ?>
                                    <img src="<?php echo esc_url($settings['image1']['url']); ?>" alt="<?php esc_attr_e('Image', 'guto-toolkit'); ?>">
                                <?php endif; ?>

                                <?php if( $settings['image2']['url'] != '' ): ?>
                                    <div class="ohc-image-shape wow fadeInUp" data-wow-delay="500ms" data-wow-duration="1500ms">
                                        <img src="<?php echo esc_url($settings['image2']['url']); ?>" alt="<?php esc_attr_e('Image2', 'guto-toolkit'); ?>">
                                    </div>
                                <?php endif; ?>
                            </div>
                        </div>
                    </div>
                </div>

                <?php if( $settings['shape1']['url'] != '' ): ?>
                    <div class="ohc-banner-white-shape">
                        <img src="<?php echo esc_url($settings['shape1']['url']); ?>" alt="<?php esc_attr_e('Shape Image', 'guto-toolkit'); ?>">
                    </div>
                <?php endif; ?>
                <?php if( $settings['shape2']['url'] != '' ): ?>
                    <div class="ohc-banner-shape-1 wow fadeInLeft" data-wow-delay="500ms" data-wow-duration="2000ms">
                        <img src="<?php echo esc_url($settings['shape2']['url']); ?>" alt="<?php esc_attr_e('Shape Image', 'guto-toolkit'); ?>">
                    </div>
                <?php endif; ?>
                <?php if( $settings['shape3']['url'] != '' ): ?>
                    <div class="ohc-banner-shape-2 wow fadeInDown" data-wow-delay="500ms" data-wow-duration="2000ms">
                        <img src="<?php echo esc_url($settings['shape3']['url']); ?>" alt="<?php esc_attr_e('Shape Image', 'guto-toolkit'); ?>">
                    </div>
                <?php endif; ?>
                <?php if( $settings['shape4']['url'] != '' ): ?>
                    <div class="ohc-banner-shape-3 wow fadeInRight" data-wow-delay="500ms" data-wow-duration="2000ms">
                        <img src="<?php echo esc_url($settings['shape4']['url']); ?>" alt="<?php esc_attr_e('Shape Image', 'guto-toolkit'); ?>">
                    </div>
                <?php endif; ?>
            </div>

        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_OHC_Banner );