<?php
/**
 * Contact Area Form Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_OHC_Contact_FArea extends Widget_Base {

	public function get_name() {
        return 'OHC_ContactF_Area';
    }

	public function get_title() {
        return esc_html__( 'Contact Form Area', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-form-horizontal';
    }

	public function get_categories() {
        return [ 'guto-online-health-coach' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
            'Guto_Contact_Area',
            [
                'label' => esc_html__( 'Guto Contact Area', 'guto-toolkit' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

            // Form
            $this->add_control(
                'shortcode',
                [
                    'label' => esc_html__( 'Contact Shortcode', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                ]
            );


            $repeater = new Repeater();
            $repeater->add_control(
                'icon',
                [
                    'label' => esc_html__( 'Select Icon', 'guto-toolkit' ),
                    'type' => Controls_Manager::ICON,
                    'label_block' => true,
                    'options' => guto_toolkit_icons(),
                ]
            );
            $repeater->add_control(
                'title',
                [
                    'label' => esc_html__( 'Title', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default'       => esc_html__('Phone', 'guto-toolkit'),
                    'label_block'   => true,
                ]
            );
            $repeater->add_control(
                'content',
                [
                    'label'     => esc_html__( 'Content', 'guto-toolkit' ),
                    'type'      => Controls_Manager::TEXTAREA,
                    'default'   => esc_html__('175 5th Ave, New York, NY 10010, United States', 'guto-toolkit'),
                ]
            );
            $this->add_control(
                'list_items',
                [
                    'label' => esc_html__('List Item', 'guto-toolkit'),
                    'type' => Controls_Manager::REPEATER,
                    'fields' => $repeater->get_controls(),
                ]
            );

        $this->end_controls_section();
    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        ?>

        <div class="container">
            <div class="row align-items-center">
                <div class="col-lg-7 col-md-12">
                    <div class="ohc-contact-form">
                        <?php if($settings['shortcode']): ?>
                            <div id="contactForm">
                                <?php echo do_shortcode( $settings['shortcode'] ); ?>
                            </div>
                        <?php endif; ?>
                    </div>
                </div>

                <div class="col-lg-5 col-md-12">
                    <?php foreach( $settings['list_items'] as $item ) :
                        $icon = $item['icon'];
                    ?>
                        <div class="ohc-contact-info-item">
                            <?php if( !empty( $icon ) ) : ?>
                                <div class="icon">
                                    <i class='<?php echo esc_attr( $icon ); ?>'></i>
                                </div>
                            <?php endif; ?>

                            <h3><?php echo esc_html( $item['title'] ); ?></h3>
                            <?php echo wp_kses_post( $item['content'] ); ?>
                        </div>
                    <?php endforeach; ?>
                </div>
            </div>
        </div>

        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_OHC_Contact_FArea );