<?php
/**
 * FAQ Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_OHC_Faq extends Widget_Base {

	public function get_name() {
        return 'OHC_FAQ';
    }

	public function get_title() {
        return esc_html__( 'FAQ', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-help-o';
    }

	public function get_categories() {
        return [ 'guto-online-health-coach' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'Guto_Faq',
			[
				'label' => esc_html__( 'Faq Control', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );
            $repeater = new Repeater();
            $repeater->add_control(
				'title',
				[
                    'label' => esc_html__( 'Title', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__( 'How does Guto Production house Work?', 'guto-toolkit' ),
				]
            );
            $repeater->add_control(
                'content',
                [
                    'label' => esc_html__( 'Content', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXTAREA,
                    'label_block' => true,
                    'default' => "Anim pariatur cliche reprehenderit, enim eiusmod high life accusamus terry richardson ad squid. 3 wolf moon officia aute, non cupidatat skateboard dolor brunch. Food truck quinoa nesciunt laborum eiusmod. Brunch 3 wolf moon tempor, sunt aliqua put a bird on it squid single-origin coffee nulla assumenda shoreditch et. Nihil anim keffiyeh helvetica, craft beer labore wes anderson cred nesciunt sapiente ea proident. Ad vegan excepteur butcher vice lomo.",
                ]
            );
            $this->add_control(
                'faq_tabs',
                [
                    'label' => esc_html__('Faq Tabs', 'guto-toolkit'),
                    'type'   => Controls_Manager::REPEATER,
                    'fields' => $repeater->get_controls(),
                ]
            );
        $this->end_controls_section();

    }

	protected function render() {

        $settings = $this->get_settings_for_display();
        ?>
            <div class="container">
                <div class="ohc-faq-accordion">
                    <div class="accordion" id="ohcFaqAccordion">
                        <?php $i = 1; foreach( $settings['faq_tabs'] as $item ) :
                            if( $i == 1 ) :
                                $show     = 'show';
                                $coll_cls = '';
                            else:
                                $show   = '';
                                $coll_cls = 'collapsed';
                            endif;
                        ?>
                            <div class="accordion-item">
                                <button class="accordion-button <?php echo esc_attr($coll_cls); ?>" type="button" data-bs-toggle="collapse" data-bs-target="#collapse<?php echo esc_attr($i); ?>" aria-expanded="false" aria-controls="collapseTwo">
                                    <?php echo esc_html( $item['title'] ); ?>
                                </button>
                                <div id="collapse<?php echo esc_attr($i); ?>" class="accordion-collapse collapse <?php echo esc_attr($show); ?>" data-bs-parent="#ohcFaqAccordion">
                                    <div class="accordion-body">
                                        <?php echo wp_kses_post( $item['content'] ); ?>
                                    </div>
                                </div>
                            </div>
                        <?php $i++; endforeach; ?>
                    </div>
                </div>

            </div>
        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_OHC_Faq );