<?php

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

class OHC_Features_Area extends Widget_Base {

    public function get_name() {
        return 'guto_ohc_features_area';
    }

    public function get_title() {
        return __( 'Features Area', 'guto-toolkit' );
    }

    public function get_icon() {
        return 'eicon-info-box';
    }

    public function get_categories() {
        return [ 'guto-online-health-coach' ];
    }

    protected function _register_controls() {

        $this->start_controls_section(
			'Guto_OHC_Features_Area',
			[
				'label' => esc_html__( 'Features Content', 'guto-toolkit' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
        );

            $this->add_control(
                'columns',
                [
                    'label' => esc_html__( 'Choose Columns', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        '1'   => esc_html__( '1', 'guto-toolkit' ),
                        '2'   => esc_html__( '2', 'guto-toolkit' ),
                        '3'   => esc_html__( '3', 'guto-toolkit' ),
                        '4'   => esc_html__( '4', 'guto-toolkit' ),
                    ],
                    'default' => '3',
                ]
            );

            $repeater = new Repeater();
            $repeater->add_control(
                'image',
                [
                    'label' => esc_html__( 'Image', 'guto-toolkit' ),
                    'type' => Controls_Manager::MEDIA,
                ]
            );
            $repeater->add_control(
                'title',
                [
                    'label' => esc_html__( 'Title', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'label_block' => true,
                    'default' =>  esc_html__( 'Learn The Latest Skills', 'guto-toolkit' ),
                ]
            );
            $repeater->add_control(
                'desc',
                [
                    'label' => esc_html__( 'Description', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXTAREA,
                    'label_block' => true,
                    'default' =>  esc_html__( 'Lorem ipsum dolor sit amet, elit, sed do eiusmod tempor incididunt ut labore et dolore magna ajgtliqua quis ipsum.', 'guto-toolkit' ),
                ]
            );
            $repeater->add_control(
                'user_link_text',
                [
                    'label' 	=> esc_html__( 'Link Text', 'guto-toolkit' ),
                    'type' 		=> Controls_Manager::TEXT,
                    'default' 	=> __('Profile', 'guto-toolkit'),
                ]
            );
            $repeater->add_control(
                'link_type',
                [
                    'label' 		=> esc_html__( 'Link Type', 'guto-toolkit' ),
                    'type' 			=> Controls_Manager::SELECT,
                    'label_block' 	=> true,
                    'options' => [
                        '1'  	=> esc_html__( 'Link To Page', 'guto-toolkit' ),
                        '2' 	=> esc_html__( 'External Link', 'guto-toolkit' ),
                    ],
                ]
            );
            $repeater->add_control(
                'link_to_page',
                [
                    'label' 		=> esc_html__( 'Link Page', 'guto-toolkit' ),
                    'type' 			=> Controls_Manager::SELECT,
                    'label_block' 	=> true,
                    'options' 		=> guto_toolkit_get_page_as_list(),
                    'condition' => [
                        'link_type' => '1',
                    ]
                ]
            );
            $repeater->add_control(
                'ex_link',
                [
                    'label'		=> esc_html__('External Link', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: TEXT,
                    'condition' => [
                        'link_type' => '2',
                    ]
                ]
            );

            $this->add_control(
                'cards',
                [
                    'label' => esc_html__('Add Card', 'guto-toolkit'),
                    'type' => Controls_Manager::REPEATER,
                    'fields' => $repeater->get_controls(),
                ]
            );
        $this->end_controls_section();

        $this->start_controls_section(
			'fa_style',
			[
				'label' => esc_html__( 'Style', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

			$this->add_control(
				'title_color',
				[
					'label' => esc_html__( 'Title Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ohc-single-services h3' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'title_typography',
                    'label' => __( 'Title Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .ohc-single-services h3',
                ]
            );

			$this->add_control(
				'content_color',
				[
					'label' => esc_html__( 'Content Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .ohc-single-services p' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'content_typography',
                    'label' => __( 'Content Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .ohc-single-services p',
                ]
            );

			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name'     => 'link_typography',
                    'label'    => __( 'Link Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .ohc-single-services .link-btn',
                ]
            );
        $this->end_controls_section();

    }

    protected function render()
    {
        $settings = $this->get_settings();
        // Card Columns
        $columns = $settings['columns'];
        if ($columns == '1') {
            $column = 'col-lg-12 col-md-6';
        } elseif ($columns == '2') {
            $column = 'col-lg-6 col-md-6';
        } elseif ($columns == '4') {
            $column = 'col-lg-3 col-md-6';
        } else {
            $column = 'col-lg-4 col-md-6';
        }
        ?>

        <div class="container">
            <div class="row justify-content-center">
                <?php $count = 1; foreach( $settings['cards'] as $item ): 
                    if($count % 2 == 0 ):
                        $box_class = 'ohc-single-services bg-FFF2E2';
                    else:
                        $box_class = 'ohc-single-services';
                    endif;
                ?>
                    <div class="<?php echo esc_attr( $column ); ?>">
                        <div class="<?php echo esc_attr( $box_class ); ?>">
                            <?php if($item['image']['url'] != ''): ?>
                                <img src="<?php echo esc_url($item['image']['url']); ?>" alt="<?php echo esc_attr($item['title']); ?>">
                            <?php endif; ?>
                            <h3><?php echo esc_html($item['title']); ?></h3>
                            <p><?php echo wp_kses_post($item['desc']); ?></p>

                            <?php if($item['user_link_text'] != ''):
                                $button_text = $item['user_link_text'];
                                // Get Button Link
                                if($item['link_type'] == 1){
                                    $link = get_page_link( $item['link_to_page'] );
                                } else {
                                    $link = $item['ex_link'];
                                }
                            ?>
                                <a href="<?php echo esc_url($link); ?>" class="link-btn"><?php echo esc_html($button_text); ?></a>
                            <?php endif; ?>
                        </div>
                    </div>
                <?php $count++; endforeach; ?>
            </div>
        </div>

        <?php
    }
}


Plugin::instance()->widgets_manager->register( new OHC_Features_Area );