<?php
/**
 * OHC Feedback Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_OHC_Feedback_Box extends Widget_Base {

	public function get_name() {
        return 'Guto_OHC_Feedback_Box';
    }

	public function get_title() {
        return esc_html__( 'Feedback Area', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-apps';
    }

	public function get_categories() {
        return [ 'guto-online-health-coach' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'Feedback_section',
			[
				'label' => esc_html__( 'Feedback Control', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);

            $repeater = new Repeater();
            $repeater->add_control(
                'rating',
                [
                    'type'        => Controls_Manager::NUMBER,
                    'label'       => esc_html__( 'Rating', 'guto-toolkit' ),
                    'label_block' => true,
                    'default'     => 5,
                ]
            );
            $repeater->add_control(
                'feedback',
                [
                    'type'        => Controls_Manager::TEXTAREA,
                    'label'       => esc_html__( 'Feedback', 'guto-toolkit' ),
                    'label_block' => true,
                ]
            );
            $repeater->add_control(
                'image',
                [
                    'label' => esc_html__( 'Image', 'guto-toolkit' ),
                    'type' => Controls_Manager::MEDIA,
                    'label_block'   => true,
                ]
            );
            $repeater->add_control(
                'name',
                [
                    'label' => esc_html__( 'Name', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default'       => esc_html__( 'John Smith', 'guto-toolkit' ),
                    'label_block'   => true,
                ]
            );
            $repeater->add_control(
                'designation',
                [
                    'label' => esc_html__( 'Designation', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default'       => esc_html__( 'Designer', 'guto-toolkit' ),
                    'label_block'   => true,
                ]
            );
            $this->add_control(
                'items',
                [
                    'label'   => esc_html__( 'Add Item', 'guto-toolkit' ),
                    'type' => Controls_Manager::REPEATER,
                    'fields' => $repeater->get_controls(),
                ]
            );
        $this->end_controls_section();

        // Images
        $this->start_controls_section(
			'banner_images',
			[
				'label' => esc_html__( 'Images', 'guto-toolkit' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
        );
            $this->add_control(
                'image1',
                [
                    'label'		=> esc_html__('Banner Image One', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: MEDIA,
                ]
            );

            $this->add_control(
                'shape1',
                [
                    'label'		=> esc_html__('Shape One', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: MEDIA,
                ]
            );
            $this->add_control(
                'shape2',
                [
                    'label'		=> esc_html__('Shape Two', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: MEDIA,
                ]
            );
            $this->add_control(
                'shape3',
                [
                    'label'		=> esc_html__('Shape Three', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: MEDIA,
                ]
            );
        $this->end_controls_section();

        $this->start_controls_section(
			'counter_style',
			[
				'label' => esc_html__( 'Style', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

            $this->add_control(
                'sec_bg_color',
                [
                    'label' => esc_html__( 'Section Background Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .ohc-feedback-area' => 'background-color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_control(
                'rating_color',
                [
                    'label' => esc_html__( 'Rating Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .single-ohc-feedback-box .rating i' => 'color: {{VALUE}}',
                    ],
                ]
			);

            $this->add_control(
				'feedback_color',
				[
					'label' => esc_html__( 'Feedback Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .single-ohc-feedback-box p' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'feedback_typography',
                    'label' => esc_html__( 'Feedback Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .single-ohc-feedback-box p',
                ]
            );
            $this->add_control(
				'name_color',
				[
					'label' => esc_html__( 'Name Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .single-ohc-feedback-box .client-info .title h5' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'name_typography',
                    'label' => esc_html__( 'Name Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .single-ohc-feedback-box .client-info .title h5',
                ]
            );
            $this->add_control(
				'designation_color',
				[
					'label' => esc_html__( 'Designation Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .single-ohc-feedback-box .client-info .title span' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'designation_typography',
                    'label' => esc_html__( 'Designation Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .single-ohc-feedback-box .client-info .title span',
                ]
            );
        $this->end_controls_section();
    }

	protected function render() {
		$settings = $this->get_settings_for_display(); ?>

        <div class="ohc-feedback-area">
            <div class="container">
                <div class="row align-items-center">
                    <div class="col-lg-7 col-md-12">
                        <div class="ohc-feedback-slides owl-carousel owl-theme">
                            <?php foreach( $settings['items'] as $item ): ?>
                                <div class="single-ohc-feedback-box">
                                    <div class="rating">
                                        <?php for ($i = 1; $i <= $item['rating']; $i++): ?>
                                            <i class='bx bxs-star'></i>
                                        <?php endfor; ?>
                                    </div>
                                    <p><?php echo wp_kses_post( $item['feedback'] ); ?></p>
                                    <div class="client-info">
                                        <div class="d-flex align-items-center">
                                            <?php if( $item['image']['url'] != '' ): ?>
                                                <img src="<?php echo esc_url( $item['image']['url'] ); ?>" alt="<?php echo esc_attr( $item['name'] ) ?>">
                                            <?php endif; ?>
                                            <div class="title">
                                                <h5><?php echo esc_html( $item['name'] ); ?></h5>
                                                <span><?php echo esc_html( $item['designation'] ); ?></span>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            <?php endforeach; ?>
                        </div>
                    </div>

                    <?php if( $settings['image1']['url'] != '' ): ?>
                        <div class="col-lg-5 col-md-12">
                            <div class="ohc-feedback-image">
                                <img src="<?php echo esc_url($settings['image1']['url']); ?>" alt="<?php esc_attr_e('Image', 'guto-toolkit'); ?>">
                            </div>
                        </div>
                    <?php endif; ?>
                </div>
            </div>

            <?php if( $settings['shape1']['url'] != '' ): ?>
                <div class="ohc-feedback-shape-1 wow fadeInUp" data-wow-delay="300ms" data-wow-duration="1500ms">
                    <img src="<?php echo esc_url($settings['shape1']['url']); ?>" alt="<?php esc_attr_e('Shape Image', 'guto-toolkit'); ?>">
                </div>
            <?php endif; ?>

            <?php if( $settings['shape2']['url'] != '' ): ?>
                <div class="ohc-feedback-shape-2 wow fadeInUp" data-wow-delay="300ms" data-wow-duration="1500ms">
                    <img src="<?php echo esc_url($settings['shape2']['url']); ?>" alt="<?php esc_attr_e('Shape Image', 'guto-toolkit'); ?>">
                </div>
            <?php endif; ?>

            <?php if( $settings['shape3']['url'] != '' ): ?>
                <div class="ohc-feedback-shape-3 wow fadeInUp" data-wow-delay="300ms" data-wow-duration="1500ms">
                    <img src="<?php echo esc_url($settings['shape3']['url']); ?>" alt="<?php esc_attr_e('Shape Image', 'guto-toolkit'); ?>">
                </div>
            <?php endif; ?>
        </div>

        <?php
	}


}

Plugin::instance()->widgets_manager->register( new Guto_OHC_Feedback_Box );