<?php
/**
 * OHC Instructor Area Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_OHC_Instructor_Area extends Widget_Base {

	public function get_name() {
        return 'Guto_OHC_Instructor_Area';
    }

	public function get_title() {
        return esc_html__( 'Instructor Area', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-gallery-masonry';
    }

	public function get_categories() {
        return [ 'guto-online-health-coach' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'Instructor_section',
			[
				'label' => esc_html__( 'Instructor Control', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
		);
            $this->add_control(
                'columns',
                [
                    'label' => esc_html__( 'Choose Columns', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        '1'   => esc_html__( '1', 'guto-toolkit' ),
                        '2'   => esc_html__( '2', 'guto-toolkit' ),
                        '3'   => esc_html__( '3', 'guto-toolkit' ),
                        '4'   => esc_html__( '4', 'guto-toolkit' ),
                    ],
                    'default' => '4',
                ]
            );
            $repeater = new Repeater();

            $repeater->add_control(
                'image',
                [
                    'label' => esc_html__( 'Image', 'guto-toolkit' ),
                    'type' => Controls_Manager::MEDIA,
                    'label_block'   => true,
                ]
            );
            $repeater->add_control(
                'name',
                [
                    'label' => esc_html__( 'Name', 'guto-toolkit' ),
                    'type'  => Controls_Manager::TEXT,
                    'default'       => esc_html__( 'John Smith', 'guto-toolkit' ),
                    'label_block'   => true,
                ]
            );
            $repeater->add_control(
                'designation',
                [
                    'label' => esc_html__( 'Designation', 'guto-toolkit' ),
                    'type'  => Controls_Manager::TEXT,
                    'default'       => esc_html__( 'Designer', 'guto-toolkit' ),
                    'label_block'   => true,
                ]
            );
            $this->add_control(
                'items',
                [
                    'label'   => esc_html__( 'Add Item', 'guto-toolkit' ),
                    'type' => Controls_Manager::REPEATER,
                    'fields' => $repeater->get_controls(),
                ]
            );
        $this->end_controls_section();

        $this->start_controls_section(
			'counter_style',
			[
				'label' => esc_html__( 'Style', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);

            $this->add_control(
				'name_color',
				[
					'label' => esc_html__( 'Name Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .single-ohc-instructor-box .content h3' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'name_typography',
                    'label' => esc_html__( 'Name Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}}  .single-ohc-instructor-box .content h3',
                ]
            );
            $this->add_control(
				'designation_color',
				[
					'label' => esc_html__( 'Designation Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}}  .single-ohc-instructor-box .content span' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'designation_typography',
                    'label' => esc_html__( 'Designation Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .single-ohc-instructor-box .content span',
                ]
            );

        $this->end_controls_section();
    }

	protected function render() {
		$settings = $this->get_settings_for_display();

        // Card Columns
        $columns = $settings['columns'];
        if ($columns == '1') {
            $column = 'col-lg-12 col-md-6';
        }elseif ($columns == '2') {
            $column = 'col-lg-6 col-md-6';
        }elseif ($columns == '3') {
            $column = 'col-lg-4 col-md-6';
        }elseif ($columns == '4') {
            $column = 'col-lg-3 col-md-6';
        } ?>
            <div class="container">
                <div class="row justify-content-center">
                    <?php foreach( $settings['items'] as $item ): ?>
                        <div class="<?php echo esc_attr( $column );?>">
                            <div class="single-ohc-instructor-box">
                                <?php if( $item['image']['url'] != '' ): ?>
                                    <img src="<?php echo esc_url( $item['image']['url'] ); ?>" alt="<?php echo esc_attr( $item['name'] ) ?>">
                                <?php endif; ?>

                                <div class="content">
                                    <h3><?php echo esc_html( $item['name'] ); ?></h3>
                                    <span><?php echo esc_html( $item['designation'] ); ?></span>
                                </div>
                            </div>
                        </div>
                    <?php endforeach; ?>
                </div>
            </div>

        <?php
	}


}

Plugin::instance()->widgets_manager->register( new Guto_OHC_Instructor_Area );