<?php
/**
 * OHC Section Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_OHC_Section extends Widget_Base {

	public function get_name() {
        return 'OHC Section';
    }

	public function get_title() {
        return esc_html__( 'Online Health Coach Section', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-handle';
    }

	public function get_categories() {
        return [ 'guto-online-health-coach' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'Guto_Section',
			[
				'label' => esc_html__( 'Guto Section', 'guto-toolkit' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
        );
            $this->add_control(
                'top_title',
                [
                    'label'   => esc_html__( 'Top Title', 'guto-toolkit' ),
                    'type'    => Controls_Manager::TEXT,
                    'default' => esc_html__('OUR COURSES', 'guto-toolkit'),
                ]
            );
            $this->add_control(
                'title',
                [
                    'label'   => esc_html__( 'Title', 'guto-toolkit' ),
                    'type'    => Controls_Manager::TEXTAREA,
                    'default' => esc_html__('Guto Popular Courses', 'guto-toolkit'),
                ]
            );
            $this->add_control(
                'content',
                [
                    'label'   => esc_html__( 'Content', 'guto-toolkit' ),
                    'type'    => Controls_Manager::TEXTAREA,
                    'default' => esc_html__('Lorem ipsum dolor sit amet consectetur adipiscing elit sed do eiusmod tempor incididunt ut labore et dolore magna aliqua quis ipsum suspendisse.', 'guto-toolkit'),
                ]
            );
        $this->end_controls_section();

        $this->start_controls_section(
			'section_style',
			[
				'label' => esc_html__( 'Style', 'guto-toolkit' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
        );
            $this->add_control(
                'top_title_color',
                [
                    'label'     => esc_html__( 'Top Title Color', 'guto-toolkit' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .ohc-section-title span' => 'color: {{VALUE}}',
                    ],
                ]
            );
            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name'     => 'top_title_typography',
                    'label'    => esc_html__( 'Top Title Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .ohc-section-title span',
                ]
            );
            $this->add_control(
                'title_color',
                [
                    'label' => esc_html__( 'Title Color', 'guto-toolkit' ),
                    'type'  => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .ohc-section-title h2, .ohc-section-title h1, .ohc-section-title h3, .ohc-section-title h4, .ohc-section-title h5, .ohc-section-title h6' => 'color: {{VALUE}}',
                    ],
                ]
            );
            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name'     => 'title_typography',
                    'label'    => esc_html__( 'Title Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .ohc-section-title h2, .ohc-section-title h1, .ohc-section-title h3, .ohc-section-title h4, .ohc-section-title h5, .ohc-section-title h6',
                ]
            );
            $this->add_control(
                'content_color',
                [
                    'label'     => esc_html__( 'Content Color', 'guto-toolkit' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .ohc-section-title p, .ohc-section-title ul li, .ohc-section-title ol li' => 'color: {{VALUE}}',
                    ],
                ]
            );
            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name'     => 'content_typography',
                    'label'    => esc_html__( 'Content Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .ohc-section-title p, .ohc-section-title ul li, .ohc-section-title ol li',
                ]
            );
        $this->end_controls_section();

    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        // Inline Editing
        $this-> add_inline_editing_attributes('title','none');
        ?>
            <div class="container">
                <div class="ohc-section-title">
                    <?php if( $settings['top_title'] != '' ): ?>
                        <span class="sub-title"><?php echo wp_kses_post( $settings['top_title'] ); ?></span>
                    <?php endif; ?>

                    <?php if( $settings['title'] != '' ): ?>
                        <h2><?php echo wp_kses_post( $settings['title'] ); ?></h2>
                    <?php endif; ?>

                    <?php if( $settings['content'] != '' ): ?>
                        <p><?php echo wp_kses_post( $settings['content'] ); ?></p>
                    <?php endif; ?>
                </div>
            </div>
        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_OHC_Section );