<?php
/**
 * Product Categories Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_Product_Categories extends Widget_Base {

	public function get_name() {
        return 'Product Categories';
    }

	public function get_title() {
        return esc_html__( 'Product Categories', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-product-categories';
    }

	public function get_categories() {
        return [ 'guto-organic-shop' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'content_section',
			[
				'label' => esc_html__( 'Content', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

        $this->add_control(
                'section_title', [
                    'label'     => esc_html__( 'Title', 'guto-toolkit' ),
                    'type'      => Controls_Manager::TEXT,
                    'default'   => esc_html__('Popular Categories', 'guto-toolkit')
                ]
            );

        $this->add_control(
            'section_desc', [
                'label'     => esc_html__( 'Description', 'guto-toolkit' ),
                'type'      => Controls_Manager::WYSIWYG,
                'default'   => esc_html__('Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Quis ipsum suspendisse ultrices gravida.', 'guto-toolkit'),
            ]
        );

    $this->end_controls_section();

    }

	protected function render() {

        $settings = $this->get_settings_for_display();  ?>

        <!-- Start OS Popular Categories Area -->
        <section class="os-popular-categories-area pb-100">
            <div class="container">
                <div class="section-title">
                    <?php if( ! $settings['section_title'] == '' && ! $settings['section_desc'] == '' || ! $settings['section_title'] == '' || ! $settings['section_desc'] == '' ) : ?>
                        <div class="section-title">
                            <h2><?php echo esc_html__( $settings['section_title'] ); ?></h2>
                            <p><?php echo wp_kses_post( $settings['section_desc'] ); ?></p>
                        </div>
                    <?php endif; ?>
                </div>
                <div class="os-categories-slider owl-carousel owl-theme">
                    <?php
                    $prod_categories = get_terms( 'product_cat', array(
                        'orderby'    => 'name',
                        'order'      => 'ASC',
                        'hide_empty' => true
                    ));
                    foreach( $prod_categories as $prod_cat ) :
                        $cat_thumb_id = get_term_meta( $prod_cat->term_id, 'thumbnail_id', true );
                        $shop_catalog_img = wp_get_attachment_image_src( $cat_thumb_id, 'shop_catalog' );
                        $term_link = get_term_link( $prod_cat, 'product_cat' );?>
                        <div class="os-single-categories">
                            <a href="<?php echo $term_link; ?>">
                                <?php if( ! $shop_catalog_img == '' ) : ?>
                                    <img src="<?php echo $shop_catalog_img[0]; ?>" alt="Image" />
                                <?php endif; ?>
                                <span><?php echo $prod_cat->name; ?></span>
                            </a>
                        </div>
                    <?php endforeach; wp_reset_query(); ?>
                </div>
            </div>
        </section>
        <!-- End OS Popular Categories Area -->

        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_Product_Categories );