<?php
/**
 * Product Slider Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_Products_Slider extends Widget_Base {

	public function get_name() {
        return 'Products_Slider';
    }

	public function get_title() {
        return esc_html__( 'Products Slider', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-post-slider';
    }

	public function get_categories() {
        return [ 'guto-elements' ];
	}
	protected function register_controls() {

        $this->start_controls_section(
			'Guto_Products_Slider',
			[
				'label' => esc_html__( 'Guto Products', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );
            $this->add_control(
                'product_slider_style',
                [
                    'label' => esc_html__( 'Product Slider Style', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        '1'         => esc_html__( 'Style One', 'guto-toolkit' ),
                        '2'         => esc_html__( 'Style Two', 'guto-toolkit' )
                    ],
                    'default' => '1',
                ]
            );

            $this->add_control(
                'section_title', [
                    'label'     => esc_html__( 'Title', 'guto-toolkit' ),
                    'type'      => Controls_Manager::TEXT,
                    'default'   => esc_html__('Top Products', 'guto-toolkit')
                ]
            );

            $this->add_control(
                'section_desc', [
                    'label'     => esc_html__( 'Description', 'guto-toolkit' ),
                    'type'      => Controls_Manager::WYSIWYG,
                    'default'   => esc_html__('Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Quis ipsum suspendisse ultrices gravida.', 'guto-toolkit')
                ]
            );

            $this->add_control(
                'show_product',
                [
                    'label' => esc_html__( 'Show Product By', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        'recent'      => esc_html__( 'Recent products', 'guto-toolkit' ),
                        'trending'    => esc_html__( 'Trending Products', 'guto-toolkit' ),
                        'sellers'     => esc_html__( 'Best Sellers', 'guto-toolkit' ),
                    ],
                    'default' => 'recent',
                ]
            );

            $this->add_control(
                'category_name', [
                    'label' => esc_html__( 'Category Name', 'guto-toolkit' ),
                    'description' => esc_html__( 'Enter the category name slug. Use comma to separate multiple category slugs.', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                ]
            );

            $this->add_control(
                'order',
                [
                    'label' => esc_html__( 'Posts Order By', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        'DESC'      => esc_html__( 'DESC', 'guto-toolkit' ),
                        'ASC'       => esc_html__( 'ASC', 'guto-toolkit' ),
                    ],
                    'default' => 'DESC',
                ]
            );

            $this->add_control(
                'count',
                [
                    'label' => esc_html__( 'Item', 'guto-toolkit' ),
                    'type' => Controls_Manager::NUMBER,
                    'default' => 5,
                ]
            );

            $this->add_control(
                'shape1',
                [
                    'label'     => esc_html__('Shape Image One', 'guto-toolkit'),
                    'type'      => Controls_Manager:: MEDIA,
                    'condition' => [
                        'product_slider_style' => '2',
                    ]
                ]
            );

            $this->add_control(
                'shape2',
                [
                    'label'     => esc_html__('Shape Image Two', 'guto-toolkit'),
                    'type'      => Controls_Manager:: MEDIA,
                    'condition' => [
                        'product_slider_style' => '2',
                    ]
                ]
            );

            $this->add_control(
                'shape3',
                [
                    'label'     => esc_html__('Shape Image Three', 'guto-toolkit'),
                    'type'      => Controls_Manager:: MEDIA,
                    'condition' => [
                        'product_slider_style' => '2',
                    ]
                ]
            );


        $this->end_controls_section();

    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        if ( !guto_toolkit_plugin_active( 'woocommerce/woocommerce.php' ) ) {
            if( is_user_logged_in() ):
                ?>
                <div class="container">
                    <div class="alert alert-danger" role="alert">
                        <?php echo esc_html__( 'Please Install and activated WooCommerce plugin', 'guto-toolkit' ); ?>
                    </div>
                </div>
                <?php
            endif;
			return;
		}

         // Post Query
         if (!empty($settings['category_name'])) {
            if( $settings['show_product'] == 'recent' ):
                $posts = new \WP_Query(array(
                    'post_type'         => 'product',
                    'posts_per_page'    => $settings['count'],
                    'order'             => $settings['order'],
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'product_cat',
                            'field'    => 'slug',
                            'terms'    => explode( ',', str_replace( ' ', '', $settings['category_name'])),
                        ),
                    ),
                ));
            elseif( $settings['show_product'] == 'trending' ):
                $posts = new \WP_Query(array(
                    'post_type'             => 'product',
                    'posts_per_page'        => $settings['count'],
                    'order'                 => $settings['order'],
                    'meta_key'              => 'guto_post_views_count',
                    'ignore_sticky_posts'   => 1,
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'product_cat',
                            'field'    => 'slug',
                            'terms'    => explode( ',', str_replace( ' ', '', $settings['category_name'])),
                        ),
                    ),

                ));

            elseif( $settings['show_product'] == 'sellers' ):
                $posts = new \WP_Query(array(
                    'post_type'             => 'product',
                    'posts_per_page'        => $settings['count'],
                    'order'                 => $settings['order'],
                    'meta_key'              => 'total_sales',
                    'orderby'               => 'meta_value_num',
                    'ignore_sticky_posts'   => 1,
                    'tax_query' => array(
                        array(
                            'taxonomy' => 'product_cat',
                            'field'    => 'slug',
                            'terms'    => explode( ',', str_replace( ' ', '', $settings['category_name'])),
                        ),
                    ),
                ));
            endif;
        }
        else {
            if( $settings['show_product'] == 'recent' ):
                $posts = new \WP_Query(array(
                    'post_type'         => 'product',
                    'posts_per_page'    => $settings['count'],
                    'order'             => $settings['order'],
                ));
            elseif( $settings['show_product'] == 'trending' ):
                $posts = new \WP_Query(array(
                    'post_type'             => 'product',
                    'posts_per_page'        => $settings['count'],
                    'order'                 => $settings['order'],
                    'meta_key'              => 'guto_post_views_count',
                    'ignore_sticky_posts'   => 1,
                ));

            elseif( $settings['show_product'] == 'sellers' ):
                $posts = new \WP_Query(array(
                    'post_type'             => 'product',
                    'posts_per_page'        => $settings['count'],
                    'order'                 => $settings['order'],
                    'meta_key'              => 'total_sales',
                    'orderby'               => 'meta_value_num',
                    'ignore_sticky_posts'   => 1,
                ));
            endif;
        }

		if( $settings['product_slider_style'] == '1' ) : ?>
            <div class="container">
                <?php $i = 0; while($posts->have_posts()): $posts->the_post();  ?>
                <?php ++$i; endwhile; ?>

                <?php if( $i == 1 ): ?>
                    <div class="row four-grid-card text-align-center">
                        <?php while($posts->have_posts()): $posts->the_post(); ?>
                            <?php wc_get_template_part( 'content', 'product' ); ?>
                        <?php endwhile; ?>
                        <?php wp_reset_query(); ?>
                    </div>
                <?php else: ?>
                    <ul class="products-slides owl-carousel owl-theme">
                        <?php while($posts->have_posts()): $posts->the_post(); ?>
                            <?php wc_get_template_part( 'content', 'product' ); ?>
                        <?php endwhile; ?>
                        <?php wp_reset_query(); ?>
                    </ul>
                <?php endif; ?>
            </div>

            <!-- Start Products Modal -->
            <?php while($posts->have_posts()): $posts->the_post();  ?>
                    <div class="modal productsQuickView fade" id="productsQuickView<?php echo esc_attr(get_the_ID());?>" tabindex="-1" role="dialog" aria-hidden="true">
                        <div class="modal-dialog modal-dialog-centered" role="document">
                            <div class="modal-content">
                                <button type="button" class="btn-close close" data-bs-dismiss="modal" aria-label="Close"></button>
                                <div class="row">
                                    <div class="col-lg-6">
                                        <div class="products-image">
                                        <?php the_post_thumbnail( 'full' ); ?>
                                        </div>
                                    </div>

                                    <div class="col-lg-6">
                                        <div class="products-content">
                                            <h3><?php the_title(); ?></h3>
                                            <?php woocommerce_template_loop_price(); ?>
                                            <?php woocommerce_template_loop_rating(); ?>
                                            <?php woocommerce_template_single_excerpt(); ?>

                                            <?php woocommerce_template_single_add_to_cart(); ?>

                                            <div class="product-meta">
                                                <?php woocommerce_template_single_meta(); ?>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
            <?php endwhile; ?>
            <!-- End Products Modal -->
            <?php wp_reset_query();

        elseif( $settings['product_slider_style'] == '2' ) :
            global $post, $product; ?>

            <!-- Start OS Top Products Area -->
            <section class="os-top-products-area ptb-100">
                <div class="container">
                    <?php if( ! $settings['section_title'] == '' && ! $settings['section_desc'] == '' || ! $settings['section_title'] == '' || ! $settings['section_desc'] == '' ) : ?>
                        <div class="section-title">
                            <h2><?php echo esc_html__( $settings['section_title'] ); ?></h2>
                            <p><?php echo wp_kses_post( $settings['section_desc'] ); ?></p>
                        </div>
                    <?php endif; ?>
                    <div class="os-top-product-slider owl-carousel owl-theme">
                        <?php while($posts->have_posts()): $posts->the_post(); ?>
                            <div class="os-single-top-products">
                                <a href="<?php the_permalink(); ?>">
                                    <?php the_post_thumbnail( 'full' ); ?>
                                </a>
                                <div class="os-top-products-content">
                                    <h3>
                                        <a href="<?php the_permalink(); ?>">
                                            <?php the_title(); ?>
                                        </a>
                                    </h3>
                                    <?php woocommerce_template_loop_price(); ?>
                                    <?php woocommerce_template_loop_rating(); ?>
                                </div>
                                <?php woocommerce_show_product_loop_sale_flash(); ?>
                            </div>
                        <?php endwhile; ?>
                    </div>
                </div>
                <?php if( $settings['shape1']['url'] != '' ): ?>
                    <div class="shape shape1">
                        <img src="<?php echo esc_url($settings['shape1']['url']); ?>" alt="<?php esc_attr_e('Shape Image', 'guto-toolkit'); ?>">
                    </div>
                <?php endif; ?>

                <?php if( $settings['shape2']['url'] != '' ): ?>
                    <div class="shape shape2">
                        <img src="<?php echo esc_url($settings['shape2']['url']); ?>" alt="<?php esc_attr_e('Shape Image', 'guto-toolkit'); ?>">
                    </div>
                <?php endif; ?>

                <?php if( $settings['shape3']['url'] != '' ): ?>
                    <div class="shape shape3">
                        <img src="<?php echo esc_url($settings['shape3']['url']); ?>" alt="<?php esc_attr_e('Shape Image', 'guto-toolkit'); ?>">
                    </div>
                <?php endif; ?>
            </section>
        <?php endif;
	}



}

Plugin::instance()->widgets_manager->register( new Guto_Products_Slider );