<?php
/**
 * About Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_RB_About_Area extends Widget_Base {

	public function get_name() {
        return 'Guto_RB_About';
    }

	public function get_title() {
        return esc_html__( 'About', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-info-box';
    }

	public function get_categories() {
        return [ 'guto-recipe-blog' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'Guto_DM_About_Area',
			[
				'label' => esc_html__( 'About Controls', 'guto-toolkit' ),
				'tab' 	=> Controls_Manager::TAB_CONTENT,
			]
		);
            $this->add_control(
                'top_title',
                [
                    'label' 	=> esc_html__( 'Top Title', 'guto-toolkit' ),
                    'type' 		=> Controls_Manager::TEXTAREA,
                    'default' 	=> esc_html__('About Guto Marketing', 'guto-toolkit'),
                ]
            );
			$this->add_control(
				'title',
				[
					'label' 	=> esc_html__( 'Title', 'guto-toolkit' ),
					'type' 		=> Controls_Manager::TEXTAREA,
					'default' 	=> esc_html__('We and Our Team Have been Working Successfully in Digital Marketing for Over 25 Years', 'guto-toolkit'),
				]
			);

			$this->add_control(
                'title_tag',
                [
                    'label' 	=> esc_html__( 'Title Tag', 'guto-toolkit' ),
                    'type' 		=> Controls_Manager::SELECT,
                    'options' 	=> [
                        'h1'         => esc_html__( 'h1', 'guto-toolkit' ),
                        'h2'         => esc_html__( 'h2', 'guto-toolkit' ),
                        'h3'         => esc_html__( 'h3', 'guto-toolkit' ),
                        'h4'         => esc_html__( 'h4', 'guto-toolkit' ),
                        'h5'         => esc_html__( 'h5', 'guto-toolkit' ),
                        'h6'         => esc_html__( 'h6', 'guto-toolkit' ),
                    ],
                    'default' => 'h3',
                ]
            );

			$this->add_control(
				'content',
				[
					'label' 	=> esc_html__( 'Content', 'guto-toolkit' ),
					'type' 		=> Controls_Manager::TEXTAREA,
					'default' 	=> esc_html__('Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Quis ipsum suspendisse ultrices gravida. Risus commodo viverra maecenas accumsan lacus vel facilisis.', 'guto-toolkit'),
				]
            );

			$this->add_control(
				'name_text',
				[
					'label' 	=> esc_html__( 'Name', 'guto-toolkit' ),
					'type' 		=> Controls_Manager::TEXT,
					'default' 	=> esc_html__('Christopher Nolan', 'guto-toolkit'),
				]
            );

			$this->add_control(
				'designation_text',
				[
					'label' 	=> esc_html__( 'Designation', 'guto-toolkit' ),
					'type' 		=> Controls_Manager::TEXT,
					'default' 	=> esc_html__('Manager', 'guto-toolkit'),
				]
            );

            $this->add_control(
                'sig_image',
                [
                    'label'		=> esc_html__('Signature', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: MEDIA,
                ]
            );

            $this->add_control(
                'image1',
                [
                    'label'		=> esc_html__('Image', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: MEDIA,
                ]
            );

        $this->end_controls_section();

        $this->start_controls_section(
			'about_sec_style',
			[
				'label' => esc_html__( 'Style', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
            $this->add_control(
                'top_title_color',
                [
                    'label' => esc_html__( 'Top Title Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .rb-about-content span' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'top_title_typography',
                    'label' => esc_html__( 'Top Title Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .rb-about-content span',
                ]
            );
			$this->add_control(
				'title_color',
				[
					'label' => esc_html__( 'Title Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .rb-about-content h3, .rb-about-content h1, .rb-about-content h2, .rb-about-content h4, .rb-about-content h5, .rb-about-content h6' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'title_typography',
                    'label' => esc_html__( 'Title Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .rb-about-content h3, .rb-about-content h1, .rb-about-content h2, .rb-about-content h4, .rb-about-content h5, .rb-about-content h6',
                ]
            );

			$this->add_control(
				'content_color',
				[
					'label' => esc_html__( 'Content Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .rb-about-content p' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'content_typography',
                    'label' => esc_html__( 'Content Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .rb-about-content p',
                ]
            );

            $this->add_control(
				'name_color',
				[
					'label' => esc_html__( 'Name Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .rb-about-content .signature h4' => 'color: {{VALUE}}',
					],
				]
			);
			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'name_typography',
                    'label' => esc_html__( 'Name Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .rb-about-content .signature h4',
                ]
            );
            $this->add_control(
				'des_color',
				[
					'label' => esc_html__( 'Designation Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .rb-about-content .signature span' => 'color: {{VALUE}}',
					],
				]
			);
			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'des_typography',
                    'label' => esc_html__( 'Designation Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .rb-about-content .signature span',
                ]
            );
        $this->end_controls_section();

    }

	protected function render() {

		$settings = $this->get_settings_for_display();

        ?>

            <div class="container">
                <div class="row align-items-center">
                    <div class="col-lg-6">
                        <div class="rb-about-content">
                            <span><?php echo esc_html( $settings['top_title'] ); ?></span>

                            <<?php echo esc_attr( $settings['title_tag'] ); ?>>
                                <?php echo esc_html( $settings['title'] ); ?>
                            </<?php echo esc_attr( $settings['title_tag'] ); ?>>

                            <?php echo wp_kses_post( $settings['content'] ); ?>

                            <div class="signature">
                                <h4><?php echo esc_html( $settings['name_text'] ); ?></h4>
                                <span><?php echo esc_html( $settings['designation_text'] ); ?></span>

                                <?php if( $settings['sig_image']['url'] != '' ) : ?>
                                    <img src="<?php echo esc_url($settings['sig_image']['url']); ?>" alt="<?php echo esc_attr__('Signature','guto-toolkit'); ?>">
                                <?php endif; ?>
                            </div>
                        </div>
                    </div>

                    <?php if( $settings['image1']['url'] != '' ) : ?>
                        <div class="col-lg-6">
                            <div class="rb-about-image">
                                <img src="<?php echo esc_url($settings['image1']['url']); ?>" alt="<?php echo esc_attr__('image','guto-toolkit'); ?>">
                            </div>
                        </div>
                    <?php endif; ?>
                </div>
            </div>

        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_RB_About_Area );