<?php
/**
 * Recipe Blog Banner Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_RB_Banner extends Widget_Base {

	public function get_name() {
        return 'Guto_RB_Banner';
    }

	public function get_title() {
        return esc_html__( 'Banner', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-banner';
    }

	public function get_categories() {
        return [ 'guto-recipe-blog' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'Guto_DM_Banner_Area',
			[
				'label' => esc_html__( 'Banner Controls', 'guto-toolkit' ),
				'tab' 	=> Controls_Manager::TAB_CONTENT,
			]
		);
            $this->add_control(
                'banner_image',
                [
                    'label'		=> esc_html__('Banner Image', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: MEDIA,
                ]
            );
            $this->add_control(
                'shape_img1',
                [
                    'label'		=> esc_html__('Shape 1', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: MEDIA,
                ]
            );
            $this->add_control(
                'shape_img2',
                [
                    'label'		=> esc_html__('Shape 2', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: MEDIA,
                ]
            );
            $this->add_control(
                'shape_img3',
                [
                    'label'		=> esc_html__('Shape 3', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: MEDIA,
                ]
            );

            $this->add_control(
                'order', [
                    'label'     => __( 'Order', 'guto-toolkit' ),
                    'type'      => Controls_Manager::SELECT,
                    'options'   => [
                        'ASC'  => 'ASC',
                        'DESC' => 'DESC'
                    ],
                    'default' => 'ASC'
                ]
            );

            $this->add_control(
                'cat', [
                    'label'        => __( 'Category', 'guto-toolkit' ),
                    'description'  => __( 'Enter the category slugs separated by commas (Eg. cat1, cat2)', 'guto-toolkit' ),
                    'type'         => Controls_Manager::TEXT,
                    'label_block'  => true,
                ]
            );

            $this->add_control(
                'read_text',
                [
                    'label' => esc_html__( 'Post Reading Time Text', 'guto-toolkit' ),
                    'type'  => Controls_Manager::TEXT,
                ]
            );
            $this->add_control(
                'right_arrow_icon',
                [
                    'label' => esc_html__( 'Right Arrow', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'label_block' => true,
                    'options' => guto_toolkit_icons(),
                ]
            );
            $this->add_control(
                'link_type',
                [
                    'label' 		=> esc_html__( 'Arrow Link Type', 'guto-toolkit' ),
                    'type' 			=> Controls_Manager::SELECT,
                    'label_block' 	=> true,
                    'options' => [
                        '1'  	=> esc_html__( 'Link To Page', 'guto-toolkit' ),
                        '2' 	=> esc_html__( 'External Link', 'guto-toolkit' ),
                    ],
                    'default' => '2'
                ]
            );

            $this->add_control(
                'link_to_page',
                [
                    'label' 		=> esc_html__( 'Link Page', 'guto-toolkit' ),
                    'type' 			=> Controls_Manager::SELECT,
                    'label_block' 	=> true,
                    'options' 		=> guto_toolkit_get_page_as_list(),
                    'condition' => [
                        'link_type' => '1',
                    ]
                ]
            );

            $this->add_control(
                'ex_link',
                [
                    'label'		=> esc_html__('External Link', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: URL,
                    'show_external' => true,
                    'default' => [
                        'url' => '#',
                        'is_external' => true,
                        'nofollow' => true,
                    ],
                    'condition' => [
                        'link_type' => '2',
                    ]
                ]
            );
        $this->end_controls_section();

        $this->start_controls_section(
			'banner_style',
			[
				'label' => esc_html__( 'Style', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
            $this->add_control(
				'background_color',
				[
					'label' => esc_html__( 'Background Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .rb-banner-area' => 'background-color: {{VALUE}}',
					],
                    'separator' => 'before',
				]
			);

            $this->add_control(
				'top_title_color',
				[
					'label' => esc_html__( 'Top Title Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .rb-banner-content span a' => 'color: {{VALUE}}',
					],
                    'separator' => 'before',
				]
			);
			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'top_title_typography',
                    'label' => esc_html__( 'Top Title Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .rb-banner-content span a',
                ]
            );
			$this->add_control(
				'title_color',
				[
					'label' => esc_html__( 'Title Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .rb-banner-content h1 a' => 'color: {{VALUE}}',
					],
                    'separator' => 'before',
				]
			);
			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'title_typography',
                    'label' => esc_html__( 'Title Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .rb-banner-content h1 a',
                ]
            );
			$this->add_control(
				'content_color',
				[
					'label' => esc_html__( 'Content Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .rb-banner-content p' => 'color: {{VALUE}}',
					],
				]
			);

			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'content_typography',
                    'label' => esc_html__( 'Content Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .rb-banner-content p',
                ]
            );
            $this->add_control(
				'meta_color',
				[
					'label' => esc_html__( 'Meta Color', 'guto-toolkit' ),
					'type' => Controls_Manager::COLOR,
					'selectors' => [
						'{{WRAPPER}} .rb-banner-content .banner-list li' => 'color: {{VALUE}}',
					],
				]
			);
			$this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'meta_typography',
                    'label' => esc_html__( 'Meta Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .rb-banner-content .banner-list li',
                ]
            );
        $this->end_controls_section();

    }

	protected function render() {

		$settings = $this->get_settings_for_display();

        // Arrow Link
        if($settings['link_type'] == 1){
            $link = get_page_link( $settings['link_to_page'] );
        } elseif($settings['link_type'] == 2) {
            $link = $settings['ex_link']['url'];
            $target = $settings['ex_link']['is_external'] ? ' target="_blank"' : '';
		    $nofollow = $settings['ex_link']['nofollow'] ? ' rel="nofollow"' : '';
        }

        // Left Post Arg
        if ( !empty($settings['cat']) ) {
            $post_array = new \WP_Query(array(
                'post_type'         => 'post',
                'posts_per_page'    => 1,
                'order'             => $settings['order'],
                'tax_query'         => array(
                    array(
                        'taxonomy' => 'category',
                        'field'    => 'slug',
                        'terms'    => explode( ',', str_replace( ' ', '', $settings['cat'])),
                    ),
                ),
            ));
        } else {
            $post_array = new \WP_Query(array(
                'post_type'        => 'post',
                'posts_per_page'   => 1,
                'order'            => $settings['order'],
            ));
        } ?>
            <div class="rb-banner-area">
                <div class="container">
                    <div class="row align-items-center">
                        <?php
                            while($post_array->have_posts()): $post_array->the_post();
                            $categories = get_the_category();
                        ?>
                        <div class="col-lg-6 col-md-12">
                            <div class="rb-banner-content">
                                <?php if ( ! empty( $categories ) ) { ?>
                                    <span class="wow fadeInLeft" data-wow-delay="500ms" data-wow-duration="1500ms">
                                        <a href="<?php echo esc_url( get_category_link( $categories[0]->term_id ) ) ?>"><?php echo esc_html( $categories[0]->name ) ?></a>
                                    </span>
                                <?php } ?>

                                <h1 class="wow fadeInLeft" data-wow-delay="100ms" data-wow-duration="1000ms"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h1>

                                <p class="wow fadeInLeft" data-wow-delay="300ms" data-wow-duration="1500ms"><?php echo get_the_excerpt()?></p>

                                <ul class="banner-list wow fadeInRight" data-wow-delay="300ms" data-wow-duration="1500ms">
                                    <li> <?php echo esc_html(get_the_date('M d, y')) ?></li>
                                    <li> <?php echo esc_html(guto_lite_reading_time()) ?>
                                        <?php echo esc_html($settings['read_text']); ?>
                                    </li>
                                    <li><?php comments_number(); ?></li>
                                </ul>
                            </div>
                        </div>

                        <div class="col-lg-6 col-md-12">
                            <div class="rb-banner-image wow fadeInRight" data-wow-delay="300ms" data-wow-duration="1500ms">
                                <?php if( !empty( $settings['banner_image']['url'] )): ?>
                                    <img src="<?php echo esc_url( $settings['banner_image']['url'] ); ?>" alt="<?php echo esc_attr__('Image','guto-toolkit');?>">
                                <?php endif;?>

                                <?php if( $settings['right_arrow_icon'] != '' ): ?>
                                    <div class="right-arrow">
                                        <?php if($settings['link_type'] == 1) : ?>
                                            <a href="<?php echo esc_url( $link ); ?>">
                                                <i class="<?php echo esc_attr( $settings['right_arrow_icon'] ); ?>"></i>
                                            </a>
                                        <?php elseif($settings['link_type'] == 2) :
                                            echo '<a href="' .  $link . '" ' . $target . $nofollow . '> <i class="'.$settings['right_arrow_icon'].'"></i> </a>';
                                        endif; ?>
                                    </div>
                                <?php endif; ?>
                            </div>
                        </div>
                        <?php
                            endwhile;
                            wp_reset_postdata();
                        ?>
                    </div>
                </div>

                <?php if( !empty( $settings['shape_img1']['url'] )): ?>
                <div class="rb-banner-shape-1 wow fadeInLeft" data-wow-delay="300ms" data-wow-duration="1500ms">
                    <img src="<?php echo esc_url( $settings['shape_img1']['url'] ); ?>" alt="<?php echo esc_attr__('Shape1','guto-toolkit');?>">
                </div>
                <?php endif;?>

                <?php if( !empty( $settings['shape_img2']['url'] )): ?>
                <div class="rb-banner-shape-2">
                    <img src="<?php echo esc_url( $settings['shape_img2']['url'] ); ?>" alt="<?php echo esc_attr__('Shape2','guto-toolkit');?>">
                </div>
                <?php endif;?>

                <?php if( !empty( $settings['shape_img3']['url'] )): ?>
                <div class="rb-square-shape">
                    <img src="<?php echo esc_url( $settings['shape_img3']['url'] ); ?>" alt="<?php echo esc_attr__('Shape3','guto-toolkit');?>">
                </div>
                <?php endif;?>
            </div>

        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_RB_Banner );