<?php
/**
 * RB Recipe Posts Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_RB_Blog_Posts extends Widget_Base {

	public function get_name() {
        return 'Guto_RB_Blog_Posts';
    }

	public function get_title() {
        return esc_html__( 'Recipe Blog', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-post-slider';
    }

	public function get_categories() {
        return [ 'guto-recipe-blog' ];
	}
	protected function _register_controls() {

        $this->start_controls_section(
			'Guto_RB_Posts',
			[
				'label' => esc_html__( 'Guto Posts', 'guto-toolkit' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
        );
            $this->add_control(
                'columns',
                [
                    'label' => esc_html__( 'Choose Columns', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        '1'   => esc_html__( '1', 'guto-toolkit' ),
                        '2'   => esc_html__( '2', 'guto-toolkit' ),
                        '3'   => esc_html__( '3', 'guto-toolkit' ),
                        '4'   => esc_html__( '4', 'guto-toolkit' ),
                    ],
                    'default' => '2',
                ]
            );

            $this->add_control(
                'cat', [
                    'label' => esc_html__( 'Category', 'guto-toolkit' ),
                    'description' => esc_html__( 'Enter the category slugs separated by commas (Eg. cat1, cat2)', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'label_block' => true,
                ]
            );

            $this->add_control(
                'order',
                [
                    'label' => esc_html__( 'Posts Order By', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        'DESC'      => esc_html__( 'DESC', 'guto-toolkit' ),
                        'ASC'       => esc_html__( 'ASC', 'guto-toolkit' ),
                    ],
                    'default' => 'DESC',
                ]
            );

            $this->add_control(
                'count',
                [
                    'label'   => esc_html__( 'Item', 'guto-toolkit' ),
                    'type'    => Controls_Manager::NUMBER,
                    'default' => 6,
                ]
            );
            $this->add_control(
                'read_text',
                [
                    'label' => esc_html__( 'Post Reading Time Text', 'guto-toolkit' ),
                    'type'  => Controls_Manager::TEXT,
                ]
            );
            $this->add_control(
                'count_excerpt', [
                    'label'       => __( 'Show excerpt word', 'guto-toolkit' ),
                    'type'        => Controls_Manager::NUMBER,
                    'label_block' => true,
                    'default'     => 12,
                ]
            );

            $this->add_control(
				'pagination_show',
				[
					'label'        => __( 'Show Pagination?', 'guto-toolkit' ),
					'type'         => Controls_Manager::SWITCHER,
					'label_on'     => __( 'Show', 'vaximo-toolkit' ),
					'label_off'    => __( 'Hide', 'vaximo-toolkit' ),
					'return_value' => 'yes',
                    'default'      => 'no',
				]
            );
        $this->end_controls_section();

        $this->start_controls_section(
			'blog_styledm',
			[
				'label' => esc_html__( 'Style Controls', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
        );

            $this->add_control(
                'cat_color',
                [
                    'label' => esc_html__( 'Category Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .rb-single-blog .blog-content span a' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'cat_typography',
                    'label' => esc_html__( 'Category Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .rb-single-blog .blog-content span a',
                ]
            );
            $this->add_control(
                'title_color',
                [
                    'label' => esc_html__( 'Title Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .rb-single-blog .blog-content h3 a' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'title_typography',
                    'label' => esc_html__( 'Title Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .rb-single-blog .blog-content h3 a',
                ]
            );
            $this->add_control(
                'con_color',
                [
                    'label' => esc_html__( 'Exceprt Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .rb-single-blog .blog-content p' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'excerpt_typography',
                    'label' => esc_html__( 'Exceprt Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .rb-single-blog .blog-content p',
                ]
            );

            $this->add_control(
                'meta_color',
                [
                    'label' => esc_html__( 'Meta Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .rb-single-blog .blog-content .blog-list li' => 'color: {{VALUE}}',
                    ],
                ]
            );
            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'meta_typography',
                    'label' => esc_html__( 'Meta Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .rb-single-blog .blog-content .blog-list li',
                ]
            );
        $this->end_controls_section();

    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        // Card Columns
        $columns = $settings['columns'];
        if ($columns == '1') {
            $column = 'col-lg-12 col-md-6';
        }elseif ($columns == '2') {
            $column = 'col-lg-6 col-md-6';
        }elseif ($columns == '3') {
            $column = 'col-lg-4 col-md-6';
        }elseif ($columns == '4') {
            $column = 'col-lg-3 col-md-6';
        }

        // Post Query
        if( $settings['cat'] != '' ) {
            $paged = ( get_query_var( 'paged' ) ) ? get_query_var( 'paged' ) : 1;
            $args = array(
                'post_type'     => 'post',
                'posts_per_page'=> $settings['count'],
                'order'         => $settings['order'],
                'paged' => $paged,
                'tax_query'     => array(
                    array(
                        'taxonomy'      => 'category',
                        'field'         => 'slug',
                        'terms'         => $settings['cat'],
                        'hide_empty'    => false
                    )
                )
            );
        } else {
            $paged = ( get_query_var( 'paged' ) ) ? get_query_var( 'paged' ) : 1;
            $args = array(
                'post_type'         => 'post',
                'posts_per_page'    => $settings['count'],
                'order'             => $settings['order'],
                'paged' => $paged
            );
        }
        $post_array = new \WP_Query( $args ); ?>

            <div class="container">
                <div class="row justify-content-center">
                    <?php while($post_array->have_posts()): $post_array->the_post();
                        $categories = get_the_category();
                    ?>
                        <div class="<?php echo esc_attr( $column );?>">
                            <div class="rb-single-blog wow fadeInUp" data-wow-delay="50ms" data-wow-duration="500ms">

                                <?php if(get_the_post_thumbnail_url() != ''): ?>
                                    <div class="blog-image">
                                        <a href="<?php the_permalink(); ?>">
                                            <img src="<?php echo get_the_post_thumbnail_url( get_the_ID(), 'guto_lite_dm_thumb_size' ); ?>" alt="<?php the_post_thumbnail_caption();  ?>">
                                        </a>
                                    </div>
                                <?php endif; ?>

                                <div class="blog-content">
                                    <?php if( !empty( $categories ) ) : ?>
                                        <span>
                                            <a href="<?php echo esc_url( get_category_link( $categories[0]->term_id ) ) ?>">
                                                <?php echo esc_html( $categories[0]->name ); ?>
                                            </a>
                                        </span>
                                    <?php endif; ?>

                                    <h3><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>

                                    <p><?php echo esc_html(wp_trim_words( get_the_excerpt(), $settings['count_excerpt'], '' )); ?></p>

                                    <ul class="blog-list">
                                        <li> <?php echo esc_html(get_the_date('M d, y')) ?></li>
                                        <li> <?php echo esc_html(guto_lite_reading_time()) ?>
                                            <?php echo esc_html($settings['read_text']); ?>
                                        </li>
                                        <li><?php comments_number(); ?></li>
                                    </ul>
                                </div>
                            </div>
                        </div>
                    <?php endwhile; ?>
                    <?php wp_reset_query(); ?>


                    <?php if ( $settings['pagination_show'] == 'yes' ) { ?>
                        <div class="col-lg-12 col-md-12">
                            <div class="rb-pagination-area">
                                <div class="nav-links">
                                <?php
                                $big = 999999999; // need an unlikely integer
                                echo paginate_links( array(
                                    'base' => str_replace( $big, '%#%', get_pagenum_link( $big ) ),
                                    'format' => '?paged=%#%',
                                    'current' => max(1, get_query_var('paged') ),
                                    'total' => $post_array->max_num_pages,
                                    //'format' => '?paged=%#%',
                                    'prev_text' => '<i class="bx bx-chevron-left"></i>',
                                    'next_text' => '<i class="bx bx-chevron-right"></i>',
                                ) ); ?>
                                </div>
                            </div>
                        </div>
                    <?php } ?>

                </div>
            </div>

        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_RB_Blog_Posts );