<?php
/**
 * Categories Widget
 */

namespace Elementor;
class Guto_RB_Categories extends Widget_Base {

	public function get_name() {
        return 'Guto_RB_Categories';
    }

	public function get_title() {
        return esc_html__( 'Categories', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-tools';
    }

	public function get_categories() {
        return [ 'guto-recipe-blog' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'cat_section',
			[
				'label' => esc_html__( 'Categories', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );
            $this->add_control(
                'count',
                [
                    'label' => esc_html__( 'Post Per Page', 'guto-toolkit' ),
                    'type' => Controls_Manager::NUMBER,
                    'default' => 9,
                ]
            );
        $this->end_controls_section();

        $this->start_controls_section(
			'cat_style',
			[
				'label' => esc_html__( 'Posts Style', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
        );
            $this->add_control(
                'sec_bg_color',
                [
                    'label' => esc_html__( 'Background Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .rb-food-area' => 'background-color: {{VALUE}}',
                    ],
                ]
            );
            $this->add_control(
                'post_title_color',
                [
                    'label' => esc_html__( 'Title Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .rb-food-item span a' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'posttitle_typography',
                    'label' => esc_html__( 'Title Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .rb-food-item span a',
                ]
            );
        $this->end_controls_section();

    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        ?>

        <div class="container-fluid">
            <div class="rb-food-slides owl-carousel owl-theme wow fadeInUp" data-wow-delay="300ms" data-wow-duration="1500ms">
                <?php $categories = get_terms( ['taxonomy' => 'recipe_cat'] ); ?>

                <?php  $i = 1;
                foreach($categories as $key => $category) {
                    $term = get_term_by('slug', $category->name, 'recipe_cat');
                    $cat_image		 = fw_get_db_term_option($term->term_id , 'recipe_cat', 'recipe_cat_image' );
                ?>
                    <div class="rb-food-item">
                        <?php if( !empty($cat_image[ 'url' ])) : ?>
                        <a href="<?php echo esc_url( get_term_link($category) ); ?>">
                            <img src="<?php echo esc_url( $cat_image[ 'url' ]); ?>" alt="<?php echo esc_attr__('Image', 'guto-toolkit'); ?>">
                        </a>
                        <?php endif; ?>

                        <span><a href="<?php echo esc_url( get_term_link($category) ); ?>"><?php echo esc_html($category->name); ?></a></span>
                    </div>
                <?php if( $i == $settings['count']  ){ break; }
                    $i++;
                } ?>

            </div>
        </div>

        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_RB_Categories );