<?php
/**
 * Contact Area Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_RB_Contact_Area extends Widget_Base {

	public function get_name() {
        return 'RB_Contact_Area';
    }

	public function get_title() {
        return esc_html__( 'Contact Area', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-form-horizontal';
    }

	public function get_categories() {
        return [ 'guto-recipe-blog' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
            'Guto_Contact_Area',
            [
                'label' => esc_html__( 'Guto Contact Area', 'guto-toolkit' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

            $this->add_control(
                'title',
                [
                    'label'     => esc_html__( 'Info Title', 'guto-toolkit' ),
                    'type'      => Controls_Manager::TEXT,
                    'default'   => esc_html__('Contact Information', 'guto-toolkit'),
                ]
            );
            $this->add_control(
                'content',
                [
                    'label'     => esc_html__( 'Info Content', 'guto-toolkit' ),
                    'type'      => Controls_Manager::TEXTAREA,
                ]
            );


            $this->add_control(
                'form_title',
                [
                    'label'     => esc_html__( 'Form Title', 'guto-toolkit' ),
                    'type'      => Controls_Manager::TEXT,
                    'default'   => esc_html__('Contact With Us', 'guto-toolkit'),
                ]
            );
            // Form
            $this->add_control(
                'shortcode',
                [
                    'label' => esc_html__( 'Contact Shortcode', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                ]
            );

        $this->end_controls_section();
    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        ?>
            <div class="container">
                <div class="row">
                    <div class="col-lg-4 col-md-12">
                        <div class="rb-contact-address">
                            <h3><?php echo esc_html( $settings['title'] ); ?></h3>
                            <ul class="address-info">
                                <?php echo wp_kses_post( $settings['content'] ); ?>
                            </ul>
                        </div>
                    </div>

                    <div class="col-lg-8 col-md-12">
                        <div class="rb-contact-form">
                            <h3><?php echo esc_html( $settings['form_title'] ); ?></h3>

                            <?php if($settings['shortcode']): ?>
                                <div id="contactForm">
                                    <?php echo do_shortcode( $settings['shortcode'] ); ?>
                                </div>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
            </div>
        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_RB_Contact_Area );