<?php
/**
 * RB Posts Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_RB_Posts extends Widget_Base {

	public function get_name() {
        return 'Guto_RBPosts';
    }

	public function get_title() {
        return esc_html__( 'Latest Posts', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-post-slider';
    }

	public function get_categories() {
        return [ 'guto-recipe-blog' ];
	}
	protected function _register_controls() {

        $this->start_controls_section(
			'Guto_RB_Posts',
			[
				'label' => esc_html__( 'Guto Posts', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );
            $this->add_control(
                'columns',
                [
                    'label' => esc_html__( 'Choose Columns', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        '1'   => esc_html__( '1', 'guto-toolkit' ),
                        '2'   => esc_html__( '2', 'guto-toolkit' ),
                        '3'   => esc_html__( '3', 'guto-toolkit' ),
                        '4'   => esc_html__( '4', 'guto-toolkit' ),
                    ],
                    'default' => '2',
                ]
            );

            $this->add_control(
                'cat', [
                    'label' => esc_html__( 'Category', 'guto-toolkit' ),
                    'description' => esc_html__( 'Enter the category slugs separated by commas (Eg. cat1, cat2)', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'label_block' => true,
                ]
            );

            $this->add_control(
                'order',
                [
                    'label' => esc_html__( 'Posts Order By', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        'DESC'      => esc_html__( 'DESC', 'guto-toolkit' ),
                        'ASC'       => esc_html__( 'ASC', 'guto-toolkit' ),
                    ],
                    'default' => 'DESC',
                ]
            );

            $this->add_control(
                'count',
                [
                    'label'   => esc_html__( 'Item', 'guto-toolkit' ),
                    'type'    => Controls_Manager::NUMBER,
                    'default' => 6,
                ]
            );
            $this->add_control(
                'read_text',
                [
                    'label' => esc_html__( 'Post Reading Time Text', 'guto-toolkit' ),
                    'type'  => Controls_Manager::TEXT,
                ]
            );
        $this->end_controls_section();

        $this->start_controls_section(
			'blog_styledm',
			[
				'label' => esc_html__( 'Style Controls', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
        );

            $this->add_control(
                'cat_color',
                [
                    'label' => esc_html__( 'Category Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .rb-single-recipes .recipes-content span a' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'cat_typography',
                    'label' => esc_html__( 'Category Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .rb-single-recipes .recipes-content span a',
                ]
            );
            $this->add_control(
                'title_color',
                [
                    'label' => esc_html__( 'Title Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .rb-single-recipes .recipes-content h3 a' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'title_typography',
                    'label' => esc_html__( 'Title Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .rb-single-recipes .recipes-content h3 a',
                ]
            );
            $this->add_control(
                'con_color',
                [
                    'label' => esc_html__( 'Exceprt Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .rb-single-recipes .recipes-content p' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'excerpt_typography',
                    'label' => esc_html__( 'Exceprt Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .rb-single-recipes .recipes-content p',
                ]
            );

            $this->add_control(
                'meta_color',
                [
                    'label' => esc_html__( 'Meta Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .rb-single-recipes .recipes-content .recipes-list li' => 'color: {{VALUE}}',
                    ],
                ]
            );
            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'meta_typography',
                    'label' => esc_html__( 'Meta Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .rb-single-recipes .recipes-content .recipes-list li',
                ]
            );

        $this->end_controls_section();

    }

	protected function render() {

        $settings = $this->get_settings_for_display();


         // Card Columns
        $columns = $settings['columns'];
        if ($columns == '1') {
            $column = 'col-lg-12 col-md-6';
        }elseif ($columns == '2') {
            $column = 'col-lg-6 col-md-6';
        }elseif ($columns == '3') {
            $column = 'col-lg-4 col-md-6';
        }elseif ($columns == '4') {
            $column = 'col-lg-3 col-md-6';
        }

        // Post Query
        if( $settings['cat'] != '' ) {
            $args = array(
                'post_type'     => 'recipes',
                'posts_per_page'=> $settings['count'],
                'order'         => $settings['order'],
                'tax_query'     => array(
                    array(
                        'taxonomy'      => 'recipe_cat',
                        'field'         => 'slug',
                        'terms'         => $settings['cat'],
                        'hide_empty'    => false
                    )
                )
            );
        } else {
            $args = array(
                'post_type'         => 'recipes',
                'posts_per_page'    => $settings['count'],
                'order'             => $settings['order']
            );
        }
        $post_array = new \WP_Query( $args ); ?>

            <div class="row justify-content-center">
                <?php while($post_array->have_posts()): $post_array->the_post();
                    //$categories = get_the_category();
                    $terms = get_the_terms( get_the_ID() , 'recipe_cat' );
                ?>
                    <div class="<?php echo esc_attr( $column );?>">
                        <div class="rb-single-recipes wow fadeInUp" data-wow-delay="50ms" data-wow-duration="500ms">

                            <?php if(get_the_post_thumbnail_url() != ''): ?>
                                <div class="recipes-image">
                                    <a href="<?php the_permalink(); ?>">
                                        <img src="<?php echo get_the_post_thumbnail_url( get_the_ID(), 'guto_lite_dm_thumb_size' ); ?>" alt="<?php the_post_thumbnail_caption();  ?>">
                                    </a>
                                </div>
                            <?php endif; ?>

                            <div class="recipes-content">
                                <?php if( !empty( $terms ) ) : ?>
                                    <span>
                                        <a href="<?php echo esc_url( get_category_link( $terms[0]->term_id ) ) ?>">
                                            <?php echo esc_html( $terms[0]->name ); ?>
                                        </a>
                                    </span>
                                <?php endif; ?>

                                <h3><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>

                                <?php the_excerpt(); ?>

                                <ul class="recipes-list">
                                    <li> <?php echo esc_html(get_the_date('M d, y')) ?></li>
                                    <li> <?php echo esc_html(guto_lite_reading_time()) ?>
                                        <?php echo esc_html($settings['read_text']); ?>
                                    </li>
                                    <li><?php comments_number(); ?></li>
                                </ul>
                            </div>
                        </div>
                    </div>
                <?php endwhile; ?>
                <?php wp_reset_query(); ?>
            </div>

        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_RB_Posts );