<?php
/**
 * RB Newsletter Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_RB_Newsletter extends Widget_Base {

	public function get_name() {
        return 'Guto_RB_Newsletter';
    }

	public function get_title() {
        return __( 'Newsletter', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-email-field';
    }

	public function get_categories() {
        return [ 'guto-recipe-blog' ];
    }

    public function get_keywords() {
        return [ 'mailchimp', 'form', 'newsletter' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'Guto_Newsletter',
			[
				'label' => esc_html__( 'Newsletter', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

            $this->add_control(
                'title', [
                    'label' => esc_html__( 'Newsletter Title', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__( 'Subscribe Newsletter' , 'guto-toolkit' ),
                    'label_block' => true,
                ]
            );
            $this->add_control(
                'news_img',
                [
                    'label' => esc_html__( 'Image', 'guto-toolkit' ),
                    'type' => Controls_Manager::MEDIA,
                    'label_block' => true,
                ]
            );

            $this->add_control(
                'action_url', [
                    'label' => esc_html__( 'Action URL', 'guto-toolkit' ),
                    'description' => esc_html__( 'Enter here your MailChimp action URL. <a href="https://doc.gutotheme.com/docs/tips-guides-troubleshoots/get-mailchimp-newsletter-form-action-url/" target="_blank"> How to </a>', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'label_block' => true,
                ]
            );
            $this->add_control(
                'news_title', [
                    'label' => esc_html__( 'Newsletter Title', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__( 'Subscribe to Our Newsletter To Avail Your Cookbook' , 'guto-toolkit' ),
                    'label_block' => true,
                ]
            );
            $this->add_control(
                'placeholder_text', [
                    'label' => esc_html__( 'Email Placeholder Text', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__( 'Your email' , 'guto-toolkit' ),
                    'label_block' => true,
                ]
            );

            $this->add_control(
                'button_text', [
                    'label' => esc_html__( 'Button Text', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__( 'Subscribe' , 'guto-toolkit' ),
                    'label_block' => true,
                ]
            );
        $this->end_controls_section();

        $this->start_controls_section(
			'newsletter_style',
			[
				'label' => esc_html__( 'Style', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
        );
            $this->add_control(
                'card_bg_color',
                [
                    'label' => esc_html__( 'Card Background Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .widget_newsletter .newsletter-content' => 'background-color: {{VALUE}}',
                    ],
                ]
            );
            $this->add_control(
                'sec_title_color',
                [
                    'label' => esc_html__( 'Section Title Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}}  .widget .widget-title' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'sectitle_typography',
                    'label' => esc_html__( 'Section Title Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .widget .widget-title',
                ]
            );

            $this->add_control(
                'news_title_color',
                [
                    'label' => esc_html__( 'Newsletter Title Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}}  .widget_newsletter .newsletter-content h3' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'news_title_typography',
                    'label' => esc_html__( 'Newsletter Title Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .widget_newsletter .newsletter-content h3',
                ]
            );

            $this->add_control(
                'btn_color',
                [
                    'label' => esc_html__( 'Button Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .rb-default-btn' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'btn_typography',
                    'label' => esc_html__( 'Button Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .rb-default-btn',
                ]
            );

        $this->end_controls_section();
    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        // Inline Editing
        $this-> add_inline_editing_attributes('title','none');

        ?>

            <div class="widget widget_newsletter">

                <?php if(!empty( $settings['title'] )) : ?>
                    <h3 class="widget-title"><?php echo esc_html( $settings['title'] ); ?></h3>
                <?php endif; ?>

                <?php if( $settings['news_img']['url'] != '' ): ?>
                    <img src="<?php echo esc_url( $settings['news_img']['url'] ); ?>" alt="<?php echo esc_attr( $settings['title'] ); ?>">
                <?php endif; ?>

                <div class="newsletter-content">
                    <?php if(!empty( $settings['news_title'] )) : ?>
                        <h3><?php echo esc_html( $settings['news_title'] ); ?></h3>
                    <?php endif; ?>

                    <form class="mailchimp newsletter-form" method="post">
                        <div class="form-group">
                            <input type="email" class="form-control memail" placeholder="<?php echo esc_attr($settings['placeholder_text']); ?>" name="EMAIL" required>
                        </div>

                        <?php if( $settings['button_text'] != '' ): ?>
                            <button type="submit" class="rb-default-btn"><?php echo esc_html( $settings['button_text'] ); ?></button>
                        <?php endif; ?>

                        <p class="mchimp-errmessage" style="display: none;"></p>
                        <p class="mchimp-sucmessage" style="display: none;"></p>
                    </form>

                </div>
            </div>

            <script>
                ;(function($){
                    "use strict";
                    $(document).ready(function () {
                        // MAILCHIMP
                        if ($(".mailchimp").length > 0) {
                            $(".mailchimp").ajaxChimp({
                                callback: mailchimpCallback,
                                url: "<?php echo esc_js($settings['action_url']) ?>"
                            });
                        }
                        if ($(".mailchimp_two").length > 0) {
                            $(".mailchimp_two").ajaxChimp({
                                callback: mailchimpCallback,
                                url: "<?php echo esc_js($settings['action_url']) ?>" //Replace this with your own mailchimp post URL. Don't remove the "". Just paste the url inside "".
                            });
                        }
                        $(".memail").on("focus", function () {
                            $(".mchimp-errmessage").fadeOut();
                            $(".mchimp-sucmessage").fadeOut();
                        });
                        $(".memail").on("keydown", function () {
                            $(".mchimp-errmessage").fadeOut();
                            $(".mchimp-sucmessage").fadeOut();
                        });
                        $(".memail").on("click", function () {
                            $(".memail").val("");
                        });

                        function mailchimpCallback(resp) {
                            if (resp.result === "success") {
                                $(".mchimp-errmessage").html(resp.msg).fadeIn(1000);
                                $(".mchimp-sucmessage").fadeOut(500);
                            } else if (resp.result === "error") {
                                $(".mchimp-errmessage").html(resp.msg).fadeIn(1000);
                            }
                        }
                    });
                })(jQuery)
            </script>
    <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_RB_Newsletter );