<?php
/**
 * RB Recipe Category Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_RB_Recipe_Cat extends Widget_Base {

	public function get_name() {
        return 'Guto_RB_Recipe_Cat';
    }

	public function get_title() {
        return __( 'Recipe Category', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-tags';
    }

	public function get_categories() {
        return [ 'guto-recipe-blog' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'Guto_Post_Tag',
			[
				'label' => esc_html__( 'Recipe Category', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );
            $this->add_control(
                'title', [
                    'label'   => esc_html__( 'Title', 'guto-toolkit' ),
                    'type'    => Controls_Manager::TEXT,
                    'default' => esc_html__( 'Top Categories' , 'guto-toolkit' ),
                    'label_block' => true,
                ]
            );
            $this->add_control(
                'count',
                [
                    'label' => esc_html__( 'Count Category Number', 'guto-toolkit' ),
                    'type' => Controls_Manager::NUMBER,
                    'default' => 6,
                ]
            );
        $this->end_controls_section();

        $this->start_controls_section(
			'newsletter_style',
			[
				'label' => esc_html__( 'Style', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
        );
            $this->add_control(
                'title_color',
                [
                    'label' => esc_html__( 'Title Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .widget-title' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'title_typography',
                    'label' => esc_html__( 'Title Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}}  .widget-title',
                ]
            );

        $this->end_controls_section();
    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        $taxonomy = 'recipe_cat';
        $terms = get_terms($taxonomy) ;
        $i = 1; ?>

        <div class="widget widget_categories">
            <?php if($settings['title']): ?>
                <h3 class="widget-title"><?php echo esc_html($settings['title']); ?></h3>
            <?php endif; ?>

            <?php if ( $terms && !is_wp_error( $terms ) ) : ?>
            <ul>
                <?php foreach ( $terms as $term ) {
                    $cat_image		 = fw_get_db_term_option($term->term_id , 'recipe_cat', 'recipe_cat_image' );
                ?>
                    <li>
                        <?php if( !empty($cat_image[ 'url' ])) : ?>
                            <img src="<?php echo esc_url( $cat_image[ 'url' ]); ?>" alt="<?php echo esc_attr__('Image', 'guto-toolkit'); ?>">
                        <?php endif; ?>
                        <a href="<?php echo get_term_link($term->slug, $taxonomy); ?>"><?php echo esc_html($term->name); ?></a>
                        <span><?php echo esc_html__('(','guto-toolkit'); ?><?php echo esc_html($term->count) ?><?php echo esc_html__(')','guto-toolkit'); ?></span>
                    </li>
                <?php if( $i == $settings['count']  ){ break; }
                    $i++;
                } ?>
            </ul>
            <?php endif;?>
        </div>

    <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_RB_Recipe_Cat );