<?php
/**
 * RB Section Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_RB_Section extends Widget_Base {

	public function get_name() {
        return 'RB_Section';
    }

	public function get_title() {
        return esc_html__( 'Section', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-handle';
    }

    public function get_categories() {
        return [ 'guto-recipe-blog' ];
	}

	protected function _register_controls() {

        $this->start_controls_section(
			'Guto_Section',
			[
				'label' => esc_html__( 'Guto Section', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

            $this->add_control(
                'title',
                [
                    'label' => esc_html__( 'Title', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__('Latest Recipes', 'guto-toolkit'),
                ]
            );

        $this->end_controls_section();

        $this->start_controls_section(
			'section_style',
			[
				'label' => esc_html__( 'Style', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
        );
            $this->add_control(
                'title_color',
                [
                    'label' => esc_html__( 'Title Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .rb-section-title h2' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'title_typography',
                    'label' => esc_html__( 'Title Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .rb-section-title h2',
                ]
            );

        $this->end_controls_section();

    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        // Inline Editing
        $this-> add_inline_editing_attributes('title','none');
        ?>
            <?php if($settings['title'] != '' ): ?>
                <div class="container">
                    <div class="rb-section-title">
                        <h2><?php echo wp_kses_post( $settings['title'] ); ?></h2>
                    </div>
                </div>
            <?php endif; ?>
        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_RB_Section );