<?php
/**
 * Top Pick Posts Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_RB_Top_Pick extends Widget_Base {

	public function get_name() {
        return 'RB_Top_Pick';
    }

	public function get_title() {
        return esc_html__( 'Top Pick Posts', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-video-playlist';
    }

	public function get_categories() {
        return [ 'guto-recipe-blog' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'Guto_Video_Area',
			[
				'label' => esc_html__( 'Top Pick', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

            $this->add_control(
                'sec_title', [
                    'label' => esc_html__( 'Section Title', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'label_block' => true,
                ]
            );

            $this->add_control(
                'shape_img',
                [
                    'label' => esc_html__( 'Shape Image', 'guto-toolkit' ),
                    'type' => Controls_Manager::MEDIA,
                    'label_block' => true,
                ]
            );

            $this->add_control(
                'count', [
                    'label'       => __( 'Show post count', 'guto-toolkit' ),
                    'type'        => Controls_Manager::NUMBER,
                    'label_block' => true,
                    'default'     => 4,
                ]
            );

            $this->add_control(
                'order', [
                    'label'     => __( 'Order', 'guto-toolkit' ),
                    'type'      => Controls_Manager::SELECT,
                    'options'   => [
                        'ASC'  => 'ASC',
                        'DESC' => 'DESC'
                    ],
                    'default' => 'ASC'
                ]
            );

            $this->add_control(
                'cat', [
                    'label'        => __( 'Category', 'guto-toolkit' ),
                    'description'  => __( 'Enter the category slugs separated by commas (Eg. cat1, cat2)', 'guto-toolkit' ),
                    'type'         => Controls_Manager::TEXT,
                    'label_block'  => true,
                ]
            );

            $this->add_control(
                'read_text',
                [
                    'label' => esc_html__( 'Post Reading Time Text', 'guto-toolkit' ),
                    'type'  => Controls_Manager::TEXT,
                ]
            );

            $this->add_control(
                'count_excerpt', [
                    'label'       => __( 'Show excerpt word', 'guto-toolkit' ),
                    'type'        => Controls_Manager::NUMBER,
                    'label_block' => true,
                    'default'     => 12,
                ]
            );

        $this->end_controls_section();

        $this->start_controls_section(
			'section_style',
			[
				'label' => esc_html__( 'Style', 'guto-toolkit' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
        );
            $this->add_control(
                'cat_color', [
                    'label'     => __( 'Category Color', 'guto-toolkit' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .pick-recipe-item .pick-content .pick-tag li a' => 'color: {{VALUE}};',
                    ],
                ]
            );
            $this->add_group_control(
                Group_Control_Typography::get_type(), [
                    'label'    => __( 'Category Typography', 'guto-toolkit' ),
                    'name'     => 'typography_cat',
                    'selector' => '
                    {{WRAPPER}} .pick-recipe-item .pick-content .pick-tag li a',
                ]
            );
            $this->add_control(
                'title_color', [
                    'label'     => __( 'Title Color', 'guto-toolkit' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .pick-recipe-item .pick-content h3 a' => 'color: {{VALUE}};',
                    ],
                ]
            );
            $this->add_group_control(
                Group_Control_Typography::get_type(), [
                    'label'    => __( 'Title Typography', 'guto-toolkit' ),
                    'name'     => 'typography_title',
                    'selector' => '
                    {{WRAPPER}} .pick-recipe-item .pick-content h3 a',
                ]
            );
            $this->add_control(
                'ex_color', [
                    'label'     => __( 'Excerpt Color', 'guto-toolkit' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .pick-recipe-item .pick-content p' => 'color: {{VALUE}};',
                    ],
                ]
            );
            $this->add_group_control(
                Group_Control_Typography::get_type(), [
                    'label'    => __( 'Excerpt Typography', 'guto-toolkit' ),
                    'name'     => 'typography_excer',
                    'selector' => '
                    {{WRAPPER}} .pick-recipe-item .pick-content p',
                ]
            );
            $this->add_control(
                'meta_color', [
                    'label'     => __( 'Meta Color', 'guto-toolkit' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .pick-recipe-item .pick-content .pick-list li' => 'color: {{VALUE}};',
                    ],
                ]
            );
            $this->add_group_control(
                Group_Control_Typography::get_type(), [
                    'label'    => __( 'Meta Typography', 'guto-toolkit' ),
                    'name'     => 'typography_meta',
                    'selector' => '
                    {{WRAPPER}} .pick-recipe-item .pick-content .pick-list li',
                ]
            );
        $this->end_controls_section();
    }

	protected function render() {

        $settings = $this->get_settings_for_display();
        // Post Arg
        if ( !empty($settings['cat']) ) {
            $post_array = new \WP_Query(array(
                'post_type'        => 'recipes',
                'posts_per_page'   => $settings['count'],
                'order'            => $settings['order'],
                'meta_key'         => '_thumbnail_id',
                'tax_query'        => array(
                    array(
                        'taxonomy' => 'recipe_cat',
                        'field'    => 'slug',
                        'terms'    => explode( ',', str_replace( ' ', '', $settings['cat'])),
                    ),
                ),
            ));
        } else {
            $post_array = new \WP_Query(array(
                'post_type'        => 'recipes',
                'posts_per_page'   => $settings['count'],
                'order'            => $settings['order'],
                'meta_key'         => '_thumbnail_id',
            ));
        } ?>

        <div class="rb-pick-recipe-area pb-100">
            <div class="container pt-100">
                <?php if( !empty($settings['sec_title']) ) : ?>
                    <div class="rb-section-title">
                        <h2><?php echo esc_html($settings['sec_title']); ?></h2>
                    </div>
                <?php endif; ?>

                <div class="rb-pick-recipe-slides owl-carousel owl-theme">
                <?php
                    while($post_array->have_posts()): $post_array->the_post();
                    $terms = get_the_terms( get_the_ID() , 'recipe_cat' );
                ?>

                    <div class="pick-recipe-item wow fadeInUp" data-wow-delay="50ms" data-wow-duration="500ms">
                        <?php if(get_the_post_thumbnail_url() != ''): ?>
                            <div class="pick-image">
                                <a href="<?php the_permalink(); ?>">
                                    <img src="<?php echo get_the_post_thumbnail_url( get_the_ID(), 'guto_lite_thumb_size_550' ); ?>" alt="<?php the_post_thumbnail_caption();  ?>">
                                </a>
                            </div>
                        <?php endif; ?>

                        <div class="pick-content">
                            <ul class="pick-tag">
                                <?php if( !empty( $terms ) ) : ?>
                                    <li>
                                        <a href="<?php echo esc_url( get_category_link( $terms[0]->term_id ) ) ?>">
                                            <?php echo esc_html( $terms[0]->name ); ?>
                                        </a>
                                    </li>
                                <?php endif; ?>
                            </ul>
                            <h3><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>

                            <p><?php echo esc_html(wp_trim_words( get_the_excerpt(), $settings['count_excerpt'], '' )); ?></p>

                            <ul class="pick-list">
                                <li> <?php echo esc_html(get_the_date('M d, y')) ?></li>
                                <li> <?php echo esc_html(guto_lite_reading_time()) ?>
                                    <?php echo esc_html($settings['read_text']); ?>
                                </li>
                                <li><?php comments_number(); ?></li>
                            </ul>
                        </div>
                    </div>

                <?php
                    endwhile;
                    wp_reset_postdata();
                ?>
                </div>

                <?php if( $settings['shape_img']['url'] != '' ): ?>
                    <div class="pick-recipe-shape">
                        <img src="<?php echo esc_url( $settings['shape_img']['url'] ); ?>" alt="<?php echo esc_attr( $settings['sec_title'] ); ?>">
                    </div>
                <?php endif; ?>

            </div>
        </div>

        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_RB_Top_Pick );