<?php
/**
 * Video Area Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_RB_Video_Area extends Widget_Base {

	public function get_name() {
        return 'Recipe_Video_Area';
    }

	public function get_title() {
        return esc_html__( 'Video Posts', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-video-playlist';
    }

	public function get_categories() {
        return [ 'guto-recipe-blog' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'Guto_Video_Area',
			[
				'label' => esc_html__( 'Guto Video', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

            $this->add_control(
                'count', [
                    'label'       => __( 'Show post count', 'guto-toolkit' ),
                    'type'        => Controls_Manager::NUMBER,
                    'label_block' => true,
                    'default'     => 4,
                ]
            );

            $this->add_control(
                'order', [
                    'label'     => __( 'Order', 'guto-toolkit' ),
                    'type'      => Controls_Manager::SELECT,
                    'options'   => [
                        'ASC'  => 'ASC',
                        'DESC' => 'DESC'
                    ],
                    'default' => 'ASC'
                ]
            );

            $this->add_control(
                'cat', [
                    'label'        => __( 'Category', 'guto-toolkit' ),
                    'description'  => __( 'Enter the category slugs separated by commas (Eg. cat1, cat2)', 'guto-toolkit' ),
                    'type'         => Controls_Manager::TEXT,
                    'label_block'  => true,
                ]
            );

            $this->add_control(
                'view_text',
                [
                    'label'    => esc_html__( 'Post Reading Text', 'guto-toolkit' ),
                    'type'     => Controls_Manager::TEXT,
                    'default'  =>  esc_html__( 'Min ', 'guto-toolkit' ),
                ]
            );

        $this->end_controls_section();

        $this->start_controls_section(
			'section_style',
			[
				'label' => esc_html__( 'Style', 'guto-toolkit' ),
				'tab'   => Controls_Manager::TAB_STYLE,
			]
        );
            $this->add_control(
                'title_color', [
                    'label'     => __( 'Title Color', 'guto-toolkit' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .rb-video-item .content h3 a' => 'color: {{VALUE}};',
                    ],
                ]
            );
            $this->add_group_control(
                Group_Control_Typography::get_type(), [
                    'label'    => __( 'Title Typography', 'guto-toolkit' ),
                    'name'     => 'typography_title',
                    'selector' => '
                    {{WRAPPER}} .rb-video-item .content h3 a',
                ]
            );
            $this->add_control(
                'meta_color', [
                    'label'     => __( 'Meta Color', 'guto-toolkit' ),
                    'type'      => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .rb-video-item .content .list li' => 'color: {{VALUE}};',
                    ],
                ]
            );
            $this->add_group_control(
                Group_Control_Typography::get_type(), [
                    'label'    => __( 'Meta Typography', 'guto-toolkit' ),
                    'name'     => 'typography_meta',
                    'selector' => '
                    {{WRAPPER}} .rb-video-item .content .list li',
                ]
            );
        $this->end_controls_section();
    }

	protected function render() {

        $settings = $this->get_settings_for_display();
        // Post Arg
        if ( !empty($settings['cat']) ) {
            $post_array = new \WP_Query(array(
                'post_type'        => 'recipes',
                'posts_per_page'   => $settings['count'],
                'order'            => $settings['order'],
                'meta_key'         => '_thumbnail_id',
                'tax_query'        => array(
                    array(
                        'taxonomy' => 'recipe_cat',
                        'field'    => 'slug',
                        'terms'    => explode( ',', str_replace( ' ', '', $settings['cat'])),
                    ),
                ),
            ));
        } else {
            $post_array = new \WP_Query(array(
                'post_type'        => 'recipes',
                'posts_per_page'   => $settings['count'],
                'order'            => $settings['order'],
                'meta_key'         => '_thumbnail_id',
            ));
        } ?>

        <div class="container-fluid">
            <div class="rb-video-slides owl-carousel owl-theme">
                <?php
                    while($post_array->have_posts()): $post_array->the_post();
                    $terms = get_the_terms( get_the_ID() , 'recipe_cat' );

                    $video_link  = fw_get_db_post_option( get_the_ID(), 'recipe_video_link' );
                ?>
                    <div class="rb-video-item wow fadeInUp" data-wow-delay="50ms" data-wow-duration="500ms">
                        <div class="video-image">
                            <?php if(get_the_post_thumbnail_url() != ''): ?>
                                <img src="<?php echo get_the_post_thumbnail_url( get_the_ID(), 'full' ); ?>" alt="<?php the_post_thumbnail_caption();  ?>">
                            <?php endif; ?>

                            <?php if( !empty($video_link) ) : ?>
                                <a href="<?php echo esc_url( $video_link ); ?>" class="video-btn popup-youtube">
                                    <i class='bx bx-play'></i>
                                </a>
                            <?php endif; ?>
                        </div>

                        <div class="content">

                            <h3><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h3>

                            <ul class="list">
                                <li> <?php echo esc_html(get_the_date('M d, y')) ?></li>
                                <li> <?php echo esc_html(guto_lite_reading_time()) ?>
                                    <?php echo esc_html($settings['view_text']); ?>
                                </li>
                                <li><?php comments_number(); ?></li>
                            </ul>
                        </div>
                    </div>
                <?php
                    endwhile;
                    wp_reset_postdata();
                ?>
            </div>
        </div>

        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_RB_Video_Area );