<?php
/**
 * RB Author info Widget
 */
namespace Elementor;
class Guto_RB_Author_Info extends Widget_Base{
    public function get_name(){
        return "RB_Author_Info";
    }
    public function get_title(){
        return "Author Info";
    }
    public function get_icon(){
        return "eicon-archive";
    }
    public function get_categories(){
        return [ 'guto-recipe-blog' ];
    }
    protected function _register_controls(){

        $this->start_controls_section(
            'Guto_Author',
            [
                'label' => esc_html__( 'Guto Author', 'guto-toolkit' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

            $this->add_control(
                'member_img',
                [
                    'label' => esc_html__( 'Image', 'guto-toolkit' ),
                    'type' => Controls_Manager::MEDIA,
                    'label_block' => true,
                ]
            );
            $this->add_control(
                'bg_img',
                [
                    'label' => esc_html__( 'Background Image', 'guto-toolkit' ),
                    'type' => Controls_Manager::MEDIA,
                    'label_block' => true,
                ]
            );
            $this->add_control(
                'title',
                [
                    'label' => esc_html__( 'Title', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default'       => esc_html__('Sarah Taylor', 'guto-toolkit'),
                    'label_block'   => true,
                ]
            );
            $this->add_control(
                'content',
                [
                    'label' => esc_html__( 'Content', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXTAREA,
                    'label_block'   => true,
                ]
            );

            $repeater = new Repeater();
            $repeater->add_control(
                'social_icon',
                [
                    'label' => esc_html__( 'Social Icon', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'label_block' => true,
                    'options' => guto_toolkit_icons(),
                ]
            );
            $repeater->add_control(
                'social_url',
                [
                    'label' => esc_html__( 'Social Link', 'guto-toolkit' ),
                    'type' => Controls_Manager::URL,
                ]
            );
            $this->add_control(
                'social_list',
                [
                    'label' => esc_html__( 'Add Social Icon', 'guto-toolkit' ),
                    'type' => Controls_Manager::REPEATER,
                    'fields' => $repeater->get_controls(),
                ]
            );
        $this-> end_controls_section();

        // Start Style content controls
        $this-> start_controls_section(
            'style',
            [
                'label' => esc_html__('Style', 'guto-toolkit'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
            $this->add_control(
                'name_color',
                [
                    'label' => esc_html__( 'Name Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}}  .widget_information .information-content h3' => 'color: {{VALUE}}',
                    ],
                ]
            );
            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'name_typography',
                    'label' => esc_html__( 'Name Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .widget_information .information-content h3',
                ]
            );

            $this->add_control(
                'content_color',
                [
                    'label' => esc_html__( 'Content Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .widget_information .information-content p' => 'color: {{VALUE}}',
                    ],
                ]
            );
            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'content_typography',
                    'label' => esc_html__( 'Content Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .widget_information .information-content p',
                ]
            );

            $this->add_control(
                'social_color',
                [
                    'label' => esc_html__( 'Icon Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .widget_information .information-content .social li a i' => 'color: {{VALUE}}',
                    ],
                ]
            );
        $this-> end_controls_section();
    }
    protected function render()
    {
        $settings = $this->get_settings_for_display();
        ?>

        <div class="widget widget_information"  style="background-image:url(<?php echo esc_url( $settings['bg_img']['url'] ); ?>);">
            <?php if( $settings['member_img']['url'] != '' ): ?>
                <img src="<?php echo esc_url( $settings['member_img']['url'] ); ?>" alt="<?php echo esc_attr( $settings['title'] ); ?>">
            <?php endif; ?>

            <div class="information-content">
                <?php if(!empty( $settings['title'] )) : ?>
                    <h3><?php echo esc_html( $settings['title'] ); ?></h3>
                <?php endif; ?>

                <?php if(!empty( $settings['content'] )) : ?>
                    <p><?php echo wp_kses_post( $settings['content'] ); ?></p>
                <?php endif; ?>

                <ul class="social">
                    <?php foreach( $settings['social_list'] as $item ) :
                        if( $item['social_icon'] != '' && $item['social_url']['url'] != '' ) : ?>
                            <li><a href="<?php echo esc_url( $item['social_url']['url'] ); ?>" target="_blank"><i class="<?php echo esc_attr( $item['social_icon'] ); ?>"></i></a></li>
                        <?php endif;
                    endforeach; ?>
                </ul>
            </div>
        </div>


        <?php
    }


}

Plugin::instance()->widgets_manager->register( new Guto_RB_Author_Info );
