<?php
/**
 * RB Popular Posts Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_RB_Popular_Posts extends Widget_Base {

	public function get_name() {
        return 'Guto_RB_Popular_Posts';
    }

	public function get_title() {
        return esc_html__( 'Popular Posts', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-post-slider';
    }

	public function get_categories() {
        return [ 'guto-recipe-blog' ];
	}
	protected function _register_controls() {

        $this->start_controls_section(
			'Guto_RB_Posts',
			[
				'label' => esc_html__( 'Guto Posts', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

            $this->add_control(
                'sec_title', [
                    'label' => esc_html__( 'Section Title', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'label_block' => true,
                ]
            );

            $this->add_control(
                'cat', [
                    'label' => esc_html__( 'Category', 'guto-toolkit' ),
                    'description' => esc_html__( 'Enter the category slugs separated by commas (Eg. cat1, cat2)', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'label_block' => true,
                ]
            );

            $this->add_control(
                'order',
                [
                    'label' => esc_html__( 'Posts Order By', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        'DESC'      => esc_html__( 'DESC', 'guto-toolkit' ),
                        'ASC'       => esc_html__( 'ASC', 'guto-toolkit' ),
                    ],
                    'default' => 'DESC',
                ]
            );

            $this->add_control(
                'count',
                [
                    'label'   => esc_html__( 'Item', 'guto-toolkit' ),
                    'type'    => Controls_Manager::NUMBER,
                    'default' => 3,
                ]
            );
            $this->add_control(
                'read_text',
                [
                    'label' => esc_html__( 'Post Reading Time Text', 'guto-toolkit' ),
                    'type'  => Controls_Manager::TEXT,
                ]
            );
        $this->end_controls_section();

        $this->start_controls_section(
			'blog_styledm',
			[
				'label' => esc_html__( 'Style Controls', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
        );

            $this->add_control(
                'title_color',
                [
                    'label' => esc_html__( 'Section Title Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .widget .widget-title' => 'color: {{VALUE}}',
                    ],
                ]
            );
            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'title_typography',
                    'label' => esc_html__( 'Section Title Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .widget .widget-title',
                ]
            );
            $this->add_control(
                'ptitle_color',
                [
                    'label' => esc_html__( 'Post Title Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .widget_rb_posts_thumb .item .info .title a' => 'color: {{VALUE}}',
                    ],
                ]
            );
            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'ptitle_typography',
                    'label' => esc_html__( 'Post Title Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .widget_rb_posts_thumb .item .info .title a',
                ]
            );
            $this->add_control(
                'meta_color',
                [
                    'label' => esc_html__( 'Meta Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}}  .widget_rb_posts_thumb .item .info .list li' => 'color: {{VALUE}}',
                    ],
                ]
            );
            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'meta_typography',
                    'label' => esc_html__( 'Meta Typography', 'guto-toolkit' ),
                    'selector' => '{{WRAPPER}} .widget_rb_posts_thumb .item .info .list li',
                ]
            );

        $this->end_controls_section();

    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        // Post Query
        if( $settings['cat'] != '' ) {
            $args = array(
                'post_type'     => 'recipes',
                'posts_per_page'=> $settings['count'],
                'order'         => $settings['order'],
                'tax_query'     => array(
                    array(
                        'taxonomy'      => 'recipe_cat',
                        'field'         => 'slug',
                        'terms'         => $settings['cat'],
                        'hide_empty'    => false
                    )
                )
            );
        } else {
            $args = array(
                'post_type'         => 'recipes',
                'posts_per_page'    => $settings['count'],
                'order'             => $settings['order'],
            );
        }
        $post_array = new \WP_Query( $args ); ?>

            <div class="widget widget_rb_posts_thumb">
                <?php if( !empty($settings['sec_title']) ) : ?>
                <h3 class="widget-title"><?php echo esc_html($settings['sec_title']); ?></h3>
                <?php endif; ?>

                <?php while($post_array->have_posts()): $post_array->the_post();
                    $terms = get_the_terms( get_the_ID() , 'recipe_cat' );
                ?>
                    <div class="item">
                        <a href="<?php the_permalink(); ?>" class="thumb">
                            <span class="fullimage cover bg1"  style="background-image:url(<?php echo get_the_post_thumbnail_url( get_the_ID(), 'full' ); ?>);"></span>
                        </a>

                        <div class="info">
                            <h4 class="title usmall">
                                <a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
                            </h4>

                            <ul class="list">
                                <li> <?php echo esc_html(get_the_date('M d, y')) ?></li>
                                <li> <?php echo esc_html(guto_lite_reading_time()) ?>
                                    <?php echo esc_html($settings['read_text']); ?>
                                </li>
                            </ul>
                        </div>
                    </div>
                <?php endwhile; ?>
                <?php wp_reset_query(); ?>
            </div>

        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_RB_Popular_Posts );