<?php
/**
 * Restaurant About Area Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_Restaurant_About extends Widget_Base {

	public function get_name() {
        return 'Restaurant_About';
    }

	public function get_title() {
        return esc_html__( 'Restaurant About', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-info-box';
    }

	public function get_categories() {
        return [ 'guto-restaurant' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'Guto_Restaurant_About_Area',
			[
				'label' => esc_html__( 'Guto About Area', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

            $this->add_control(
                'title',
                [
                    'label' => esc_html__( 'Title', 'guto-toolkit' ),
                    'type' => Controls_Manager::WYSIWYG,
                    'default' => __('Few Words <span>About Us</span>', 'guto-toolkit'),
                ]
            );

            $this->add_control(
                'title_tag',
                [
                    'label' => esc_html__( 'Title Tag', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        'h1'         => esc_html__( 'h1', 'guto-toolkit' ),
                        'h2'         => esc_html__( 'h2', 'guto-toolkit' ),
                        'h3'         => esc_html__( 'h3', 'guto-toolkit' ),
                        'h4'         => esc_html__( 'h4', 'guto-toolkit' ),
                        'h5'         => esc_html__( 'h5', 'guto-toolkit' ),
                        'h6'         => esc_html__( 'h6', 'guto-toolkit' ),
                    ],
                    'default' => 'h2',
                ]
            );

            $this->add_control(
                'content',
                [
                    'label' => esc_html__( 'Content', 'guto-toolkit' ),
                    'type' => Controls_Manager::WYSIWYG,
                    'default' => __('<p>Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy eirmod tempor invidunt ut labore et dolore magna aliquyam erat, sed diam voluptua. At vero eos et accusam et justo duo dolores et</p>
                        <p>ea rebum. Stet clita kasd gubergren, no sea takimata sanctus est. et dolore magna aliquyam duo dolores et Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy eirmod tempor invidunt ut labore et dolore magna aliquyam erat consetetur sadipscing.</p>', 'guto-toolkit'),
                ]
            );

            $this->add_control(
				'button_text',
				[
					'label' 	=> esc_html__( 'Button Text', 'guto-toolkit' ),
					'type' 		=> Controls_Manager::TEXT,
					'default' 	=> esc_html__('Explore About Us', 'guto-toolkit'),
				]
            );

            $this->add_control(
				'button_icon',
				[
					'label' => esc_html__( 'Button Icon', 'guto-toolkit' ),
                    'type' => Controls_Manager::ICON,
                    'label_block' => true,
                    'default' => 'bx bx-right-arrow-alt',
                    'options' => guto_toolkit_icons(),
				]
            );

            $this->add_control(
                'link_type',
                [
                    'label' 		=> esc_html__( 'Button Link Type', 'guto-toolkit' ),
                    'type' 			=> Controls_Manager::SELECT,
                    'label_block' 	=> true,
                    'options' => [
                        '1'  	=> esc_html__( 'Link To Page', 'guto-toolkit' ),
                        '2' 	=> esc_html__( 'External Link', 'guto-toolkit' ),
                    ],
                    'default' => '2',
                ]
            );

            $this->add_control(
                'link_to_page',
                [
                    'label' 		=> esc_html__( 'Button Link Page', 'guto-toolkit' ),
                    'type' 			=> Controls_Manager::SELECT,
                    'label_block' 	=> true,
                    'options' 		=> guto_toolkit_get_page_as_list(),
                    'condition' => [
                        'link_type' => '1',
                    ]
                ]
            );

            $this->add_control(
                'ex_link',
                [
                    'label'		=> esc_html__('Button External Link', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: URL,
                    'show_external' => true,
                    'default' => [
                        'url' => '#',
                        'is_external' => true,
                        'nofollow' => true,
                    ],
                    'condition' => [
                        'link_type' => '2',
                    ]
                ]
            );

            $this->add_control(
                'about_image',
                [
                    'label' => esc_html__( 'About Area Image', 'guto-toolkit' ),
                    'type'	 => Controls_Manager::MEDIA,
                    'show_label' => true,
                ]
            );

            $this->add_control(
                'about_shape_img',
                [
                    'label' => esc_html__( 'Shape Image', 'guto-toolkit' ),
                    'type'	 => Controls_Manager::MEDIA,
                    'show_label' => true,
                ]
            );

        $this->end_controls_section();

    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        // Inline Editing
        $this-> add_inline_editing_attributes('title', 'none');
        $this-> add_inline_editing_attributes('content', 'none');

        // Get Button Link
        if($settings['link_type'] == 1){
            $link = get_page_link( $settings['link_to_page'] );
        } elseif($settings['link_type'] == 2) {
            $link = $settings['ex_link']['url'];
            $target = $settings['ex_link']['is_external'] ? ' target="_blank"' : '';
		    $nofollow = $settings['ex_link']['nofollow'] ? ' rel="nofollow"' : '';
        }

        $button_text = $settings['button_text']; ?>

        <!-- Start Restaurant About Us Area -->
        <?php if( is_home() || is_front_page() ) : ?>
            <section class="restaurant-about-us-area pt-100">
        <?php else: ?>
            <section class="restaurant-about-us-area ptb-100">
        <?php endif; ?>
            <div class="container">
                <div class="row align-items-center">
                    <div class="col-lg-6">
                        <?php if( $settings['about_image']['url'] != '' ): ?>
                            <div class="restaurant-about-img">
                                <img src="<?php echo esc_url($settings['about_image']['url']); ?>" alt="<?php esc_attr_e('About Image', 'guto-toolkit'); ?>">
                            </div>
                        <?php endif; ?>
                    </div>
                    <div class="col-lg-6">
                        <div class="restaurant-about-content">
                            <<?php echo esc_attr( $settings['title_tag'] ); ?> <?php echo $this-> get_render_attribute_string('title'); ?>><?php echo wp_kses_post( $settings['title'] ); ?></<?php echo esc_attr( $settings['title_tag'] ); ?>>

                            <?php echo wp_kses_post( $settings['content'] ); ?>

                            <?php if( $button_text != '' ): ?>
                                <?php if($settings['link_type'] == 1): ?>
                                    <a href="<?php echo esc_url( $link ); ?>" class="default-btn"><?php echo esc_html( $button_text ); ?><i class="<?php echo esc_attr( $settings['button_icon'] ); ?>"></i></a>
                                <?php elseif($settings['link_type'] == 2):
                                    echo '<a href="' .  $link . '" class="default-btn" ' . $target . $nofollow . '> ' . $button_text . ' <i class="'.$settings['button_icon'].'"></i></a>';
                                endif; ?>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
            </div>
            <?php if( $settings['about_shape_img']['url'] != '' ): ?>
                <div class="about-shape">
                    <img src="<?php echo esc_url($settings['about_shape_img']['url']); ?>" alt="<?php esc_attr_e('Shape Image', 'guto-toolkit'); ?>">
                </div>
            <?php endif; ?>
        </section>
        <!-- End Restaurant About Us Area -->

        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_Restaurant_About );
