<?php
/**
 * Restaurant App Area Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_Restaurant_App extends Widget_Base {

	public function get_name() {
        return 'Restaurant_App';
    }

	public function get_title() {
        return esc_html__( 'Restaurant App', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-apps';
    }

	public function get_categories() {
        return [ 'guto-restaurant' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'Guto_Restaurant_App_Area',
			[
				'label' => esc_html__( 'Guto App Area', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

            $this->add_control(
                'title',
                [
                    'label' => esc_html__( 'Title', 'guto-toolkit' ),
                    'type' => Controls_Manager::WYSIWYG,
                    'default' => __('Download Our Mobile App & Get <span>Free Delivery</span>', 'guto-toolkit'),
                ]
            );

            $this->add_control(
                'title_tag',
                [
                    'label' => esc_html__( 'Title Tag', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        'h1'         => esc_html__( 'h1', 'guto-toolkit' ),
                        'h2'         => esc_html__( 'h2', 'guto-toolkit' ),
                        'h3'         => esc_html__( 'h3', 'guto-toolkit' ),
                        'h4'         => esc_html__( 'h4', 'guto-toolkit' ),
                        'h5'         => esc_html__( 'h5', 'guto-toolkit' ),
                        'h6'         => esc_html__( 'h6', 'guto-toolkit' ),
                    ],
                    'default' => 'h2',
                ]
            );

            $this->add_control(
                'content',
                [
                    'label' => esc_html__( 'Content', 'guto-toolkit' ),
                    'type' => Controls_Manager::WYSIWYG,
                    'default' => __('<p>Lorem ipsum dolor sit amet consectetur adipisicing elit. Maxime unde vitae omnis, a deleniti earum tempore quaerat, obcaecati facere dolore natus dolorem architecto. Explicabo suscipit tempore, nam vero impedit aspernatur! earum tempore quaerat</p>
                        <p>Lorem ipsum dolor sit amet consectetur adipisicing elit. Commodi deserunt, repellendus culpa laudantium praesentium nemo eligendi voluptas similique sit dolore iusto odio expedita nulla recusandae, a dolorum asperiores iste animi. amet consectetur</p>', 'guto-toolkit'),
                ]
            );

            $this->add_control(
				'button1_text',
				[
					'label' 	=> esc_html__( 'Button1 Text', 'guto-toolkit' ),
					'type' 		=> Controls_Manager::TEXT,
					'default' 	=> esc_html__('Download From Playstore', 'guto-toolkit'),
				]
            );

            $this->add_control(
				'button1_icon',
				[
					'label' => esc_html__( 'Button1 Icon', 'guto-toolkit' ),
                    'type' => Controls_Manager::ICON,
                    'label_block' => true,
                    'default' => 'bx bxl-play-store',
                    'options' => guto_toolkit_icons(),
				]
            );

            $this->add_control(
                'link1_type',
                [
                    'label' 		=> esc_html__( 'Button1 Link Type', 'guto-toolkit' ),
                    'type' 			=> Controls_Manager::SELECT,
                    'label_block' 	=> true,
                    'options' => [
                        '1'  	=> esc_html__( 'Link To Page', 'guto-toolkit' ),
                        '2' 	=> esc_html__( 'External Link', 'guto-toolkit' ),
                    ],
                    'default' => '2',
                ]
            );

            $this->add_control(
                'link1_to_page',
                [
                    'label' 		=> esc_html__( 'Button1 Link Page', 'guto-toolkit' ),
                    'type' 			=> Controls_Manager::SELECT,
                    'label_block' 	=> true,
                    'options' 		=> guto_toolkit_get_page_as_list(),
                    'condition' => [
                        'link1_type' => '1',
                    ]
                ]
            );

            $this->add_control(
                'ex1_link',
                [
                    'label'		=> esc_html__('Button1 External Link', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: URL,
                    'show_external' => true,
                    'default' => [
                        'url' => '#',
                        'is_external' => true,
                        'nofollow' => true,
                    ],
                    'condition' => [
                        'link1_type' => '2',
                    ]
                ]
            );

            $this->add_control(
                'button2_text',
                [
                    'label'     => esc_html__( 'Button2 Text', 'guto-toolkit' ),
                    'type'      => Controls_Manager::TEXT,
                    'default'   => esc_html__('Download From Applestore', 'guto-toolkit'),
                ]
            );

            $this->add_control(
                'button2_icon',
                [
                    'label' => esc_html__( 'Button2 Icon', 'guto-toolkit' ),
                    'type' => Controls_Manager::ICON,
                    'label_block' => true,
                    'default' => 'bx bxl-apple',
                    'options' => guto_toolkit_icons(),
                ]
            );

            $this->add_control(
                'link2_type',
                [
                    'label'         => esc_html__( 'Button2 Link Type', 'guto-toolkit' ),
                    'type'          => Controls_Manager::SELECT,
                    'label_block'   => true,
                    'options' => [
                        '1'     => esc_html__( 'Link To Page', 'guto-toolkit' ),
                        '2'     => esc_html__( 'External Link', 'guto-toolkit' ),
                    ],
                    'default' => '2',
                ]
            );

            $this->add_control(
                'link2_to_page',
                [
                    'label'         => esc_html__( 'Button2 Link Page', 'guto-toolkit' ),
                    'type'          => Controls_Manager::SELECT,
                    'label_block'   => true,
                    'options'       => guto_toolkit_get_page_as_list(),
                    'condition' => [
                        'link2_type' => '1',
                    ]
                ]
            );

            $this->add_control(
                'ex2_link',
                [
                    'label'     => esc_html__('Button2 External Link', 'guto-toolkit'),
                    'type'      => Controls_Manager:: URL,
                    'show_external' => true,
                    'default' => [
                        'url' => '#',
                        'is_external' => true,
                        'nofollow' => true,
                    ],
                    'condition' => [
                        'link2_type' => '2',
                    ]
                ]
            );

            $this->add_control(
                'app_image',
                [
                    'label' => esc_html__( 'App Area Image', 'guto-toolkit' ),
                    'type'	 => Controls_Manager::MEDIA,
                    'show_label' => true,
                ]
            );

        $this->end_controls_section();

    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        // Inline Editing
        $this-> add_inline_editing_attributes('title', 'none');
        $this-> add_inline_editing_attributes('content', 'none');

        // Get Button1 Link
        if($settings['link1_type'] == 1){
            $link1 = get_page_link( $settings['link1_to_page'] );
        } elseif($settings['link1_type'] == 2) {
            $link1 = $settings['ex1_link']['url'];
            $target1 = $settings['ex1_link']['is_external'] ? ' target="_blank"' : '';
		    $nofollow1 = $settings['ex1_link']['nofollow'] ? ' rel="nofollow"' : '';
        }

        $button1_text = $settings['button1_text'];

        // Get Button2 Link
        if($settings['link2_type'] == 1){
            $link2 = get_page_link( $settings['link2_to_page'] );
        } elseif($settings['link2_type'] == 2) {
            $link2 = $settings['ex2_link']['url'];
            $target2 = $settings['ex2_link']['is_external'] ? ' target="_blank"' : '';
            $nofollow2 = $settings['ex2_link']['nofollow'] ? ' rel="nofollow"' : '';
        }

        $button2_text = $settings['button2_text'];

        ?>

        <!-- Start Restaurant App Download Area -->
        <?php if( is_home() || is_front_page() ) : ?>
            <section class="restaurant-app-download-area ptb-100">
        <?php else: ?>
            <section class="restaurant-app-download-area pb-100">
        <?php endif; ?>
            <div class="container">
                <div class="row align-items-center">
                    <div class="col-lg-6">
                        <div class="restaurant-app-download-content">
                            <<?php echo esc_attr( $settings['title_tag'] ); ?> <?php echo $this-> get_render_attribute_string('title'); ?>><?php echo wp_kses_post( $settings['title'] ); ?></<?php echo esc_attr( $settings['title_tag'] ); ?>>

                            <?php echo wp_kses_post( $settings['content'] ); ?>

                            <div class="restaurant-app-download-btn">

                                <?php if( $button1_text != '' ): ?>
                                    <?php if($settings['link1_type'] == 1): ?>
                                        <a href="<?php echo esc_url( $link1 ); ?>" class="default-btn mr-30"><?php echo esc_html( $button1_text ); ?><i class="<?php echo esc_attr( $settings['button1_icon'] ); ?>"></i></a>
                                    <?php elseif($settings['link1_type'] == 2):
                                        echo '<a href="' .  $link1 . '" class="default-btn mr-30" ' . $target1 . $nofollow1 . '> ' . $button1_text . ' <i class="'.$settings['button1_icon'].'"></i></a>';
                                    endif; ?>
                                <?php endif; ?>

                                <?php if( $button2_text != '' ): ?>
                                    <?php if($settings['link2_type'] == 1): ?>
                                        <a href="<?php echo esc_url( $link2 ); ?>" class="default-btn"><?php echo esc_html( $button2_text ); ?><i class="<?php echo esc_attr( $settings['button2_icon'] ); ?>"></i></a>
                                    <?php elseif($settings['link2_type'] == 2):
                                        echo '<a href="' .  $link2 . '" class="default-btn" ' . $target2 . $nofollow2 . '> ' . $button2_text . ' <i class="'.$settings['button2_icon'].'"></i></a>';
                                    endif; ?>
                                <?php endif; ?>

                            </div>
                        </div>
                    </div>
                    <div class="col-lg-6">
                        <?php if( $settings['app_image']['url'] != '' ): ?>
                            <div class="play-store">
                                <img src="<?php echo esc_url($settings['app_image']['url']); ?>" alt="<?php esc_attr_e('App Image', 'guto-toolkit'); ?>">
                            </div>
                        <?php endif; ?>
                    </div>
                </div>
            </div>
        </section>
        <!-- End Restaurant App Download Area -->

        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_Restaurant_App );
