<?php
/**
 * Restaurant Booking Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_Restaurant_Booking extends Widget_Base {

	public function get_name() {
        return 'Restaurant_Booking';
    }

	public function get_title() {
        return esc_html__( 'Restaurant Booking', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-form-horizontal';
    }

	public function get_categories() {
        return [ 'guto-restaurant' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
            'Guto_Restaurant_Booking',
            [
                'label' => esc_html__( 'Guto Restaurant Booking', 'guto-toolkit' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );
            $this->add_control(
                'title',
                [
                    'label' => esc_html__( 'Title', 'guto-toolkit' ),
                    'type' => Controls_Manager::WYSIWYG,
                    'default' => __('<span>Book</span> A Table Now', 'guto-toolkit'),
                ]
            );

            $this->add_control(
                'title_tag',
                [
                    'label' => esc_html__( 'Title Tag', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        'h1'         => esc_html__( 'h1', 'guto-toolkit' ),
                        'h2'         => esc_html__( 'h2', 'guto-toolkit' ),
                        'h3'         => esc_html__( 'h3', 'guto-toolkit' ),
                        'h4'         => esc_html__( 'h4', 'guto-toolkit' ),
                        'h5'         => esc_html__( 'h5', 'guto-toolkit' ),
                        'h6'         => esc_html__( 'h6', 'guto-toolkit' ),
                    ],
                    'default' => 'h2',
                ]
            );

            $this->add_control(
                'booking_bg_image',
                [
                    'label' => esc_html__( 'Booking Background Image', 'guto-toolkit' ),
                    'type'   => Controls_Manager::MEDIA,
                    'show_label' => true,
                ]
            );

            $this->add_control(
                'shortcode',
                [
                    'label' => esc_html__( 'Booking Form Shortcode', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                ]
            );

        $this->end_controls_section();
    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        // Inline Editing
        $this-> add_inline_editing_attributes('title', 'none'); ?>

        <!-- Start Restaurant Book A Table Area -->
        <section class="restaurant-book-a-table-area">
            <div class="container">
                <div class="restaurant-book-a-table-bg ptb-100" style="background-image:url(<?php echo esc_url($settings['booking_bg_image']['url']); ?>);">
                    <div class="restaurant-section-title">
                        <<?php echo esc_attr( $settings['title_tag'] ); ?> <?php echo $this-> get_render_attribute_string('title'); ?>>
                            <?php echo wp_kses_post( $settings['title'] ); ?>
                        </<?php echo esc_attr( $settings['title_tag'] ); ?>>
                    </div>
                    <?php if($settings['shortcode']): ?>
                        <?php echo do_shortcode( $settings['shortcode'] ); ?>
                    <?php endif; ?>
                </div>
            </div>
        </div>

        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_Restaurant_Booking );
