<?php
/**
 * Restaurant Feedback Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_Restaurant_Feedback extends Widget_Base {

	public function get_name() {
        return 'Restaurant_Feedback';
    }

	public function get_title() {
        return esc_html__( 'Restaurant Feedback', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-testimonial';
    }

	public function get_categories() {
        return [ 'guto-restaurant' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'content_section',
			[
				'label' => esc_html__( 'Content', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

        $this->add_control(
            'title',
            [
                'label' => esc_html__( 'Title', 'guto-toolkit' ),
                'type' => Controls_Manager::WYSIWYG,
                'default' => __('Some <span>Sweet Talk</span> From The Clients', 'guto-toolkit'),
            ]
        );

        $this->add_control(
            'title_tag',
            [
                'label' => esc_html__( 'Title Tag', 'guto-toolkit' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'h1'         => esc_html__( 'h1', 'guto-toolkit' ),
                    'h2'         => esc_html__( 'h2', 'guto-toolkit' ),
                    'h3'         => esc_html__( 'h3', 'guto-toolkit' ),
                    'h4'         => esc_html__( 'h4', 'guto-toolkit' ),
                    'h5'         => esc_html__( 'h5', 'guto-toolkit' ),
                    'h6'         => esc_html__( 'h6', 'guto-toolkit' ),
                ],
                'default' => 'h2',
            ]
        );

		$this->add_control(
            'guto_feedback_items',
            [
                'label' => esc_html__('Slider Item', 'guto-toolkit'),
                'type' => Controls_Manager::REPEATER,
                'default' => [
                    [ 'name' => esc_html__(' Item #1', 'guto-toolkit') ],

                ],
                'fields' => [
                    [
                        'name' => 'author_name',
                        'label' => esc_html__('Name', 'guto-toolkit'),
                        'type' => Controls_Manager::TEXT,
                        'default' => esc_html__('Jane Ronan', 'guto-toolkit'),
                        'label_block' => true,
                    ],
                    [
                        'name' => 'designation',
                        'label' => esc_html__('Designation', 'guto-toolkit'),
                        'type' => Controls_Manager::TEXT,
                        'default' => esc_html__('IT Compnay Of CEO', 'guto-toolkit'),
                        'label_block' => true,
                    ],
                    [
                        'name' => 'feedback',
                        'label' => esc_html__('Feedback Content', 'guto-toolkit'),
                        'type' => Controls_Manager::TEXTAREA,
                        'default' => __('Lorem ipsum dolor sit amet, consetet ur sadipscing elitr, sed diam nonumy eirmod tempor invidunt ut labore et dolore magna aliquyam erat, sed diam voluptua.', 'guto-toolkit'),
                        'label_block' => true,
                    ],
                    [
                        'name' => 'rating',
                        'label' => esc_html__( 'Rating', 'guto-toolkit' ),
                        'type' => Controls_Manager::SELECT,
                        'options' => [
                            'rate-1'         => esc_html__( '1', 'guto-toolkit' ),
                            'rate-2'         => esc_html__( '2', 'guto-toolkit' ),
                            'rate-3'         => esc_html__( '3', 'guto-toolkit' ),
                            'rate-4'         => esc_html__( '4', 'guto-toolkit' ),
                            'rate-5'         => esc_html__( '5', 'guto-toolkit' ),
                        ],
                        'default' => 'rate-5',
                    ]

                ],
            ]
        );

    $this->end_controls_section();

    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        $slider = $settings['guto_feedback_items'];

        // Inline Editing
        $this-> add_inline_editing_attributes('title', 'none'); ?>

        <!-- Start Restaurant Sweet Talk Area -->
        <div class="restaurant-sweet-talk-area ptb-100">
            <div class="container">
                <div class="restaurant-section-title">
                    <<?php echo esc_attr( $settings['title_tag'] ); ?> <?php echo $this-> get_render_attribute_string('title'); ?>>
                        <?php echo wp_kses_post( $settings['title'] ); ?>
                    </<?php echo esc_attr( $settings['title_tag'] ); ?>>
                </div>
                <div class="restaurant-sweet-talk-slider owl-carousel owl-theme">
                    <?php foreach ($slider as $key => $value): ?>
                        <div class="restaurant-single-sweet-talk">
                            <div class="restaurant-sweet-talk-content">
                                <i class='bx bxs-quote-left'></i>
                                <p><?php echo wp_kses_post( $value['feedback'] ); ?></p>
                            </div>
                            <div class="restaurant-sweet-talk-name">
                                <h3><?php echo esc_html( $value['author_name'] ); ?></h3>
                                <span><?php echo esc_html( $value['designation'] ); ?></span>
                                <ul>
                                    <?php if( $value['rating'] == 'rate-1' ) : ?>
                                        <li>
                                            <i class="bx bxs-star"></i>
                                        </li>
                                    <?php elseif( $value['rating'] == 'rate-2' ) : ?>
                                        <li>
                                            <i class="bx bxs-star"></i>
                                        </li>
                                        <li>
                                            <i class="bx bxs-star"></i>
                                        </li>
                                    <?php elseif( $value['rating'] == 'rate-3' ) : ?>
                                        <li>
                                            <i class="bx bxs-star"></i>
                                        </li>
                                        <li>
                                            <i class="bx bxs-star"></i>
                                        </li>
                                        <li>
                                            <i class="bx bxs-star"></i>
                                        </li>
                                    <?php elseif( $value['rating'] == 'rate-4' ) : ?>
                                        <li>
                                            <i class="bx bxs-star"></i>
                                        </li>
                                        <li>
                                            <i class="bx bxs-star"></i>
                                        </li>
                                        <li>
                                            <i class="bx bxs-star"></i>
                                        </li>
                                        <li>
                                            <i class="bx bxs-star"></i>
                                        </li>
                                    <?php elseif( $value['rating'] == 'rate-5' ) : ?>
                                        <li>
                                            <i class="bx bxs-star"></i>
                                        </li>
                                        <li>
                                            <i class="bx bxs-star"></i>
                                        </li>
                                        <li>
                                            <i class="bx bxs-star"></i>
                                        </li>
                                        <li>
                                            <i class="bx bxs-star"></i>
                                        </li>
                                        <li>
                                            <i class="bx bxs-star"></i>
                                        </li>
                                    <?php endif; ?>
                                </ul>
                            </div>
                        </div>
                    <?php endforeach; ?>
                </div>
            </div>
        </div>
        <!-- End Restaurant Sweet Talk Area -->

        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_Restaurant_Feedback );
