<?php
/**
 * Restaurant Menu Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_Restaurant_Menu extends Widget_Base {

	public function get_name() {
        return 'Guto_Restaurant_Menu';
    }

	public function get_title() {
        return esc_html__( 'Restaurant Menu', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-menu-toggle';
    }

	public function get_categories() {
        return [ 'guto-restaurant' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'content_section',
			[
				'label' => esc_html__( 'Content', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

        $this->add_control(
            'title',
            [
                'label' => esc_html__( 'Title', 'guto-toolkit' ),
                'type' => Controls_Manager::WYSIWYG,
                'default' => __('Our Top <span>Dishes</span>', 'guto-toolkit'),
            ]
        );

        $this->add_control(
            'title_tag',
            [
                'label' => esc_html__( 'Title Tag', 'guto-toolkit' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'h1'         => esc_html__( 'h1', 'guto-toolkit' ),
                    'h2'         => esc_html__( 'h2', 'guto-toolkit' ),
                    'h3'         => esc_html__( 'h3', 'guto-toolkit' ),
                    'h4'         => esc_html__( 'h4', 'guto-toolkit' ),
                    'h5'         => esc_html__( 'h5', 'guto-toolkit' ),
                    'h6'         => esc_html__( 'h6', 'guto-toolkit' ),
                ],
                'default' => 'h2',
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'menu_section_one',
            [
                'label' => esc_html__( 'Menu 1', 'guto-toolkit' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'show_menu_one',
            [
                'label' => __( 'Show/Hide Menu 1', 'guto-toolkit' ),
                'type' => \Elementor\Controls_Manager::CHOOSE,
                'options' => [
                    'show' => [
                        'title' => __( 'Show', 'guto-toolkit' ),
                        'icon' => 'fa fa-check'
                    ],
                    'hide' => [
                        'title' => __( 'Hide', 'guto-toolkit' ),
                        'icon' => 'fa fa-close'
                    ]
                ],
                'default' => 'show',
                'toggle' => true
            ]
        );

        $this->add_control(
            'featured_img1_menu1',
            [
                'label' => esc_html__( 'Featured Image 1', 'guto-toolkit' ),
                'type' => Controls_Manager::MEDIA,
                'show_label' => true,
            ]
        );

        $this->add_control(
            'featured_img2_menu1',
            [
                'label' => esc_html__( 'Featured Image 2', 'guto-toolkit' ),
                'type' => Controls_Manager::MEDIA,
                'show_label' => true,
            ]
        );

        $this->add_control(
            'button1_text',
            [
                'label'     => esc_html__( 'Button1 Text', 'guto-toolkit' ),
                'type'      => Controls_Manager::TEXT,
                'default'   => esc_html__('Explore Our Menu', 'guto-toolkit'),
            ]
        );

        $this->add_control(
            'button1_icon',
            [
                'label' => esc_html__( 'Button1 Icon', 'guto-toolkit' ),
                'type' => Controls_Manager::ICON,
                'label_block' => true,
                'default' => 'bx bx-right-arrow-alt',
                'options' => guto_toolkit_icons(),
            ]
        );

        $this->add_control(
            'link1_type',
            [
                'label'         => esc_html__( 'Button1 Link Type', 'guto-toolkit' ),
                'type'          => Controls_Manager::SELECT,
                'label_block'   => true,
                'options' => [
                    '1'     => esc_html__( 'Link To Page', 'guto-toolkit' ),
                    '2'     => esc_html__( 'External Link', 'guto-toolkit' ),
                ],
                'default' => '2',
            ]
        );

        $this->add_control(
            'link1_to_page',
            [
                'label'         => esc_html__( 'Button1 Link Page', 'guto-toolkit' ),
                'type'          => Controls_Manager::SELECT,
                'label_block'   => true,
                'options'       => guto_toolkit_get_page_as_list(),
                'condition' => [
                    'link1_type' => '1',
                ]
            ]
        );

        $this->add_control(
            'ex1_link',
            [
                'label'     => esc_html__('Button1 External Link', 'guto-toolkit'),
                'type'      => Controls_Manager:: URL,
                'show_external' => true,
                'default' => [
                    'url' => '#',
                    'is_external' => true,
                    'nofollow' => true,
                ],
                'condition' => [
                    'link1_type' => '2',
                ]
            ]
        );

		$this->add_control(
            'guto_restaurant_menu_items_one',
            [
                'label' => esc_html__('Menu Item', 'guto-toolkit'),
                'type' => Controls_Manager::REPEATER,
                'default' => [
                    [ 'name' => esc_html__(' Item #1', 'guto-toolkit') ],

                ],
                'fields' => [
                    [
                        'name'  => 'menu_name',
                        'label'     => esc_html__( 'Menu Name', 'guto-toolkit' ),
                        'type'      => Controls_Manager::TEXT,
                        'default'   => esc_html__('Chicken Steak', 'guto-toolkit'),
                    ],
                    [
                        'name'  => 'description',
                        'label'     => esc_html__( 'Description', 'guto-toolkit' ),
                        'type'      => Controls_Manager::TEXTAREA,
                        'default'   => esc_html__('Lorem ipsum dolor sit amet consectetur adipisicing elit. Dolor repudiandae natus nobis temporibus maiores officiis delectus exercitationem', 'guto-toolkit'),
                    ],
                    [
                        'name'  => 'price',
                        'label'     => esc_html__( 'Price', 'guto-toolkit' ),
                        'type'      => Controls_Manager::TEXT,
                        'default'   => esc_html__('$15.00', 'guto-toolkit'),
                    ],
                    [
                        'name'  => 'image',
                        'label' => esc_html__( 'Menu Image', 'guto-toolkit' ),
                        'type' => Controls_Manager::MEDIA,
                        'show_label' => true,
                    ],
                    [
                        'name'  => 'link',
                        'label'     => esc_html__( 'Menu Link', 'guto-toolkit' ),
                        'type'      => Controls_Manager::TEXT,
                        'default'   => esc_html__('#', 'guto-toolkit'),
                    ],
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'menu_section_two',
            [
                'label' => esc_html__( 'Menu 2', 'guto-toolkit' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'show_menu_two',
            [
                'label' => __( 'Show/Hide Menu 2', 'guto-toolkit' ),
                'type' => \Elementor\Controls_Manager::CHOOSE,
                'options' => [
                    'show' => [
                        'title' => __( 'Show', 'guto-toolkit' ),
                        'icon' => 'fa fa-check'
                    ],
                    'hide' => [
                        'title' => __( 'Hide', 'guto-toolkit' ),
                        'icon' => 'fa fa-close'
                    ]
                ],
                'default' => 'show',
                'toggle' => true
            ]
        );

        $this->add_control(
            'featured_img1_menu2',
            [
                'label' => esc_html__( 'Featured Image 1', 'guto-toolkit' ),
                'type' => Controls_Manager::MEDIA,
                'show_label' => true,
            ]
        );

        $this->add_control(
            'featured_img2_menu2',
            [
                'label' => esc_html__( 'Featured Image 2', 'guto-toolkit' ),
                'type' => Controls_Manager::MEDIA,
                'show_label' => true,
            ]
        );

        $this->add_control(
            'button2_text',
            [
                'label'     => esc_html__( 'Button Text', 'guto-toolkit' ),
                'type'      => Controls_Manager::TEXT,
                'default'   => esc_html__('Explore Our Menu', 'guto-toolkit'),
            ]
        );

        $this->add_control(
            'button2_icon',
            [
                'label' => esc_html__( 'Button Icon', 'guto-toolkit' ),
                'type' => Controls_Manager::ICON,
                'label_block' => true,
                'default' => 'bx bx-right-arrow-alt',
                'options' => guto_toolkit_icons(),
            ]
        );

        $this->add_control(
            'link2_type',
            [
                'label'         => esc_html__( 'Button Link Type', 'guto-toolkit' ),
                'type'          => Controls_Manager::SELECT,
                'label_block'   => true,
                'options' => [
                    '1'     => esc_html__( 'Link To Page', 'guto-toolkit' ),
                    '2'     => esc_html__( 'External Link', 'guto-toolkit' ),
                ],
                'default' => '2',
            ]
        );

        $this->add_control(
            'link2_to_page',
            [
                'label'         => esc_html__( 'Button Link Page', 'guto-toolkit' ),
                'type'          => Controls_Manager::SELECT,
                'label_block'   => true,
                'options'       => guto_toolkit_get_page_as_list(),
                'condition' => [
                    'link2_type' => '1',
                ]
            ]
        );

        $this->add_control(
            'ex2_link',
            [
                'label'     => esc_html__('Button2 External Link', 'guto-toolkit'),
                'type'      => Controls_Manager:: URL,
                'show_external' => true,
                'default' => [
                    'url' => '#',
                    'is_external' => true,
                    'nofollow' => true,
                ],
                'condition' => [
                    'link2_type' => '2',
                ]
            ]
        );

        $this->add_control(
            'guto_restaurant_menu_items_two',
            [
                'label' => esc_html__('Menu Item', 'guto-toolkit'),
                'type' => Controls_Manager::REPEATER,
                'default' => [
                    [ 'name' => esc_html__(' Item #1', 'guto-toolkit') ],

                ],
                'fields' => [
                    [
                        'name'  => 'menu_name',
                        'label'     => esc_html__( 'Menu Name', 'guto-toolkit' ),
                        'type'      => Controls_Manager::TEXT,
                        'default'   => esc_html__('Chicken Steak', 'guto-toolkit'),
                    ],
                    [
                        'name'  => 'description',
                        'label'     => esc_html__( 'Description', 'guto-toolkit' ),
                        'type'      => Controls_Manager::TEXTAREA,
                        'default'   => esc_html__('Lorem ipsum dolor sit amet consectetur adipisicing elit. Dolor repudiandae natus nobis temporibus maiores officiis delectus exercitationem', 'guto-toolkit'),
                    ],
                    [
                        'name'  => 'price',
                        'label'     => esc_html__( 'Price', 'guto-toolkit' ),
                        'type'      => Controls_Manager::TEXT,
                        'default'   => esc_html__('$15.00', 'guto-toolkit'),
                    ],
                    [
                        'name'  => 'image',
                        'label' => esc_html__( 'Menu Image', 'guto-toolkit' ),
                        'type' => Controls_Manager::MEDIA,
                        'show_label' => true,
                    ],
                    [
                        'name'  => 'link',
                        'label'     => esc_html__( 'Menu Link', 'guto-toolkit' ),
                        'type'      => Controls_Manager::TEXT,
                        'default'   => esc_html__('#', 'guto-toolkit'),
                    ],
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'menu_section_three',
            [
                'label' => esc_html__( 'Menu 3', 'guto-toolkit' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'show_menu_three',
            [
                'label' => __( 'Show/Hide Menu 3', 'guto-toolkit' ),
                'type' => \Elementor\Controls_Manager::CHOOSE,
                'options' => [
                    'show' => [
                        'title' => __( 'Show', 'guto-toolkit' ),
                        'icon' => 'fa fa-check'
                    ],
                    'hide' => [
                        'title' => __( 'Hide', 'guto-toolkit' ),
                        'icon' => 'fa fa-close'
                    ]
                ],
                'default' => 'show',
                'toggle' => true
            ]
        );

        $this->add_control(
            'featured_img1_menu3',
            [
                'label' => esc_html__( 'Featured Image 1', 'guto-toolkit' ),
                'type' => Controls_Manager::MEDIA,
                'show_label' => true,
            ]
        );

        $this->add_control(
            'featured_img2_menu3',
            [
                'label' => esc_html__( 'Featured Image 2', 'guto-toolkit' ),
                'type' => Controls_Manager::MEDIA,
                'show_label' => true,
            ]
        );

        $this->add_control(
            'button3_text',
            [
                'label'     => esc_html__( 'Button Text', 'guto-toolkit' ),
                'type'      => Controls_Manager::TEXT,
                'default'   => esc_html__('Explore Our Menu', 'guto-toolkit'),
            ]
        );

        $this->add_control(
            'button3_icon',
            [
                'label' => esc_html__( 'Button Icon', 'guto-toolkit' ),
                'type' => Controls_Manager::ICON,
                'label_block' => true,
                'default' => 'bx bx-right-arrow-alt',
                'options' => guto_toolkit_icons(),
            ]
        );

        $this->add_control(
            'link3_type',
            [
                'label'         => esc_html__( 'Button Link Type', 'guto-toolkit' ),
                'type'          => Controls_Manager::SELECT,
                'label_block'   => true,
                'options' => [
                    '1'     => esc_html__( 'Link To Page', 'guto-toolkit' ),
                    '2'     => esc_html__( 'External Link', 'guto-toolkit' ),
                ],
                'default' => '2',
            ]
        );

        $this->add_control(
            'link3_to_page',
            [
                'label'         => esc_html__( 'Button Link Page', 'guto-toolkit' ),
                'type'          => Controls_Manager::SELECT,
                'label_block'   => true,
                'options'       => guto_toolkit_get_page_as_list(),
                'condition' => [
                    'link3_type' => '1',
                ]
            ]
        );

        $this->add_control(
            'ex3_link',
            [
                'label'     => esc_html__('Button External Link', 'guto-toolkit'),
                'type'      => Controls_Manager:: URL,
                'show_external' => true,
                'default' => [
                    'url' => '#',
                    'is_external' => true,
                    'nofollow' => true,
                ],
                'condition' => [
                    'link3_type' => '2',
                ]
            ]
        );

        $this->add_control(
            'guto_restaurant_menu_items_three',
            [
                'label' => esc_html__('Menu Item', 'guto-toolkit'),
                'type' => Controls_Manager::REPEATER,
                'default' => [
                    [ 'name' => esc_html__(' Item #1', 'guto-toolkit') ],

                ],
                'fields' => [
                    [
                        'name'  => 'menu_name',
                        'label'     => esc_html__( 'Menu Name', 'guto-toolkit' ),
                        'type'      => Controls_Manager::TEXT,
                        'default'   => esc_html__('Chicken Steak', 'guto-toolkit'),
                    ],
                    [
                        'name'  => 'description',
                        'label'     => esc_html__( 'Description', 'guto-toolkit' ),
                        'type'      => Controls_Manager::TEXTAREA,
                        'default'   => esc_html__('Lorem ipsum dolor sit amet consectetur adipisicing elit. Dolor repudiandae natus nobis temporibus maiores officiis delectus exercitationem', 'guto-toolkit'),
                    ],
                    [
                        'name'  => 'price',
                        'label'     => esc_html__( 'Price', 'guto-toolkit' ),
                        'type'      => Controls_Manager::TEXT,
                        'default'   => esc_html__('$15.00', 'guto-toolkit'),
                    ],
                    [
                        'name'  => 'image',
                        'label' => esc_html__( 'Menu Image', 'guto-toolkit' ),
                        'type' => Controls_Manager::MEDIA,
                        'show_label' => true,
                    ],
                    [
                        'name'  => 'link',
                        'label'     => esc_html__( 'Menu Link', 'guto-toolkit' ),
                        'type'      => Controls_Manager::TEXT,
                        'default'   => esc_html__('#', 'guto-toolkit'),
                    ],
                ],
            ]
        );

        $this->end_controls_section();

    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        $this-> add_inline_editing_attributes('title', 'none');

        // Get Button1 Link
        if($settings['link1_type'] == 1){
            $link1 = get_page_link( $settings['link1_to_page'] );
        } elseif($settings['link1_type'] == 2) {
            $link1 = $settings['ex1_link']['url'];
            $target1 = $settings['ex1_link']['is_external'] ? ' target="_blank"' : '';
            $nofollow1 = $settings['ex1_link']['nofollow'] ? ' rel="nofollow"' : '';
        }

        $button1_text = $settings['button1_text'];

        // Get Button2 Link
        if($settings['link2_type'] == 1){
            $link2 = get_page_link( $settings['link2_to_page'] );
        } elseif($settings['link2_type'] == 2) {
            $link2 = $settings['ex2_link']['url'];
            $target2 = $settings['ex2_link']['is_external'] ? ' target="_blank"' : '';
            $nofollow2 = $settings['ex2_link']['nofollow'] ? ' rel="nofollow"' : '';
        }

        $button2_text = $settings['button2_text'];

         // Get Button3 Link
        if($settings['link3_type'] == 1){
            $link3 = get_page_link( $settings['link3_to_page'] );
        } elseif($settings['link3_type'] == 2) {
            $link3 = $settings['ex3_link']['url'];
            $target3 = $settings['ex3_link']['is_external'] ? ' target="_blank"' : '';
            $nofollow3 = $settings['ex3_link']['nofollow'] ? ' rel="nofollow"' : '';
        }

        $button3_text = $settings['button3_text'];

        $restaurant_menu_one = $settings['guto_restaurant_menu_items_one'];
        $restaurant_menu_two = $settings['guto_restaurant_menu_items_two'];
        $restaurant_menu_three = $settings['guto_restaurant_menu_items_three'];

        ?>

        <!-- Start Restaurant Our Top Dishes Area -->
        <?php if( is_home() || is_front_page() ) : ?>
            <section class="restaurant-our-top-dishes-area pt-100">
        <?php else: ?>
            <section class="restaurant-our-top-dishes-area ptb-100">
        <?php endif; ?>
            <div class="container">
                <div class="restaurant-section-title">
                    <<?php echo esc_attr( $settings['title_tag'] ); ?> <?php echo $this-> get_render_attribute_string('title'); ?>>
                        <?php echo wp_kses_post( $settings['title'] ); ?>
                    </<?php echo esc_attr( $settings['title_tag'] ); ?>>
                </div>
                <?php if( $settings['show_menu_one'] == 'show' ) : ?>
                    <!-- Start First Menu -->
                    <div class="row align-items-center pb-100">
                        <div class="col-lg-6">
                            <div class="restaurant-dishes-list">
                                <ul>
                                    <?php foreach ($restaurant_menu_one as $key => $value) : ?>
                                        <li>
                                            <?php if( ! $value['image']['url'] == '' ) : ?>
                                                <a href="<?php echo esc_html__( $value['link'] ); ?>">
                                                    <img src="<?php echo esc_url( $value['image']['url']); ?>" alt="Image">
                                                </a>
                                            <?php endif; ?>
                                            <h3>
                                                <a href="<?php echo esc_html__( $value['link'] ); ?>">
                                                    <?php echo esc_html__( $value['menu_name'] ); ?>
                                                </a>
                                            </h3>
                                            <p><?php echo wp_kses_post( $value['description'] ); ?></p>
                                            <span><?php echo esc_html__( $value['price'] ); ?></span>
                                        </li>
                                    <?php endforeach; ?>
                                    <?php if( $button1_text != '' ): ?>
                                        <li class="p-0">
                                            <?php if($settings['link1_type'] == 1): ?>
                                                <a href="<?php echo esc_url( $link1 ); ?>" class="default-btn"><?php echo esc_html( $button1_text ); ?><i class="<?php echo esc_attr( $settings['button1_icon'] ); ?>"></i>
                                                </a>
                                            <?php elseif($settings['link1_type'] == 2):
                                                echo '<a href="' .  $link1 . '" class="default-btn" ' . $target1 . $nofollow1 . '>' . $button1_text . ' <i class="'.$settings['button1_icon'].'"></i></a>';
                                            endif; ?>
                                        </li>
                                    <?php endif; ?>
                                </ul>
                            </div>
                        </div>
                        <div class="col-lg-6">
                            <div class="row">
                                <div class="col-lg-6">
                                    <div class="restaurant-dishes-bg bg-1" style="background-image:url(<?php echo esc_url($settings['featured_img1_menu1']['url']); ?>);"></div>
                                </div>
                                <div class="col-lg-6">
                                    <div class="restaurant-dishes-bg bg-2" style="background-image:url(<?php echo esc_url($settings['featured_img2_menu1']['url']); ?>);"></div>
                                </div>
                            </div>
                        </div>
                    </div>
                    <!-- End First Menu -->
                <?php endif; ?>
                <?php if( $settings['show_menu_two'] == 'show' ) : ?>
                    <!-- Start Second Menu -->
                    <div class="row align-items-center pb-100">
                        <div class="col-lg-6">
                            <div class="row">
                                <div class="col-lg-6">
                                    <div class="restaurant-dishes-bg bg-3" style="background-image:url(<?php echo esc_url($settings['featured_img1_menu2']['url']); ?>);"></div>
                                </div>
                                <div class="col-lg-6">
                                    <div class="restaurant-dishes-bg bg-4" style="background-image:url(<?php echo esc_url($settings['featured_img2_menu2']['url']); ?>);"></div>
                                </div>
                            </div>
                        </div>
                        <div class="col-lg-6">
                            <div class="restaurant-dishes-list mt-30-for responsive">
                                <ul>
                                    <?php foreach ($restaurant_menu_two as $key => $value) : ?>
                                        <li>
                                            <?php if( ! $value['image']['url'] == '' ) : ?>
                                                <a href="<?php echo esc_html__( $value['link'] ); ?>">
                                                    <img src="<?php echo esc_url( $value['image']['url']); ?>" alt="Image">
                                                </a>
                                            <?php endif; ?>
                                            <h3>
                                                <a href="<?php echo esc_html__( $value['link'] ); ?>">
                                                    <?php echo esc_html__( $value['menu_name'] ); ?>
                                                </a>
                                            </h3>
                                            <p><?php echo wp_kses_post( $value['description'] ); ?></p>
                                            <span><?php echo esc_html__( $value['price'] ); ?></span>
                                        </li>
                                    <?php endforeach; ?>
                                    <?php if( $button2_text != '' ): ?>
                                        <li class="p-0">
                                            <?php if($settings['link2_type'] == 1): ?>
                                                <a href="<?php echo esc_url( $link1 ); ?>" class="default-btn"><?php echo esc_html( $button2_text ); ?><i class="<?php echo esc_attr( $settings['button2_icon'] ); ?>"></i>
                                                </a>
                                            <?php elseif($settings['link2_type'] == 2):
                                                echo '<a href="' .  $link2 . '" class="default-btn" ' . $target2 . $nofollow2 . '>' . $button2_text . ' <i class="'.$settings['button2_icon'].'"></i></a>';
                                            endif; ?>
                                        </li>
                                    <?php endif; ?>
                                </ul>
                            </div>
                        </div>
                    </div>
                    <!-- End Second Menu -->
                <?php endif; ?>
                <?php if( $settings['show_menu_three'] == 'show' ) : ?>
                    <!-- Start Third Menu -->
                    <div class="row align-items-center">
                        <div class="col-lg-6">
                            <div class="restaurant-dishes-list mt-30-for responsive">
                                <ul>
                                    <?php foreach ($restaurant_menu_three as $key => $value) : ?>
                                        <li>
                                            <?php if( ! $value['image']['url'] == '' ) : ?>
                                                <a href="<?php echo esc_html__( $value['link'] ); ?>">
                                                    <img src="<?php echo esc_url( $value['image']['url']); ?>" alt="Image">
                                                </a>
                                            <?php endif; ?>
                                            <h3>
                                                <a href="<?php echo esc_html__( $value['link'] ); ?>">
                                                    <?php echo esc_html__( $value['menu_name'] ); ?>
                                                </a>
                                            </h3>
                                            <p><?php echo wp_kses_post( $value['description'] ); ?></p>
                                            <span><?php echo esc_html__( $value['price'] ); ?></span>
                                        </li>
                                    <?php endforeach; ?>
                                    <?php if( $button3_text != '' ): ?>
                                        <li class="p-0">
                                            <?php if($settings['link3_type'] == 1): ?>
                                                <a href="<?php echo esc_url( $link3 ); ?>" class="default-btn"><?php echo esc_html( $button3_text ); ?><i class="<?php echo esc_attr( $settings['button3_icon'] ); ?>"></i>
                                                </a>
                                            <?php elseif($settings['link3_type'] == 2):
                                                echo '<a href="' .  $link3 . '" class="default-btn" ' . $target3 . $nofollow3 . '>' . $button3_text . ' <i class="'.$settings['button3_icon'].'"></i></a>';
                                            endif; ?>
                                        </li>
                                    <?php endif; ?>
                                </ul>
                            </div>
                        </div>
                        <div class="col-lg-6">
                            <div class="row">
                                <div class="col-lg-6">
                                    <div class="restaurant-dishes-bg bg-5" style="background-image:url(<?php echo esc_url($settings['featured_img1_menu3']['url']); ?>);"></div>
                                </div>
                                <div class="col-lg-6">
                                    <div class="restaurant-dishes-bg bg-6" style="background-image:url(<?php echo esc_url($settings['featured_img2_menu3']['url']); ?>);"></div>
                                </div>
                            </div>
                        </div>
                    </div>
                    <!-- End Third Menu -->
                <?php endif; ?>
            </div>
        </section>
        <!-- End Restaurant Our Top Dishes Area -->

        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_Restaurant_Menu );
