<?php
/**
 * Restaurant Offer Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

class Guto_Restaurant_Offer extends Widget_Base {

    public function get_name() {
        return 'Restaurant_Offer';
    }

    public function get_title() {
        return esc_html__( 'Restaurant Offer', 'guto-toolkit' );
    }

    public function get_icon() {
        return 'eicon-posts-group';
    }

    public function get_categories() {
        return [ 'guto-restaurant' ];
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'content_section',
            [
                'label' => esc_html__( 'Content', 'guto-toolkit' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'title',
            [
                'label' => esc_html__( 'Title', 'guto-toolkit' ),
                'type' => Controls_Manager::WYSIWYG,
                'default' => __('What <span>Services</span> We Offer', 'guto-toolkit'),
            ]
        );

        $this->add_control(
            'title_tag',
            [
                'label' => esc_html__( 'Title Tag', 'guto-toolkit' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'h1'         => esc_html__( 'h1', 'guto-toolkit' ),
                    'h2'         => esc_html__( 'h2', 'guto-toolkit' ),
                    'h3'         => esc_html__( 'h3', 'guto-toolkit' ),
                    'h4'         => esc_html__( 'h4', 'guto-toolkit' ),
                    'h5'         => esc_html__( 'h5', 'guto-toolkit' ),
                    'h6'         => esc_html__( 'h6', 'guto-toolkit' ),
                ],
                'default' => 'h2',
            ]
        );

        $this->add_control(
            'image',
            [
                'label' => esc_html__( 'Section Image', 'guto-toolkit' ),
                'type' => Controls_Manager::MEDIA,
                'show_label' => true,
            ]
        );

        $this->add_control(
            'guto_offer_items',
            [
                'label' => esc_html__('Offer Item', 'guto-toolkit'),
                'type' => Controls_Manager::REPEATER,
                'default' => [
                    [ 'name' => esc_html__(' Item #1', 'guto-toolkit') ],

                ],
                'fields' => [
                     [
                        'name' => 'number',
                        'label' => esc_html__('Number', 'guto-toolkit'),
                        'type' => Controls_Manager::NUMBER,
                        'default' => __('1', 'guto-toolkit'),
                        'label_block' => true,
                    ],
                    [
                        'name' => 'heading',
                        'label' => esc_html__('Heding', 'guto-toolkit'),
                        'type' => Controls_Manager::TEXT,
                        'default' => esc_html__('Dine In', 'guto-toolkit'),
                        'label_block' => true,
                    ],
                    [
                        'name' => 'description',
                        'label' => esc_html__('Description', 'guto-toolkit'),
                        'type' => Controls_Manager::TEXTAREA,
                        'default' => __('Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy eirmod tempor invidunt ut labore et dolore.', 'guto-toolkit'),
                        'label_block' => true,
                    ],

                ],
            ]
        );

    $this->end_controls_section();

    }

    protected function render() {

        $settings = $this->get_settings_for_display();

        $slider = $settings['guto_offer_items'];

        // Inline Editing
        $this-> add_inline_editing_attributes('title', 'none'); ?>

        <!-- Start Restaurant Offer Area -->
        <section class="restaurant-offer-area pt-100 pb-70" style="background-image:url(<?php echo esc_url($settings['image']['url']); ?>);">
            <div class="container">
                <div class="restaurant-section-title">
                    <<?php echo esc_attr( $settings['title_tag'] ); ?> <?php echo $this-> get_render_attribute_string('title'); ?>>
                        <?php echo wp_kses_post( $settings['title'] ); ?>
                    </<?php echo esc_attr( $settings['title_tag'] ); ?>>
                </div>
                <div class="row justify-content-center">
                    <?php foreach ($slider as $key => $value): ?>
                        <div class="col-lg-4 col-md-6">
                            <div class="restaurant-single-services-box">
                                <span><?php echo esc_html( $value['number'] ); ?></span>
                                <h3><?php echo esc_html( $value['heading'] ); ?></h3>
                                <p><?php echo wp_kses_post( $value['description'] ); ?></p>
                            </div>
                        </div>
                    <?php endforeach; ?>
                </div>
            </div>
        </div>
        <!-- End Restaurant Offer Area -->

        <?php
    }



}

Plugin::instance()->widgets_manager->register( new Guto_Restaurant_Offer );
