<?php
/**
 * Restaurant Slider Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_Restaurant_Slider extends Widget_Base {

	public function get_name() {
        return 'Guto_Restaurant_Slider';
    }

	public function get_title() {
        return esc_html__( 'Restaurant Slider', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-banner';
    }

	public function get_categories() {
        return [ 'guto-restaurant' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'content_section',
			[
				'label' => esc_html__( 'Content', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

		$this->add_control(
            'guto_restaurant_slider_items',
            [
                'label' => esc_html__('Slider Item', 'guto-toolkit'),
                'type' => Controls_Manager::REPEATER,
                'default' => [
                    [ 'name' => esc_html__(' Item #1', 'guto-toolkit') ],

                ],
                'fields' => [
                    [
                        'name'  => 'title',
                        'label'     => esc_html__( 'Title', 'guto-toolkit' ),
                        'type'      => Controls_Manager::TEXT,
                        'default'   => esc_html__('Taste The Top Best Dishes With Us', 'guto-toolkit'),
                    ],
                    [
                        'name'  => 'title_tag',
                        'label'     => esc_html__( 'Title Tag', 'guto-toolkit' ),
                        'type'      => Controls_Manager::SELECT,
                        'options'   => [
                            'h1'         => esc_html__( 'h1', 'guto-toolkit' ),
                            'h2'         => esc_html__( 'h2', 'guto-toolkit' ),
                            'h3'         => esc_html__( 'h3', 'guto-toolkit' ),
                            'h4'         => esc_html__( 'h4', 'guto-toolkit' ),
                            'h5'         => esc_html__( 'h5', 'guto-toolkit' ),
                            'h6'         => esc_html__( 'h6', 'guto-toolkit' ),
                        ],
                        'default' => 'h1',
                    ],
                    [
                        'name'  => 'subtitle',
                        'label'     => esc_html__( 'Subtitle', 'guto-toolkit' ),
                        'type'      => Controls_Manager::TEXT,
                        'default'   => esc_html__('Juicy Pepperoni Pizza', 'guto-toolkit'),
                    ],
                    [
                        'name'  => 'price',
                        'label'     => esc_html__( 'Price', 'guto-toolkit' ),
                        'type'      => Controls_Manager::TEXT,
                        'default'   => esc_html__('$21.00', 'guto-toolkit'),
                    ],
                    [
                        'name'  => 'image',
                        'label' => esc_html__( 'Slider Image', 'guto-toolkit' ),
                        'type' => Controls_Manager::MEDIA,
                        'show_label' => true,
                    ],
                    [
                        'name'  => 'button_icon',
                        'label' => esc_html__( 'Button Icon', 'guto-toolkit' ),
                        'type' => Controls_Manager::ICON,
                        'label_block' => true,
                        'default' => 'bx bx-shopping-bag',
                        'options' => guto_toolkit_icons(),
                    ],
                    [
                        'name'  => 'button_text',
                        'label'     => esc_html__( 'Button Text', 'guto-toolkit' ),
                        'type'      => Controls_Manager::TEXT,
                        'default'   => esc_html__('Order Now', 'guto-toolkit'),
                    ],
                    [
                        'name'  => 'link_type',
                        'label'         => esc_html__( 'Button Link Type', 'guto-toolkit' ),
                        'type'          => Controls_Manager::SELECT,
                        'label_block'   => true,
                        'options' => [
                            '1'     => esc_html__( 'Link To Page', 'guto-toolkit' ),
                            '2'     => esc_html__( 'External Link', 'guto-toolkit' ),
                        ],
                        'default' => '2',
                    ],
                    [
                        'name'  => 'link_to_page',
                        'label'         => esc_html__( 'Button Link Page', 'guto-toolkit' ),
                        'type'          => Controls_Manager::SELECT,
                        'label_block'   => true,
                        'options'       => guto_toolkit_get_page_as_list(),
                        'condition' => [
                            'link_type' => '1',
                        ]
                    ],
                    [
                        'name'  => 'ex_link',
                        'label'        => esc_html__('Button External Link', 'guto-toolkit'),
                        'type'      => Controls_Manager:: URL,
                        'show_external' => true,
                        'default' => [
                            'url' => '#',
                            'is_external' => true,
                            'nofollow' => true,
                        ],
                        'condition' => [
                            'link_type' => '2',
                        ]
                    ]
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'shape_section',
            [
                'label' => esc_html__( 'Shape', 'guto-toolkit' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

            $this->add_control(
                'shape_img_1',
                [
                'label' => esc_html__( 'Shape Image 1', 'guto-toolkit' ),
                'type' => Controls_Manager::MEDIA,
                'show_label' => true,
                ],
            );
            $this->add_control(
                'shape_img_2',
                [
                'label' => esc_html__( 'Shape Image 2', 'guto-toolkit' ),
                'type' => Controls_Manager::MEDIA,
                'show_label' => true,
                ],
            );

        $this->end_controls_section();

    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        $this-> add_inline_editing_attributes('title', 'none');

        $restaurant_slider = $settings['guto_restaurant_slider_items'];

        $count = 0;
        foreach ($restaurant_slider as $items => $counts):
            $count++;
        endforeach;
        ?>

        <!-- Start Restaurant Hero Slider Area -->
        <section class="restaurant-hero-slider-area">
            <div class="restaurant-hero-slider owl-theme owl-carousel" data-slider-id="1">
                <?php foreach ($restaurant_slider as $key => $value):
                    // Get Button Link
                    if($value['link_type'] == 1){
                        $link = get_page_link( $value['link_to_page'] );
                    } elseif($value['link_type'] == 2) {
                        $link = $value['ex_link']['url'];
                        $target = $value['ex_link']['is_external'] ? ' target="_blank"' : '';
                        $nofollow = $value['ex_link']['nofollow'] ? ' rel="nofollow"' : '';
                    }
                    $button_text = $value['button_text']; ?>
                    <div class="hero-slider-item">
                        <div class="d-table">
                            <div class="d-table-cell">
                                <div class="container-fluid">
                                    <div class="row align-items-center">
                                        <div class="col-lg-6 col-md-6">
                                            <div class="restaurant-hero-slider-content">
                                                <<?php echo esc_attr( $value['title_tag'] ); ?> <?php echo $this-> get_render_attribute_string('title'); ?>>
                                                    <?php echo esc_html( $value['title'] ); ?>
                                                </<?php echo esc_attr( $value['title_tag'] ); ?>>
                                                <h3><?php echo esc_html( $value['subtitle'] ); ?></h3>
                                                <span><?php echo esc_html( $value['price'] ); ?></span>
                                                <div class="slider-btn">
                                                    <?php if( $button_text != '' ): ?>
                                                        <?php if($value['link_type'] == 1): ?>
                                                            <a href="<?php echo esc_url( $link ); ?>" class="default-btn black-btn"><?php echo esc_html( $button_text ); ?><i class="<?php echo esc_attr( $value['button_icon'] ); ?>"></i>
                                                            </a>
                                                        <?php elseif($value['link_type'] == 2):
                                                            echo '<a href="' .  $link . '" class="default-btn black-btn" ' . $target . $nofollow . '>' . $button_text . ' <i class="'.$value['button_icon'].'"></i></a>';
                                                        endif; ?>
                                                    <?php endif; ?>
                                                </div>
                                            </div>
                                        </div>
                                        <div class="col-lg-6 col-md-6 pr-0">
                                            <?php if( ! $value['image']['url'] == '' ) : ?>
                                                <div class="restaurant-hero-slider-img">
                                                    <img src="<?php echo esc_url( $value['image']['url']); ?>" alt="Image">
                                                </div>
                                            <?php endif; ?>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                <?php endforeach; ?>
            </div>
            <!-- Start Carousel Thumbs -->
            <div class="thumbs-wrap">
                <div class="owl-thumbs hero-slider-thumb" data-slider-id="1">
                    <div class="owl-thumb-item">
                        <span></span>
                    </div>

                    <div class="owl-thumb-item">
                        <span></span>
                    </div>

                    <div class="owl-thumb-item">
                        <span></span>
                    </div>
                </div>
            </div>
            <?php if( ! $settings['shape_img_1']['url'] == '' ) : ?>
                <div class="shape shape-1">
                    <img src="<?php echo esc_url( $settings['shape_img_1']['url'] ); ?>" alt="Image">
                </div>
            <?php endif; ?>
            <?php if( ! $settings['shape_img_2']['url'] == '' ) : ?>
                <div class="shape shape-2">
                    <img src="<?php echo esc_url( $settings['shape_img_2']['url'] ); ?>" alt="Image">
                </div>
            <?php endif; ?>
            <!-- End Carousel Thumbs -->
        </section>
        <!-- End Restaurant Hero Slide Area -->

        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_Restaurant_Slider );