<?php
/**
 * Restaurant Special Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

class Guto_Restaurant_Special extends Widget_Base {

    public function get_name() {
        return 'Restaurant_Special';
    }

    public function get_title() {
        return esc_html__( 'Restaurant Special Offer', 'guto-toolkit' );
    }

    public function get_icon() {
        return 'eicon-posts-group';
    }

    public function get_categories() {
        return [ 'guto-restaurant' ];
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'content_section',
            [
                'label' => esc_html__( 'Content', 'guto-toolkit' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'title',
            [
                'label' => esc_html__( 'Title', 'guto-toolkit' ),
                'type' => Controls_Manager::WYSIWYG,
                'default' => __('Avail Our Special <span>Offers</span>', 'guto-toolkit'),
            ]
        );

        $this->add_control(
            'title_tag',
            [
                'label' => esc_html__( 'Title Tag', 'guto-toolkit' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'h1'         => esc_html__( 'h1', 'guto-toolkit' ),
                    'h2'         => esc_html__( 'h2', 'guto-toolkit' ),
                    'h3'         => esc_html__( 'h3', 'guto-toolkit' ),
                    'h4'         => esc_html__( 'h4', 'guto-toolkit' ),
                    'h5'         => esc_html__( 'h5', 'guto-toolkit' ),
                    'h6'         => esc_html__( 'h6', 'guto-toolkit' ),
                ],
                'default' => 'h2',
            ]
        );

        $this->add_control(
            'image1',
            [
                'label' => esc_html__( 'Offer Image 1', 'guto-toolkit' ),
                'type' => Controls_Manager::MEDIA,
                'show_label' => true,
            ]
        );

        $this->add_control(
            'link1_type',
            [
                'label'         => esc_html__( 'Image Link Type', 'guto-toolkit' ),
                'type'          => Controls_Manager::SELECT,
                'label_block'   => true,
                'options' => [
                    '1'     => esc_html__( 'Link To Page', 'guto-toolkit' ),
                    '2'     => esc_html__( 'External Link', 'guto-toolkit' ),
                ],
                'default' => '2',
            ]
        );

        $this->add_control(
            'link1_to_page',
            [
                'label'         => esc_html__( 'Image Link Page', 'guto-toolkit' ),
                'type'          => Controls_Manager::SELECT,
                'label_block'   => true,
                'options'       => guto_toolkit_get_page_as_list(),
                'condition' => [
                    'link1_type' => '1',
                ]
            ]
        );

        $this->add_control(
            'ex1_link',
            [
                'label'     => esc_html__('Image External Link', 'guto-toolkit'),
                'type'      => Controls_Manager:: URL,
                'show_external' => true,
                'default' => [
                    'url' => '#',
                    'is_external' => true,
                    'nofollow' => true,
                ],
                'condition' => [
                    'link1_type' => '2',
                ]
            ]
        );

        $this->add_control(
            'image2',
            [
                'label' => esc_html__( 'Offer Image 2', 'guto-toolkit' ),
                'type' => Controls_Manager::MEDIA,
                'show_label' => true,
            ]
        );

        $this->add_control(
            'link2_type',
            [
                'label'         => esc_html__( 'Image Link Type', 'guto-toolkit' ),
                'type'          => Controls_Manager::SELECT,
                'label_block'   => true,
                'options' => [
                    '1'     => esc_html__( 'Link To Page', 'guto-toolkit' ),
                    '2'     => esc_html__( 'External Link', 'guto-toolkit' ),
                ],
                'default' => '2',
            ]
        );

        $this->add_control(
            'link2_to_page',
            [
                'label'         => esc_html__( 'Image Link Page', 'guto-toolkit' ),
                'type'          => Controls_Manager::SELECT,
                'label_block'   => true,
                'options'       => guto_toolkit_get_page_as_list(),
                'condition' => [
                    'link1_type' => '1',
                ]
            ]
        );

        $this->add_control(
            'ex2_link',
            [
                'label'     => esc_html__('Image External Link', 'guto-toolkit'),
                'type'      => Controls_Manager:: URL,
                'show_external' => true,
                'default' => [
                    'url' => '#',
                    'is_external' => true,
                    'nofollow' => true,
                ],
                'condition' => [
                    'link1_type' => '2',
                ]
            ]
        );

    $this->end_controls_section();

    }

    protected function render() {

        $settings = $this->get_settings_for_display();

        // Inline Editing
        $this-> add_inline_editing_attributes('title', 'none');

        // Get Button1 Link
        if($settings['link1_type'] == 1){
            $link1 = get_page_link( $settings['link1_to_page'] );
        } elseif($settings['link1_type'] == 2) {
            $link1 = $settings['ex1_link']['url'];
            $target1 = $settings['ex1_link']['is_external'] ? ' target="_blank"' : '';
            $nofollow1 = $settings['ex1_link']['nofollow'] ? ' rel="nofollow"' : '';
        }

        // Get Button2 Link
        if($settings['link2_type'] == 1){
            $link2 = get_page_link( $settings['link2_to_page'] );
        } elseif($settings['link2_type'] == 2) {
            $link2 = $settings['ex2_link']['url'];
            $target2 = $settings['ex2_link']['is_external'] ? ' target="_blank"' : '';
            $nofollow2 = $settings['ex2_link']['nofollow'] ? ' rel="nofollow"' : '';
        }

        ?>

        <!-- Start Restaurant Special Offers Area -->
        <section class="restaurant-special-Offers pt-100 pb-70">
            <div class="container">
                <div class="restaurant-section-title">
                    <<?php echo esc_attr( $settings['title_tag'] ); ?> <?php echo $this-> get_render_attribute_string('title'); ?>>
                        <?php echo wp_kses_post( $settings['title'] ); ?>
                    </<?php echo esc_attr( $settings['title_tag'] ); ?>>
                </div>
                <div class="row">
                    <?php if( ! $settings['image1']['url'] == '' ) : ?>
                        <div class="col-lg-6 col-md-6">
                            <div class="restaurant-special-offers-img">
                                <?php if($settings['link1_type'] == 1): ?>
                                    <a href="<?php echo esc_url( $link1 ); ?>">
                                    <?php elseif($settings['link1_type'] == 2):
                                        echo '<a href="' .  $link1 . '" ' . $target1 . $nofollow1 . '>';
                                    endif; ?>
                                    <img src="<?php echo esc_url( $settings['image1']['url'] ); ?>" alt="Image">
                                </a>
                            </div>
                        </div>
                    <?php endif; ?>
                    <?php if( ! $settings['image2']['url'] == '' ) : ?>
                        <div class="col-lg-6 col-md-6">
                            <div class="restaurant-special-offers-img">
                                <?php if($settings['link2_type'] == 1): ?>
                                    <a href="<?php echo esc_url( $link2 ); ?>">
                                    <?php elseif($settings['link2_type'] == 2):
                                        echo '<a href="' .  $link2 . '" ' . $target2 . $nofollow2 . '>';
                                    endif; ?>
                                    <img src="<?php echo esc_url( $settings['image2']['url'] ); ?>" alt="Image">
                                </a>
                            </div>
                        </div>
                    <?php endif; ?>
                </div>
            </div>
        </div>
        <!-- End Restaurant Special Offers Area -->

        <?php
    }



}

Plugin::instance()->widgets_manager->register( new Guto_Restaurant_Special );
