<?php
/**
 * Restaurant Video Area Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_Restaurant_Video extends Widget_Base {

	public function get_name() {
        return 'Restaurant_Video';
    }

	public function get_title() {
        return esc_html__( 'Restaurant Video', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-play';
    }

	public function get_categories() {
        return [ 'guto-restaurant' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'Guto_Video_Area',
			[
				'label' => esc_html__( 'Guto Video Area', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

            $this->add_control(
                'title',
                [
                    'label' => esc_html__( 'Title', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default' => __('See How We <span>Serve</span> Our Clients', 'guto-toolkit'),
                ]
            );

            $this->add_control(
                'title_tag',
                [
                    'label' => esc_html__( 'Title Tag', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        'h1'         => esc_html__( 'h1', 'guto-toolkit' ),
                        'h2'         => esc_html__( 'h2', 'guto-toolkit' ),
                        'h3'         => esc_html__( 'h3', 'guto-toolkit' ),
                        'h4'         => esc_html__( 'h4', 'guto-toolkit' ),
                        'h5'         => esc_html__( 'h5', 'guto-toolkit' ),
                        'h6'         => esc_html__( 'h6', 'guto-toolkit' ),
                    ],
                    'default' => 'h2',
                ]
            );

            $this->add_control(
                'link',
                [
                    'label'		=> esc_html__('YouTube Video Link', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: TEXT,
                    'default' => __('https://www.youtube.com/watch?v=AC9EfT-y9e4', 'guto-toolkit'),
                ]
            );

            $this->add_control(
                'bg_image',
                [
                    'label' => esc_html__( 'Video Area Background Image', 'guto-toolkit' ),
                    'type'	 => Controls_Manager::MEDIA,
                    'show_label' => true,
                ]
            );

        $this->end_controls_section();

    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        // Inline Editing
        $this-> add_inline_editing_attributes('title', 'none'); ?>

        <!-- Start Restaurant Video Area -->
        <div class="restaurant-video-area ptb-100" style="background-image:url('<?php echo esc_url( $settings['bg_image']['url'] ); ?>');">
            <div class="container">
                <div class="restaurant-section-title">
                    <<?php echo esc_attr( $settings['title_tag'] ); ?> <?php echo $this-> get_render_attribute_string('title'); ?>><?php echo wp_kses_post( $settings['title'] ); ?></<?php echo esc_attr( $settings['title_tag'] ); ?>>
                </div>
                <div class="row">
                    <?php if( $settings['link'] != '' ): ?>
                        <div class="restaurant-video-button">
                            <a href="<?php echo esc_url($settings['link']); ?>" class="popup-youtube restaurant-video-btn"><i class='bx bx-play'></i></a>
                        </div>
                    <?php endif; ?>
                </div>
            </div>
        </div>
        <!-- End Restaurant Video Area -->

        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_Restaurant_Video );
