<?php
/**
 * Facility Area Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_Facility_Area extends Widget_Base {

	public function get_name() {
        return 'Facility_Area';
    }

	public function get_title() {
        return esc_html__( 'Facility Area', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-carousel';
    }

	public function get_categories() {
        return [ 'guto-elements' ];
    }

	protected function register_controls() {

        $this->start_controls_section(
			'Guto_Facility_Area',
			[
				'label' => esc_html__( 'Guto Facility Area', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

        $this->add_control(
            'facility_style',
            [
                'label' => esc_html__( 'Facility Style', 'guto-toolkit' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    '1'         => esc_html__( 'Style One', 'guto-toolkit' ),
                    '2'         => esc_html__( 'Style Two', 'guto-toolkit' ),
                ],
                'default' => '1',
            ]
        );

		$this->add_control(
            'items',
            [
                'label' => esc_html__('Items', 'guto-toolkit'),
                'type' => Controls_Manager::REPEATER,
                'separator' => 'before',
                'fields' => [
					[
						'name'	=> 'title',
						'label' => esc_html__( 'Title', 'guto-toolkit' ),
                        'type'		=> Controls_Manager:: TEXT,
					],
                    [
                        'name'  => 'icon',
                        'label' => esc_html__( 'Icon', 'guto-toolkit' ),
                        'type' => Controls_Manager::ICON,
                        'label_block' => true,
                        'options' => guto_toolkit_icons(),
                    ],
                ]
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
			'section_style',
			[
				'label' => esc_html__( 'Style', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
        );

            $this->add_control(
                'title_color',
                [
                    'label' => esc_html__( 'Title Color', 'guto-toolkit' ),
                    'type' => Controls_Manager::COLOR,
                    'selectors' => [
                        '{{WRAPPER}} .single-facility-box h3, .os-future-area span' => 'color: {{VALUE}}',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'title_typography',
                    'label' => esc_html__( 'Title Typography', 'guto-toolkit' ),
                    'scheme' => Core\Schemes\Typography::TYPOGRAPHY_1,
                    'selector' => '{{WRAPPER}} .single-facility-box h3, .os-future-area span',
                ]
            );

        $this->end_controls_section();
    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        if( $settings['facility_style'] == '1' ): ?>

            <div class="container">
                <div class="row">
                    <?php foreach($settings['items'] as $item): ?>
                        <div class="col-lg-3 col-sm-6 col-md-6">
                            <div class="single-facility-box">
                                <div class="icon">
                                    <i class="<?php echo esc_attr($item['icon']); ?>"></i>
                                </div>
                                <h3><?php echo esc_html( $item['title'] ); ?></h3>
                            </div>
                        </div>
                    <?php endforeach; ?>
                </div>
            </div>

        <?php elseif( $settings['facility_style'] == '2' ): ?>

            <!-- Start OS Future Area -->
            <div class="os-future-area ptb-100">
                <div class="container">
                    <div class="os-future-bg">
                        <div class="row">
                            <?php foreach($settings['items'] as $item): ?>
                                <div class="col-lg-3 col-sm-6 col-md-6">
                                    <div class="os-single-future">
                                        <i class="<?php echo esc_attr($item['icon']); ?>"></i>
                                        <span><?php echo esc_html( $item['title'] ); ?></span>
                                    </div>
                                </div>
                            <?php endforeach; ?>
                        </div>
                    </div>
                </div>
            </div>
            <!-- End OS Future Area -->

        <?php endif;
	}



}

Plugin::instance()->widgets_manager->register( new Guto_Facility_Area );