<?php
/**
 * Yoga About Area Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_Yoga_About_Area extends Widget_Base {

	public function get_name() {
        return 'Yoga_About_Area';
    }

	public function get_title() {
        return esc_html__( 'Yoga About', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-info-box';
    }

	public function get_categories() {
        return [ 'guto-yoga' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'Yoga_About_Area',
			[
				'label' => esc_html__( 'Yoga About', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

            $this->add_control(
                'title',
                [
                    'label' => esc_html__( 'Title', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__('Find Your Inner Beauty Through Yoga And Mediation', 'guto-toolkit'),
                ]
            );

            $this->add_control(
                'title_tag',
                [
                    'label' => esc_html__( 'Title Tag', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        'h1'         => esc_html__( 'h1', 'guto-toolkit' ),
                        'h2'         => esc_html__( 'h2', 'guto-toolkit' ),
                        'h3'         => esc_html__( 'h3', 'guto-toolkit' ),
                        'h4'         => esc_html__( 'h4', 'guto-toolkit' ),
                        'h5'         => esc_html__( 'h5', 'guto-toolkit' ),
                        'h6'         => esc_html__( 'h6', 'guto-toolkit' ),
                    ],
                    'default' => 'h2',
                ]
            );

            $this->add_control(
                'content',
                [
                    'label' => esc_html__( 'Content', 'guto-toolkit' ),
                    'type' => Controls_Manager::WYSIWYG,
                    'default' => esc_html__('Lorem ipsum dolor sit amet, consectetur adipiscing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Quis ipsum suspendisse ultrices gravida.', 'guto-toolkit'),
                ]
            );

            $this->add_control(
				'button_text',
				[
					'label' 	=> esc_html__( 'Button Text', 'guto-toolkit' ),
					'type' 		=> Controls_Manager::TEXT,
					'default' 	=> esc_html__('Join For Me', 'guto-toolkit'),
				]
            );

            $this->add_control(
                'link_type',
                [
                    'label' 		=> esc_html__( 'Button Link Type', 'guto-toolkit' ),
                    'type' 			=> Controls_Manager::SELECT,
                    'label_block' 	=> true,
                    'options' => [
                        '1'  	=> esc_html__( 'Link To Page', 'guto-toolkit' ),
                        '2' 	=> esc_html__( 'External Link', 'guto-toolkit' ),
                    ],
                    'default' => '2'
                ]
            );

            $this->add_control(
                'link_to_page',
                [
                    'label' 		=> esc_html__( 'Button Link Page', 'guto-toolkit' ),
                    'type' 			=> Controls_Manager::SELECT,
                    'label_block' 	=> true,
                    'options' 		=> guto_toolkit_get_page_as_list(),
                    'condition' => [
                        'link_type' => '1',
                    ]
                ]
            );

            $this->add_control(
                'ex_link',
                [
                    'label'		=> esc_html__('Button External Link', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: URL,
                    'show_external' => true,
                    'default' => [
                        'url' => '#',
                        'is_external' => true,
                        'nofollow' => true,
                    ],
                    'condition' => [
                        'link_type' => '2',
                    ]
                ]
            );

            $this->add_control(
                'guto_about_classes',
                [
                    'label' => esc_html__('Classes Item', 'guto-toolkit'),
                    'type' => Controls_Manager::REPEATER,
                    'default' => [
                        [ 'name' => esc_html__(' Item #1', 'guto-toolkit') ],

                    ],
                    'fields' => [
                        [
                            'name' => 'classes_title',
                            'label' => esc_html__('Item Title', 'guto-toolkit'),
                            'type' => Controls_Manager::TEXT,
                            'default' => esc_html__('Classes', 'guto-toolkit'),
                            'label_block' => true,
                        ],
                        [
                            'name' => 'classes_link',
                            'label' => esc_html__('Item Link', 'guto-toolkit'),
                            'type' => Controls_Manager::TEXT,
                            'default' => esc_html__('#', 'guto-toolkit'),
                            'label_block' => true,
                        ],
                        [
                            'name' => 'classes_image',
                            'label' => esc_html__('Item Image', 'guto-toolkit'),
                            'type' => Controls_Manager::MEDIA,
                            'show_label' => true,
                        ],
                    ],
                ]
            );

            $this->add_control(
                'image',
                [
                    'label' => esc_html__( 'About Image', 'guto-toolkit' ),
                    'type'	 => Controls_Manager::MEDIA,
                    'show_label' => true,
                ]
            );

        $this->end_controls_section();

    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        // Inline Editing
        $this-> add_inline_editing_attributes('title','none');
        $this-> add_inline_editing_attributes('content','none');

        $guto_about_classes = $settings['guto_about_classes'];

        // Get Button Link
        if($settings['link_type'] == 1){
            $link = get_page_link( $settings['link_to_page'] );
        } elseif($settings['link_type'] == 2) {
            $link = $settings['ex_link']['url'];
            $target = $settings['ex_link']['is_external'] ? ' target="_blank"' : '';
		    $nofollow = $settings['ex_link']['nofollow'] ? ' rel="nofollow"' : '';
        }

        $button_text = $settings['button_text'];

        ?>

        <section class="yoga-about-area ptb-100">
            <div class="container">
                <div class="row align-items-center">
                    <div class="col-lg-6">
                        <div class="yoga-about-content">
                            <<?php echo esc_attr( $settings['title_tag'] ); ?> <?php echo $this-> get_render_attribute_string('title'); ?>><?php echo wp_kses_post( $settings['title'] ); ?></<?php echo esc_attr( $settings['title_tag'] ); ?>>

                            <p><?php echo wp_kses_post( $settings['content'] ); ?></p>
                            <?php if( $button_text != '' ): ?>
                                <?php if($settings['link_type'] == 1): ?>
                                    <a href="<?php echo esc_url( $link ); ?>" class="yoga-default-btn"><?php echo esc_html( $button_text ); ?></a>
                                <?php elseif($settings['link_type'] == 2):
                                    echo '<a href="' .  $link . '" class="yoga-default-btn" ' . $target . $nofollow . '>' . $button_text . ' </a>';
                                endif; ?>
                            <?php endif; ?>
                            <div class="yoga-about-img-group">
                                <div class="row align-items-center">
                                    <?php foreach ($guto_about_classes as $key => $value): ?>
                                        <div class="col-lg-6 col-md-6">
                                            <a href="<?php echo esc_url( $value['classes_link'] ); ?>" class="classes about-1">
                                                <img src="<?php echo esc_url( $value['classes_image']['url'] ); ?>" alt="check">                                                <h3><?php echo esc_html( $value['classes_title'] ); ?></h3>
                                            </a>
                                        </div>
                                    <?php endforeach; ?>
                                </div>
                            </div>
                        </div>
                    </div>
                    <div class="col-lg-6">
                        <?php if( $settings['image']['url'] != '' ): ?>
                            <div class="about-3">
                                <img src="<?php echo esc_url($settings['image']['url']); ?>" alt="<?php esc_attr_e('About Image', 'guto-toolkit'); ?>">
                            </div>
                        <?php endif; ?>
                    </div>
                </div>
            </div>
        </section>

        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_Yoga_About_Area );
