<?php
/**
 * Yoga Banner Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_Yoga_Banner extends Widget_Base {

	public function get_name() {
        return 'Guto_Yoga_Banner';
    }

	public function get_title() {
        return esc_html__( 'Yoga Banner', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-banner';
    }

	public function get_categories() {
        return [ 'guto-yoga' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'Guto_Yoga_Banner_Area',
			[
				'label' => esc_html__( 'Banner Controls', 'guto-toolkit' ),
				'tab' 	=> Controls_Manager::TAB_CONTENT,
			]
		);

			$this->add_control(
				'title',
				[
					'label' 	=> esc_html__( 'Title', 'guto-toolkit' ),
					'type' 		=> Controls_Manager::TEXT,
					'default' 	=> __("Hey I'm <span>Alexa</span>", 'guto-toolkit'),
				]
			);

			$this->add_control(
                'title_tag',
                [
                    'label' 	=> esc_html__( 'Title Tag', 'guto-toolkit' ),
                    'type' 		=> Controls_Manager::SELECT,
                    'options' 	=> [
                        'h1'         => esc_html__( 'h1', 'guto-toolkit' ),
                        'h2'         => esc_html__( 'h2', 'guto-toolkit' ),
                        'h3'         => esc_html__( 'h3', 'guto-toolkit' ),
                        'h4'         => esc_html__( 'h4', 'guto-toolkit' ),
                        'h5'         => esc_html__( 'h5', 'guto-toolkit' ),
                        'h6'         => esc_html__( 'h6', 'guto-toolkit' ),
                    ],
                    'default' => 'h1',
                ]
            );

			$this->add_control(
				'content',
				[
					'label' 	=> esc_html__( 'Content', 'guto-toolkit' ),
					'type' 		=> Controls_Manager::TEXTAREA,
					'default' 	=> esc_html__('A Yoga Trainer Who Can Lead You To A Healthier Mind & Life With Personal Attention And Professional Guidance.', 'guto-toolkit'),
				]
            );

			$this->add_control(
				'button_text',
				[
					'label' 	=> esc_html__( 'Button Text', 'guto-toolkit' ),
					'type' 		=> Controls_Manager::TEXT,
					'default' 	=> esc_html__('Join For Free', 'guto-toolkit'),
				]
            );

            $this->add_control(
                'link_type',
                [
                    'label' 		=> esc_html__( 'Button Link Type', 'guto-toolkit' ),
                    'type' 			=> Controls_Manager::SELECT,
                    'label_block' 	=> true,
                    'options' => [
                        '1'  	=> esc_html__( 'Link To Page', 'guto-toolkit' ),
                        '2' 	=> esc_html__( 'External Link', 'guto-toolkit' ),
                    ],
                    'default' > '2'
                ]
            );

            $this->add_control(
                'link_to_page',
                [
                    'label' 		=> esc_html__( 'Button Link Page', 'guto-toolkit' ),
                    'type' 			=> Controls_Manager::SELECT,
                    'label_block' 	=> true,
                    'options' 		=> guto_toolkit_get_page_as_list(),
                    'condition' => [
                        'link_type' => '1',
                    ]
                ]
            );

            $this->add_control(
                'ex_link',
                [
                    'label'		=> esc_html__('Button External Link', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: URL,
                    'show_external' => true,
                    'default' => [
                        'url' => '#',
                        'is_external' => true,
                        'nofollow' => true,
                    ],
                    'condition' => [
                        'link_type' => '2',
                    ]
                ]
            );

            $this->add_control(
                'big_title',
                [
                    'label'     => esc_html__( 'Big Title', 'guto-toolkit' ),
                    'type'      => Controls_Manager::TEXT,
                    'default'   => esc_html__("Yoga", 'guto-toolkit'),
                ]
            );

        $this->end_controls_section();

        $this->start_controls_section(
			'banner_images',
			[
				'label' => esc_html__( 'Images', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

            $this->add_control(
                'bg_image',
                [
                    'label'     => esc_html__('Banner Background Image', 'guto-toolkit'),
                    'type'      => Controls_Manager:: MEDIA,
                    'show_label' => true,
                ]
            );

            $this->add_control(
                'image',
                [
                    'label'		=> esc_html__('Banner Image', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: MEDIA,
                    'show_label' => true,
                ]
            );

            $this->add_control(
                'shape1',
                [
                    'label'		=> esc_html__('Shape Image One', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: MEDIA,
                    'show_label' => true,
                ]
            );

            $this->add_control(
                'shape2',
                [
                    'label'		=> esc_html__('Shape Image Two', 'guto-toolkit'),
                    'type'		=> Controls_Manager:: MEDIA,
                    'show_label' => true,
                ]
            );

        $this->end_controls_section();

    }

	protected function render() {

		$settings = $this->get_settings_for_display();

        // Inline Editing
        $this-> add_inline_editing_attributes('title','none');
        $this-> add_inline_editing_attributes('content','none');

        // Get Button Link
        if($settings['link_type'] == 1){
            $link = get_page_link( $settings['link_to_page'] );
        } elseif($settings['link_type'] == 2) {
            $link = $settings['ex_link']['url'];
            $target = $settings['ex_link']['is_external'] ? ' target="_blank"' : '';
		    $nofollow = $settings['ex_link']['nofollow'] ? ' rel="nofollow"' : '';
        }

        $button_text = $settings['button_text']; ?>
            <!-- Start Yoga Banner Area -->
            <section class="yoga-banner-area">
                <div class="d-table">
                    <div class="d-table-cell">
                        <div class="container">
                            <div class="row align-items-center">
                                <div class="col-lg-6">
                                    <div class="yoga-banner-content">
                                        <<?php echo esc_attr( $settings['title_tag'] ); ?> <?php echo $this-> get_render_attribute_string('title'); ?>>
                                            <?php echo wp_kses_post( $settings['title'] ); ?>
                                        </<?php echo esc_attr( $settings['title_tag'] ); ?>>
                                        <p <?php echo $this-> get_render_attribute_string('content'); ?>><?php echo wp_kses_post( $settings['content'] ); ?></p>

                                        <?php if( $button_text != '' ): ?>
                                            <?php if($settings['link_type'] == 1): ?>
                                                <a href="<?php echo esc_url( $link ); ?>" class="yoga-default-btn"><?php echo esc_html( $button_text ); ?></a>
                                            <?php elseif($settings['link_type'] == 2):
                                                echo '<a href="' .  $link . '" class="yoga-default-btn" ' . $target . $nofollow . '>' . $button_text . ' </a>';
                                            endif; ?>
                                        <?php endif; ?>
                                    </div>
                                </div>
                                <div class="col-lg-6">
                                    <span class="yoga">
                                         <?php echo wp_kses_post( $settings['big_title'] ); ?>
                                    </span>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <div class="banner-img">
                    <?php if( $settings['image']['url'] != '' ): ?>
                        <img src="<?php echo esc_url($settings['image']['url']); ?>" alt="<?php echo esc_attr($settings['title']); ?>">
                    <?php endif; ?>
                </div>
                <?php if( $settings['shape1']['url'] != '' ): ?>
                    <div class="banner-img-shape">
                        <img src="<?php echo esc_url($settings['shape1']['url']); ?>" alt="<?php esc_attr_e('Shape Image', 'guto-toolkit'); ?>">
                    </div>
                <?php endif; ?>

                <?php if( $settings['shape2']['url'] != '' ): ?>
                    <div class="banner-shape-left">
                        <img src="<?php echo esc_url($settings['shape2']['url']); ?>" alt="<?php esc_attr_e('Shape Image', 'guto-toolkit'); ?>">
                    </div>
                <?php endif; ?>
            </section>
            <!-- End Yoga Banner Area -->
        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_Yoga_Banner );
