<?php
/**
 * Yoga Classes Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_Yoga_Classes extends Widget_Base {

	public function get_name() {
        return 'Yoga Classes';
    }

	public function get_title() {
        return esc_html__( 'Yoga Classes', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-menu-toggle';
    }

	public function get_categories() {
        return [ 'guto-yoga' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'content_section',
			[
				'label' => esc_html__( 'Content', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

        $this->add_control(
            'title',
            [
                'label' => esc_html__( 'Heading', 'guto-toolkit' ),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__("Schedule", 'guto-toolkit'),
            ]
        );

        $this->add_control(
            'title_tag',
            [
                'label' => esc_html__( 'Title Tag', 'guto-toolkit' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'h1'         => esc_html__( 'h1', 'guto-toolkit' ),
                    'h2'         => esc_html__( 'h2', 'guto-toolkit' ),
                    'h3'         => esc_html__( 'h3', 'guto-toolkit' ),
                    'h4'         => esc_html__( 'h4', 'guto-toolkit' ),
                    'h5'         => esc_html__( 'h5', 'guto-toolkit' ),
                    'h6'         => esc_html__( 'h6', 'guto-toolkit' ),
                ],
                'default' => 'h2',
            ]
        );

        $this->add_control(
            'button_text',
            [
                'label'     => esc_html__( 'Button Text', 'guto-toolkit' ),
                'type'      => Controls_Manager::TEXT,
                'default'   => esc_html__('Download Schedule', 'guto-toolkit'),
            ]
        );

        $this->add_control(
            'button_link',
            [
                'label'     => esc_html__( 'Button Link', 'guto-toolkit' ),
                'type'      => Controls_Manager::TEXT,
                'default'   => esc_html__('#', 'guto-toolkit'),
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'content_day',
            [
                'label' => esc_html__( 'Class Day', 'guto-toolkit' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'yoga_classes_day',
            [
                'label' => esc_html__('Day', 'guto-toolkit'),
                'type' => Controls_Manager::REPEATER,
                'default' => [
                    [ 'name' => esc_html__(' Item #1', 'guto-toolkit') ],
                ],
                'fields' => [
                    [
                        'name' => 'class_day',
                        'label' => esc_html__('Day', 'guto-toolkit'),
                        'type' => Controls_Manager::TEXT,
                        'default' => esc_html__('SUN', 'guto-toolkit'),
                        'label_block' => true,
                    ],
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'content_time_name',
            [
                'label' => esc_html__( 'Class Time & Name', 'guto-toolkit' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'yoga_classes_time_name',
            [
                'label' => esc_html__('Time & Name', 'guto-toolkit'),
                'type' => Controls_Manager::REPEATER,
                'default' => [
                    [ 'name' => esc_html__(' Item #1', 'guto-toolkit') ],
                ],
                'fields' => [
                    [
                        'name' => 'class_time',
                        'label' => esc_html__('Time', 'guto-toolkit'),
                        'type' => Controls_Manager::TEXT,
                        'default' => esc_html__('06:00 AM', 'guto-toolkit'),
                        'label_block' => true,
                    ],
                    [
                        'name' => 'class_name1',
                        'label' => esc_html__('Class Name 1', 'guto-toolkit'),
                        'type' => Controls_Manager::TEXT,
                        'default' => esc_html__('Zumba', 'guto-toolkit'),
                        'label_block' => true,
                    ],
                    [
                        'name' => 'class_name2',
                        'label' => esc_html__('Class Name 2', 'guto-toolkit'),
                        'type' => Controls_Manager::TEXT,
                        'default' => esc_html__('Gentle Yoga', 'guto-toolkit'),
                        'label_block' => true,
                    ],
                    [
                        'name' => 'class_name3',
                        'label' => esc_html__('Class Name 3', 'guto-toolkit'),
                        'type' => Controls_Manager::TEXT,
                        'default' => esc_html__('', 'guto-toolkit'),
                        'label_block' => true,
                    ],
                    [
                        'name' => 'class_name4',
                        'label' => esc_html__('Class Name 4', 'guto-toolkit'),
                        'type' => Controls_Manager::TEXT,
                        'default' => esc_html__('Gentle Yoga', 'guto-toolkit'),
                        'label_block' => true,
                    ],
                    [
                        'name' => 'class_name5',
                        'label' => esc_html__('Class Name 5', 'guto-toolkit'),
                        'type' => Controls_Manager::TEXT,
                        'default' => esc_html__('Hatha Yoga', 'guto-toolkit'),
                        'label_block' => true,
                    ],
                    [
                        'name' => 'class_name6',
                        'label' => esc_html__('Class Name 6', 'guto-toolkit'),
                        'type' => Controls_Manager::TEXT,
                        'default' => esc_html__('Hatha Yoga', 'guto-toolkit'),
                        'label_block' => true,
                    ],
                    [
                        'name' => 'class_name7',
                        'label' => esc_html__('Class Name 7', 'guto-toolkit'),
                        'type' => Controls_Manager::TEXT,
                        'default' => esc_html__('Hatha Yoga', 'guto-toolkit'),
                        'label_block' => true,
                    ],
                ],
            ]
        );

    $this->end_controls_section();

    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        // Inline Editing
        $this-> add_inline_editing_attributes('title', 'none');

        $classes_day = $settings['yoga_classes_day'];
        $classes_time_name = $settings['yoga_classes_time_name']; ?>

        <!-- Start Yoga Schedule Area -->
        <section class="yoga-schedule-area ptb-100">
            <div class="container">
                <div class="row">
                    <div class="col-lg-6 col-sm-6">
                        <<?php echo esc_attr( $settings['title_tag'] ); ?> <?php echo $this-> get_render_attribute_string('title'); ?>>
                                <?php echo esc_html( $settings['title'] ); ?>
                            </<?php echo esc_attr( $settings['title_tag'] ); ?>>
                    </div>
                    <div class="col-lg-6 col-sm-6">
                        <a href="<?php echo esc_url( $settings['button_link'] ); ?>" class="yoga-default-btn"><?php echo esc_html__( $settings['button_text'] ); ?></a>
                    </div>
                </div>
                <div class="yoga-doctor-vaccination-table table-responsive">
                    <table class="table">
                        <thead>
                            <tr>
                                <th class="color-none"></th>
                                <?php foreach ($classes_day as $key => $value) : ?>
                                    <th><?php echo esc_html__( $value['class_day'] ); ?></th>
                                <?php endforeach; ?>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($classes_time_name as $key => $value) : ?>
                                <tr>
                                    <td class="tb-color">
                                        <span><?php echo esc_html__( $value['class_time'] ); ?></span>
                                    </td>
                                    <td>
                                        <span><?php echo esc_html__( $value['class_name1'] ); ?></span>
                                    </td>
                                    <td>
                                        <span><?php echo esc_html__( $value['class_name2'] ); ?></span>
                                    </td>
                                    <td>
                                        <span><?php echo esc_html__( $value['class_name3'] ); ?></span>
                                    </td>
                                    <td>
                                        <span><?php echo esc_html__( $value['class_name4'] ); ?></span>
                                    </td>
                                    <td>
                                        <span><?php echo esc_html__( $value['class_name5'] ); ?></span>
                                    </td>
                                    <td>
                                        <span><?php echo esc_html__( $value['class_name6'] ); ?></span>
                                    </td>
                                    <td>
                                        <span><?php echo esc_html__( $value['class_name7'] ); ?></span>
                                    </td>
                                </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                </div>
            </div>
        </section>
        <!-- End Yoga Schedule Area -->

        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_Yoga_Classes );
