<?php
/**
 * Yoga Contact Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

class Guto_Yoga_Contact extends Widget_Base {

    public function get_name() {
        return 'Yoga_Contact_Area';
    }

    public function get_title() {
        return esc_html__( 'Yoga Contact', 'guto-toolkit' );
    }

    public function get_icon() {
        return 'eicon-form-horizontal';
    }

    public function get_categories() {
        return [ 'guto-yoga' ];
    }

    protected function _register_controls() {

        $this->start_controls_section(
            'Yoga_Contact_Area',
            [
                'label' => esc_html__( 'Yoga Contact', 'guto-toolkit' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

            $this->add_control(
                'contact_form_title', [
                    'label' => esc_html__( 'Form Title', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'label_block' => true,
                    'default' => 'Get In Touch',
                ]
            );

            $this->add_control(
                'shortcode',
                [
                    'label' => esc_html__( 'Contact Shortcode', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                ]
            );

             $this->add_control(
                'contact_address_title', [
                    'label' => esc_html__( 'Address Title', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'label_block' => true,
                    'default' => 'Contact Details',
                ]
            );

            $this->add_control(
                'list_items',
                [
                    'label' => esc_html__('List Item', 'guto-toolkit'),
                    'type' => Controls_Manager::REPEATER,
                    'separator' => 'before',
                    'fields' => [
                        [
                            'name'      => 'title',
                            'label'     => esc_html__( 'Title', 'guto-toolkit' ),
                            'type'      => Controls_Manager::TEXT,
                            'default'   => esc_html__('Address', 'guto-toolkit'),
                        ],
                        [
                            'name'      => 'content',
                            'label'     => esc_html__( 'Content', 'guto-toolkit' ),
                            'type'      => Controls_Manager::TEXTAREA,
                            'default'   => esc_html__('CA 560 Bush St & 20th Ave, Apt 5 San Francisco, 230909, Canada', 'guto-toolkit'),
                        ],
                    ],
                ]
            );

        $this->end_controls_section();
    }

    protected function render() {

        $settings = $this->get_settings_for_display();

        // Inline Editing
        $this-> add_inline_editing_attributes('title', 'none'); ?>

        <!-- Start Yoga Contact Area -->
        <div class="yoga-contact-area ptb-100">
            <div class="container">
                <div class="row">
                    <div class="col-lg-8">
                        <div class="contact-form">
                            <h2><?php echo esc_html__( $settings['contact_form_title']); ?></h2>
                            <?php if($settings['shortcode']): ?>
                                <div class="yoga-contact-form">
                                    <?php echo do_shortcode( $settings['shortcode'] ); ?>
                                </div>
                            <?php endif; ?>
                        </div>
                    </div>
                    <div class="col-lg-4">
                        <div class="yoga-address">
                            <h3><?php echo esc_html__( $settings['contact_address_title']); ?></h3>
                            <ul>
                                <?php foreach( $settings['list_items'] as $item ) : ?>
                                    <li>
                                        <span><?php echo esc_html( $item['title'] ); ?></span>
                                        <?php echo wp_kses_post( $item['content'] ); ?>
                                    </li>
                                <?php endforeach; ?>
                            </ul>
                        </div>
                    </div>
                </div>
            </div>
        </div>
        <!-- End Yoga Contact Area -->

        <?php
    }



}

Plugin::instance()->widgets_manager->register( new Guto_Yoga_Contact );
