<?php
/**
 * Yoga Courses Widget
 */

namespace Elementor;

class Guto_Yoga_Courses extends Widget_Base {

	public function get_name() {
        return 'Yoga Courses';
    }

	public function get_title() {
        return esc_html__( 'Yoga Courses', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-posts-grid';
    }

	public function get_categories() {
        return [ 'guto-yoga' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'courses_section',
			[
				'label' => esc_html__( 'Courses', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );


            $this->add_control(
                'order',
                [
                    'label' => esc_html__( 'Courses Order By', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        'DESC'      => esc_html__( 'DESC', 'guto-toolkit' ),
                        'ASC'       => esc_html__( 'ASC', 'guto-toolkit' ),
                    ],
                    'default' => 'DESC',
                ]
            );

            $this->add_control(
                'count',
                [
                    'label' => esc_html__( 'Courses Per Page', 'guto-toolkit' ),
                    'type' => Controls_Manager::NUMBER,
                    'default' => 3,
                ]
            );

            $this->add_control(
                'view_details_text',
                [
                    'label' => esc_html__( 'View Details Text', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__('View Details', 'guto-toolkit'),
                ]
            );

            $this->add_control(
                'btn_text',
                [
                    'label' => esc_html__( 'Button Text', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__('Join Now', 'guto-toolkit'),
                ]
            );

        $this->end_controls_section();

    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        // Events Query
        $args = array(
            'post_type'         => 'courses',
            'posts_per_page'    => $settings['count'],
            'order'             => $settings['order']
        );

        $courses_array = new \WP_Query( $args ); ?>

        <!-- Start Yoga Courses Area -->
        <section class="yoga-courses-area pt-100 pb-70">
            <div class="container">
                <div class="row justify-content-center">
                    <?php while($courses_array->have_posts()) : $courses_array->the_post(); ?>
                        <div class="col-lg-4 col-md-6">
                            <div class="yoga-single-courses">
                                <?php if( get_the_post_thumbnail_url() ): ?>
                                    <img src="<?php the_post_thumbnail_url(); ?>" alt="<?php the_title(); ?>">
                                <?php endif; ?>
                                <div class="yoga-single-courses-content">
                                    <ul class="title">
                                        <li>
                                            <h3><?php the_title(); ?></h3>
                                        </li>
                                        <?php if ( defined( 'FW' ) ) {
                                            $course_price = fw_get_db_post_option( get_the_ID(), 'course_price' ); ?>
                                            <li class="price">
                                                <span><?php echo esc_html__( $course_price ); ?></span>
                                            </li>
                                        <?php } ?>
                                    </ul>
                                    <p><?php echo the_excerpt(); ?></p>
                                    <ul class="details">
                                        <li class="read-more-details">
                                            <a href="<?php the_permalink(); ?>" class="read-more">
                                                <?php echo esc_html__( $settings['view_details_text'] ); ?>
                                            </a>
                                        </li>
                                        <li>
                                            <a href="<?php the_permalink(); ?>" class="yoga-default-btn">
                                                <?php echo esc_html__( $settings['btn_text'] ); ?>
                                            </a>
                                        </li>
                                    </ul>
                                </div>
                            </div>
                        </div>
                    <?php endwhile; ?>
                    <?php wp_reset_query(); ?>
                </div>
            </div>
        </section>
        <!-- End Yoga Courses Area -->

        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_Yoga_Courses );
