<?php
/**
 * Yoga Event Details
 */

namespace Elementor;

class Guto_Yoga_Event_Details extends Widget_Base {

	public function get_name() {
        return 'Yoga Event Details';
    }

	public function get_title() {
        return esc_html__( 'Yoga Event Details', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-post-list';
    }

	public function get_categories() {
        return [ 'guto-yoga' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'event_schedule_section',
			[
				'label' => esc_html__( 'Event Schedule', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

        $this->add_control(
            'event_schedule_heading',
            [
                'label' => esc_html__( 'Heading', 'guto-toolkit' ),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Event Timing', 'guto-toolkit'),
            ]
        );

        $this->add_control(
            'yoga_event_schedule',
            [
                'label' => esc_html__('Timing Item', 'guto-toolkit'),
                'type' => Controls_Manager::REPEATER,
                'default' => [
                    [ 'name' => esc_html__(' Item #1', 'guto-toolkit') ],

                ],
                'fields' => [
                    [
                        'name' => 'day',
                        'label' => esc_html__('Event Day', 'guto-toolkit'),
                        'type' => Controls_Manager::TEXT,
                        'default' => esc_html__('SUN:', 'guto-toolkit'),
                        'label_block' => true,
                    ],
                    [
                        'name'  => 'time',
                        'label' => esc_html__( 'Event Time', 'guto-toolkit' ),
                        'type' => Controls_Manager::TEXT,
                        'default' => esc_html__('05:30 AM - 07:00 AM', 'guto-toolkit'),
                        'label_block' => true,
                    ],
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'event_register_section',
            [
                'label' => esc_html__( 'Event Register', 'guto-toolkit' ),
                'tab' => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'event_contact_heading',
            [
                'label' => esc_html__( 'Heading', 'guto-toolkit' ),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('Register For Join', 'guto-toolkit'),
            ]
        );

        $this->add_control(
            'event_register_form_shortcode',
            [
                'label' => esc_html__( 'Register Form Shortcode', 'guto-toolkit' ),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__('', 'guto-toolkit'),
            ]
        );

        $this->end_controls_section();

    }

	protected function render() {

        $settings = $this->get_settings_for_display();
        $yoga_event_schedule = $settings['yoga_event_schedule']; ?>

        <div class="yoga-event-details-content">
            <div class="row">
                <div class="col-lg-4">
                    <div class="yoga-class-timing">
                        <h3><?php echo esc_html__( $settings['event_schedule_heading'] ); ?></h3>
                        <ul>
                            <?php foreach ($yoga_event_schedule as $key => $value): ?>
                                <li>
                                    <?php echo esc_html__( $value['day'] ); ?>
                                    <span><?php echo esc_html__( $value['time'] ); ?></span>
                                </li>
                            <?php endforeach; ?>
                        </ul>
                    </div>
                </div>
                <div class="col-lg-8">
                    <div class="yoga-enroll-now">
                        <h3><?php echo esc_html__( $settings['event_contact_heading'] ); ?></h3>
                        <?php echo do_shortcode( $settings['event_register_form_shortcode'] ); ?>
                    </div>
                </div>
            </div>
        </div>

        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_Yoga_Event_Details );
