<?php
/**
 * Yoga Events Widget
 */

namespace Elementor;

class Guto_Yoga_Events extends Widget_Base {

	public function get_name() {
        return 'Yoga Events';
    }

	public function get_title() {
        return esc_html__( 'Yoga Events', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-post-list';
    }

	public function get_categories() {
        return [ 'guto-yoga' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'events_section',
			[
				'label' => esc_html__( 'Events', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

            $this->add_control(
                'events_style',
                [
                    'label' => esc_html__( 'Choose Style', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        '1'   => esc_html__( 'Style One', 'guto-toolkit' ),
                        '2'   => esc_html__( 'Style Two', 'guto-toolkit' ),
                    ],
                    'default' => '1',
                ]
            );

            $this->add_control(
                'title',
                [
                    'label' => esc_html__( 'Title', 'guto-toolkit' ),
                    'type' => Controls_Manager::TEXT,
                    'default' => esc_html__('Upcoming Events', 'guto-toolkit'),
                    'condition' => [
                        'events_style' => '1',
                    ]
                ]
            );

            $this->add_control(
                'title_tag',
                [
                    'label' => esc_html__( 'Title Tag', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        'h1'         => esc_html__( 'h1', 'guto-toolkit' ),
                        'h2'         => esc_html__( 'h2', 'guto-toolkit' ),
                        'h3'         => esc_html__( 'h3', 'guto-toolkit' ),
                        'h4'         => esc_html__( 'h4', 'guto-toolkit' ),
                        'h5'         => esc_html__( 'h5', 'guto-toolkit' ),
                        'h6'         => esc_html__( 'h6', 'guto-toolkit' ),
                    ],
                    'default' => 'h2',
                    'condition' => [
                        'events_style' => '1',
                    ]
                ]
            );

            $this->add_control(
                'content',
                [
                    'label' => esc_html__( 'Content', 'guto-toolkit' ),
                    'type' => Controls_Manager::WYSIWYG,
                    'default' => esc_html__('Lorem ipsum dolor sit amet, consetetur sadipscing elitr, sed diam nonumy eirmod tempor invidunt ut labore et dolore magna aliquyam erat, sed diam voluptua at vero', 'guto-toolkit'),
                    'condition' => [
                        'events_style' => '1',
                    ]
                ]
            );

            $this->add_control(
                'button_text',
                [
                    'label'     => esc_html__( 'Button Text', 'guto-toolkit' ),
                    'type'      => Controls_Manager::TEXT,
                    'default'   => esc_html__('View All Events', 'guto-toolkit'),
                    'condition' => [
                        'events_style' => '1',
                    ]
                ]
            );

            $this->add_control(
                'link_type',
                [
                    'label'         => esc_html__( 'Button Link Type', 'guto-toolkit' ),
                    'type'          => Controls_Manager::SELECT,
                    'label_block'   => true,
                    'options' => [
                        '1'     => esc_html__( 'Link To Page', 'guto-toolkit' ),
                        '2'     => esc_html__( 'External Link', 'guto-toolkit' ),
                    ],
                    'default' => '2',
                    'condition' => [
                        'events_style' => '1',
                    ]
                ]
            );

            $this->add_control(
                'link_to_page',
                [
                    'label'         => esc_html__( 'Button Link Page', 'guto-toolkit' ),
                    'type'          => Controls_Manager::SELECT,
                    'label_block'   => true,
                    'options'       => guto_toolkit_get_page_as_list(),
                    'condition' => [
                        'link_type' => '1',
                        'events_style' => '1',
                    ]
                ]
            );

            $this->add_control(
                'ex_link',
                [
                    'label'     => esc_html__('Button External Link', 'guto-toolkit'),
                    'type'      => Controls_Manager:: URL,
                    'show_external' => true,
                    'default' => [
                        'url' => '#',
                        'is_external' => true,
                        'nofollow' => true,
                    ],
                    'condition' => [
                        'link_type' => '2',
                        'events_style' => '1',
                    ]
                ]
            );

            $this->add_control(
                'order',
                [
                    'label' => esc_html__( 'Events Order By', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        'DESC'      => esc_html__( 'DESC', 'guto-toolkit' ),
                        'ASC'       => esc_html__( 'ASC', 'guto-toolkit' ),
                    ],
                    'default' => 'DESC',
                ]
            );

            $this->add_control(
                'count',
                [
                    'label' => esc_html__( 'Events Per Page', 'guto-toolkit' ),
                    'type' => Controls_Manager::NUMBER,
                    'default' => 3,
                ]
            );

            $this->add_control(
                'show_load_more',
                [
                    'label' => esc_html__( 'Show Load More', 'guto-toolkit' ),
                    'type' => Controls_Manager::SELECT,
                    'options' => [
                        '1'   => esc_html__( 'Show', 'guto-toolkit' ),
                        '2'   => esc_html__( 'Hide', 'guto-toolkit' ),
                    ],
                    'default' => '1',
                    'condition' => [
                        'events_style' => '2',
                    ]
                ]
            );

            $this->add_control(
                'load_more_text',
                [
                    'label'     => esc_html__( 'Load More Text', 'guto-toolkit' ),
                    'type'      => Controls_Manager::TEXT,
                    'default'   => esc_html__('Load More', 'guto-toolkit'),
                    'condition' => [
                        'events_style' => '2',
                    ]
                ]
            );

            $this->add_control(
                'shape_img',
                [
                    'label' => esc_html__( 'Shape Image', 'guto-toolkit' ),
                    'type'   => Controls_Manager::MEDIA,
                    'show_label' => true,
                    'condition' => [
                        'events_style' => '1',
                    ]
                ]
            );

        $this->end_controls_section();

    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        // Get Button Link
        if($settings['link_type'] == 1){
            $link = get_page_link( $settings['link_to_page'] );
        } elseif($settings['link_type'] == 2) {
            $link = $settings['ex_link']['url'];
            $target = $settings['ex_link']['is_external'] ? ' target="_blank"' : '';
            $nofollow = $settings['ex_link']['nofollow'] ? ' rel="nofollow"' : '';
        }

        $button_text = $settings['button_text'];

        // Events Query
        $args = array(
            'post_type'         => 'events',
            'posts_per_page'    => $settings['count'],
            'order'             => $settings['order']
        );

        $events_array = new \WP_Query( $args ); ?>

        <!-- Start Yoga Events Area -->
        <?php if( $settings['events_style']  == '1' ) : ?>
            <section class="yoga-events-area pt-100 pb-70">
                <div class="container">
                    <div class="row align-items-center justify-content-center">
                        <div class="col-lg-3">
                            <div class="yoga-event-content">
                                <<?php echo esc_attr( $settings['title_tag'] ); ?> <?php echo $this-> get_render_attribute_string('title'); ?>><?php echo wp_kses_post( $settings['title'] ); ?></<?php echo esc_attr( $settings['title_tag'] ); ?>>
                                <p><?php echo wp_kses_post( $settings['content'] ); ?></p>
                                <?php if( $button_text != '' ): ?>
                                <?php if($settings['link_type'] == 1): ?>
                                    <a href="<?php echo esc_url( $link ); ?>" class="yoga-default-btn"><?php echo esc_html( $button_text ); ?></a>
                                <?php elseif($settings['link_type'] == 2):
                                    echo '<a href="' .  $link . '" class="yoga-default-btn" ' . $target . $nofollow . '>' . $button_text . ' </a>';
                                endif; ?>
                            <?php endif; ?>
                            </div>
                        </div>
                        <?php while($events_array->have_posts()) : $events_array->the_post(); ?>
                            <div class="col-lg-3 col-sm-6">
                                <div class="yoga-single-events">
                                    <?php if( get_the_post_thumbnail_url() ): ?>
                                        <img src="<?php the_post_thumbnail_url(); ?>" alt="<?php the_title(); ?>">
                                    <?php endif; ?>
                                    <div class="yoga-single-events-content">
                                        <div class="date">
                                            <span class="day"><?php the_time('d'); ?></span>
                                            <span class="month"><?php the_time('M'); ?></span>
                                            <span class="year"><?php the_time('Y'); ?></span>
                                        </div>
                                        <h3>
                                            <a href="<?php the_permalink(); ?>"><?php the_title(); ?>
                                        </h3>
                                    </div>
                                </div>
                            </div>
                        <?php endwhile; ?>
                        <?php wp_reset_query(); ?>
                    </div>
                </div>
                <?php if( ! $settings['shape_img']['url'] == "" ) : ?>
                    <div class="section-left-shape">
                        <img src="<?php echo esc_url($settings['shape_img']['url']); ?>" alt="<?php esc_attr_e('Shape Image', 'guto-toolkit'); ?>">
                    </div>
                <?php endif; ?>
            </section>
        <?php elseif( $settings['events_style']  == '2' ) : ?>
            <section class="yoga-events-page-area ptb-100">
                <div class="container">
                    <div class="row">
                        <?php while($events_array->have_posts()) : $events_array->the_post(); ?>
                            <div class="col-lg-3 col-sm-6" style="display:none;">
                                <div class="yoga-single-events">
                                    <?php if( get_the_post_thumbnail_url() ): ?>
                                        <img src="<?php the_post_thumbnail_url(); ?>" alt="<?php the_title(); ?>">
                                    <?php endif; ?>
                                    <div class="yoga-single-events-content">
                                        <div class="date">
                                            <span class="day"><?php the_time('d'); ?></span>
                                            <span class="month"><?php the_time('M'); ?></span>
                                            <span class="year"><?php the_time('Y'); ?></span>
                                        </div>
                                        <h3>
                                            <a href="<?php the_permalink(); ?>"><?php the_title(); ?>
                                        </h3>
                                    </div>
                                </div>
                            </div>
                        <?php endwhile; ?>
                        <?php wp_reset_query();
                        if( $settings['show_load_more'] == '1' ) : ?>
                            <div class="col-12 text-center">
                               <a href="#" id="loadMore" class="yoga-default-btn"><?php echo esc_html__( $settings['load_more_text'] ); ?></a>
                            </div>
                        <?php endif; ?>
                    </div>
                </div>
            </section>
        <?php endif; ?>
        <!-- End Yoga Events Area -->

        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_Yoga_Events );
