<?php
/**
 * Yoga Feedback Widget
 */

namespace Elementor;

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

class Guto_Yoga_Feedback extends Widget_Base {

	public function get_name() {
        return 'Yoga Feedback';
    }

	public function get_title() {
        return esc_html__( 'Yoga Feedback', 'guto-toolkit' );
    }

	public function get_icon() {
        return 'eicon-testimonial';
    }

	public function get_categories() {
        return [ 'guto-yoga' ];
    }

	protected function _register_controls() {

        $this->start_controls_section(
			'content_section',
			[
				'label' => esc_html__( 'Content', 'guto-toolkit' ),
				'tab' => Controls_Manager::TAB_CONTENT,
			]
        );

        $this->add_control(
            'title',
            [
                'label' => esc_html__( 'Title', 'guto-toolkit' ),
                'type' => Controls_Manager::TEXT,
                'default' => esc_html__("Client's Review", 'guto-toolkit'),
            ]
        );

        $this->add_control(
            'title_tag',
            [
                'label' => esc_html__( 'Title Tag', 'guto-toolkit' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'h1'         => esc_html__( 'h1', 'guto-toolkit' ),
                    'h2'         => esc_html__( 'h2', 'guto-toolkit' ),
                    'h3'         => esc_html__( 'h3', 'guto-toolkit' ),
                    'h4'         => esc_html__( 'h4', 'guto-toolkit' ),
                    'h5'         => esc_html__( 'h5', 'guto-toolkit' ),
                    'h6'         => esc_html__( 'h6', 'guto-toolkit' ),
                ],
                'default' => 'h2',
            ]
        );

        $this->add_control(
            'feedback_featured_img',
            [
                'label' => esc_html__( 'Featured Image', 'guto-toolkit' ),
                'type' => Controls_Manager::MEDIA,
                'show_label' => true,
            ]
        );

        $this->add_control(
            'feedback_shape_img',
            [
                'label' => esc_html__( 'Shape Image', 'guto-toolkit' ),
                'type' => Controls_Manager::MEDIA,
                'show_label' => true,
            ]
        );

		$this->add_control(
            'yoga_feedback_items',
            [
                'label' => esc_html__('Feedback Item', 'guto-toolkit'),
                'type' => Controls_Manager::REPEATER,
                'default' => [
                    [ 'name' => esc_html__(' Item #1', 'guto-toolkit') ],

                ],
                'fields' => [
                    [
                        'name' => 'feedback',
                        'label' => esc_html__('Feedback Content', 'guto-toolkit'),
                        'type' => Controls_Manager::TEXTAREA,
                        'default' => esc_html__('“Lorem ipsum dolor sit amet consectetur adipisicing elit. Architecto deleniti illum vel quos dignissimos! Itaque, labore dolor fuga incidunt necessitatibus possimus, suscipit sapiente magnam vitae perspiciatis odio enim, ipsum aspernatur. Lorem ipsum dolor sit amet consectetur adipisicing elit”', 'guto-toolkit'),
                        'label_block' => true,
                    ],
                    [
                        'name'  => 'image',
                        'label' => esc_html__( 'Image', 'guto-toolkit' ),
                        'type' => Controls_Manager::MEDIA,
                        'show_label' => true,
                    ],
                    [
                        'name' => 'author_name',
                        'label' => esc_html__('Name', 'guto-toolkit'),
                        'type' => Controls_Manager::TEXT,
                        'default' => esc_html__('Emelli Anderson', 'guto-toolkit'),
                        'label_block' => true,
                    ],
                    [
                        'name' => 'designation',
                        'label' => esc_html__('Designation', 'guto-toolkit'),
                        'type' => Controls_Manager::TEXT,
                        'default' => esc_html__('Teacher', 'guto-toolkit'),
                        'label_block' => true,
                    ],
                ],
            ]
        );

    $this->end_controls_section();

    }

	protected function render() {

        $settings = $this->get_settings_for_display();

        $feedback_slider = $settings['yoga_feedback_items'];

        // Inline Editing
        $this-> add_inline_editing_attributes('title', 'none'); ?>

        <!-- Start Yoga Clients Area -->
        <section class="yoga-clients-area ptb-100">
            <div class="container">
                <div class="row">
                    <div class="col-lg-6">
                        <div class="yoga-client-img">
                            <?php if( $settings['feedback_featured_img']['url'] != '' ): ?>
                                <img src="<?php echo esc_url( $settings['feedback_featured_img']['url'] ); ?>" alt="Feedback">
                            <?php endif; ?>
                        </div>
                    </div>
                    <div class="col-lg-6">
                        <div class="yoga-clients-content">
                            <<?php echo esc_attr( $settings['title_tag'] ); ?> <?php echo $this-> get_render_attribute_string('title'); ?>>
                                <?php echo esc_html( $settings['title'] ); ?>
                            </<?php echo esc_attr( $settings['title_tag'] ); ?>>
                            <div class="yoga-clients-slider owl-carousel owl-theme">
                                <?php foreach ($feedback_slider as $key => $value): ?>
                                    <div class="yoga-single-clients">
                                        <i class="flaticon-quote"></i>
                                        <p><?php echo wp_kses_post( $value['feedback'] ); ?></p>
                                        <div class="client-avatar">
                                            <?php if( $value['image']['url'] != '' ): ?>
                                                <img src="<?php echo esc_url( $value['image']['url'] ); ?>" alt="<?php echo esc_attr( $value['author_name'] ) ?>">
                                            <?php endif; ?>
                                            <h5><?php echo esc_html( $value['author_name'] ); ?></h5>
                                            <span><?php echo esc_html( $value['designation'] ); ?></span>
                                        </div>
                                    </div>
                                <?php endforeach; ?>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <div class="section-right-shape">
                <?php if( $settings['feedback_shape_img']['url'] != '' ): ?>
                    <img src="<?php echo esc_url( $settings['feedback_shape_img']['url'] ); ?>" alt="Feedback">
                <?php endif; ?>
            </div>
        </section>
        <!-- End Yoga Clients Area -->

        <?php
	}



}

Plugin::instance()->widgets_manager->register( new Guto_Yoga_Feedback );
