<?php

/**
 * Guto Toolkit Elementor Extension Class
 *
 * @link       https://profiles.wordpress.org/gutotheme/
 * @since      1.0.0
 *
 * @package    Guto_Toolkit
 * @subpackage Guto_Toolkit/includes
 */

/**
 * Guto Toolkit Elementor Extension Class
 *
 * This class responsible for defining Elementor extension functionality
 *
 * @since      1.0.0
 * @package    Guto_Toolkit
 * @subpackage Guto_Toolkit/includes
 * @author     GutoTheme
 */

final class Elementor_Guto_Toolkit_Extension {

	const VERSION = '1.0.0';
	const MINIMUM_ELEMENTOR_VERSION = '1.0.0';
	const MINIMUM_PHP_VERSION = '7.0';

	// Instance
    private static $_instance = null;

	public static function instance() {

		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;

	}

	// Constructor
	public function __construct() {
		add_action( 'plugins_loaded', [ $this, 'init' ] );

	}

	// init
	public function init() {
        load_plugin_textdomain( 'guto-toolkit' );

		// Check for required PHP version
		if ( version_compare( PHP_VERSION, self::MINIMUM_PHP_VERSION, '<' ) ) {
			add_action( 'admin_notices', [ $this, 'admin_notice_minimum_php_version' ] );
			return;
		}

		// Add Plugin actions
		add_action( 'elementor/widgets/register', [ $this, 'init_widgets' ] );

        add_action('elementor/elements/categories_registered',[ $this, 'register_new_category'] );

    }

    public function register_new_category($manager){
        $manager->add_category('guto-elements',[
            'title'=>esc_html__('Guto Toolkit','guto-toolkit'),
            'icon'=> 'fa fa-image'
        ]);
        $manager->add_category('guto-it-agency',[
            'title'=>esc_html__('Guto IT Agency','guto-toolkit'),
            'icon'=> 'fa fa-image'
        ]);
        $manager->add_category('guto-fashion-shop',[
            'title'=>esc_html__('Guto Fashion Shop','guto-toolkit'),
            'icon'=> 'fa fa-image'
        ]);
        $manager->add_category('guto-news-and-magazine',[
            'title'=>esc_html__('Guto News and Magazine','guto-toolkit'),
            'icon'=> 'fa fa-image'
        ]);
		$manager->add_category('guto-freelancer',[
            'title'=>esc_html__('Guto Freelancer','guto-toolkit'),
            'icon'=> 'fa fa-image'
        ]);
		$manager->add_category('guto-nav',[
            'title'=>esc_html__('Guto Navbar','guto-toolkit'),
            'icon'=> 'fa fa-image'
        ]);
        $manager->add_category('guto-motivational-speaker',[
            'title'=>esc_html__('Guto Motivational Speaker','guto-toolkit'),
            'icon'=> 'fa fa-image'
        ]);
    }

	public function admin_notice_minimum_elementor_version() {

		if ( isset( $_GET['activate'] ) ) unset( $_GET['activate'] );

		$message = sprintf(
			/* translators: 1: Plugin name 2: Elementor 3: Required Elementor version */
			esc_html__( '"%1$s" requires "%2$s" version %3$s or greater.', 'guto-toolkit' ),
			'<strong>' . esc_html__( 'Guto Toolkit', 'guto-toolkit' ) . '</strong>',
			'<strong>' . esc_html__( 'Elementor', 'guto-toolkit' ) . '</strong>',
			 self::MINIMUM_ELEMENTOR_VERSION
		);

		printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );

	}
	public function admin_notice_minimum_php_version() {

		if ( isset( $_GET['activate'] ) ) unset( $_GET['activate'] );

		$message = sprintf(
			/* translators: 1: Plugin name 2: PHP 3: Required PHP version */
			esc_html__( '"%1$s" requires "%2$s" version %3$s or greater.', 'guto-toolkit' ),
			'<strong>' . esc_html__( 'Guto Toolkit', 'guto-toolkit' ) . '</strong>',
			'<strong>' . esc_html__( 'PHP', 'guto-toolkit' ) . '</strong>',
			 self::MINIMUM_PHP_VERSION
		);

		printf( '<div class="notice notice-warning is-dismissible"><p>%1$s</p></div>', $message );

	}

	// Register Widgets
	public function init_widgets() {
		// Banner One
		$gt_banner_widget_enable 	= (array)get_option('new_settings2');
		$banner_widget_enable 		= isset( $gt_banner_widget_enable['guto_toolkit_feature_banner_enable']) ? $gt_banner_widget_enable['guto_toolkit_feature_banner_enable'] : '';

		// Section
		$gt_section_widget_enable 	= (array)get_option('new_settings2');
		$section_widget_enable 		= isset( $gt_section_widget_enable['guto_toolkit_feature_section_enable']) ? $gt_section_widget_enable['guto_toolkit_feature_section_enable'] : '';

		// About Area
		$gt_about_area_widget_enable 	= (array)get_option('new_settings2');
		$about_area_widget_enable 		= isset( $gt_about_area_widget_enable['guto_toolkit_feature_about_area_enable']) ? $gt_about_area_widget_enable['guto_toolkit_feature_about_area_enable'] : '';

		// Feedback
		$gt_feedback_widget_enable 	= (array)get_option('new_settings2');
		$feedback_widget_enable 		= isset( $gt_feedback_widget_enable['guto_toolkit_feature_feedback_enable']) ? $gt_feedback_widget_enable['guto_toolkit_feature_feedback_enable'] : '';

		// Video Area
		$gt_video_area_widget_enable 	= (array)get_option('new_settings2');
		$video_area_widget_enable 		= isset( $gt_video_area_widget_enable['guto_toolkit_feature_video_area_enable']) ? $gt_video_area_widget_enable['guto_toolkit_feature_video_area_enable'] : '';

		// Team Area
		$gt_team_widget_enable 	= (array)get_option('new_settings2');
		$team_widget_enable 		= isset( $gt_team_widget_enable['guto_toolkit_feature_team_enable']) ? $gt_team_widget_enable['guto_toolkit_feature_team_enable'] : '';

		// Partner
		$gt_partner_widget_enable 	= (array)get_option('new_settings2');
		$partner_widget_enable 		= isset( $gt_partner_widget_enable['guto_toolkit_feature_partner_enable']) ? $gt_partner_widget_enable['guto_toolkit_feature_partner_enable'] : '';

		// Blog Posts
		$gt_blog_widget_enable 	= (array)get_option('new_settings2');
		$blog_widget_enable 		= isset( $gt_blog_widget_enable['guto_toolkit_feature_blog_enable']) ? $gt_blog_widget_enable['guto_toolkit_feature_blog_enable'] : '';

		// Funfacts
		$gt_funfacts_widget_enable 	= (array)get_option('new_settings2');
		$funfacts_widget_enable 		= isset( $gt_funfacts_widget_enable['guto_toolkit_feature_funfacts_enable']) ? $gt_funfacts_widget_enable['guto_toolkit_feature_funfacts_enable'] : '';

		// Overview Area
		$gt_overview_area_widget_enable 	= (array)get_option('new_settings2');
		$overview_area_widget_enable 		= isset( $gt_overview_area_widget_enable['guto_toolkit_feature_overview_area_enable']) ? $gt_overview_area_widget_enable['guto_toolkit_feature_overview_area_enable'] : '';

		// Projects
		$gt_projects_widget_enable 	= (array)get_option('new_settings2');
		$projects_widget_enable 		= isset( $gt_projects_widget_enable['guto_toolkit_feature_projects_enable']) ? $gt_projects_widget_enable['guto_toolkit_feature_projects_enable'] : '';

		// Popup
		$gt_popup_widget_enable 	= (array)get_option('new_settings2');
		$popup_widget_enable 		= isset( $gt_popup_widget_enable['guto_toolkit_feature_popup_enable']) ? $gt_popup_widget_enable['guto_toolkit_feature_popup_enable'] : '';

		// Project Info
		$gt_project_info_widget_enable 	= (array)get_option('new_settings2');
		$project_info_widget_enable 		= isset( $gt_project_info_widget_enable['guto_toolkit_feature_project_info_enable']) ? $gt_project_info_widget_enable['guto_toolkit_feature_project_info_enable'] : '';

		// Pricing
		$gt_pricing_widget_enable 	= (array)get_option('new_settings2');
		$pricing_widget_enable 		= isset( $gt_pricing_widget_enable['guto_toolkit_feature_pricing_enable']) ? $gt_pricing_widget_enable['guto_toolkit_feature_pricing_enable'] : '';

		// FAQ
		$gt_faq_widget_enable 	= (array)get_option('new_settings2');
		$faq_widget_enable 		= isset( $gt_faq_widget_enable['guto_toolkit_feature_faq_enable']) ? $gt_faq_widget_enable['guto_toolkit_feature_faq_enable'] : '';

		// Coming Soon
		$gt_coming_soon_widget_enable 	= (array)get_option('new_settings2');
		$coming_soon_widget_enable 		= isset( $gt_coming_soon_widget_enable['guto_toolkit_feature_coming_soon_enable']) ? $gt_coming_soon_widget_enable['guto_toolkit_feature_coming_soon_enable'] : '';

		// Contact Area
		$gt_contact_area_widget_enable 	= (array)get_option('new_settings2');
		$contact_area_widget_enable 		= isset( $gt_contact_area_widget_enable['guto_toolkit_feature_contact_area_enable']) ? $gt_contact_area_widget_enable['guto_toolkit_feature_contact_area_enable'] : '';

		// Categories Area
		$gt_categories_area_widget_enable 	= (array)get_option('new_settings2');
		$categories_area_widget_enable 		= isset( $gt_categories_area_widget_enable['guto_toolkit_feature_categories_area_enable']) ? $gt_categories_area_widget_enable['guto_toolkit_feature_categories_area_enable'] : '';

		// Newsletter
		$gt_newsletter_widget_enable 	= (array)get_option('new_settings2');
		$newsletter_widget_enable 		= isset( $gt_newsletter_widget_enable['guto_toolkit_feature_newsletter_enable']) ? $gt_newsletter_widget_enable['guto_toolkit_feature_newsletter_enable'] : '';

		// Instagram
		$gt_instagram_widget_enable 	= (array)get_option('new_settings2');
		$instagram_widget_enable 		= isset( $gt_instagram_widget_enable['guto_toolkit_feature_instagram_enable']) ? $gt_instagram_widget_enable['guto_toolkit_feature_instagram_enable'] : '';

		// Single Facility Box
		$gt_facility_box_widget_enable 	= (array)get_option('new_settings2');
		$facility_box_widget_enable 		= isset( $gt_facility_box_widget_enable['guto_toolkit_feature_facility_box_enable']) ? $gt_facility_box_widget_enable['guto_toolkit_feature_facility_box_enable'] : '';

		// Products Slider
		$gt_product_slider_widget_enable 	= (array)get_option('new_settings2');
		$product_slider_widget_enable 		= isset( $gt_product_slider_widget_enable['guto_toolkit_feature_product_slider_enable']) ? $gt_product_slider_widget_enable['guto_toolkit_feature_product_slider_enable'] : '';

		// Products Grid
		$gt_product_grid_widget_enable 	= (array)get_option('new_settings2');
		$product_grid_widget_enable 		= isset( $gt_product_grid_widget_enable['guto_toolkit_feature_product_grid_enable']) ? $gt_product_grid_widget_enable['guto_toolkit_feature_product_grid_enable'] : '';

		// Promotions Area
		$gt_promotions_area_widget_enable 	= (array)get_option('new_settings2');
		$promotions_area_widget_enable 		= isset( $gt_promotions_area_widget_enable['guto_toolkit_feature_promotions_area_enable']) ? $gt_promotions_area_widget_enable['guto_toolkit_feature_promotions_area_enable'] : '';

		// IT Agency Service Area
		$gt_it_services_area_widget_enable 	= (array)get_option('new_settings2');
		$it_services_area_widget_enable 		= isset( $gt_it_services_area_widget_enable['guto_toolkit_feature_it_services_area_enable']) ? $gt_it_services_area_widget_enable['guto_toolkit_feature_it_services_area_enable'] : '';

		// IT Working Process
		$gt_it_working_process_widget_enable 	= (array)get_option('new_settings2');
		$it_working_process_widget_enable 		= isset( $gt_it_working_process_widget_enable['guto_toolkit_feature_it_working_process_enable']) ? $gt_it_working_process_widget_enable['guto_toolkit_feature_it_working_process_enable'] : '';

		// Fashion Shop Banner
		$gt_fa_shop_banner_widget_enable 	= (array)get_option('new_settings2');
		$fa_shop_banner_widget_enable 		= isset( $gt_fa_shop_banner_widget_enable['guto_toolkit_feature_fa_shop_banner_enable']) ? $gt_fa_shop_banner_widget_enable['guto_toolkit_feature_fa_shop_banner_enable'] : '';

		// NM Breaking Area
		$gt_nm_breaking_area_widget_enable 	= (array)get_option('new_settings2');
		$nm_breaking_area_widget_enable 		= isset( $gt_nm_breaking_area_widget_enable['guto_toolkit_feature_nm_breaking_area_enable']) ? $gt_nm_breaking_area_widget_enable['guto_toolkit_feature_nm_breaking_area_enable'] : '';

		// NM Banner Area
		$gt_nm_banner_area_widget_enable 	= (array)get_option('new_settings2');
		$nm_banner_area_widget_enable 		= isset( $gt_nm_banner_area_widget_enable['guto_toolkit_feature_nm_banner_area_enable']) ? $gt_nm_banner_area_widget_enable['guto_toolkit_feature_nm_banner_area_enable'] : '';

		// NM World News
		$gt_nm_world_news_widget_enable 	= (array)get_option('new_settings2');
		$nm_world_news_widget_enable 		= isset( $gt_nm_world_news_widget_enable['guto_toolkit_feature_nm_world_news_enable']) ? $gt_nm_world_news_widget_enable['guto_toolkit_feature_nm_world_news_enable'] : '';

		// NM Stay Connected
		$gt_nm_stay_connected_widget_enable 	= (array)get_option('new_settings2');
		$nm_stay_connected_widget_enable 		= isset( $gt_nm_stay_connected_widget_enable['guto_toolkit_feature_nm_stay_connected_enable']) ? $gt_nm_stay_connected_widget_enable['guto_toolkit_feature_nm_stay_connected_enable'] : '';

		// NM Section
		$gt_nm_section_widget_enable 	= (array)get_option('new_settings2');
		$nm_section_widget_enable 		= isset( $gt_nm_section_widget_enable['guto_toolkit_feature_nm_section_enable']) ? $gt_nm_section_widget_enable['guto_toolkit_feature_nm_section_enable'] : '';

		// NM Video Posts
		$gt_nm_video_posts_widget_enable 	= (array)get_option('new_settings2');
		$nm_video_posts_widget_enable 		= isset( $gt_nm_video_posts_widget_enable['guto_toolkit_feature_nm_video_posts_enable']) ? $gt_nm_video_posts_widget_enable['guto_toolkit_feature_nm_video_posts_enable'] : '';

		// NM Newsletter
		$gt_nm_newsletter_widget_enable 	= (array)get_option('new_settings2');
		$nm_newsletter_widget_enable 		= isset( $gt_nm_newsletter_widget_enable['guto_toolkit_feature_nm_newsletter_enable']) ? $gt_nm_newsletter_widget_enable['guto_toolkit_feature_nm_newsletter_enable'] : '';

		// NM Posts Tag
		$gt_nm_posts_tag_widget_enable 	= (array)get_option('new_settings2');
		$nm_posts_tag_widget_enable 		= isset( $gt_nm_posts_tag_widget_enable['guto_toolkit_feature_nm_posts_tag_enable']) ? $gt_nm_posts_tag_widget_enable['guto_toolkit_feature_nm_posts_tag_enable'] : '';

		// Freelancer Banner
		$gt_freelancer_banner_widget_enable 	= (array)get_option('new_settings2');
		$freelancer_banner_widget_enable 		= isset( $gt_freelancer_banner_widget_enable['guto_toolkit_feature_freelancer_banner_enable']) ? $gt_freelancer_banner_widget_enable['guto_toolkit_feature_freelancer_banner_enable'] : '';
		// Freelancer Services
		$gt_freelancer_services_widget_enable 	= (array)get_option('new_settings2');
		$freelancer_services_widget_enable 		= isset( $gt_freelancer_services_widget_enable['guto_toolkit_feature_freelancer_services_enable']) ? $gt_freelancer_services_widget_enable['guto_toolkit_feature_freelancer_services_enable'] : '';
		// Freelancer About
		$gt_freelancer_about_widget_enable 	= (array)get_option('new_settings2');
		$freelancer_about_widget_enable 		= isset( $gt_freelancer_about_widget_enable['guto_toolkit_feature_freelancer_about_enable']) ? $gt_freelancer_about_widget_enable['guto_toolkit_feature_freelancer_about_enable'] : '';
		// Freelancer Feedback
		$gt_freelancer_feedback_widget_enable 	= (array)get_option('new_settings2');
		$freelancer_feedback_widget_enable 		= isset( $gt_freelancer_feedback_widget_enable['guto_toolkit_feature_freelancer_feedback_enable']) ? $gt_freelancer_feedback_widget_enable['guto_toolkit_feature_freelancer_feedback_enable'] : '';
		// Freelancer Projects
		$gt_freelancer_projects_widget_enable 	= (array)get_option('new_settings2');
		$freelancer_projects_widget_enable 		= isset( $gt_freelancer_projects_widget_enable['guto_toolkit_feature_freelancer_projects_enable']) ? $gt_freelancer_projects_widget_enable['guto_toolkit_feature_freelancer_projects_enable'] : '';
		// Freelancer Blog Posts
		$gt_freelancer_blog_widget_enable 	= (array)get_option('new_settings2');
		$freelancer_blog_widget_enable 		= isset( $gt_freelancer_blog_widget_enable['guto_toolkit_feature_freelancer_blog_enable']) ? $gt_freelancer_blog_widget_enable['guto_toolkit_feature_freelancer_blog_enable'] : '';
		// Freelancer Contact Info
		$gt_freelancer_contact_info_widget_enable 	= (array)get_option('new_settings2');
		$freelancer_contact_info_widget_enable 		= isset( $gt_freelancer_contact_info_widget_enable['guto_toolkit_feature_freelancer_contact_info_enable']) ? $gt_freelancer_contact_info_widget_enable['guto_toolkit_feature_freelancer_contact_info_enable'] : '';
		// Freelancer Client
		$gt_freelancer_client_widget_enable 	= (array)get_option('new_settings2');
		$freelancer_client_widget_enable 		= isset( $gt_freelancer_client_widget_enable['guto_toolkit_feature_freelancer_client_enable']) ? $gt_freelancer_client_widget_enable['guto_toolkit_feature_freelancer_client_enable'] : '';
		// Freelancer Contact Area
		$gt_freelancer_contact_area_widget_enable 	= (array)get_option('new_settings2');
		$freelancer_contact_area_widget_enable 		= isset( $gt_freelancer_contact_area_widget_enable['guto_toolkit_feature_freelancer_contact_area_enable']) ? $gt_freelancer_contact_area_widget_enable['guto_toolkit_feature_freelancer_contact_area_enable'] : '';
		// Freelancer Project Details
		$gt_freelancer_project_details_widget_enable 	= (array)get_option('new_settings2');
		$freelancer_project_details_widget_enable 		= isset( $gt_freelancer_project_details_widget_enable['guto_toolkit_feature_freelancer_project_details_enable']) ? $gt_freelancer_project_details_widget_enable['guto_toolkit_feature_freelancer_project_details_enable'] : '';
		// Freelancer Service Details
		$gt_freelancer_service_details_widget_enable 	= (array)get_option('new_settings2');
		$freelancer_service_details_widget_enable 		= isset( $gt_freelancer_service_details_widget_enable['guto_toolkit_feature_freelancer_service_details_enable']) ? $gt_freelancer_service_details_widget_enable['guto_toolkit_feature_freelancer_service_details_enable'] : '';

		// MS Contact
		$gt_ms_contact_widget_enable 	= (array)get_option('new_settings2');
		$ms_contact_widget_enable 		= isset( $gt_ms_contact_widget_enable['guto_toolkit_feature_ms_contact_enable']) ? $gt_ms_contact_widget_enable['guto_toolkit_feature_ms_contact_enable'] : '';
		// MS Banner
		$gt_ms_banner_widget_enable 	= (array)get_option('new_settings2');
		$ms_banner_widget_enable 		= isset( $gt_ms_banner_widget_enable['guto_toolkit_feature_ms_banner_enable']) ? $gt_ms_banner_widget_enable['guto_toolkit_feature_ms_banner_enable'] : '';
		// MS Service
		$gt_ms_service_widget_enable 	= (array)get_option('new_settings2');
		$ms_service_widget_enable 		= isset( $gt_ms_service_widget_enable['guto_toolkit_feature_ms_service_enable']) ? $gt_ms_service_widget_enable['guto_toolkit_feature_ms_service_enable'] : '';
		// MS About
		$gt_ms_about_widget_enable 	= (array)get_option('new_settings2');
		$ms_about_widget_enable 		= isset( $gt_ms_about_widget_enable['guto_toolkit_feature_ms_about_enable']) ? $gt_ms_about_widget_enable['guto_toolkit_feature_ms_about_enable'] : '';
		// MS Feedback
		$gt_ms_feedback_widget_enable 	= (array)get_option('new_settings2');
		$ms_feedback_widget_enable 		= isset( $gt_ms_feedback_widget_enable['guto_toolkit_feature_ms_feedback_enable']) ? $gt_ms_feedback_widget_enable['guto_toolkit_feature_ms_feedback_enable'] : '';
		// MS Blog
		$gt_ms_blog_widget_enable 	= (array)get_option('new_settings2');
		$ms_blog_widget_enable 		= isset( $gt_ms_blog_widget_enable['guto_toolkit_feature_ms_blog_enable']) ? $gt_ms_blog_widget_enable['guto_toolkit_feature_ms_blog_enable'] : '';
		// MS Free
		$gt_ms_free_widget_enable 	= (array)get_option('new_settings2');
		$ms_free_widget_enable 		= isset( $gt_ms_free_widget_enable['guto_toolkit_feature_ms_free_enable']) ? $gt_ms_free_widget_enable['guto_toolkit_feature_ms_free_enable'] : '';
		// MS Newsletter
		$gt_ms_newsletter_widget_enable 	= (array)get_option('new_settings2');
		$ms_newsletter_widget_enable 		= isset( $gt_ms_newsletter_widget_enable['guto_toolkit_feature_ms_newsletter_enable']) ? $gt_ms_newsletter_widget_enable['guto_toolkit_feature_ms_newsletter_enable'] : '';
		// MS Course
		$gt_ms_course_widget_enable 	= (array)get_option('new_settings2');
		$ms_course_widget_enable 		= isset( $gt_ms_course_widget_enable['guto_toolkit_feature_ms_course_enable']) ? $gt_ms_course_widget_enable['guto_toolkit_feature_ms_course_enable'] : '';
		// MS Countdown
		$gt_ms_countdown_widget_enable 	= (array)get_option('new_settings2');
		$ms_countdown_widget_enable 		= isset( $gt_ms_countdown_widget_enable['guto_toolkit_feature_ms_countdown_enable']) ? $gt_ms_countdown_widget_enable['guto_toolkit_feature_ms_countdown_enable'] : '';
		// MS Events Grid
		$gt_ms_event_grid_widget_enable 	= (array)get_option('new_settings2');
		$ms_event_grid_widget_enable 		= isset( $gt_ms_event_grid_widget_enable['guto_toolkit_feature_ms_event_grid_enable']) ? $gt_ms_event_grid_widget_enable['guto_toolkit_feature_ms_event_grid_enable'] : '';
		// MS Single Event
		$gt_ms_single_event_widget_enable 	= (array)get_option('new_settings2');
		$ms_single_event_widget_enable 		= isset( $gt_ms_single_event_widget_enable['guto_toolkit_feature_ms_single_event_enable']) ? $gt_ms_single_event_widget_enable['guto_toolkit_feature_ms_single_event_enable'] : '';

		// LC About
		$gt_lc_about_widget_enable 	= (array)get_option('new_settings2');
		$lc_about_widget_enable = isset( $gt_lc_about_widget_enable['guto_toolkit_feature_lc_about_enable']) ? $gt_lc_about_widget_enable['guto_toolkit_feature_lc_about_enable'] : '';
		// LC Award
		$gt_lc_award_widget_enable 	= (array)get_option('new_settings2');
		$lc_award_widget_enable = isset( $gt_lc_award_widget_enable['guto_toolkit_feature_lc_award_enable']) ? $gt_lc_award_widget_enable['guto_toolkit_feature_lc_award_enable'] : '';
		// LC Banner
		$gt_lc_banner_widget_enable 	= (array)get_option('new_settings2');
		$lc_banner_widget_enable = isset( $gt_lc_banner_widget_enable['guto_toolkit_feature_lc_banner_enable']) ? $gt_lc_banner_widget_enable['guto_toolkit_feature_lc_banner_enable'] : '';
		// LC Blog
		$gt_lc_blog_widget_enable 	= (array)get_option('new_settings2');
		$lc_blog_widget_enable = isset( $gt_lc_blog_widget_enable['guto_toolkit_feature_lc_blog_enable']) ? $gt_lc_blog_widget_enable['guto_toolkit_feature_lc_blog_enable'] : '';
		// LC Contact
		$gt_lc_contact_widget_enable 	= (array)get_option('new_settings2');
		$lc_contact_widget_enable = isset( $gt_lc_contact_widget_enable['guto_toolkit_feature_lc_contact_enable']) ? $gt_lc_contact_widget_enable['guto_toolkit_feature_lc_contact_enable'] : '';
		// LC Countdown
		$gt_lc_countdown_widget_enable 	= (array)get_option('new_settings2');
		$lc_countdown_widget_enable = isset( $gt_lc_countdown_widget_enable['guto_toolkit_feature_lc_countdown_enable']) ? $gt_lc_countdown_widget_enable['guto_toolkit_feature_lc_countdown_enable'] : '';
		// LC Course
		$gt_lc_course_widget_enable 	= (array)get_option('new_settings2');
		$lc_course_widget_enable = isset( $gt_lc_course_widget_enable['guto_toolkit_feature_lc_course_enable']) ? $gt_lc_course_widget_enable['guto_toolkit_feature_lc_course_enable'] : '';
        // LC Event Grid
		$gt_lc_event_grid_widget_enable 	= (array)get_option('new_settings2');
		$lc_event_grid_widget_enable = isset( $gt_lc_event_grid_widget_enable['guto_toolkit_feature_lc_event_grid_enable']) ? $gt_lc_event_grid_widget_enable['guto_toolkit_feature_lc_event_grid_enable'] : '';
		// LC Single Event
		$gt_lc_single_event_widget_enable 	= (array)get_option('new_settings2');
		$lc_single_event_widget_enable = isset( $gt_lc_single_event_widget_enable['guto_toolkit_feature_lc_single_event_enable']) ? $gt_lc_single_event_widget_enable['guto_toolkit_feature_lc_single_event_enable'] : '';
		// LC Feedback
		$gt_lc_feedback_widget_enable 	= (array)get_option('new_settings2');
		$lc_feedback_widget_enable = isset( $gt_lc_feedback_widget_enable['guto_toolkit_feature_lc_feedback_enable']) ? $gt_lc_feedback_widget_enable['guto_toolkit_feature_lc_feedback_enable'] : '';
		// LC Free
		$gt_lc_free_widget_enable 	= (array)get_option('new_settings2');
		$lc_free_widget_enable = isset( $gt_lc_free_widget_enable['guto_toolkit_feature_lc_free_enable']) ? $gt_lc_free_widget_enable['guto_toolkit_feature_lc_free_enable'] : '';
		// LC Newsletter
		$gt_lc_newsletter_widget_enable 	= (array)get_option('new_settings2');
		$lc_newsletter_widget_enable = isset( $gt_lc_newsletter_widget_enable['guto_toolkit_feature_lc_newsletter_enable']) ? $gt_lc_newsletter_widget_enable['guto_toolkit_feature_lc_newsletter_enable'] : '';
		// LC Service
		$gt_lc_service_widget_enable 	= (array)get_option('new_settings2');
		$lc_service_widget_enable = isset( $gt_lc_service_widget_enable['guto_toolkit_feature_lc_service_enable']) ? $gt_lc_service_widget_enable['guto_toolkit_feature_lc_service_enable'] : '';


		// Include Widgets
		if($banner_widget_enable):
			require_once( __DIR__ . '/el-widgets/banner-one.php' );
		endif;

		if($section_widget_enable):
			require_once( __DIR__ . '/el-widgets/section.php' );
		endif;

		if($about_area_widget_enable):
			require_once( __DIR__ . '/el-widgets/about-area.php' );
		endif;

		if($feedback_widget_enable):
			require_once( __DIR__ . '/el-widgets/feedback.php' );
		endif;

		if($video_area_widget_enable):
			require_once( __DIR__ . '/el-widgets/video-area.php' );
		endif;

		if($team_widget_enable):
			require_once( __DIR__ . '/el-widgets/team.php' );
		endif;

		if($partner_widget_enable):
			require_once( __DIR__ . '/el-widgets/partner.php' );
		endif;

		if($blog_widget_enable):
			require_once( __DIR__ . '/el-widgets/blog-posts.php' );
		endif;

		if($funfacts_widget_enable):
			require_once( __DIR__ . '/el-widgets/funfacts.php' );
		endif;

		if($overview_area_widget_enable):
			require_once( __DIR__ . '/el-widgets/overview-area.php' );
		endif;

		if($projects_widget_enable):
			require_once( __DIR__ . '/el-widgets/projects.php' );
		endif;

		if($popup_widget_enable):
			require_once( __DIR__ . '/el-widgets/popup.php' );
		endif;

		if($project_info_widget_enable):
			require_once( __DIR__ . '/el-widgets/project-info.php' );
		endif;

		if($pricing_widget_enable):
			require_once( __DIR__ . '/el-widgets/pricing.php' );
		endif;

		if($faq_widget_enable):
			require_once( __DIR__ . '/el-widgets/faq.php' );
		endif;

		if($coming_soon_widget_enable):
			require_once( __DIR__ . '/el-widgets/coming-soon.php' );
		endif;

		if($contact_area_widget_enable):
			require_once( __DIR__ . '/el-widgets/contact-area.php' );
		endif;

		if($categories_area_widget_enable):
			require_once( __DIR__ . '/el-widgets/categories-area.php' );
		endif;

		if($newsletter_widget_enable):
			require_once( __DIR__ . '/el-widgets/newsletter.php' );
		endif;

		if($instagram_widget_enable):
			require_once( __DIR__ . '/el-widgets/instagram-area.php' );
		endif;

		if($facility_box_widget_enable):
			require_once( __DIR__ . '/el-widgets/single-facility-box.php' );
		endif;

		if($product_slider_widget_enable):
			require_once( __DIR__ . '/el-widgets/products-slider.php' );
		endif;

		if($product_grid_widget_enable):
			require_once( __DIR__ . '/el-widgets/products-grid.php' );
		endif;

		if($promotions_area_widget_enable):
			require_once( __DIR__ . '/el-widgets/promotions-area.php' );
		endif;

		if($it_services_area_widget_enable):
			require_once( __DIR__ . '/el-widgets/services.php' );
		endif;

		if($it_working_process_widget_enable):
			require_once( __DIR__ . '/el-widgets/working-process.php' );
		endif;

		if($fa_shop_banner_widget_enable):
			require_once( __DIR__ . '/el-widgets/banner-two.php' );
		endif;

		if($nm_breaking_area_widget_enable):
			require_once( __DIR__ . '/el-widgets/news-and-magazine/nm-breaking-area.php' );
		endif;

		if($nm_banner_area_widget_enable):
			require_once( __DIR__ . '/el-widgets/news-and-magazine/nm-banner-area.php' );
			require_once( __DIR__ . '/el-widgets/news-and-magazine/nm-business.php' );
		endif;

		if($nm_world_news_widget_enable):
			require_once( __DIR__ . '/el-widgets/news-and-magazine/nm-world-news.php' );
			require_once( __DIR__ . '/el-widgets/news-and-magazine/nm-fashion.php' );
			require_once( __DIR__ . '/el-widgets/news-and-magazine/nm-fitness.php' );
			require_once( __DIR__ . '/el-widgets/news-and-magazine/nm-lifestyle.php' );
			require_once( __DIR__ . '/el-widgets/news-and-magazine/nm-politics-area.php' );
			require_once( __DIR__ . '/el-widgets/news-and-magazine/nm-sports-area.php' );
			require_once( __DIR__ . '/el-widgets/news-and-magazine/nm-popular-posts.php' );
		endif;

		if($nm_stay_connected_widget_enable):
			require_once( __DIR__ . '/el-widgets/news-and-magazine/nm-stay-connected.php' );
		endif;

		if($nm_section_widget_enable):
			require_once( __DIR__ . '/el-widgets/news-and-magazine/nm-section.php' );
		endif;

		if($nm_video_posts_widget_enable):
			require_once( __DIR__ . '/el-widgets/news-and-magazine/nm-video-posts.php' );
		endif;

		if($nm_newsletter_widget_enable):
			require_once( __DIR__ . '/el-widgets/news-and-magazine/nm-newsletter.php' );
		endif;

		if($nm_posts_tag_widget_enable):
			require_once( __DIR__ . '/el-widgets/news-and-magazine/nm-post-tag.php' );
		endif;

		if($freelancer_banner_widget_enable):
			require_once( __DIR__ . '/el-widgets/freelancer/fr-banner.php' );
		endif;
		if($freelancer_services_widget_enable):
			require_once( __DIR__ . '/el-widgets/freelancer/fr-services.php' );
		endif;
		if($freelancer_about_widget_enable):
			require_once( __DIR__ . '/el-widgets/freelancer/fr-about.php' );
		endif;
		if($freelancer_feedback_widget_enable):
			require_once( __DIR__ . '/el-widgets/freelancer/fr-feedback.php' );
		endif;
		if($freelancer_projects_widget_enable):
			require_once( __DIR__ . '/el-widgets/freelancer/fr-projects.php' );
		endif;
		if($freelancer_blog_widget_enable):
			require_once( __DIR__ . '/el-widgets/freelancer/fr-blog-posts.php' );
		endif;
		if($freelancer_contact_info_widget_enable):
			require_once( __DIR__ . '/el-widgets/freelancer/fr-contact-info.php' );
		endif;
		if($freelancer_client_widget_enable):
			require_once( __DIR__ . '/el-widgets/freelancer/fr-client.php' );
		endif;
		if($freelancer_contact_area_widget_enable):
			require_once( __DIR__ . '/el-widgets/freelancer/fr-contact-area.php' );
		endif;
		if($freelancer_project_details_widget_enable):
			require_once( __DIR__ . '/el-widgets/freelancer/fr-project-details.php' );
		endif;
		if($freelancer_service_details_widget_enable):
			require_once( __DIR__ . '/el-widgets/freelancer/fr-service-details.php' );
		endif;
		if($ms_contact_widget_enable):
			require_once( __DIR__ . '/el-widgets/motivational-speaker/ms-contact.php' );
		endif;
		if($ms_banner_widget_enable):
			require_once( __DIR__ . '/el-widgets/motivational-speaker/ms-banner.php' );
		endif;
		if($ms_service_widget_enable):
			require_once( __DIR__ . '/el-widgets/motivational-speaker/ms-service.php' );
		endif;
		if($ms_about_widget_enable):
			require_once( __DIR__ . '/el-widgets/motivational-speaker/ms-about.php' );
		endif;
		if($ms_feedback_widget_enable):
			require_once( __DIR__ . '/el-widgets/motivational-speaker/ms-feedback.php' );
		endif;
		if($ms_blog_widget_enable):
			require_once( __DIR__ . '/el-widgets/motivational-speaker/ms-blog.php' );
		endif;
		if($ms_free_widget_enable):
			require_once( __DIR__ . '/el-widgets/motivational-speaker/ms-free.php' );
		endif;
		if($ms_newsletter_widget_enable):
			require_once( __DIR__ . '/el-widgets/motivational-speaker/ms-newsletter.php' );
		endif;
		if($ms_course_widget_enable):
			require_once( __DIR__ . '/el-widgets/motivational-speaker/ms-course.php' );
		endif;
		if($ms_countdown_widget_enable):
			require_once( __DIR__ . '/el-widgets/motivational-speaker/ms-countdown.php' );
		endif;
		if($ms_event_grid_widget_enable):
			require_once( __DIR__ . '/el-widgets/motivational-speaker/ms-event-grid.php' );
		endif;
		if($ms_single_event_widget_enable):
			require_once( __DIR__ . '/el-widgets/motivational-speaker/ms-single-event.php' );
		endif;
    }

}
Elementor_Guto_Toolkit_Extension::instance();
