<?php

/**
 * Guto Toolkit Plugin Functions
 *
 * @link       https://profiles.wordpress.org/gutotheme/
 * @since      1.0.0
 *
 * @package    Guto_Toolkit
 * @subpackage Guto_Toolkit/includes
 */

/**
 * Guto Toolkit Plugin Functions
 *
 * This class responsible for defining Elementor extension functionality
 *
 * @since      1.0.0
 * @package    Guto_Toolkit
 * @subpackage Guto_Toolkit/includes
 * @author     GutoTheme
 */

/**
 * Remove empty p tag from content
 */
function guto_toolkit_remove_empty_p($content){
    $content = force_balance_tags($content);
    return preg_replace('#<p>\s*+(<br\s*/*>)?\s*</p>#i', '', $content);
}
add_filter('the_content', 'guto_toolkit_remove_empty_p', 20, 1);

/**
 * Check a plugin activate
 */
function guto_toolkit_plugin_active( $plugin ) {
	include_once( ABSPATH . 'wp-admin/includes/plugin.php' );
	if ( is_plugin_active( $plugin ) ) {
		return true;
	}
	return false;
}

/**
 * Post category list
 */
function guto_toolkit_get_post_cat_list() {
	$post_category_id = get_queried_object_id();
	$args = array(
		'parent' => $post_category_id
	);

	$terms = get_terms( 'category', get_the_ID());
	$cat_options = array(esc_html__('', 'guto-toolkit') => '');

	if ($terms) {
		foreach ($terms as $term) {
			$cat_options[$term->name] = $term->name;
		}
	}
	return $cat_options;
}

/**
 * Page list
 */
function guto_toolkit_get_page_as_list() {
    $args = wp_parse_args(array(
        'post_type' => 'page',
        'numberposts' => -1,
    ));

    $posts = get_posts($args);
    $post_options = array(esc_html__('', 'guto-toolkit') => '');

    if ($posts) {
        foreach ($posts as $post) {
            $post_options[$post->post_title] = $post->ID;
        }
    }
    $flipped = array_flip($post_options);
    return $flipped;
}

/**
 * Services list
 */
function guto_toolkit_get_page_services_cat_el()
{
    $arg = array(
        'taxonomy' => 'service_cat',
        'orderby' => 'name',
        'order'   => 'ASC'
    );
    $args = get_categories($arg);
    $args_options = array(esc_html__('', 'guto-toolkit') => '');
    if ($args) {
        foreach ($args as $args) {
            $args_options[$args->name] = $args->slug;
        }
    }
    return $args_options;
}

/**
 * Projetcs list
 */
function guto_toolkit_get_page_projects_cat_el()
{
    $arg = array(
        'taxonomy' => 'projects_cat',
        'orderby' => 'name',
        'order'   => 'ASC'
    );
    $args = get_categories($arg);
    $args_options = array(esc_html__('', 'guto-toolkit') => '');
    if ($args) {
        foreach ($args as $args) {
            $args_options[$args->name] = $args->slug;
        }
    }
    return $args_options;
}

/**
 * Courses category list
 */
function guto_toolkit_get_products_cat_list() {
	if ( !guto_toolkit_plugin_active( 'woocommerce/woocommerce.php' ) ) {
		return;
	}
	$products_category_id = get_queried_object_id();
	$args = array(
		'parent' => $products_category_id
	);

	$terms = get_terms( 'product_cat', get_the_ID());
	$cat_options = array(esc_html__('', 'guto-toolkit') => '');

	if ($terms) {
		foreach ($terms as $term) {
			$cat_options[$term->name] = $term->name;
		}
	}
	return $cat_options;
}

/**
 * Product list
 */
function guto_toolkit_get_product_as_list() {
	if ( !guto_toolkit_plugin_active( 'woocommerce/woocommerce.php' ) ) {
		return;
	}
    $args = wp_parse_args(array(
        'post_type' => 'product',
        'numberposts' => -1,
    ));

    $posts = get_posts($args);
    $post_options = array(esc_html__('', 'guto-toolkit') => '');

    if ($posts) {
        foreach ($posts as $post) {
            $post_options[$post->post_title] = $post->ID;
        }
    }
    $flipped = array_flip($post_options);
    return $flipped;
}

/**
 * Post list
 */
function guto_toolkit_get_post_title_array( $postType = 'post' ) {
	$args = wp_parse_args(array(
        'post_type' => $postType,
        'numberposts' => -1,
    ));

    $posts = get_posts( $args );
    $post_options = array( esc_html__('', 'guto-toolkit') => '' );

    if ($posts) {
        foreach ( $posts as $post ) {
            $post_options[$post->post_title] = $post->ID;
        }
    }
    $flipped = array_flip( $post_options);
	return $flipped;
}

/**
 * Newsletter script
 */
function guto_toolkit_add_script_to_footer(){
    if( ! is_admin() ) {
        if( function_exists('guto_lite_option') ):
            $action_url	= guto_lite_option('newsletter_action_url');
        else:
            $action_url	= '';
        endif;
		?>

		<script>
			jQuery(document).ready(function($){
				$(document).on('click', '.plus-btn', function(e) { // replace '.quantity' with document (without single quote)
					$input = $(this).prev('input.qty');
					var val = parseInt($input.val());
					var step = $input.attr('step');
					step = 'undefined' !== typeof(step) ? parseInt(step) : 1;
					$input.val( val + step ).change();
				});
				$(document).on('click', '.minus-btn',  // replace '.quantity' with document (without single quote)
					function(e) {
					$input = $(this).next('input.qty');
					var val = parseInt($input.val());
					var step = $input.attr('step');
					step = 'undefined' !== typeof(step) ? parseInt(step) : 1;
					if (val > 0) {
						$input.val( val - step ).change();
					}
				});
			});

			<?php if($action_url): ?>
				;(function($){
					"use strict";
					$(document).ready(function () {
						// MAILCHIMP
						if ($(".mailchimp").length > 0) {
							$(".mailchimp").ajaxChimp({
								callback: mailchimpCallback,
								url: "<?php echo esc_js($action_url) ?>"
							});
						}
						if ($(".mailchimp_two").length > 0) {
							$(".mailchimp_two").ajaxChimp({
								callback: mailchimpCallback,
								url: "<?php echo esc_js($action_url) ?>"
							});
						}
						$(".memail").on("focus", function () {
							$(".mchimp-errmessage").fadeOut();
							$(".mchimp-sucmessage").fadeOut();
						});
						$(".memail").on("keydown", function () {
							$(".mchimp-errmessage").fadeOut();
							$(".mchimp-sucmessage").fadeOut();
						});
						$(".memail").on("click", function () {
							$(".memail").val("");
						});

						function mailchimpCallback(resp) {
							if (resp.result === "success") {
								$(".mchimp-sucmessage").html(resp.msg).fadeIn(1000);
								$(".mchimp-sucmessage").fadeOut(500);
							} else if (resp.result === "error") {
								$(".mchimp-errmessage").html(resp.msg).fadeIn(1000);
							}
						}
					});
				})(jQuery)
			<?php endif; ?>
		</script>

	<?php
	}
}
add_action( 'wp_footer', 'guto_toolkit_add_script_to_footer' );

/**
 * Get the existing menus in array format
 * @return array
 */
function guto_get_menu_array() {
    $menus = wp_get_nav_menus();
    $menu_array = [];
    foreach ( $menus as $menu ) {
        $menu_array[$menu->slug] = $menu->name;
    }
    return $menu_array;
}

/**
 * Estimated Reading Time
 */
if ( ! function_exists( 'guto_toolkit_reading_time' ) ) :
	function guto_toolkit_reading_time() {
		global $post;

		$thecontent = $post->post_content;
		$words 		= str_word_count( strip_tags( $thecontent ) );
		$m 			= floor( $words / 200 );
		$estimate 	= $m;
		$output 	= $estimate;
		return $output;
	}
endif;

/**
 * New WooCommerce Cart Style
 */
if ( ! function_exists( 'woocommerce_product_cart_style_fs' ) ) :
	function woocommerce_product_cart_style_fs() {
		global $product;

		if ( ! $product->is_purchasable() ) {
		    return;
		}

		echo wc_get_stock_html( $product );

		if ( $product->is_in_stock() ) : ?>

		    <?php do_action( 'woocommerce_before_add_to_cart_form' ); ?>

		    <form class="cart" action="<?php echo esc_url( apply_filters( 'woocommerce_add_to_cart_form_action', $product->get_permalink() ) ); ?>" method="post" enctype='multipart/form-data'>
		        <?php do_action( 'woocommerce_before_add_to_cart_button' ); ?>

		        <button type="submit" name="add-to-cart" value="<?php echo esc_attr( $product->get_id() ); ?>" class="add-to-cart-btn"><i class="bx bx-cart"></i><?php echo esc_html( $product->single_add_to_cart_text() ); ?></button>

		        <?php do_action( 'woocommerce_after_add_to_cart_button' ); ?>
		    </form>

		    <?php do_action( 'woocommerce_after_add_to_cart_form' ); ?>

		<?php endif;
	}
endif;

/**
 * New WooCommerce Cart Style Two
 */
if ( ! function_exists( 'woocommerce_product_cart_style_fs_two' ) ) :
	function woocommerce_product_cart_style_fs_two() {
		global $product;

		if ( ! $product->is_purchasable() ) {
		    return;
		}

		echo wc_get_stock_html( $product );

		if ( $product->is_in_stock() ) : ?>

		    <?php do_action( 'woocommerce_before_add_to_cart_form' ); ?>

		    <form class="cart" action="<?php echo esc_url( apply_filters( 'woocommerce_add_to_cart_form_action', $product->get_permalink() ) ); ?>" method="post" enctype='multipart/form-data'>
		        <?php do_action( 'woocommerce_before_add_to_cart_button' );

		        do_action( 'woocommerce_before_add_to_cart_button' );

				do_action( 'woocommerce_before_add_to_cart_quantity' );

				woocommerce_quantity_input( array(
					'min_value'   => apply_filters( 'woocommerce_quantity_input_min', $product->get_min_purchase_quantity(), $product ),
					'max_value'   => apply_filters( 'woocommerce_quantity_input_max', $product->get_max_purchase_quantity(), $product ),
					'input_value' => isset( $_POST['quantity'] ) ? wc_stock_amount( wp_unslash( $_POST['quantity'] ) ) : $product->get_min_purchase_quantity(), // phpcs:ignore WordPress.Security.ValidatedSanitizedInput.InputNotSanitized
				) );

				do_action( 'woocommerce_after_add_to_cart_quantity' ); ?>

		        <button type="submit" name="add-to-cart" value="<?php echo esc_attr( $product->get_id() ); ?>" class="default-btn"><i class="bx bx-cart"></i><?php echo esc_html( $product->single_add_to_cart_text() ); ?></button>

		        <?php do_action( 'woocommerce_after_add_to_cart_button' ); ?>
		    </form>

		    <?php do_action( 'woocommerce_after_add_to_cart_form' ); ?>

		<?php endif;
	}
endif;

/**
 * New WooCommerce Cart Style Three
 */
if ( ! function_exists( 'woocommerce_product_cart_style_os' ) ) :
	function woocommerce_product_cart_style_os() {
		global $product;

		if ( ! $product->is_purchasable() ) {
		    return;
		}

		echo wc_get_stock_html( $product );

		if ( $product->is_in_stock() ) : ?>

		    <?php do_action( 'woocommerce_before_add_to_cart_form' ); ?>

		    <form class="cart" action="<?php echo esc_url( apply_filters( 'woocommerce_add_to_cart_form_action', $product->get_permalink() ) ); ?>" method="post" enctype='multipart/form-data'>
		        <?php do_action( 'woocommerce_before_add_to_cart_button' );

		        do_action( 'woocommerce_before_add_to_cart_button' ); ?>

		        <button type="submit" name="add-to-cart" value="<?php echo esc_attr( $product->get_id() ); ?>" class="default-btn"><i class="bx bx-cart"></i><?php echo esc_html( $product->single_add_to_cart_text() ); ?></button>

		        <?php do_action( 'woocommerce_after_add_to_cart_button' ); ?>
		    </form>

		    <?php do_action( 'woocommerce_after_add_to_cart_form' ); ?>

		<?php endif;
	}
endif;

/**
 * New WooCommerce Cart Style Four
 */
if ( ! function_exists( 'woocommerce_product_cart_style_lc' ) ) :
	function woocommerce_product_cart_style_lc() {
		global $product;

		if ( ! $product->is_purchasable() ) {
		    return;
		}

		echo wc_get_stock_html( $product );

		if ( $product->is_in_stock() ) : ?>

		    <?php do_action( 'woocommerce_before_add_to_cart_form' ); ?>

		    <form class="cart" action="<?php echo esc_url( apply_filters( 'woocommerce_add_to_cart_form_action', $product->get_permalink() ) ); ?>" method="post" enctype='multipart/form-data'>
		        <?php do_action( 'woocommerce_before_add_to_cart_button' );

		        do_action( 'woocommerce_before_add_to_cart_button' ); ?>

		        <button type="submit" name="add-to-cart" value="<?php echo esc_attr( $product->get_id() ); ?>" class="lc-default-btn"><i class="bx bx-cart"></i><?php echo esc_html( $product->single_add_to_cart_text() ); ?></button>

		        <?php do_action( 'woocommerce_after_add_to_cart_button' ); ?>
		    </form>

		    <?php do_action( 'woocommerce_after_add_to_cart_form' ); ?>

		<?php endif;
	}
endif;

add_action( 'show_user_profile', 'author_user_profile_fields' );
add_action( 'edit_user_profile', 'author_user_profile_fields' );

function author_user_profile_fields( $user ) { ?>
    <h3><?php _e("Author Working Information", "guto-toolkit"); ?></h3>

    <table class="form-table">
    <tr>
        <th><label for="heading"><?php _e("Heading"); ?></label></th>
        <td>
            <input type="text" name="heading" id="heading" value="<?php echo esc_attr( get_the_author_meta( 'heading', $user->ID ) ); ?>" class="regular-text" /><br />
        </td>
    </tr>
    <tr>
        <th><label for="work"><?php _e("Work/Designation"); ?></label></th>
        <td>
            <input type="text" name="work" id="work" value="<?php echo esc_attr( get_the_author_meta( 'work', $user->ID ) ); ?>" class="regular-text" /><br />
        </td>
    </tr>
    <tr>
        <th><label for="media"><?php _e("Cover Image URL"); ?></label></th>
        <td>
            <input type="url" name="media" id="media" value="<?php echo esc_attr( get_the_author_meta( 'media', $user->ID ) ); ?>" class="regular-text" /><br />
        </td>
    </tr>
    </table>
<?php }

add_action( 'personal_options_update', 'save_author_user_profile_fields' );
add_action( 'edit_user_profile_update', 'save_author_user_profile_fields' );

function save_author_user_profile_fields( $user_id ) {
    if ( empty( $_POST['_wpnonce'] ) || ! wp_verify_nonce( $_POST['_wpnonce'], 'update-user_' . $user_id ) ) {
        return;
    }

    if ( !current_user_can( 'edit_user', $user_id ) ) {
        return false;
    }
    update_user_meta( $user_id, 'heading', $_POST['heading'] );
    update_user_meta( $user_id, 'work', $_POST['work'] );
    update_user_meta( $user_id, 'media', $_POST['media'] );
}


/**
 * Select course for link
 */
function guto_toolkit_get_course_as_list() {
    $args = wp_parse_args(array(
        'post_type' => 'lp_course',
        'numberposts' => -1,
    ));

    $posts = get_posts($args);
    $post_options = array('' => '');

    if ($posts) {
        foreach ($posts as $post) {
            $post_options[$post->post_title] = $post->ID;
        }
    }
    $flipped = array_flip($post_options);
    return $flipped;
}

/**
 * Check a plugin activate
 */
function guto_plugin_active( $plugin ) {
	include_once( ABSPATH . 'wp-admin/includes/plugin.php' );
	if ( is_plugin_active( $plugin ) ) {
		return true;
	}
	return false;
}

/**
 * Courses category list
 */
function guto_toolkit_get_courses_cat_list() {
	if ( !guto_plugin_active( 'learnpress/learnpress.php' ) ) {
		return;
	}
	$courses_category_id = get_queried_object_id();
	$args = array(
		'parent' => $courses_category_id
	);

	$terms = get_terms( 'course_category', get_the_ID());
	$cat_options = array('' => '');

	if ($terms) {
		foreach ($terms as $term) {
			$cat_options[$term->name] = $term->name;
		}
	}
	return $cat_options;
}

/**
 * Print rating
 */
if ( !function_exists( 'guto_print_rating' ) ) {
	function guto_print_rating( $rate ) {
		if ( !guto_plugin_active( 'learnpress-course-review/learnpress-course-review.php' ) ) {
			return;
		}

		?>
		<div class="review-stars-rated">
			<ul class="review-stars">
				<li><span class="fa fa-star-o"></span></li>
				<li><span class="fa fa-star-o"></span></li>
				<li><span class="fa fa-star-o"></span></li>
				<li><span class="fa fa-star-o"></span></li>
				<li><span class="fa fa-star-o"></span></li>
			</ul>
			<ul class="review-stars filled"
			    style="<?php echo esc_attr( 'width: calc(' . ( $rate * 20 ) . '% - 2px)' ) ?>">
				<li><span class="fa fa-star"></span></li>
				<li><span class="fa fa-star"></span></li>
				<li><span class="fa fa-star"></span></li>
				<li><span class="fa fa-star"></span></li>
				<li><span class="fa fa-star"></span></li>
			</ul>
		</div>
		<?php

	}
}

/**
 * Display course ratings
 */
if ( !function_exists( 'guto_course_ratings' ) ) {
	function guto_course_ratings() {

		if ( !guto_plugin_active( 'learnpress-course-review/learnpress-course-review.php' ) ) {
			return;
		}

		$course_id   = get_the_ID();
		$course_rate = learn_press_get_course_rate( $course_id );
		$ratings     = learn_press_get_course_rate_total( $course_id );
		?>
		<div class="course-review">
			<?php guto_print_rating( $course_rate ); ?>
		</div>
		<?php
	}
}

/**
 * Display ratings count
 */
if ( !function_exists( 'guto_course_ratings_count' ) ) {
	function guto_course_ratings_count( $course_id = null ) {
		if ( !guto_plugin_active( 'learnpress-course-review/learnpress-course-review.php' ) ) {
			return;
		}
		if ( !$course_id ) {
			$course_id = get_the_ID();
		}
		$ratings = learn_press_get_course_rate_total( $course_id ) ? learn_press_get_course_rate_total( $course_id ) : 0;
		echo esc_html( $ratings );
	}
}

/**
 * Display course review
 */
if ( !function_exists( 'guto_course_review' ) ) {
	function guto_course_review() {
		if ( !guto_plugin_active( 'learnpress-course-review/learnpress-course-review.php' ) ) {
			return;
		}

		$course_id     = get_the_ID();
		$course_review = learn_press_get_course_review( $course_id, isset( $_REQUEST['paged'] ) ? $_REQUEST['paged'] : 1, 5, true );
		$course_rate   = learn_press_get_course_rate( $course_id );
		$total         = learn_press_get_course_rate_total( $course_id );
		$reviews       = $course_review['reviews'];

		?>
		<?php if( $reviews ): ?>
			<div class="courses-review-comments">
				<h3><?php esc_html_e( 'Reviews', 'guto-toolkit' ); ?></h3>

				<?php foreach ( $reviews as $review ) : ?>
					<div class="user-review">
						<?php echo get_avatar( $review->ID, 70 ); ?>

						<div class="review-rating">
							<div class="review-stars">
								<i class="bx bxs-star"></i>
								<i class="bx bxs-star"></i>
								<i class="bx bxs-star"></i>
								<i class="bx bxs-star"></i>
								<i class="bx bxs-star"></i>
							</div>

							<span class="d-inline-block"><?php echo esc_html( $review->display_name ); ?></span>
						</div>

						<span class="d-block sub-comment"><?php echo esc_html( $review->title ); ?></span>
						<p><?php echo esc_html( $review->content ); ?></p>
					</div>
				<?php endforeach; ?>


				<?php if ( empty( $course_review['finish'] ) && $total ) : ?>
					<div class="review-load-more">
						<span id="course-review-load-more" data-paged="<?php echo esc_attr( $course_review['paged'] ); ?>"><i class="fa fa-angle-double-down"></i></span>
					</div>
				<?php endif; ?>

			</div>
		<?php endif; ?>

		<?php
	}
}

function guto_year_shortcode() {
	$year = date('Y');
	return $year;
  }
  add_shortcode('year', 'guto_year_shortcode');

// Disables the block editor from managing widgets in the Gutenberg plugin.
add_filter( 'gutenberg_use_widgets_block_editor', '__return_false', 100 );

// Disables the block editor from managing widgets. renamed from wp_use_widgets_block_editor
add_filter( 'use_widgets_block_editor', '__return_false' );