<?php
 /**
 * Insurance Contact Widget
 */
class guto_insurance_contact extends WP_Widget{

    function __construct(){
        $widget_ops = array('description' => esc_html__('Display Contact Info', 'guto-toolkit'));
        parent::__construct( false, esc_html__('Insurance Contact Info', 'guto-toolkit'), $widget_ops);
    }

    function widget($args, $instance){
        extract($args);
        global $guto_theme;

        $title  = apply_filters('widget_title', $instance['title']);

        echo wp_kses_post($before_widget); ?>

        <div class="insurance-contact-info-box">
            <?php if($title) echo wp_kses_post($before_title.$title.$after_title); ?>
            <ul>
                <?php if( $instance['phone'] != '' ): ?>
                    <li>
                        <i class='bx bx-phone-call'></i>
                        <span><?php echo esc_html__('Phone: ', 'guto-toolkit'); ?></span>
                        <a href="<?php echo esc_url( $instance['phone_link'] ); ?>">
                            <?php echo wp_kses_post($instance['phone']); ?></a>
                    </li>
                <?php endif; ?>
                <?php if( $instance['email'] != '' ): ?>
                    <li>
                        <i class='bx bx-envelope'></i>
                        <span><?php echo esc_html__('Email: ', 'guto-toolkit'); ?></span>
                        <a href="<?php echo esc_url( $instance['email_link'] ); ?>"><?php echo wp_kses_post($instance['email']); ?></a>
                    </li>
                <?php endif; ?>
            </ul>
        </div>
        <?php
        echo wp_kses_post($after_widget);
    }

    function update($new_instance, $old_instance){
        $instance                    = $old_instance;
        $instance['title']           = strip_tags($new_instance['title']);
        $instance['phone']           = $new_instance['phone'];
        $instance['phone_link']      = $new_instance['phone_link'];
        $instance['email']           = $new_instance['email'];
        $instance['email_link']      = $new_instance['email_link'];
        return $instance;
    }

    function form($instance){
        $defaults = array(
            'title'             => esc_html__('Need some help?', 'guto-toolkit'),
            'phone'             => esc_html__('+44 587 154756', 'guto-toolkit'),
            'phone_link'        => esc_html__('tel:+44 587 154756', 'guto-toolkit'),
            'email'             => esc_html__('hello@guto.com', 'guto-toolkit'),
            'email_link'        => esc_html__('mailto:hello@guto.com', 'guto-toolkit'),
        );
        $instance = wp_parse_args((array)$instance, $defaults);
        ?>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('title')); ?>">
                <?php esc_html_e('Title:', 'guto-toolkit'); ?>
                <input class="widget" id="<?php echo esc_attr($this->get_field_id('title')); ?>" name="<?php echo esc_attr($this->get_field_name('title')); ?>" type="text" value="<?php echo wp_kses_post($instance['title']); ?>" />
            </label>
        </p>

        <p>
            <label for="<?php echo esc_attr($this->get_field_id('phone')); ?>">
                <?php esc_html_e('Phone Number:', 'guto-toolkit'); ?>
                <input class="widget" id="<?php echo esc_attr($this->get_field_id('phone')); ?>" name="<?php echo esc_attr($this->get_field_name('phone')); ?>" type="text" value="<?php echo wp_kses_post($instance['phone']); ?>" />
            </label>
        </p>

        <p>
            <label for="<?php echo esc_attr($this->get_field_id('phone_link')); ?>">
                <?php esc_html_e('Number Link:', 'guto-toolkit'); ?>
                <input class="widget" id="<?php echo esc_attr($this->get_field_id('phone_link')); ?>" name="<?php echo esc_attr($this->get_field_name('phone_link')); ?>" type="text" value="<?php echo wp_kses_post($instance['phone_link']); ?>" />
            </label>
        </p>

        <p>
            <label for="<?php echo esc_attr($this->get_field_id('email')); ?>">
                <?php esc_html_e('Email:', 'guto-toolkit'); ?>
                <input class="widget" id="<?php echo esc_attr($this->get_field_id('email')); ?>" name="<?php echo esc_attr($this->get_field_name('email')); ?>" type="text" value="<?php echo wp_kses_post($instance['email']); ?>" />
            </label>
        </p>

        <p>
            <label for="<?php echo esc_attr($this->get_field_id('email_link')); ?>">
                <?php esc_html_e('Email Link:', 'guto-toolkit'); ?>
                <input class="widget" id="<?php echo esc_attr($this->get_field_id('email_link')); ?>" name="<?php echo esc_attr($this->get_field_name('email_link')); ?>" type="text" value="<?php echo wp_kses_post($instance['email_link']); ?>" />
            </label>
        </p>
        <?php
    }

}

function guto_register_insurance_contact() {
    register_widget('guto_insurance_contact');
}

add_action('widgets_init', 'guto_register_insurance_contact');
