<?php
 /**
 * Phone Advanced Widget
 */
class Guto_phone_advanced extends WP_Widget{

    function __construct(){
        $widget_ops = array('description' => esc_html__('Display Phone Advanced Area', 'guto-toolkit'));
        parent::__construct( false, esc_html__('Insurance Phone Advanced', 'guto-toolkit'), $widget_ops);
    }

    function widget($args, $instance){
        extract($args);
        global $guto_theme;

        $title  = apply_filters('widget_title', $instance['title']);

        echo wp_kses_post($before_widget);
        if($title) echo wp_kses_post($before_title.$title.$after_title);
        ?>
        <div class="insurance-contact-info-box">
            <?php if( $instance['image'] != '' ): ?>
                <img src="<?php echo esc_url( $instance['image'] ); ?>" alt="contact">
            <?php endif; ?>
            <?php if( $instance['phone'] != '' ): ?>
                <div class="content">
                    <div class="icon">
                        <i class='bx bx-phone-call'></i>
                    </div>
                    <span>
                        <?php echo wp_kses_post( $instance['phone'] ); ?></a>
                    </span>
                </div>
                <a href="<?php echo esc_url( $instance['phone_link'] ); ?>" class="link-btn"></a>
            <?php endif; ?>
        </div>
        <?php
        echo wp_kses_post($after_widget);
    }

    function update($new_instance, $old_instance){
        $instance                    = $old_instance;
        $instance['title']           = strip_tags($new_instance['title']);
        $instance['image']           = strip_tags($new_instance['image']);
        $instance['phone']           = $new_instance['phone'];
        $instance['phone_link']      = $new_instance['phone_link'];
        return $instance;
    }

    function form($instance){
        $defaults = array(
            'title'             => esc_html__('', 'guto-toolkit'),
            'image'             => esc_html__('', 'guto-toolkit'),
            'phone'             => esc_html__('+44 587 154756', 'guto-toolkit'),
            'phone_link'        => esc_html__('tel:+44 587 154756', 'guto-toolkit'),
        );
        $instance = wp_parse_args((array)$instance, $defaults);
        ?>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('title')); ?>">
                <?php esc_html_e('Title:', 'guto-toolkit'); ?>
                <input class="widget" id="<?php echo esc_attr($this->get_field_id('title')); ?>" name="<?php echo esc_attr($this->get_field_name('title')); ?>" type="text" value="<?php echo wp_kses_post($instance['title']); ?>" />
            </label>
        </p>

        <p>
            <label for="<?php echo esc_attr($this->get_field_id('image')); ?>">
                <?php esc_html_e('Image URL:', 'guto-toolkit'); ?>
                <input class="widget" id="<?php echo esc_attr($this->get_field_id('image')); ?>" name="<?php echo esc_attr($this->get_field_name('image')); ?>" type="text" value="<?php echo wp_kses_post($instance['image']); ?>" />
            </label>
        </p>

        <p>
            <label for="<?php echo esc_attr($this->get_field_id('phone')); ?>">
                <?php esc_html_e('Phone Number:', 'guto-toolkit'); ?>
                <input class="widget" id="<?php echo esc_attr($this->get_field_id('phone')); ?>" name="<?php echo esc_attr($this->get_field_name('phone')); ?>" type="text" value="<?php echo wp_kses_post($instance['phone']); ?>" />
            </label>
        </p>

        <p>
            <label for="<?php echo esc_attr($this->get_field_id('phone_link')); ?>">
                <?php esc_html_e('Number Link:', 'guto-toolkit'); ?>
                <input class="widget" id="<?php echo esc_attr($this->get_field_id('phone_link')); ?>" name="<?php echo esc_attr($this->get_field_name('phone_link')); ?>" type="text" value="<?php echo wp_kses_post($instance['phone_link']); ?>" />
            </label>
        </p>

        <?php
    }

}

function guto_register_phone_advanced() {
    register_widget('Guto_phone_advanced');
}

add_action('widgets_init', 'guto_register_phone_advanced');
