<?php
 /**
 * Contact Info Widget
 */
class Guto_rb_contact_info extends WP_Widget{

    function __construct(){
        $widget_ops = array('description' => esc_html__('Display Recipe Contact Info', 'guto-toolkit'));
        parent::__construct( false, esc_html__('Guto Recipe Footer Contact Info', 'guto-toolkit'), $widget_ops);
    }

    function widget($args, $instance){
        extract($args);
        global $guto_theme;

        $title  = apply_filters('widget_title', $instance['title']);

        echo wp_kses_post($before_widget);
        if($title) echo wp_kses_post($before_title.$title.$after_title);
        ?>

        <ul class="widget-info">
            <?php if( $instance['location'] != '' ): ?>
                <li>
                    <i class="<?php echo esc_attr($instance['location_icon']) ?>"></i>
                    <?php echo wp_kses_post($instance['location']); ?>
                </li>
            <?php endif; ?>

            <?php if( $instance['phone'] != '' ): ?>
                <li>
                    <i class="<?php echo esc_attr($instance['phone_icon']) ?>"></i>
                    <a href="<?php echo esc_url( $instance['phone_link'] ); ?>"><?php echo wp_kses_post($instance['phone']); ?></a>
                </li>
            <?php endif; ?>

            <?php if( $instance['email'] != '' ): ?>
                <li>
                    <i class="<?php echo esc_attr($instance['email_icon']) ?>"></i>
                    <a href="<?php echo esc_url( $instance['email_link'] ); ?>"><?php echo wp_kses_post($instance['email']); ?></a>
                </li>
            <?php endif; ?>
        </ul>
        <?php
        echo wp_kses_post($after_widget);
    }

    function update($new_instance, $old_instance){
        $instance                    = $old_instance;
        $instance['title']           = strip_tags($new_instance['title']);
        $instance['location_icon']   = $new_instance['location_icon'];
        $instance['location']        = $new_instance['location'];
        $instance['phone_icon']      = $new_instance['phone_icon'];
        $instance['phone']           = $new_instance['phone'];
        $instance['phone_link']      = $new_instance['phone_link'];
        $instance['email_icon']      = $new_instance['email_icon'];
        $instance['email']           = $new_instance['email'];
        $instance['email_link']      = $new_instance['email_link'];
        return $instance;
    }

    function form($instance){
        $defaults = array(
            'title'             => esc_html__('Quick Contact', 'guto-toolkit'),
            'location_icon'     => '#',
            'location'          => esc_html__('2750 Quadra Street Victoria Road, New York, Canada', 'guto-toolkit'),
            'phone_icon'        => '#',
            'phone'             => esc_html__('+1 (123) 456 7890', 'guto-toolkit'),
            'phone_link'        => esc_html__('tel:+11234567890', 'guto-toolkit'),
            'email_icon'        => '#',
            'email'             => esc_html__('hello@guto.com', 'guto-toolkit'),
            'email_link'        => esc_html__('mailto:hello@guto.com', 'guto-toolkit'),
        );
        $instance = wp_parse_args((array)$instance, $defaults);
        ?>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('title')); ?>">
                <?php esc_html_e('Title:', 'guto-toolkit'); ?>
                <input class="widget" id="<?php echo esc_attr($this->get_field_id('title')); ?>" name="<?php echo esc_attr($this->get_field_name('title')); ?>" type="text" value="<?php echo wp_kses_post($instance['title']); ?>" />
            </label>
        </p>

        <p>
            <label for="<?php echo esc_attr($this->get_field_id('location_icon')); ?>">
                <?php esc_html_e('Location Icon:', 'guto-toolkit'); ?>
                <input class="widget" id="<?php echo esc_attr($this->get_field_id('location_icon')); ?>" name="<?php echo esc_attr($this->get_field_name('location_icon')); ?>" type="text" value="<?php echo wp_kses_post($instance['location_icon']); ?>" />
            </label>
        </p>

        <p>
            <label for="<?php echo esc_attr($this->get_field_id('location')); ?>">
                <?php esc_html_e('Location:', 'guto-toolkit'); ?>
                <input class="widget" id="<?php echo esc_attr($this->get_field_id('location')); ?>" name="<?php echo esc_attr($this->get_field_name('location')); ?>" type="text" value="<?php echo wp_kses_post($instance['location']); ?>" />
            </label>
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('phone_icon')); ?>">
                <?php esc_html_e('Phone Icon:', 'guto-toolkit'); ?>
                <input class="widget" id="<?php echo esc_attr($this->get_field_id('phone_icon')); ?>" name="<?php echo esc_attr($this->get_field_name('phone_icon')); ?>" type="text" value="<?php echo wp_kses_post($instance['phone_icon']); ?>" />
            </label>
        </p>
        <p>
            <label for="<?php echo esc_attr($this->get_field_id('phone')); ?>">
                <?php esc_html_e('Phone Number:', 'guto-toolkit'); ?>
                <input class="widget" id="<?php echo esc_attr($this->get_field_id('phone')); ?>" name="<?php echo esc_attr($this->get_field_name('phone')); ?>" type="text" value="<?php echo wp_kses_post($instance['phone']); ?>" />
            </label>
        </p>

        <p>
            <label for="<?php echo esc_attr($this->get_field_id('phone_link')); ?>">
                <?php esc_html_e('Number Link:', 'guto-toolkit'); ?>
                <input class="widget" id="<?php echo esc_attr($this->get_field_id('phone_link')); ?>" name="<?php echo esc_attr($this->get_field_name('phone_link')); ?>" type="text" value="<?php echo wp_kses_post($instance['phone_link']); ?>" />
            </label>
        </p>

        <p>
            <label for="<?php echo esc_attr($this->get_field_id('email_icon')); ?>">
                <?php esc_html_e('Email Icon:', 'guto-toolkit'); ?>
                <input class="widget" id="<?php echo esc_attr($this->get_field_id('email_icon')); ?>" name="<?php echo esc_attr($this->get_field_name('email_icon')); ?>" type="text" value="<?php echo wp_kses_post($instance['email_icon']); ?>" />
            </label>
        </p>

        <p>
            <label for="<?php echo esc_attr($this->get_field_id('email')); ?>">
                <?php esc_html_e('Email:', 'guto-toolkit'); ?>
                <input class="widget" id="<?php echo esc_attr($this->get_field_id('email')); ?>" name="<?php echo esc_attr($this->get_field_name('email')); ?>" type="text" value="<?php echo wp_kses_post($instance['email']); ?>" />
            </label>
        </p>

        <p>
            <label for="<?php echo esc_attr($this->get_field_id('email_link')); ?>">
                <?php esc_html_e('Email Link:', 'guto-toolkit'); ?>
                <input class="widget" id="<?php echo esc_attr($this->get_field_id('email_link')); ?>" name="<?php echo esc_attr($this->get_field_name('email_link')); ?>" type="text" value="<?php echo wp_kses_post($instance['email_link']); ?>" />
            </label>
        </p>
        <?php
    }

}

function guto_register_rb_contact_info() {
    register_widget('Guto_rb_contact_info');
}

add_action('widgets_init', 'guto_register_rb_contact_info');