<?php
/**
 * Guto Author Info Widget
 */
class Guto_widget_author_info extends WP_Widget{

    function __construct(){
        $widget_ops = array('description' => esc_html__('Display Author Information', 'guto-toolkit'));
        parent::__construct( false, esc_html__('Guto Author Info Card', 'guto-toolkit'), $widget_ops);
    }

    function widget($args, $instance){
        extract($args);
        global $guto_theme;

        echo wp_kses_post($before_widget);
            ?>

            <div class="widget widget_information information-two" style="background-image:url(<?php echo esc_url( $instance['bg_image'] ); ?>);">
                <?php if($instance['au_image'] != ''): ?>
                    <img src="<?php echo esc_url( $instance['au_image'] ); ?>" alt="<?php echo esc_attr( $instance['au_name'] ); ?>">
                <?php endif; ?>

                <div class="information-content">
                    <?php if($instance['au_name'] != ''): ?>
                        <h3><?php echo esc_html( $instance['au_name'] ); ?></h3>
                    <?php endif; ?>

                    <?php if($instance['au_desc'] != ''): ?>
                        <p><?php echo esc_html( $instance['au_desc'] ); ?></p>
                    <?php endif; ?>

                    <ul class="social">
                        <?php if( $instance['facebook_link'] != '' ): ?>
                            <li>
                                <a href="<?php echo esc_url( $instance['facebook_link'] ); ?>" target="_blank"><i class="bx bxl-facebook"></i></a>
                            </li>
                        <?php endif; ?>

                        <?php if( $instance['twitter_link'] != '' ): ?>
                            <li>
                                <a href="<?php echo esc_url( $instance['twitter_link'] ); ?>"><i class="bx bxl-twitter"></i></a>
                            </li>
                        <?php endif; ?>

                        <?php if( $instance['linkedin_link'] != '' ): ?>
                            <li>
                                <a href="<?php echo esc_url( $instance['linkedin_link'] ); ?>"><i class="bx bxl-linkedin"></i></a>
                            </li>
                        <?php endif; ?>

                        <?php if( $instance['instagram_link'] != '' ): ?>
                            <li>
                                <a href="<?php echo esc_url( $instance['instagram_link'] ); ?>"><i class="bx bxl-instagram"></i></a>
                            </li>
                        <?php endif; ?>
                    </ul>
                </div>
            </div>
        <?php
        echo wp_kses_post($after_widget);
    }

    function update($new_instance, $old_instance){
        $instance                           = $old_instance;
        $instance['au_image']               = $new_instance['au_image'];
        $instance['bg_image']               = $new_instance['bg_image'];
        $instance['au_name']                = $new_instance['au_name'];
        $instance['au_desc']                = $new_instance['au_desc'];

        $instance['facebook_link']      = $new_instance['facebook_link'];
        $instance['twitter_link']       = $new_instance['twitter_link'];
        $instance['linkedin_link']      = $new_instance['linkedin_link'];
        $instance['instagram_link']     = $new_instance['instagram_link'];
        return $instance;
    }

    function form($instance){
        $defaults = array(
            'au_image'          => '#',
            'bg_image'          => '#',
            'au_name'           => esc_html__('Hi, Im Alexa', 'guto-toolkit'),
            'au_desc'           => esc_html__('Lorem ipsum dolor sit amet consetetur sadipscing elitr sed diam nonumy eirmod tempor invidunt ut labore', 'guto-toolkit'),

            'facebook_link'     => '#',
            'twitter_link'      => '#',
            'linkedin_link'     => '#',
            'instagram_link'    => '#',
           
        );
        $instance = wp_parse_args((array)$instance, $defaults);
        ?>
        <p>
            <label for="<?php echo wp_kses_post($this->get_field_id('au_image')); ?>">
                <?php esc_html_e('Image URL:', 'guto-toolkit'); ?>
                <input class="widget" id="<?php echo esc_attr($this->get_field_id('au_image')); ?>" name="<?php echo esc_attr($this->get_field_name('au_image')); ?>" type="text" value="<?php echo wp_kses_post($instance['au_image']); ?>" />
            </label>
        </p>
        <p>
            <label for="<?php echo wp_kses_post($this->get_field_id('bg_image')); ?>">
                <?php esc_html_e('Background Image URL:', 'guto-toolkit'); ?>
                <input class="widget" id="<?php echo esc_attr($this->get_field_id('bg_image')); ?>" name="<?php echo esc_attr($this->get_field_name('bg_image')); ?>" type="text" value="<?php echo wp_kses_post($instance['bg_image']); ?>" />
            </label>
        </p>
        <p>
            <label for="<?php echo wp_kses_post($this->get_field_id('au_name')); ?>">
                <?php esc_html_e('Name:', 'guto-toolkit'); ?>
                <input class="widget" id="<?php echo esc_attr($this->get_field_id('au_name')); ?>" name="<?php echo esc_attr($this->get_field_name('au_name')); ?>" type="text" value="<?php echo wp_kses_post($instance['au_name']); ?>" />
            </label>
        </p>
        <p>
            <label for="<?php echo wp_kses_post($this->get_field_id('au_desc')); ?>">
                <?php esc_html_e('Description:', 'guto-toolkit'); ?>
                <input class="widget" id="<?php echo esc_attr($this->get_field_id('au_desc')); ?>" name="<?php echo esc_attr($this->get_field_name('au_desc')); ?>" type="text" value="<?php echo wp_kses_post($instance['au_desc']); ?>" />
            </label>
        </p>

        <p>
            <label for="<?php echo wp_kses_post($this->get_field_id('facebook_link')); ?>">
                <?php esc_html_e('Facebook Link:', 'guto-toolkit'); ?>
                <input class="widget" id="<?php echo esc_attr($this->get_field_id('facebook_link')); ?>" name="<?php echo esc_attr($this->get_field_name('facebook_link')); ?>" type="text" value="<?php echo wp_kses_post($instance['facebook_link']); ?>" />
            </label>
        </p>

        <p>
            <label for="<?php echo wp_kses_post($this->get_field_id('twitter_link')); ?>">
                <?php esc_html_e('Twitter Link:', 'guto-toolkit'); ?>
                <input class="widget" id="<?php echo esc_attr($this->get_field_id('twitter_link')); ?>" name="<?php echo esc_attr($this->get_field_name('twitter_link')); ?>" type="text" value="<?php echo wp_kses_post($instance['twitter_link']); ?>" />
            </label>
        </p>

        <p>
            <label for="<?php echo wp_kses_post($this->get_field_id('linkedin_link')); ?>">
                <?php esc_html_e('Linkedin Link:', 'guto-toolkit'); ?>
                <input class="widget" id="<?php echo esc_attr($this->get_field_id('linkedin_link')); ?>" name="<?php echo esc_attr($this->get_field_name('linkedin_link')); ?>" type="text" value="<?php echo wp_kses_post($instance['linkedin_link']); ?>" />
            </label>
        </p>

        <p>
            <label for="<?php echo wp_kses_post($this->get_field_id('instagram_link')); ?>">
                <?php esc_html_e('Instagram Link:', 'guto-toolkit'); ?>
                <input class="widget" id="<?php echo esc_attr($this->get_field_id('instagram_link')); ?>" name="<?php echo esc_attr($this->get_field_name('instagram_link')); ?>" type="text" value="<?php echo wp_kses_post($instance['instagram_link']); ?>" />
            </label>
        </p>

        <?php
    }

}

function guto_register_widget_author_info() {
    register_widget('Guto_widget_author_info');
}

add_action('widgets_init', 'guto_register_widget_author_info');