<?php
/**
 * Shop Cat Widget
 */

class Guto_shop_cat_wid extends WP_Widget{

    function __construct(){
        $widget_ops = array('description' => esc_html__('Display Shop Categories.', 'guto-toolkit'));
        parent::__construct( false, esc_html__('Guto Shop Categories With Image', 'guto-toolkit'), $widget_ops);
    }

    function widget($args, $instance){
        global $guto_theme;

        $title = apply_filters('widget_title', $instance['title']);

		$number = $instance['number'];

		$pro_categories = get_terms( ['taxonomy' => 'product_cat'] ); 
		
		?>

			<div class="widget widget_categories">

				<?php if( isset( $title ) && ! $title == '' ) : ?>
	    	        <h3 class="widget-title"><?php echo esc_html__( $title ); ?></h3>
	    	    <?php endif; ?>

				<ul>
					<?php $count = 1; foreach($pro_categories as $key => $category) { 
						
						$thumbnail_id = get_term_meta( $category->term_id, 'thumbnail_id', true );
						$image = wp_get_attachment_url( $thumbnail_id );
					?>
						<li>
							<?php if( $image ) : ?>
							<img src="<?php echo esc_url( $image ); ?>" alt="<?php the_title_attribute(); ?>">
							<?php endif; ?>

							<a href="<?php echo esc_url( get_term_link($category) ); ?>"><?php echo esc_html($category->name); ?></a>
							<span><?php echo esc_html__('(','guto-toolkit'); ?><?php echo esc_html($category->count) ?><?php echo esc_html__(')','guto-toolkit'); ?></span>
						</li>
					<?php  
						if($count == $number): 
							break; 
						endif;
					$count++; } ?>
				</ul>
			</div>

        <?php 
    }

    function form($instance){
        if( isset( $instance['title'] ) ) :
			$title = $instance['title'];
		endif;
        if( isset( $instance['number'] ) ) :
			$number = $instance['number'];
		endif;
        ?>
        <p>
            <label for="<?php echo wp_kses_post($this->get_field_id('title')); ?>">
                <?php esc_html_e('Title:', 'guto-toolkit'); ?>
                <input class="widget" id="<?php echo esc_attr($this->get_field_id('title')); ?>" name="<?php echo esc_attr($this->get_field_name('title')); ?>" type="text" value="<?php echo wp_kses_post($instance['title']); ?>" />
            </label>
        </p>
        <p>
            <label for="<?php echo wp_kses_post($this->get_field_id('number')); ?>"><?php esc_html_e( 'Number of cat to show:', 'guto-toolkit'); ?></label>
            <input id="<?php echo esc_attr($this->get_field_id('number')); ?>" name="<?php echo esc_attr($this->get_field_name('number')); ?>" type="text" value="<?php echo wp_kses_post($number); ?>" size="3" />
        </p>
        <?php
    }
}

function guto_register_shop_cat_wid() {
    register_widget('Guto_shop_cat_wid');
}

add_action('widgets_init', 'guto_register_shop_cat_wid');